@@ -21,11 +21,10 @@
 #define _STATE_H_
 
 #include <QString>
+#include <QSvgRenderer>
 
 #include "braindumpcore_export.h"
 
-class QSvgRenderer;
-
 class StateCategory;
 
 class BRAINDUMPCORE_EXPORT State
