@@ -19,9 +19,9 @@
 
 #include "SectionsBoxDock.h"
 
-#include <KoIcon.h>
+#include <QMenu>
 
-#include <kmenu.h>
+#include <KoIcon.h>
 
 #include "DocumentModel.h"
 #include "Section.h"
@@ -46,7 +46,7 @@ SectionsBoxDock::SectionsBoxDock() : m_view(0), m_model(0), m_proxy(new TreeSort
     m_wdgSectionsBox.listSections->setModel(m_proxy);
 
     // Setup the view mode button
-    KMenu* m_viewModeMenu = new KMenu(this);
+    QMenu* m_viewModeMenu = new QMenu(this);
     QActionGroup *group = new QActionGroup(this);
     QList<QAction*> actions;
 
@@ -74,7 +74,7 @@ SectionsBoxDock::SectionsBoxDock() : m_view(0), m_model(0), m_proxy(new TreeSort
     // Setup the add button
     m_wdgSectionsBox.bnAdd->setIcon(koIcon("list-add"));
 
-    KMenu* newSectionMenu = new KMenu(this);
+    QMenu* newSectionMenu = new QMenu(this);
     m_wdgSectionsBox.bnAdd->setMenu(newSectionMenu);
     m_wdgSectionsBox.bnAdd->setPopupMode(QToolButton::MenuButtonPopup);
     connect(m_wdgSectionsBox.bnAdd, SIGNAL(clicked()), SLOT(slotNewSectionBellowCurrent()));
@@ -228,5 +228,3 @@ void SectionsBoxDock::insertedSection(const QModelIndex& parent, int idx)
     m_wdgSectionsBox.listSections->setCurrentIndex(index);
     slotSectionActivated(index);
 }
-
-#include "SectionsBoxDock.moc"
