@@ -22,18 +22,10 @@
 #include <QDomDocument>
 #include <QFileInfo>
 #include <QTimer>
+#include <QDebug>
 
-#include <kdebug.h>
-#include <kglobal.h>
-#include <kstandarddirs.h>
-
-#include "RootSection.h"
-#include "SectionGroup.h"
-#include "Section.h"
 #include <KoStore.h>
 #include <KoOdf.h>
-#include <kio/netaccess.h>
-#include <kio/copyjob.h>
 #include <KoOdfWriteStore.h>
 #include <KoEmbeddedDocumentSaver.h>
 #include <KoGenStyles.h>
@@ -43,6 +35,10 @@
 #include <KoXmlNS.h>
 #include <KoShapeLoadingContext.h>
 #include <KoOdfLoadingContext.h>
+
+#include "RootSection.h"
+#include "SectionGroup.h"
+#include "Section.h"
 #include "SectionContainer.h"
 #include "Layout.h"
 #include "LayoutFactoryRegistry.h"
@@ -52,8 +48,8 @@ SectionsIO::SectionsIO(RootSection* rootSection) : m_rootSection(rootSection), m
 {
     m_timer->start(60 * 1000); // Every minute
     connect(m_timer, SIGNAL(timeout()), SLOT(save()));
-    m_directory = KGlobal::dirs()->localkdedir() + "share/apps/braindump/sections/";
-    KStandardDirs::makeDir(m_directory);
+    m_directory = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/sections/";
+    QDir().mkdir(m_directory);
 
     // Finally load
     load();
@@ -98,7 +94,7 @@ bool SectionsIO::SaveContext::saveSection(SectionsIO* sectionsIO)
     QString fullFileName = sectionsIO->m_directory + filename;
     QString fullFileNameTmpNew = fullFileName + ".tmp_new/";
     QString fullFileNameTmpOld = fullFileName + ".tmp_old";
-    KIO::NetAccess::del(fullFileNameTmpNew, 0);
+    QDir(fullFileNameTmpNew).removeRecursively();
 
     const char* mimeType = KoOdf::mimeType(KoOdf::Text);
 
@@ -147,14 +143,14 @@ bool SectionsIO::SaveContext::saveSection(SectionsIO* sectionsIO)
     }
 
     if(!context->saveDataCenter(store, manifestWriter)) {
-        kDebug() << "save data centers failed";
+        qDebug() << "save data centers failed";
         return false;
     }
 
     // Save embedded objects
     KoDocumentBase::SavingContext documentContext(odfStore, embeddedSaver);
     if(!embeddedSaver.saveEmbeddedDocuments(documentContext)) {
-        kDebug() << "save embedded documents failed";
+        qDebug() << "save embedded documents failed";
         return false;
     }
 
@@ -167,12 +163,11 @@ bool SectionsIO::SaveContext::saveSection(SectionsIO* sectionsIO)
     finaly.store = 0;
     delete context;
 
-    KIO::NetAccess::del(fullFileNameTmpOld, 0);
-    KIO::CopyJob *mv = KIO::move(fullFileName, fullFileNameTmpOld);
-    KIO::NetAccess::synchronousRun(mv, 0);
-    mv = KIO::move(fullFileNameTmpNew, fullFileName);
-    KIO::NetAccess::synchronousRun(mv, 0);
-    KIO::NetAccess::del(fullFileNameTmpOld, 0);
+    QDir(fullFileNameTmpOld).removeRecursively();
+    QDir().rename(fullFileName, fullFileNameTmpOld);
+    QDir().rename(fullFileNameTmpNew, fullFileName);
+    QDir(fullFileNameTmpOld).removeRecursively();
+
     return true;
 }
 
@@ -185,16 +180,14 @@ bool SectionsIO::SaveContext::loadSection(SectionsIO* sectionsIO, SectionsIO::Sa
     QString fullFileNameTmpOld = fullFileName + ".tmp_old";
     if(!QFileInfo(fullFileName).exists()) {
         if(QFileInfo(fullFileNameTmpNew).exists()) {
-            KIO::CopyJob *mv = KIO::move(fullFileNameTmpNew, fullFileName);
-            KIO::NetAccess::synchronousRun(mv, 0);
+            QDir().rename(fullFileNameTmpNew, fullFileName);
         } else if(QFileInfo(fullFileNameTmpOld).exists()) {
-            KIO::CopyJob *mv = KIO::move(fullFileNameTmpOld, fullFileName);
-            KIO::NetAccess::synchronousRun(mv, 0);
+            QDir().rename(fullFileNameTmpOld, fullFileName);
         } else {
             return false;
         }
     }
-    kDebug() << "Loading from " << fullFileName;
+    qDebug() << "Loading from " << fullFileName;
 
     const char* mimeType = KoOdf::mimeType(KoOdf::Text);
     KoStore* store = KoStore::createStore(fullFileName + '/', KoStore::Read, mimeType, KoStore::Directory);
@@ -202,7 +195,7 @@ bool SectionsIO::SaveContext::loadSection(SectionsIO* sectionsIO, SectionsIO::Sa
 
     QString errorMessage;
     if(! odfStore.loadAndParse(errorMessage)) {
-        kError() << "loading and parsing failed:" << errorMessage << endl;
+        qCritical() << "loading and parsing failed:" << errorMessage << endl;
         return false;
     }
 
@@ -217,7 +210,7 @@ bool SectionsIO::SaveContext::loadSection(SectionsIO* sectionsIO, SectionsIO::Sa
     KoXmlElement element;
     QList<KoShape*> shapes;
     forEachElement(element, body) {
-        kDebug() << "loading shape" << element.nodeName();
+        qDebug() << "loading shape" << element.nodeName();
 
         if(element.nodeName() == "braindump:section") {
             section->sectionContainer()->loadOdf(element, context, shapes);
@@ -256,9 +249,9 @@ void SectionsIO::saveTheStructure(QDomDocument& doc, QDomElement& elt, SectionGr
 
 void SectionsIO::save()
 {
-    kDebug() << "Start saving";
+    qDebug() << "Start saving";
     if(m_sectionsToSave.isEmpty()) {
-        kDebug() << "No section to save";
+        qDebug() << "No section to save";
         return;
     }
     QList<SaveContext*> contextToRemove = m_contextes.values();
@@ -276,9 +269,9 @@ void SectionsIO::save()
     foreach(SaveContext * saveContext, m_contextes) {
         if(m_sectionsToSave.contains(saveContext->section)) {
             if(saveContext->saveSection(this)) {
-                kDebug() << "Successfully loaded: " << saveContext->section->name();
+                qDebug() << "Successfully loaded: " << saveContext->section->name();
             } else {
-                kDebug() << "Saving failed"; // TODO: Report it
+                qDebug() << "Saving failed"; // TODO: Report it
             }
         }
     }
@@ -286,7 +279,7 @@ void SectionsIO::save()
 
     // Last remove unused sections
     foreach(SaveContext * saveContext, contextToRemove) {
-        KIO::NetAccess::del(KUrl(m_directory + saveContext->filename), 0);
+        QDir(m_directory + saveContext->filename).removeRecursively();
         m_contextes.remove(saveContext->section);
         delete saveContext;
     }
@@ -335,7 +328,7 @@ void SectionsIO::load()
     // Second: load each section
     foreach(SaveContext * saveContext, m_contextes) {
         if(!saveContext->loadSection(this, SaveContext::VERSION_1)) {
-            kDebug() << "Loading failed"; // TODO: Report it
+            qDebug() << "Loading failed"; // TODO: Report it
         }
     }
 }
@@ -363,5 +356,3 @@ QString SectionsIO::structureFileName()
 {
     return m_directory + "structure.xml";
 }
-
-#include "SectionsIO.moc"
