@@ -21,6 +21,8 @@
 #define VIEW_H
 
 #include <QWidget>
+#include <QAction>
+
 #include <kxmlguiclient.h>
 
 #include <KoZoomHandler.h>
@@ -28,7 +30,6 @@
 class KoCanvasControllerWidget;
 class Canvas;
 class MainWindow;
-class KAction;
 class KoZoomAction;
 class KoZoomController;
 class RootSection;
@@ -121,13 +122,13 @@ private:
 
     KoCutController* m_cutController;
     KoCopyController* m_copyController;
-    KAction* m_editCopy;
-    KAction* m_editCut;
+    QAction* m_editCopy;
+    QAction* m_editCut;
 
-    KAction *m_editPaste;
-    KAction *m_deleteSelectionAction;
-    KAction* m_groupShapes;
-    KAction* m_ungroupShapes;
+    QAction *m_editPaste;
+    QAction *m_deleteSelectionAction;
+    QAction* m_groupShapes;
+    QAction* m_ungroupShapes;
     KoZoomAction *m_zoomAction;
 };
 
