@@ -33,7 +33,7 @@ class CalligraComponentsPlugin : public QQmlExtensionPlugin
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
 
 public:
-    virtual void registerTypes(const char* uri);
+    void registerTypes(const char* uri) override;
 };
 
 #endif // CALLIGRACOMPONENTSPLUGIN_H
