@@ -43,7 +43,7 @@ using namespace Calligra::Components;
 class Document::Private
 {
 public:
-    Private(Document* qq) : q{qq}, impl{nullptr}, status{DocumentStatus::Unloaded}, textEditor{nullptr}
+    Private(Document* qq) : q{qq}, impl{nullptr}, status{DocumentStatus::Unloaded}, readOnly{false}
     { }
 
     void updateImpl();
@@ -53,7 +53,7 @@ public:
     QUrl source;
     DocumentImpl* impl;
     DocumentStatus::Status status;
-    KoTextEditor* textEditor;
+    bool readOnly;
 };
 
 Document::Document(QObject* parent)
@@ -85,6 +85,7 @@ void Document::setSource(const QUrl& value)
         emit documentTypeChanged();
 
         if(d->impl) {
+            d->impl->setReadOnly(d->readOnly);
             if(d->impl->load(d->source)) {
                 d->status = DocumentStatus::Loaded;
                 connect(d->impl->canvasController()->canvas()->shapeManager(), SIGNAL(selectionChanged()), SIGNAL(textEditorChanged()));
@@ -100,6 +101,20 @@ void Document::setSource(const QUrl& value)
     }
 }
 
+bool Document::readOnly() const
+{
+    return d->readOnly;
+}
+
+void Document::setReadOnly(bool readOnly)
+{
+    if (d->readOnly != readOnly) {
+        d->readOnly = readOnly;
+
+        emit readOnlyChanged();
+    }
+}
+
 DocumentType::Type Document::documentType() const
 {
     if(d->impl) {
@@ -213,15 +228,7 @@ QUrl Document::urlAtPoint(const QPoint& point)
 QObject * Document::textEditor()
 {
     if (d->impl && d->impl->canvasController()) {
-        if (d->textEditor) {
-            disconnect(d->textEditor, SIGNAL(cursorPositionChanged()), this, SIGNAL(selectionChanged()));
-        }
-        d->textEditor = KoTextEditor::getTextEditorFromCanvas(d->impl->canvasController()->canvas());
-        if (d->textEditor) {
-            disconnect(d->textEditor, SIGNAL(cursorPositionChanged()), this, SIGNAL(selectionChanged()));
-        }
-//         emit selectionChanged();
-        return d->textEditor;
+        return KoTextEditor::getTextEditorFromCanvas(d->impl->canvasController()->canvas());
     }
     return 0;
 }
@@ -238,28 +245,22 @@ void Document::deselectEverything()
 
 void Document::Private::updateImpl()
 {
-    if(impl) {
-        delete impl;
-    }
+    delete impl;
+    impl = nullptr;
 
-    if(!source.isEmpty()) {
-        auto type = Global::documentType(source);
-        switch(type) {
-            case DocumentType::TextDocument:
-                impl = new TextDocumentImpl{q};
-                break;
-            case DocumentType::Spreadsheet:
-                impl = new SpreadsheetImpl{q};
-                break;
-            case DocumentType::Presentation:
-                impl = new PresentationImpl{q};
-                break;
-            default:
-                impl = nullptr;
-                break;
-        }
-    } else {
-        impl = nullptr;
+    auto type = Global::documentType(source);
+    switch(type) {
+    case DocumentType::TextDocument:
+        impl = new TextDocumentImpl{q};
+        break;
+    case DocumentType::Spreadsheet:
+        impl = new SpreadsheetImpl{q};
+        break;
+    case DocumentType::Presentation:
+        impl = new PresentationImpl{q};
+        break;
+    default:
+        break;
     }
 
     if(impl) {
