@@ -25,6 +25,7 @@
 #include <QDebug>
 
 #include <QUrl>
+#include <QUrlQuery>
 #include <QMimeDatabase>
 #include <QPluginLoader>
 
@@ -44,18 +45,19 @@ Calligra::Components::Global::Global(QObject* parent)
 {
 }
 
-void Global::loadPlugins()
-{
-
-}
-
 int Global::documentType(const QUrl& document)
 {
     int result = DocumentType::Unknown;
 
+    if (!document.isValid()) {
+        return result;
+    }
+
+    const QUrlQuery query(document);
+
     // First, check if the URL gives us specific information on this topic (such as asking for a new file)
-    if(document.hasQueryItem("mimetype")) {
-        QString mime = document.queryItemValue("mimetype");
+    if(query.hasQueryItem("mimetype")) {
+        QString mime = query.queryItemValue("mimetype");
         if(mime == WORDS_MIME_TYPE) {
             result = DocumentType::TextDocument;
         }
