@@ -77,7 +77,8 @@ public:
         foreach(const KoShape* shape, koPaView->activePage()->shapes()) {
             if(!shape->hyperLink().isEmpty()) {
                 QRectF rect = shape->boundingRect();
-                while(KoShapeContainer* parent = shape->parent()) {
+                for (KoShapeContainer* parent = shape->parent();
+                     parent; parent = parent->parent()) {
                     rect.translate(parent->position());
                 }
                 links.append(QPair<QRectF, QUrl>(rect, QUrl(shape->hyperLink())));
@@ -106,7 +107,8 @@ public:
                                 if(shapeData->document() == text)
                                 {
                                     rect.translate(shape->position());
-                                    while(KoShapeContainer* parent = shape->parent()) {
+                                    for (KoShapeContainer* parent = shape->parent();
+                                         parent; parent = parent->parent()) {
                                         rect.translate(parent->position());
                                     }
                                     break;
@@ -159,10 +161,8 @@ PresentationImpl::~PresentationImpl()
 
 bool PresentationImpl::load(const QUrl& url)
 {
-    if(d->part) {
-        delete d->part;
-        delete d->document;
-    }
+    delete d->part;
+    delete d->document;
 
     d->part = new KPrPart{this};
     d->document = new KPrDocument{d->part};
