@@ -29,10 +29,12 @@
 #include <KWPart.h>
 #include <KWDocument.h>
 #include <KWCanvasItem.h>
+#include <KoColumns.h>
 #include <KoFindText.h>
 #include <KoShape.h>
 #include <KoShapeContainer.h>
 #include <KoToolManager.h>
+#include <KoUnit.h>
 #include <KoZoomController.h>
 #include <KoZoomHandler.h>
 
@@ -41,6 +43,7 @@
 #include <QTextLayout>
 #include <QDebug>
 #include <QPointer>
+#include <QUrlQuery>
 
 #include "ComponentsKoCanvasController.h"
 #include <libs/textlayout/KoTextShapeData.h>
@@ -77,13 +80,14 @@ public:
     {
         links.clear();
 
-        if(!canvas)
+        if(!canvas || !canvas->shapeManager())
             return;
 
         foreach(const KoShape* shape, canvas->shapeManager()->shapes()) {
             if(!shape->hyperLink().isEmpty()) {
                 QRectF rect = shape->boundingRect();
-                while(KoShapeContainer* parent = shape->parent()) {
+                for (KoShapeContainer* parent = shape->parent();
+                     parent; parent = parent->parent()) {
                     rect.translate(parent->position());
                 }
                 links.append(QPair<QRectF, QUrl>(rect, QUrl(shape->hyperLink())));
@@ -112,7 +116,8 @@ public:
                                 if(shapeData->document() == text)
                                 {
                                     rect.translate(shape->position());
-                                    while(KoShapeContainer* parent = shape->parent()) {
+                                    for (KoShapeContainer* parent = shape->parent();
+                                         parent; parent = parent->parent()) {
                                         rect.translate(parent->position());
                                     }
                                     break;
@@ -172,10 +177,8 @@ TextDocumentImpl::~TextDocumentImpl()
 
 bool TextDocumentImpl::load(const QUrl& url)
 {
-    if(d->part) {
-        delete d->part;
-        delete d->document;
-    }
+    delete d->part;
+    delete d->document;
 
     d->part = new KWPart{this};
     d->document = new KWDocument{d->part};
@@ -185,7 +188,64 @@ bool TextDocumentImpl::load(const QUrl& url)
     d->document->setAutoSave(0);
     d->document->setCheckAutoSaveFile(false);
 
-    bool retval = d->document->openUrl(url);
+    bool retval = false;
+    if (url.scheme() == QStringLiteral("newfile")) {
+        QUrlQuery query(url);
+
+        d->document->initEmpty();
+        KWPageStyle style = d->document->pageManager()->defaultPageStyle();
+        Q_ASSERT(style.isValid());
+
+        KoColumns columns;
+        columns.count = query.queryItemValue("columncount").toInt();
+        columns.gapWidth = query.queryItemValue("columngap").toDouble();
+        style.setColumns(columns);
+
+        KoPageLayout layout = style.pageLayout();
+        layout.format = KoPageFormat::formatFromString(query.queryItemValue("pageformat"));
+        layout.orientation = (KoPageFormat::Orientation)query.queryItemValue("pageorientation").toInt();
+        layout.height = MM_TO_POINT(query.queryItemValue("height").toDouble());
+        layout.width = MM_TO_POINT(query.queryItemValue("width").toDouble());
+        if (query.queryItemValue("facingpages").toInt() == 1) {
+            layout.bindingSide = MM_TO_POINT(query.queryItemValue("leftmargin").toDouble());
+            layout.pageEdge = MM_TO_POINT(query.queryItemValue("rightmargin").toDouble());
+            layout.leftMargin = layout.rightMargin = -1;
+        }
+        else {
+            layout.bindingSide = layout.pageEdge = -1;
+            layout.leftMargin = MM_TO_POINT(query.queryItemValue("leftmargin").toDouble());
+            layout.rightMargin = MM_TO_POINT(query.queryItemValue("rightmargin").toDouble());
+        }
+        layout.topMargin = MM_TO_POINT(query.queryItemValue("topmargin").toDouble());
+        layout.bottomMargin = MM_TO_POINT(query.queryItemValue("bottommargin").toDouble());
+        style.setPageLayout(layout);
+
+        d->document->setUnit(KoUnit::fromSymbol(query.queryItemValue("unit")));
+        d->document->relayout();
+        retval = true;
+    }
+    else if (url.scheme() == QStringLiteral("template")) {
+        // Nip away the manually added template:// bit of the uri passed from the caller
+        bool ok = d->document->loadNativeFormat(url.toString().mid(11));
+        d->document->setModified(false);
+        d->document->undoStack()->clear();
+
+        if (ok) {
+            QString mimeType = QMimeDatabase().mimeTypeForUrl(url).name();
+            // in case this is a open document template remove the -template from the end
+            mimeType.remove( QRegExp( "-template$" ) );
+            d->document->setMimeTypeAfterLoading(mimeType);
+            d->document->resetURL();
+            d->document->setEmpty();
+        } else {
+            d->document->showLoadingErrorDialog();
+            d->document->initEmpty();
+        }
+        retval = true;
+    }
+    else {
+        retval = d->document->openUrl(url);
+    }
     qDebug() << "Attempting to open" << url << "and our success was" << retval;
 
     d->canvas = static_cast<KWCanvasItem*>(d->part->canvasItem(d->document));
@@ -207,6 +267,9 @@ bool TextDocumentImpl::load(const QUrl& url)
 
 int TextDocumentImpl::currentIndex()
 {
+    if(!d->canvas || !d->canvas->viewConverter()) {
+        return 0;
+    }
     QPointF newPoint = d->canvas->viewConverter()->viewToDocument(canvasController()->documentOffset());
     KWPage page = d->document->pageManager()->page(newPoint.y());
     return page.pageNumber();
