@@ -16,6 +16,8 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
+#include <algorithm>
+
 #include <QFile>
 #include <QDebug>
 #include <QDomDocument>
@@ -26,8 +28,6 @@
 #include <QSet>
 #include <QVector>
 
-#define assert(cond, what) Q_ASSERT_X(cond, "", qPrintable(what))
-
 static QString ns() {
     return QStringLiteral("writeodf");
 }
@@ -308,7 +308,7 @@ void merge(RNGItemPtr& a, const RNGItemPtr& b)
     if (b->mixedContent) {
         a->mixedContent = true;
     }
-    assert(a->allowedItems.contains(b), "");
+    Q_ASSERT(a->allowedItems.contains(b));
     if (a->requiredItems.contains(b)) {
         foreach(RNGItemPtr i, b->requiredItems) {
             a->requiredItems.insert(i);
@@ -572,7 +572,7 @@ RNGItemPtr getDefines(QDomElement e, RNGItems& items)
         if (e.localName() == "define") {
             parseDefine(e, items, false);
         } else if (e.localName() == "start") {
-            assert(!start, "Multiple start elements.");
+            Q_ASSERT_X(!start, "getDefines", "Multiple start elements.");
             start = parseDefine(e, items, true);
         } else {
             fatal() << "Unknown element " << e.localName();
@@ -718,7 +718,7 @@ int reduce(RNGItems& items)
             RNGItemPtr user = RNGItemPtr(0);
             foreach (const RNGItemPtr& i, items) {
                 if (i->allowedItems.contains(item)) {
-                    assert(!user, "");
+                    Q_ASSERT(!user);
                     user = i;
                 }
             }
@@ -765,11 +765,11 @@ RNGItemPtr getDefine(const QString& name, const RNGItems& items)
     RNGItemPtr item = RNGItemPtr(0);
     foreach (RNGItemPtr i, items) {
         if (i->name() == name) {
-            assert(!item, "Doubly defined element " + name + ".");
+            Q_ASSERT_X(!item, "getDefine", qPrintable("Doubly defined element" + name + "."));
             item = i;
         }
     }
-    assert(item, "Define not found " + name);
+    Q_ASSERT_X(item, "getDefine", qPrintable("Define not found " + name));
     return item;
 }
 
@@ -910,7 +910,7 @@ RNGItemList getBasesList(RNGItemPtr item)
     }
     list.subtract(antilist);
     RNGItemList l = toVector(list);
-    qStableSort(l.begin(), l.end(), rngItemPtrLessThan);
+    std::stable_sort(l.begin(), l.end(), rngItemPtrLessThan);
     return l;
 }
 
@@ -921,7 +921,7 @@ RNGItemList getBasesList(RNGItemPtr item)
 RNGItemList list(const RNGItems& items)
 {
     RNGItemList list = toVector(items);
-    qStableSort(list.begin(), list.end(), rngItemPtrLessThan);
+    std::stable_sort(list.begin(), list.end(), rngItemPtrLessThan);
     return list;
 }
 
@@ -1048,7 +1048,7 @@ RequiredArgsList makeFullRequiredArgsList(const RNGItemPtr& item)
     r.length = 0;
     RNGItemList list;
     getAllRequiredAttributes(item, list);
-    qStableSort(list.begin(), list.end(), rngItemPtrLessThan);
+    std::stable_sort(list.begin(), list.end(), rngItemPtrLessThan);
     foreach (RNGItemPtr i, list) {
         QString name = makeCppName(i);
         QString type = i->singleType();
@@ -1412,7 +1412,7 @@ void convert(const QString& rngfile, const QString& outdir)
     //qDebug() << "reduce " << resolved.size();
     RNGItemList list = toVector(resolved);
     //qDebug() << "filteredItems " << list.size();
-    qStableSort(list.begin(), list.end(), rngItemPtrLessThan);
+    std::stable_sort(list.begin(), list.end(), rngItemPtrLessThan);
     makeCppNames(list);
     write(list, outdir);
     //qDebug() << list.size();
