@@ -21,7 +21,6 @@
 #define WPGIMPORT_H
 
 #include <KoFilter.h>
-#include <KoStore.h>
 #include <QVariantList>
 
 class WPGImport : public KoFilter
@@ -32,9 +31,9 @@ class WPGImport : public KoFilter
 public:
 
     WPGImport(QObject *parent, const QVariantList&);
-    virtual ~WPGImport();
+    ~WPGImport() override;
 
-    virtual KoFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to);
+    KoFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to) override;
 
 };
 
