@@ -44,12 +44,14 @@ class KOMSOOXML_EXPORT VmlDrawingReader : public MSOOXML::MsooXmlCommonReader
 {
 public:
     explicit VmlDrawingReader(KoOdfWriters *writers);
-    virtual ~VmlDrawingReader();
-    virtual KoFilter::ConversionStatus read(MSOOXML::MsooXmlReaderContext* context = 0);
+    ~VmlDrawingReader() override;
+    KoFilter::ConversionStatus read(MSOOXML::MsooXmlReaderContext* context = 0) override;
 
     QMap<QString, QString> content();
     QMap<QString, QString> frames();
 
+// Note: Do not move this, it just defines parts of this class
+// It is separated out, as it is not part of the OOXML spec
 #include <MsooXmlVmlReaderMethods.h>
 
 protected:
