@@ -25,19 +25,18 @@
 // Qt
 #include <QString>
 
-// KDE
-#include <kdebug.h>
-
 // odflib
 #include <KoXmlStreamReader.h>
 #include <KoXmlWriter.h>
 
+#include "Odf2Debug.h"
+
 
 // ----------------------------------------------------------------
 //                         private class
 
 
-class  KoOdfGraphicProperties::Private
+class Q_DECL_HIDDEN KoOdfGraphicProperties::Private
 {
 public:
     Private() {};
