@@ -26,10 +26,11 @@
 
 
 /**
- * A \class KoRawCellChild is a Cell child that can take any given QBuffer 
+ * \class KoRawCellChild
+ * \brief This class is a Cell child that can take any given QBuffer 
  * and will insert its contents blindly.
  * 
- * It's porpuse is to allow the user to insert custom elements or elements for
+ * Its purpose is to allow the user to insert custom elements or elements for
  * which the appropriate class has not been provided.
  *
  * \note The class will insert its content "blindly," so, invalid XML or ODF *can* be created.
@@ -40,10 +41,10 @@ class KOODF2_EXPORT KoRawCellChild : public KoCellChild
 {
 public:
     explicit KoRawCellChild(const QByteArray &content);
-    virtual ~KoRawCellChild();
+    ~KoRawCellChild() override;
 
 protected:
-    virtual void saveOdf(KoXmlWriter& writer, KoGenStyles& styles) const;
+    void saveOdf(KoXmlWriter& writer, KoGenStyles& styles) const override;
 
 private:
     QByteArray m_content;
