@@ -25,7 +25,8 @@
 #include <QColor>
 
 /**
- * A \class KoRowStyle represents a style of a row to be applied to one or more rows.
+ * \class KoRowStyle
+ * \brief This class represents a style of a row to be applied to one or more rows.
  * 
  * As all the styles it can be shared
  */
@@ -36,7 +37,7 @@ class KOODF2_EXPORT KoRowStyle : public KoStyle
 
 public:
     KOSTYLE_DECLARE_SHARED_POINTER(KoRowStyle)
-    ~KoRowStyle();
+    ~KoRowStyle() override;
 
     void setBackgroundColor(const QColor& color);
     QColor backgroundColor() const;
@@ -74,11 +75,11 @@ public:
 //     Image backgroundImage() const;
 
 protected:
-    virtual KoGenStyle::Type automaticstyleType() const;
-    virtual QString defaultPrefix() const;
-    virtual void prepareStyle(KoGenStyle& style) const;
-    virtual const char* styleFamilyName() const;
-    virtual KoGenStyle::Type styleType() const;
+    KoGenStyle::Type automaticstyleType() const override;
+    QString defaultPrefix() const override;
+    void prepareStyle(KoGenStyle& style) const override;
+    const char* styleFamilyName() const override;
+    KoGenStyle::Type styleType() const override;
 
 private:
     QColor m_backgroundColor;
