@@ -66,11 +66,11 @@ class KOODFREADER_EXPORT OdtReader : public OdfReader
 {
  public:
     OdtReader();
-    ~OdtReader();
+    ~OdtReader() override;
 
  protected:
     // ODT document level functions
-    DECLARE_READER_FUNCTION(OfficeText);
+    DECLARE_READER_FUNCTION(OfficeText) override;
 
  private:
     // Not much here. Most are already in OdfReader.
