@@ -26,6 +26,8 @@
 
 #include <QDebug>
 
+#include <algorithm>
+
 static const quint32 ENDOFCHAIN = 0xFFFFFFFE;
 static const quint32 FATSECT = 0xFFFFFFFD;
 static const quint32 FREESECT = 0xFFFFFFFF;
@@ -78,13 +80,13 @@ class CFBWriter::StreamIODevice : public QIODevice
 {
 public:
     StreamIODevice(CFBWriter& writer, DirectoryEntry& entry);
-    virtual ~StreamIODevice();
-    virtual void close();
-    virtual bool open(OpenMode mode);
-    virtual qint64 size() const;
+    ~StreamIODevice() override;
+    void close() override;
+    bool open(OpenMode mode) override;
+    qint64 size() const override;
 protected:
-    virtual qint64 writeData(const char *data, qint64 len);
-    virtual qint64 readData(char *data, qint64 maxlen);
+    qint64 writeData(const char *data, qint64 len) override;
+    qint64 readData(char *data, qint64 maxlen) override;
     void appendData(const char *data, qint64 len);
     qint64 internalWriteData(const char* data, qint64 len, qint64 pos);
 private:
@@ -256,7 +258,7 @@ void CFBWriter::DirectoryEntry::buildChildrenTree()
         return;
     }
     QList<QString> names = children.keys();
-    qSort(names.begin(), names.end(), compareNames);
+    std::sort(names.begin(), names.end(), compareNames);
     QList<DirectoryEntry*> entries;
     foreach (const QString& name, names) {
         entries.append(children[name]);
