@@ -18,7 +18,6 @@
 */
 
 #include <ExcelExport.h>
-#include <ExcelExport.moc>
 
 #include <QFont>
 #include <QFontMetricsF>
@@ -47,8 +46,7 @@
 
 #include <CFBWriter.h>
 
-K_PLUGIN_FACTORY(ExcelExportFactory, registerPlugin<ExcelExport>();)
-K_EXPORT_PLUGIN(ExcelExportFactory("calligrafilters"))
+K_PLUGIN_FACTORY_WITH_JSON(ExcelExportFactory, "calligra_filter_sheets2xls.json", registerPlugin<ExcelExport>();)
 
 static uint qHash(const QFont& f)
 {
@@ -188,7 +186,7 @@ KoFilter::ConversionStatus ExcelExport::convert(const QByteArray& from, const QB
     formats.insert(42, QString::fromUtf8("_-* #,##0\\ \"€\"_-;\\-* #,##0\\ \"€\"_-;_-* \"-\"\\ \"€\"_-;_-@_-"));
     formats.insert(43, QString::fromUtf8("_-* #,##0.00\\ _€_-;\\-* #,##0.00\\ _€_-;_-* \"-\"??\\ _€_-;_-@_-"));
     formats.insert(44, QString::fromUtf8("_-* #,##0.00\\ \"€\"_-;\\-* #,##0.00\\ \"€\"_-;_-* \"-\"??\\ \"€\"_-;_-@_-"));
-    for (QMap<int, QString>::iterator i = formats.begin(); i != formats.end(); ++i) {
+    for (QMap<int, QString>::ConstIterator i = formats.constBegin(); i != formats.constEnd(); ++i) {
         FormatRecord fr(0);
         fr.setIndex(i.key());
         fr.setFormatString(i.value());
@@ -1150,3 +1148,5 @@ unsigned ExcelExport::Private::fontIndex(const QFont& f, const QColor& c, QHash<
     fontRecords.append(fr);
     return idx;
 }
+
+#include <ExcelExport.moc>
