@@ -37,9 +37,9 @@ class LATEXExport : public KoFilter
 
 public:
     LATEXExport(QObject* parent, const QVariantList&);
-    virtual ~LATEXExport() {}
+    ~LATEXExport() override {}
 
-    virtual KoFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to);
+    KoFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to) override;
 };
 
 #endif /* __LATEXExport_H__ */
