@@ -22,13 +22,13 @@
 
 #include <QDir>
 #include <QApplication>
+#include <QDBusConnection>
 
-#include <kglobal.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kconfig.h>
-#include <kdebug.h>
 #include <KoFilterManager.h>
 
+#include "LatexDebug.h"
 #include "latexexportAdaptor.h"
 
 #include "document.h"
@@ -45,7 +45,7 @@
  *  true to construct a modal dialog.
  */
 LatexExportDialog::LatexExportDialog(KoStore* inputStore, QWidget* parent)
-  : KDialog(parent)
+  : KoDialog(parent)
   , m_inputStore(inputStore)
 {
     QWidget *mainWidget = new QWidget();
@@ -61,7 +61,7 @@ LatexExportDialog::LatexExportDialog(KoStore* inputStore, QWidget* parent)
     QString value;
     while (i < 10) {
         /*value = m_config->readPathEntry( QString("Recent%1").arg(i), QString() );
-        kDebug(30522) <<"recent :" << value;
+        debugLatex <<"recent :" << value;
         if(!value.isEmpty())
         {
          _recentList.append( value );
@@ -107,7 +107,7 @@ LatexExportDialog::LatexExportDialog(KoStore* inputStore, QWidget* parent)
     encodingComboBox->addItem("decmulti");
     encodingComboBox->addItem("next");
 
-    KListWidget* languagesList = m_ui.languagesList;
+    QListWidget* languagesList = m_ui.languagesList;
     languagesList->addItem("american");
     languagesList->addItem("austrian");
     languagesList->addItem("bahasa");
@@ -166,7 +166,7 @@ LatexExportDialog::~LatexExportDialog()
  */
 void LatexExportDialog::reject()
 {
-    kDebug(30522) << "Export cancelled";
+    debugLatex << "Export cancelled";
     QDialog::reject();
 }
 
@@ -177,7 +177,7 @@ void LatexExportDialog::reject()
 void LatexExportDialog::accept()
 {
     hide();
-    kDebug(30522) << "KSPREAD LATEX EXPORT FILTER --> BEGIN";
+    debugLatex << "KSPREAD LATEX EXPORT FILTER --> BEGIN";
     Config* config = Config::instance();
 
     /* Document tab */
@@ -202,27 +202,27 @@ void LatexExportDialog::accept()
 
     /* Language tab */
     config->setEncoding(m_ui.encodingComboBox->currentText());
-    KListWidget* langUsedList = m_ui.langUsedList;
+    QListWidget* langUsedList = m_ui.langUsedList;
     for (int index = 0; index < langUsedList->count(); ++index) {
-        kDebug(30522) << "lang. :" << langUsedList->item(index)->text();
+        debugLatex << "lang. :" << langUsedList->item(index)->text();
         config->addLanguage(langUsedList->item(index)->text());
     }
 
     /* The default language is the first language in the list */
-    if (langUsedList->item(0) != NULL)
+    if (langUsedList->item(0) != nullptr)
         config->setDefaultLanguage(langUsedList->item(0)->text());
-    if (langUsedList->currentItem() != NULL) {
+    if (langUsedList->currentItem() != nullptr) {
         const QString currentLanguage = langUsedList->currentItem()->text();
-        kDebug(30522) << "default lang. :" << currentLanguage;
+        debugLatex << "default lang. :" << currentLanguage;
         config->setDefaultLanguage(currentLanguage);
     }
 
     Document doc(m_inputStore, m_fileOut);
-//     kDebug(30522) << "---------- analyze file -------------";
+//     debugLatex << "---------- analyze file -------------";
     doc.analyze();
-//     kDebug(30522) << "---------- generate file -------------";
+//     debugLatex << "---------- generate file -------------";
     doc.generate();
-//     kDebug(30522) << "KSPREAD LATEX EXPORT FILTER --> END";
+//     debugLatex << "KSPREAD LATEX EXPORT FILTER --> END";
 }
 
 void LatexExportDialog::addLanguage()
@@ -232,7 +232,7 @@ void LatexExportDialog::addLanguage()
         return;
     }
     const QString text = currentItem->text();
-    kDebug(30522) << "add a new supported language" << text;
+    debugLatex << "add a new supported language" << text;
     m_ui.langUsedList->addItem(text);
     delete currentItem;
 }
@@ -244,9 +244,7 @@ void LatexExportDialog::removeLanguage()
         return;
     }
     const QString text = currentItem->text();
-    kDebug(30522) << "remove a language" << text;
+    debugLatex << "remove a language" << text;
     m_ui.languagesList->addItem(text);
     delete currentItem;
 }
-
-#include <latexexportdialog.moc>
