@@ -21,6 +21,7 @@
  *
  */
 
+#include "XlsxUtils.h"
 #include "XlsxXmlCommonReader.h"
 
 #include <math.h>
@@ -103,7 +104,7 @@ KoFilter::ConversionStatus XlsxXmlCommonReader::read_t()
     READ_PROLOGUE
     while (!atEnd()) {
         readNext();
-        kDebug() << *this;
+        qCDebug(lcXlsxImport) << *this;
         if (isCharacters()) {
             body->addTextSpan(text().toString());
         }
