@@ -132,7 +132,7 @@ public:
     //! Indicates whether if the text in the cell should be line-wrapped with the cell.
     bool wrapText;
 
-    //! Inidicates whether the displayed text in a cell should be shrunk to fit the cell width.
+    //! Indicates whether the displayed text in a cell should be shrunk to fit the cell width.
     bool shrinkToFit;
 
     //! Text rotation in cells, expressed in degrees. (Undocumented? special case: 255 means
@@ -241,11 +241,11 @@ class XlsxXmlStylesReader : public XlsxXmlCommonReader
 public:
     explicit XlsxXmlStylesReader(KoOdfWriters *writers);
 
-    virtual ~XlsxXmlStylesReader();
+    ~XlsxXmlStylesReader() override;
 
     //! Reads/parses the file of format document.xml.
     //! The output goes mainly to KoXmlWriter* KoOdfWriters::body
-    virtual KoFilter::ConversionStatus read(MSOOXML::MsooXmlReaderContext* context = 0);
+    KoFilter::ConversionStatus read(MSOOXML::MsooXmlReaderContext* context = 0) override;
 
     enum DiagonalDirection {
         DiagonalUp = 1,
