@@ -24,6 +24,7 @@
 // POSIX
 #include <cmath>
 #include <cfloat>
+#include <algorithm>
 
 //Qt includes
 #include <QByteArray>
@@ -654,7 +655,7 @@ void Filterkpr2odf::appendParagraph(KoXmlWriter* content, const KoXmlElement& ob
 
 void Filterkpr2odf::appendText(KoXmlWriter* content, const KoXmlElement& objectElement)
 {
-    //Avoid the creation of so many unneded text:span
+    //Avoid the creation of so many unneeded text:span
     static QString lastStyle;
     static QString textChain;
     bool lastSpan = objectElement.nextSibling().isNull();
@@ -689,8 +690,8 @@ void Filterkpr2odf::appendText(KoXmlWriter* content, const KoXmlElement& objectE
 
 void Filterkpr2odf::appendPie(KoXmlWriter* content, const KoXmlElement& objectElement)
 {
-    //NOTE: we cannot use set2dGeometry becuse we have to convert the
-    //given size and origen into the real ones before saving them
+    //NOTE: we cannot use set2dGeometry because we have to convert the
+    //given size and origin into the real ones before saving them
 
     KoXmlElement size = objectElement.namedItem("SIZE").toElement();
     double width = size.attribute("width").toDouble();
@@ -774,7 +775,7 @@ void Filterkpr2odf::setEndPoints(QPointF points[], const QSizeF& size, int start
         double x = 0;
         double y = 0;
 
-        // be carefull
+        // be careful
         if (angles[i] == 90) {
             y = radius2;
         } else if (angles[i] == 270) {
@@ -810,7 +811,7 @@ void Filterkpr2odf::getRealSizeAndOrig(QSizeF &size, QPointF &realOrig, int star
     // the rotation angle
     double angInRad = angle * M_PI / 180;
 
-    // 1. calulate position of end points
+    // 1. calculate position of end points
     QPointF points[2];
     setEndPoints(points, size, startAngle, endAngle);
 
@@ -833,7 +834,7 @@ void Filterkpr2odf::getRealSizeAndOrig(QSizeF &size, QPointF &realOrig, int star
     QPointF firstPoint(points[0]);
     QPointF secondPoint(points[1]);
 
-    // 2. calulate maximal points
+    // 2. calculate maximal points
     QPointF maxPoints[4];
     if (angle == 0) {
         maxPoints[0].setX(0);
@@ -1700,7 +1701,7 @@ void Filterkpr2odf::saveAnimations(KoXmlWriter* content)
 {
     content->startElement("presentation:animations");
     QList<int> keys = m_pageAnimations.keys();
-    qSort(keys);  //we need to store the effects in the order of their keys
+    std::sort(keys.begin(), keys.end());  //we need to store the effects in the order of their keys
     foreach(int key, keys) {
         QList<QString> effectList = m_pageAnimations.value(key);
         if (effectList.size() > 1) { //if it's just 1 effect we don't add the group tag
