@@ -42,10 +42,10 @@ class Filterkpr2odf : public KoFilter
 public:
     Filterkpr2odf(QObject* parent, const QVariantList&);
 
-    virtual ~Filterkpr2odf() {}
+    ~Filterkpr2odf() override {}
 
     //reimplemented from KoFilter
-    virtual KoFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to);
+    KoFilter::ConversionStatus convert(const QByteArray& from, const QByteArray& to) override;
 
 private:
     //Helper functions
@@ -78,7 +78,7 @@ private:
     void exportAnimation(const KoXmlElement& objectElement, int indentLevel);
 
     //The next functions are used to correctly export arcs, pies and chords
-    //And they were obteined from the 1.6 sources
+    //And they were obtained from the 1.6 sources
     void getRealSizeAndOrig(QSizeF& realSize, QPointF& realOrig, int startAngle, int endAngle, int angle, int pieType);
     void setEndPoints(QPointF points[], const QSizeF& size, int startAngle, int endAngle);
     void setMinMax(double &min_x, double &min_y, double &max_x, double &max_y, QPointF point);
@@ -92,7 +92,7 @@ private:
     const QString createOpacityGradientStyle(int opacity);
     const QString createMarkerStyle(int markerType);
     const QString createStrokeDashStyle(int strokeStyle);
-    const QString createHatchStyle(int brushStyle, QString fillColor);
+    const QString createHatchStyle(int brushStyle, const QString &fillColor);
     const QString createParagraphStyle(const KoXmlElement& element);
     const QString createTextStyle(const KoXmlElement& element);
     const QString createListStyle(const KoXmlElement& element);
