@@ -23,11 +23,9 @@
 #include <KoOdf.h>
 #include <QDebug>
 #include <QDir>
+#include <QBuffer>
+#include <QTest>
 
-// KDESRCDIR is defined by KDE build system
-#ifndef KDESRCDIR
-#define KDESRCDIR
-#endif
 
 namespace {
 
@@ -92,8 +90,8 @@ TestRun::compareFiles(KoStore* input, const QString& path) {
 
 void
 TestRun::test() {
-    inputFilePath = KDESRCDIR "data/diagram.ppt";
-    referenceDirPath = KDESRCDIR "data/diagram_odp/";
+    inputFilePath = QFINDTESTDATA("data/diagram.ppt");
+    referenceDirPath = QFINDTESTDATA("data/diagram_odp/");
     const KoStore::Backend backend = KoStore::Tar;
     QBuffer buffer;
     convert(buffer, backend);
@@ -116,5 +114,5 @@ TestPPT::testPPT() {
     test.test();
     QVERIFY(true);
 }
+
 QTEST_MAIN(TestPPT)
-#include <TestPPT.moc>
