@@ -24,17 +24,16 @@
 #include <QRadioButton>
 #include <QApplication>
 
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kcharsets.h>
-#include <kglobal.h>
-#include <kdebug.h>
 #include <kcombobox.h>
 #include <kmessagebox.h>
 
+#include "AsciiImportDebug.h"
 #include <ui_ImportDialogUI.h>
 
 AsciiImportDialog::AsciiImportDialog(const QString &encoding, QWidget* parent)
-: KDialog(parent)
+: KoDialog(parent)
 {
     QWidget *widget = new QWidget();
     m_ui.setupUi(widget);
@@ -49,7 +48,7 @@ AsciiImportDialog::AsciiImportDialog(const QString &encoding, QWidget* parent)
     QStringList encodings;
     encodings << i18nc("Descriptive encoding name", "Recommended ( %1 )", "UTF-8");
     encodings << i18nc("Descriptive encoding name", "Locale ( %1 )" , QString(QTextCodec::codecForLocale()->name()));
-    encodings += KGlobal::charsets()->descriptiveEncodingNames();
+    encodings += KCharsets::charsets()->descriptiveEncodingNames();
     // Add a few non-standard encodings, which might be useful for text files
     const QString description(i18nc("Descriptive encoding name", "Other ( %1 )"));
     encodings << description.arg("Apple Roman"); // Apple
@@ -62,16 +61,16 @@ AsciiImportDialog::AsciiImportDialog(const QString &encoding, QWidget* parent)
     for (int i = 2; i < m_ui.comboBoxEncoding->count(); ++i) {
         // the string in strCodec and the one given back by codec->name() are not always the same so 
         // we check both
-        const QString strCodec(KGlobal::charsets()->encodingForName(m_ui.comboBoxEncoding->itemText(i)));
+        const QString strCodec(KCharsets::charsets()->encodingForName(m_ui.comboBoxEncoding->itemText(i)));
         QTextCodec* codec = QTextCodec::codecForName(strCodec.toUtf8());
         if (!codec) {
             bool ok = false;
-            codec = KGlobal::charsets()->codecForName(strCodec, ok);
+            codec = KCharsets::charsets()->codecForName(strCodec, ok);
             if (!ok) {
                 codec = 0;
             }
         }
-        //kDebug(30502) << "Data:" << strCodec << (codec ? codec->name(): "");
+        //debugAsciiImport << "Data:" << strCodec << (codec ? codec->name(): "");
         if ((codec && encoding == codec->name()) || strCodec == encoding) {
             m_ui.comboBoxEncoding->setCurrentIndex(i);
             break;
@@ -87,8 +86,8 @@ AsciiImportDialog::~AsciiImportDialog()
 
 QTextCodec* AsciiImportDialog::getCodec() const
 {
-    const QString strCodec(KGlobal::charsets()->encodingForName(m_ui.comboBoxEncoding->currentText()));
-    kDebug(30502) << "Encoding:" << strCodec << m_ui.comboBoxEncoding->currentText();
+    const QString strCodec(KCharsets::charsets()->encodingForName(m_ui.comboBoxEncoding->currentText()));
+    debugAsciiImport << "Encoding:" << strCodec << m_ui.comboBoxEncoding->currentText();
 
     bool ok = false;
     QTextCodec* codec = QTextCodec::codecForName(strCodec.toUtf8());
@@ -97,13 +96,13 @@ QTextCodec* AsciiImportDialog::getCodec() const
     if (codec) {
         ok = true;
     } else {
-        codec = KGlobal::charsets()->codecForName(strCodec, ok);
+        codec = KCharsets::charsets()->codecForName(strCodec, ok);
     }
 
     // Still nothing?
     if (!codec || !ok) {
         // Default: UTF-8
-        kWarning(30502) << "Cannot find encoding:" << strCodec;
+        warnAsciiImport << "Cannot find encoding:" << strCodec;
         // ### TODO: what parent to use?
         KMessageBox::error(0, i18n("Cannot find encoding: %1", strCodec));
         return 0;
@@ -126,5 +125,3 @@ int AsciiImportDialog::getParagraphStrategy() const
     }
     return 0;
 }
-
-#include <ImportDialog.moc>
