@@ -32,10 +32,10 @@ class Parser95 : public Parser9x
 {
 public:
     Parser95( OLEStorage* storage, OLEStreamReader* wordDocument );
-    virtual ~Parser95();
+    ~Parser95() override;
 
 private:
-    // don't copy or assing us
+    // don't copy or assign us
     Parser95( const Parser95& rhs );
     Parser95& operator=( const Parser95& rhs );
 
