@@ -16,6 +16,7 @@
  */
 
 #include "Destination.h"
+#include "rtfdebug.h"
 
 #include <QStack>
 
@@ -39,13 +40,13 @@ namespace RtfReader
 	return m_name;
     }
 
-    void Destination::handleControlWord( const QString &controlWord, bool hasValue, const int value )
+    void Destination::handleControlWord( const QByteArray &controlWord, bool hasValue, const int value )
     {
     };
 
-    void Destination::handlePlainText( const QString &plainText )
+    void Destination::handlePlainText( const QByteArray &plainText )
     {
-	qDebug() << "plain text:" << plainText << "in" << m_name;
+        qCDebug(lcRtf) << "plain text:" << plainText << "in" << m_name;
     };
 
     void Destination::aboutToEndDestination()
