@@ -32,11 +32,11 @@ namespace RtfReader
       public:
 	IgnoredDestination( Reader *reader, AbstractRtfOutput *output, const QString &name );
 
-	virtual ~IgnoredDestination();
+	~IgnoredDestination() override;
 
-	virtual void handleControlWord( const QString &controlWord, bool hasValue, const int value );
-	virtual void handlePlainText( const QString &plainText );
-	virtual void aboutToEndDestination();
+	void handleControlWord( const QByteArray &controlWord, bool hasValue, const int value ) override;
+	void handlePlainText( const QByteArray &plainText ) override;
+	void aboutToEndDestination() override;
       };
 }
 
