@@ -32,10 +32,10 @@ namespace RtfReader
       public:
 	InfoDestination( Reader *reader, AbstractRtfOutput *output, const QString &name );
 
-	virtual ~InfoDestination();
+	~InfoDestination() override;
 
-	virtual void handleControlWord( const QString &controlWord, bool hasValue, const int value );
-	virtual void handlePlainText( const QString &plainText );
+	void handleControlWord( const QByteArray &controlWord, bool hasValue, const int value ) override;
+	void handlePlainText( const QByteArray &plainText ) override;
 
       private:
 
