@@ -39,7 +39,7 @@ class DocumentListModel : public QAbstractListModel, public QQmlParserStatus
 
 public:
     explicit DocumentListModel(QObject *parent = 0);
-    ~DocumentListModel();
+    ~DocumentListModel() override;
 
     enum CustomRoles {
         FileNameRole = Qt::UserRole + 1,
@@ -76,14 +76,14 @@ public:
     };
 
     // reimp from QAbstractListModel
-    int rowCount(const QModelIndex &parent = QModelIndex()) const;
-    int columnCount(const QModelIndex &parent = QModelIndex()) const;
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
-    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
+    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
 
     // reimp from QDeclarativeParserStatus
-    void classBegin();
-    void componentComplete();
+    void classBegin() override;
+    void componentComplete() override;
 
     DocumentType filter();
     QString documentsFolder() const;
@@ -125,9 +125,9 @@ class SearchThread : public QObject, public QRunnable
     Q_OBJECT
 public:
     SearchThread(const QHash<QString, DocumentListModel::DocumentType> &docTypes, QObject *parent = 0);
-    ~SearchThread();
+    ~SearchThread() override;
 
-    void run();
+    void run() override;
     
     void abort() { m_abort = true; }
 
