@@ -22,6 +22,7 @@
 
 #include <QObject>
 #include <QVariantMap>
+#include <QIcon>
 
 class Theme : public QObject
 {
@@ -123,7 +124,7 @@ class Theme : public QObject
     Q_PROPERTY(QString fontPath READ fontPath WRITE setFontPath NOTIFY fontPathChanged)
 public:
     explicit Theme(QObject* parent = 0);
-    virtual ~Theme();
+    ~Theme() override;
 
     /**
      * Getter for property #id.
@@ -221,6 +222,10 @@ public:
      * Get an icon from the theme.
      */
     Q_INVOKABLE QUrl icon(const QString& name, bool useSystemFallback = false);
+    /**
+     * Get an icon from the theme.
+     */
+    Q_INVOKABLE QIcon iconActual(const QString& name);
     /**
      * Get a font from the theme.
      */
@@ -250,7 +255,7 @@ Q_SIGNALS:
     void fontCacheRebuilt();
 
 protected:
-    virtual bool eventFilter(QObject*, QEvent*);
+    bool eventFilter(QObject*, QEvent*) override;
 
 private:
     class Private;
