@@ -32,7 +32,7 @@ class ThumbnailHelperImpl : public QObject
     Q_OBJECT
 public:
     explicit ThumbnailHelperImpl(QObject* parent = 0);
-    virtual ~ThumbnailHelperImpl();
+    ~ThumbnailHelperImpl() override;
 
     bool convert(const QString& in, const QString& out, int width, int height);
 private:
