@@ -13,8 +13,8 @@ class DropboxPlugin : public QQmlExtensionPlugin
     Q_PLUGIN_METADATA(IID "org.calligra.DropboxPlugin")
 
 public:
-    virtual void registerTypes(const char* uri);
-    virtual void initializeEngine(QQmlEngine* engine, const char* uri);
+    void registerTypes(const char* uri) override;
+    void initializeEngine(QQmlEngine* engine, const char* uri) override;
 };
 
 #endif // DROPBOXPLUGIN_H
