@@ -23,14 +23,12 @@
 
 #include <QApplication>
 #include <QDebug>
-#include <QDesktopServices>
 #include <QDirIterator>
 #include <QRunnable>
 #include <QThreadPool>
 #include <QTimer>
+#include <QLocale>
 
-#include <KGlobal>
-#include <KLocale>
 #include <KSharedConfig>
 #include <KConfigGroup>
 
@@ -191,12 +189,8 @@ QVariant DocumentListModel::data(const QModelIndex &index, int role) const
 
 QString DocumentListModel::prettyTime(QDateTime theTime)
 {
-    if( theTime.date().day() == QDateTime::currentDateTime().date().day() )
-        return KGlobal::locale()->formatDateTime( theTime, KLocale::FancyShortDate );
-    else if( theTime.daysTo( QDateTime::currentDateTime() ) < 7 )
-        return KGlobal::locale()->formatDate( theTime.date(), KLocale::FancyShortDate );
-    else
-        return KGlobal::locale()->formatDate( theTime.date(), KLocale::ShortDate );
+    // QT5TODO: used to be KLocale::FancyShortDate, but no such thing with QLocale (also static anyway)
+    return QLocale().toString(theTime, QLocale::ShortFormat);
 }
 
 QVariant DocumentListModel::headerData(int section, Qt::Orientation orientation, int role) const
