@@ -178,11 +178,7 @@ void GitOpsThread::performPush()
     // refresh it, and add the file
     error = git_index_read(index, true);
     if(error != 0) { const git_error* err = giterr_last(); qDebug() << "Push 3, error code from git2 was" << error << "which is described as" << err->message; return; }
-#ifdef Q_OS_WIN
-    QString relative = d->currentFile.mid(d->gitDir.length() + 9); // That is, 1 for the leading slash, and 8 for the file:///
-#else
-    QString relative = d->currentFile.mid(d->gitDir.length() + 8); // That is, 1 for the leading slash, and 8 for the file://
-#endif
+    QString relative = d->currentFile.mid(d->gitDir.length() + 1); // That is, 1 for the leading slash
     error = git_index_add_bypath(index, relative.toLocal8Bit());
     if(error != 0) { const git_error* err = giterr_last(); qDebug() << "Push 4, error code from git2 was" << error << "which is described as" << err->message; return; }
     error = git_index_write(index);
@@ -667,7 +663,7 @@ void GitController::commitAndPushCurrentFile()
         return;
     }
 
-    if(d->currentFile.startsWith(QString("file:///%1").arg(d->cloneDir)) || d->currentFile.startsWith(QString("file://%1").arg(d->cloneDir))) {
+    if(d->currentFile.startsWith(d->cloneDir)) {
         // ask commit message and checkbox for push (default on, remember?)
         bool ok = false;
         QString message = QInputDialog::getMultiLineText(0,
@@ -679,6 +675,7 @@ void GitController::commitAndPushCurrentFile()
         // we explicitly leave the action enabled here because we want the user to be able to
         // regret their cancellation and commit anyway
         if(ok) {
+            qDebug() << "Attempting to push" << d->currentFile << "in the clone dir" << d->cloneDir;
             emit operationBegun(QString("Pushing local changes to remote storage"));
             d->opThread = new GitOpsThread(d->privateKey, d->publicKey, d->userForRemote, d->needsPrivateKeyPassphrase, d->signature, d->cloneDir, GitOpsThread::PushOperation, d->currentFile, message, this);
             connect(d->opThread, SIGNAL(destroyed()), this, SLOT(clearOpThread()));
