@@ -21,8 +21,6 @@
 #ifndef _KO_GENERIC_REGISTRY_H_
 #define _KO_GENERIC_REGISTRY_H_
 
-#include <kdemacros.h>
-#include <kdebug.h>
 #include <QList>
 #include <QString>
 #include <QHash>
@@ -65,7 +63,7 @@ public:
 public:
     /**
      * Add an object to the registry. If it is a QObject, make sure it isn't in the
-     * QObject ownership hierarchy, since the registry itself is responsbile for
+     * QObject ownership hierarchy, since the registry itself is responsible for
      * deleting it.
      *
      * @param item the item to add (NOTE: T must have an QString id() const   function)
