@@ -27,14 +27,10 @@ class KarbonDocument;
 class KarbonDocumentMergeCommand : public KUndo2Command
 {
 public:
-    KarbonDocumentMergeCommand(KarbonDocument * targetPart, KarbonDocument * sourcePart);
-    virtual ~KarbonDocumentMergeCommand();
-    virtual void redo();
-    virtual void undo();
-
-private:
-    class Private;
-    Private * const d;
+    KarbonDocumentMergeCommand(KarbonDocument * targetPart, KarbonDocument &sourcePart, KUndo2Command *parent = 0);
+    ~KarbonDocumentMergeCommand() override = default;
+    void redo() override;
+    void undo() override;
 };
 
 #endif // _KARBONDOCUMENTMERGECOMMAND_H_
