@@ -34,8 +34,7 @@
 #ifndef __KARBON_VIEW__
 #define __KARBON_VIEW__
 
-#include <KoView.h>
-#include <QPointF>
+#include <KoPAView.h>
 #include <KoShapeAlignCommand.h>
 #include <KoShapeDistributeCommand.h>
 #include <karbonui_export.h>
@@ -43,6 +42,7 @@
 
 class QDropEvent;
 class QResizeEvent;
+class QLayout;
 
 class KarbonDocument;
 
@@ -50,22 +50,25 @@ class KoColor;
 class KoUnit;
 
 
+class KarbonPaletteBarWidget;
 class KarbonPart;
-class KarbonCanvas;
 
-class KARBONUI_EXPORT KarbonView : public KoView
+class KoPACanvas;
+class KoCanvasResourceManager;
+
+class KARBONUI_EXPORT KarbonView : public KoPAView
 {
     Q_OBJECT
 
 public:
     KarbonView(KarbonPart *part, KarbonDocument* doc, QWidget* parent = 0);
-    virtual ~KarbonView();
+    ~KarbonView() override;
 
     /// Returns the view is attached to
-    KarbonDocument * part() const;
+   KarbonDocument * part() const;
 
     /// Returns the canvas widget of this view
-    KarbonCanvas * canvasWidget() const;
+    KoPACanvas *canvasWidget() const;
 
     void reorganizeGUI();
     void setNumberOfRecentFiles(uint number);
@@ -73,11 +76,13 @@ public:
     /// Reimplemented from QWidget
     virtual void setCursor(const QCursor &);
     /// Reimplemented from QWidget
-    virtual void dropEvent(QDropEvent *e);
-    /// Reimplemented from KoView
-    virtual KoZoomController *zoomController() const;
+    void dropEvent(QDropEvent *e) override;
 
 
+    KoCanvasResourceManager *resourceManager() const;
+
+    KarbonPaletteBarWidget *colorBar() const;
+
 public Q_SLOTS:
     // editing:
     void editSelectAll();
@@ -114,19 +119,13 @@ public Q_SLOTS:
 
     void pathSnapToGrid();
 
-    void configure();
+    void selectionChanged() override;
 
-    void configurePageLayout();
-
-    void selectionChanged();
-
-    void togglePageMargins(bool);
-    void showRuler();
-    void showGuides();
     void editGuides();
-    void snapToGrid();
     void showPalette();
 
+    void replaceActivePage(KoPAPageBase *page, KoPAPageBase *newActivePage);
+
 protected Q_SLOTS:
     // Object related operations.
 
@@ -136,27 +135,22 @@ protected Q_SLOTS:
     void zoomDrawing();
 
     void mousePositionChanged(const QPoint &position);
-    void pageOffsetChanged();
-
-    void updateUnit(const KoUnit &unit);
 
     void applyFillToSelection();
     void applyStrokeToSelection();
     void applyPaletteColor(const KoColor &color);
 
 protected:
-    virtual void updateReadWrite(bool readwrite);
-    virtual void resizeEvent(QResizeEvent* event);
-    virtual void dragEnterEvent(QDragEnterEvent * event);
-    virtual void addImages(const QList<QImage> &imageList, const QPoint &insertAt);
+    /// Use own configuaration dialog
+    void openConfiguration() override;
+
+    void updateReadWrite(bool readwrite) override;
+    void resizeEvent(QResizeEvent* event) override;
+    void dragEnterEvent(QDragEnterEvent * event) override;
 
-    void createLayersTabDock();
     void createStrokeDock();
     void createColorDock();
 
-    virtual KoPrintJob * createPrintJob();
-    virtual KoPrintJob * createPdfPrintJob();
-
 private:
     void initActions();
     void updateRuler();
