@@ -30,7 +30,7 @@ class KarbonPaletteWidget : public QWidget
     Q_OBJECT
 public:
     explicit KarbonPaletteWidget(QWidget *parent = 0);
-    virtual ~KarbonPaletteWidget();
+    ~KarbonPaletteWidget() override;
 
     /// Set orientation of color bar
     void setOrientation(Qt::Orientation orientation);
@@ -49,11 +49,11 @@ public:
     /// Returns the current palette
     KoColorSet *palette() const;
 
-public slots:
+public Q_SLOTS:
     void scrollForward();
     void scrollBackward();
 
-signals:
+Q_SIGNALS:
     /// Emitted whenever a color was clicked
     void colorSelected(const KoColor &color);
 
@@ -61,13 +61,13 @@ signals:
     void scrollOffsetChanged();
 
 protected:
-    virtual void paintEvent(QPaintEvent *event);
-    virtual void mousePressEvent(QMouseEvent *event);
-    virtual void mouseMoveEvent(QMouseEvent *event);
-    virtual void mouseReleaseEvent(QMouseEvent *event);
-    virtual void wheelEvent(QWheelEvent *event);
-    virtual void keyPressEvent(QKeyEvent *event);
-    virtual bool event(QEvent *event);
+    void paintEvent(QPaintEvent *event) override;
+    void mousePressEvent(QMouseEvent *event) override;
+    void mouseMoveEvent(QMouseEvent *event) override;
+    void mouseReleaseEvent(QMouseEvent *event) override;
+    void wheelEvent(QWheelEvent *event) override;
+    void keyPressEvent(QKeyEvent *event) override;
+    bool event(QEvent *event) override;
 
 private:
     /// Returns color index from given position
