@@ -35,21 +35,21 @@ class BASICFLAKES_EXPORT KoPencilTool : public KoToolBase
     Q_OBJECT
 public:
     explicit KoPencilTool(KoCanvasBase *canvas);
-    ~KoPencilTool();
+    ~KoPencilTool() override;
 
-    void paint(QPainter &painter, const KoViewConverter &converter);
-    void repaintDecorations();
+    void paint(QPainter &painter, const KoViewConverter &converter) override;
+    void repaintDecorations() override;
 
-    void mousePressEvent(KoPointerEvent *event) ;
-    void mouseMoveEvent(KoPointerEvent *event);
-    void mouseReleaseEvent(KoPointerEvent *event);
-    void keyPressEvent(QKeyEvent *event);
+    void mousePressEvent(KoPointerEvent *event) override ;
+    void mouseMoveEvent(KoPointerEvent *event) override;
+    void mouseReleaseEvent(KoPointerEvent *event) override;
+    void keyPressEvent(QKeyEvent *event) override;
 
-    virtual void activate(ToolActivation toolActivation, const QSet<KoShape*> &shapes);
-    void deactivate();
+    void activate(ToolActivation toolActivation, const QSet<KoShape*> &shapes) override;
+    void deactivate() override;
 
 protected:
-    virtual QList<QPointer<QWidget> > createOptionWidgets();
+    QList<QPointer<QWidget> > createOptionWidgets() override;
 
     /**
      * Add path shape to document.
