@@ -16,6 +16,8 @@
  * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
+#include <algorithm>
+
 #include "KoAnnotationLayoutManager.h"
 
 #include <KoViewConverter.h>
@@ -191,7 +193,7 @@ void KoAnnotationLayoutManager::updateLayout(KoShape *shape)
 void KoAnnotationLayoutManager::layoutAnnotationShapes()
 {
     qreal currentY = 0.0;
-    qStableSort(d->annotationShapePositions.begin(), d->annotationShapePositions.end(), compare);
+    std::stable_sort(d->annotationShapePositions.begin(), d->annotationShapePositions.end(), compare);
 
     QList< QPair < QPointF, KoShape * > >::const_iterator it = d->annotationShapePositions.constBegin();
     while (it != d->annotationShapePositions.constEnd()) {
@@ -216,4 +218,4 @@ void KoAnnotationLayoutManager::layoutAnnotationShapes()
 // only static const integral data members can be initialized within a class
 const qreal KoAnnotationLayoutManager::shapeSpace = 10.0; // Distance between annotation shapes.
 const qreal KoAnnotationLayoutManager::shapeWidth = 200.0; // Annotation shapes width.
-const qreal KoAnnotationLayoutManager::connectionPointLines = 50.0; //Connection point of lines from shape to this point and from this point to refText psoition.
+const qreal KoAnnotationLayoutManager::connectionPointLines = 50.0; //Connection point of lines from shape to this point and from this point to refText position.
