@@ -37,11 +37,11 @@ class FLAKE_EXPORT KoAnnotationLayoutManager: public QObject
 public:
     static const qreal shapeSpace; // Distance between annotation shapes.
     static const qreal shapeWidth; // Annotation shapes width.
-    //Connection point of lines from shape to this point and from this point to refText psoition.
+    //Connection point of lines from shape to this point and from this point to refText position.
     static const qreal connectionPointLines;
 
     explicit KoAnnotationLayoutManager(QObject *parent = 0);
-    virtual ~KoAnnotationLayoutManager();
+    ~KoAnnotationLayoutManager() override;
 
     void setShapeManager(KoShapeManager *shapeManager);
 
@@ -50,8 +50,8 @@ public:
     void setViewContentWidth(qreal width);
 
     void paintConnections(QPainter &painter);
-    // Return true if shape is in annotaion shapes list.
-    bool isAnnotationShape(KoShape *shape);
+    // Return true if shape is in annotation shapes list.
+    bool isAnnotationShape(KoShape *shape) const;
 
 public Q_SLOTS:
     /// register the position of an annotation shape.
