@@ -35,7 +35,7 @@
 #include "KoCanvasSupervisor.h"
 #include "KoToolManager_p.h"
 
-#include <kdebug.h>
+#include <FlakeDebug.h>
 #include <QMouseEvent>
 #include <QPainter>
 #include <QScrollBar>
@@ -45,7 +45,7 @@
 
 #include <KoConfig.h>
 
-class KoCanvasControllerWidget::Private
+class Q_DECL_HIDDEN KoCanvasControllerWidget::Private
 {
 public:
 
