@@ -45,7 +45,7 @@ public:
     explicit KoGradientBackground(const QGradient &gradient, const QTransform &matrix = QTransform());
 
     /// Destroys the background
-    virtual ~KoGradientBackground();
+    ~KoGradientBackground() override;
 
     /// Sets the transform matrix
     void setTransform(const QTransform &matrix);
@@ -63,11 +63,11 @@ public:
     const QGradient *gradient() const;
 
     /// reimplemented from KoShapeBackground
-    virtual void paint(QPainter &painter, const KoViewConverter &converter, KoShapePaintingContext &context, const QPainterPath &fillPath) const;
+    void paint(QPainter &painter, const KoViewConverter &converter, KoShapePaintingContext &context, const QPainterPath &fillPath) const override;
     /// reimplemented from KoShapeBackground
-    virtual void fillStyle(KoGenStyle &style, KoShapeSavingContext &context);
+    void fillStyle(KoGenStyle &style, KoShapeSavingContext &context) override;
     /// reimplemented from KoShapeBackground
-    virtual bool loadStyle(KoOdfLoadingContext &context, const QSizeF &shapeSize);
+    bool loadStyle(KoOdfLoadingContext &context, const QSizeF &shapeSize) override;
 
 private:
     Q_DECLARE_PRIVATE(KoGradientBackground)
