@@ -32,19 +32,19 @@ class KoGenStyles;
 class KoGenStyle;
 
 /// Gradients from odf that are not native to Qt
-class KoOdfGradientBackground : public KoShapeBackground {
+class FLAKE_EXPORT KoOdfGradientBackground : public KoShapeBackground {
 public:
     // constructor
     KoOdfGradientBackground();
     // destructor
-    virtual ~KoOdfGradientBackground();
+    ~KoOdfGradientBackground() override;
 
     /// reimplemented from KoShapeBackground
-    virtual void fillStyle(KoGenStyle& style, KoShapeSavingContext& context);
+    void fillStyle(KoGenStyle& style, KoShapeSavingContext& context) override;
     /// reimplemented from KoShapeBackground
-    virtual bool loadStyle(KoOdfLoadingContext& context, const QSizeF& shapeSize);
+    bool loadStyle(KoOdfLoadingContext& context, const QSizeF& shapeSize) override;
     /// reimplemented from KoShapeBackground
-    virtual void paint(QPainter& painter, const KoViewConverter &converter, KoShapePaintingContext &context, const QPainterPath& fillPath) const;
+    void paint(QPainter& painter, const KoViewConverter &converter, KoShapePaintingContext &context, const QPainterPath& fillPath) const override;
 
 private:
     bool loadOdf(const KoXmlElement &element);
