@@ -34,11 +34,11 @@ Q_OBJECT
 public:
     /// constructor
     explicit KoPathShapeFactory(const QStringList&);
-    ~KoPathShapeFactory() {}
-    virtual KoShape *createDefaultShape(KoDocumentResourceManager *documentResources = 0) const;
-    bool supports(const KoXmlElement &element, KoShapeLoadingContext &context) const;
+    ~KoPathShapeFactory() override {}
+    KoShape *createDefaultShape(KoDocumentResourceManager *documentResources = 0) const override;
+    bool supports(const KoXmlElement &element, KoShapeLoadingContext &context) const override;
     /// reimplemented
-    virtual void newDocumentResourceManager(KoDocumentResourceManager *manager) const;
+    void newDocumentResourceManager(KoDocumentResourceManager *manager) const override;
 };
 
 #endif
