@@ -93,12 +93,8 @@ KoShapePrivate::KoShapePrivate(KoShape *shape)
       runThrough(0),
       visible(true),
       printable(true),
-      geometryProtected(false),
       keepAspect(false),
-      selectable(true),
-      deletable(true),
       detectCollision(false),
-      protectContent(false),
       textRunAroundSide(KoShape::BiggestRunAroundSide),
       textRunAroundDistanceLeft(0.0),
       textRunAroundDistanceTop(0.0),
@@ -109,6 +105,15 @@ KoShapePrivate::KoShapePrivate(KoShape *shape)
       anchor(0),
       minimumHeight(0.0)
 {
+    // All interactions allowed by default
+    allowedInteractions = KoShape::MoveAllowed
+                        | KoShape::ResizeAllowed
+                        | KoShape::ShearingAllowed
+                        | KoShape::RotationAllowed
+                        | KoShape::SelectionAllowed
+                        | KoShape::ContentChangeAllowed
+                        | KoShape::DeletionAllowed;
+
     connectors[KoConnectionPoint::TopConnectionPoint] = KoConnectionPoint::defaultConnectionPoint(KoConnectionPoint::TopConnectionPoint);
     connectors[KoConnectionPoint::RightConnectionPoint] = KoConnectionPoint::defaultConnectionPoint(KoConnectionPoint::RightConnectionPoint);
     connectors[KoConnectionPoint::BottomConnectionPoint] = KoConnectionPoint::defaultConnectionPoint(KoConnectionPoint::BottomConnectionPoint);
@@ -673,12 +678,9 @@ void KoShape::copySettings(const KoShape *shape)
     else
         d->printable = shape->isPrintable();
 
-    d->geometryProtected = shape->isGeometryProtected();
-    d->protectContent = shape->isContentProtected();
-    d->selectable = shape->isSelectable();
+    d->allowedInteractions = shape->allowedInteractions();
     d->keepAspect = shape->keepAspectRatio();
     d->localMatrix = shape->d_ptr->localMatrix;
-    d->deletable = shape->isDeletable();
 }
 
 void KoShape::notifyChanged()
@@ -1099,49 +1101,105 @@ bool KoShape::isPrintable() const
 void KoShape::setSelectable(bool selectable)
 {
     Q_D(KoShape);
-    d->selectable = selectable;
+#if QT_VERSION >= 0x050700
+    d->allowedInteractions.setFlag(SelectionAllowed, selectable);
+#else
+    selectable ? (d->allowedInteractions |= SelectionAllowed) : (d->allowedInteractions &= ~SelectionAllowed);
+#endif
 }
 
 bool KoShape::isSelectable() const
 {
     Q_D(const KoShape);
-    return d->selectable;
+    return d->allowedInteractions.testFlag(SelectionAllowed);
 }
 
 void KoShape::setGeometryProtected(bool on)
 {
     Q_D(KoShape);
-    d->geometryProtected = on;
+#if QT_VERSION >= 0x050700
+    d->allowedInteractions.setFlag(MoveAllowed, !on);
+    d->allowedInteractions.setFlag(ResizeAllowed, !on);
+#else
+    (!on) ? (d->allowedInteractions |= MoveAllowed) : (d->allowedInteractions &= ~MoveAllowed);
+    (!on) ? (d->allowedInteractions |= ResizeAllowed) : (d->allowedInteractions &= ~ResizeAllowed);
+#endif
 }
 
 bool KoShape::isGeometryProtected() const
 {
     Q_D(const KoShape);
-    return d->geometryProtected;
+    return !d->allowedInteractions.testFlag(MoveAllowed) || !d->allowedInteractions.testFlag(ResizeAllowed);
 }
 
 void KoShape::setContentProtected(bool protect)
 {
     Q_D(KoShape);
-    d->protectContent = protect;
+#if QT_VERSION >= 0x050700
+    d->allowedInteractions.setFlag(ContentChangeAllowed, !protect);
+#else
+    (!protect) ? (d->allowedInteractions |= ContentChangeAllowed) : (d->allowedInteractions &= ~ContentChangeAllowed);
+#endif
 }
 
 bool KoShape::isContentProtected() const
 {
     Q_D(const KoShape);
-    return d->protectContent;
+    return !d->allowedInteractions.testFlag(ContentChangeAllowed);
 }
 
 void KoShape::setDeletable(bool deletable)
 {
     Q_D(KoShape);
-    d->deletable = deletable;
+#if QT_VERSION >= 0x050700
+    d->allowedInteractions.setFlag(DeletionAllowed, deletable);
+#else
+    deletable ? (d->allowedInteractions |= DeletionAllowed) : (d->allowedInteractions &= ~DeletionAllowed);
+#endif
 }
 
 bool KoShape::isDeletable() const
 {
     Q_D(const KoShape);
-    return d->deletable;
+    return d->allowedInteractions.testFlag(DeletionAllowed);
+}
+
+void KoShape::setAllowedInteraction(KoShape::AllowedInteraction flag, bool value)
+{
+    Q_D(KoShape);
+#if QT_VERSION >= 0x050700
+    d->allowedInteractions.setFlag(flag, value);
+#else
+    value ? (d->allowedInteractions |= flag) : (d->allowedInteractions &= ~flag);
+#endif
+}
+
+bool KoShape::allowedInteraction(KoShape::AllowedInteraction flag, bool recursive) const
+{
+    return allowedInteractions(recursive).testFlag(flag);
+}
+
+void KoShape::setAllowedInteractions(KoShape::AllowedInteractions interactions)
+{
+    Q_D(KoShape);
+    d->allowedInteractions = interactions;
+}
+
+KoShape::AllowedInteractions KoShape::allowedInteractions(bool recursive) const
+{
+    Q_D(const KoShape);
+    if (!recursive) {
+        return d->allowedInteractions;
+    }
+    AllowedInteractions state;
+    if (!d->visible) {
+        return state;
+    }
+    state = d->allowedInteractions;
+    if (state && d->parent) {
+        state &= d->parent->allowedInteractions(this);
+    }
+    return state;
 }
 
 KoShapeContainer *KoShape::parent() const
@@ -1285,7 +1343,7 @@ void KoShape::waitUntilReady(const KoViewConverter &converter, bool asynchronous
 bool KoShape::isEditable() const
 {
     Q_D(const KoShape);
-    if (!d->visible || d->geometryProtected)
+    if (!d->visible || isGeometryProtected())
         return false;
 
     if (d->parent && d->parent->isChildLocked(this))
@@ -1343,8 +1401,13 @@ QString KoShape::saveStyle(KoGenStyle &style, KoShapeSavingContext &context) con
     }
 
     QString value;
-    if (isGeometryProtected()) {
-        value = "position size";
+    if (!d->allowedInteractions.testFlag(MoveAllowed)) {
+        value = "position";
+    }
+    if (!d->allowedInteractions.testFlag(ResizeAllowed)) {
+        if (! value.isEmpty())
+            value += ' ';
+        value += "size";
     }
     if (isContentProtected()) {
         if (! value.isEmpty())
@@ -1427,7 +1490,7 @@ QString KoShape::saveStyle(KoGenStyle &style, KoShapeSavingContext &context) con
         style.addPropertyPt("fo:margin-bottom", textRunAroundDistanceBottom(), KoGenStyle::GraphicType);
     }
 
-    return context.mainStyles().insert(style, context.isSet(KoShapeSavingContext::PresentationShape) ? "pr" : "gr");
+    return context.mainStyles().insert(style, context.styleFamily());
 }
 
 void KoShape::loadStyle(const KoXmlElement &element, KoShapeLoadingContext &context)
@@ -1452,7 +1515,13 @@ void KoShape::loadStyle(const KoXmlElement &element, KoShapeLoadingContext &cont
     setBorder(d->loadOdfBorder(context));
 
     QString protect(styleStack.property(KoXmlNS::style, "protect"));
-    setGeometryProtected(protect.contains("position") || protect.contains("size"));
+#if QT_VERSION >= 0x050700
+    d->allowedInteractions.setFlag(MoveAllowed, !protect.contains("position"));
+    d->allowedInteractions.setFlag(ResizeAllowed, !protect.contains("size"));
+#else
+    (!protect.contains("position")) ? (d->allowedInteractions |= MoveAllowed) : (d->allowedInteractions &= ~MoveAllowed);
+    (!protect.contains("size")) ? (d->allowedInteractions |= ResizeAllowed) : (d->allowedInteractions &= ~ResizeAllowed);
+#endif
     setContentProtected(protect.contains("content"));
 
     QString margin = styleStack.property(KoXmlNS::fo, "margin");
@@ -1595,7 +1664,7 @@ bool KoShape::loadOdfAttributes(const KoXmlElement &element, KoShapeLoadingConte
     if (attributes & OdfTransformation) {
         QString transform = element.attributeNS(KoXmlNS::draw, "transform", QString());
         if (! transform.isEmpty())
-            applyAbsoluteTransformation(parseOdfTransform(transform));
+            applyAbsoluteTransformation(parseOdfTransform(transform, context));
     }
 
     if (attributes & OdfAdditionalAttributes) {
@@ -1880,7 +1949,7 @@ void KoShape::loadOdfClipContour(const KoXmlElement &element, KoShapeLoadingCont
     }
 }
 
-QTransform KoShape::parseOdfTransform(const QString &transform)
+QTransform KoShape::parseOdfTransform(const QString &transform, KoShapeLoadingContext &context)
 {
     QTransform matrix;
 
@@ -1903,17 +1972,18 @@ QTransform KoShape::parseOdfTransform(const QString &transform)
 
         if (cmd == "rotate") {
             QTransform rotMatrix;
+#ifndef NWORKAROUND_ODF_BUGS
+            KoOdfWorkaround::fixRotate(params, context);
+#endif
             if (params.count() == 3) {
                 qreal x = KoUnit::parseValue(params[1]);
                 qreal y = KoUnit::parseValue(params[2]);
 
                 rotMatrix.translate(x, y);
-                // oo2 rotates by radians
-                rotMatrix.rotate(-params[0].toDouble()*180.0 / M_PI);
-                rotMatrix.translate(-x, -y);
+                rotMatrix.rotate(KoUnit::parseAngle(params[0], 0.0));
+                rotMatrix.translate(x, y);
             } else {
-                // oo2 rotates by radians
-                rotMatrix.rotate(-params[0].toDouble()*180.0 / M_PI);
+                rotMatrix.rotate(KoUnit::parseAngle(params[0], 0.0));
             }
             matrix = matrix * rotMatrix;
         } else if (cmd == "translate") {
@@ -1933,17 +2003,23 @@ QTransform KoShape::parseOdfTransform(const QString &transform)
                 scaleMatrix.scale(params[0].toDouble(), params[0].toDouble());
             matrix = matrix * scaleMatrix;
         } else if (cmd == "skewx") {
+#ifndef NWORKAROUND_ODF_BUGS
+            KoOdfWorkaround::fixSkew(params, context);
+#endif
             QPointF p = absolutePosition(KoFlake::TopLeftCorner);
             QTransform shearMatrix;
             shearMatrix.translate(p.x(), p.y());
-            shearMatrix.shear(tan(-params[0].toDouble()), 0.0F);
+            shearMatrix.shear(tan(KoUnit::parseAngle(params[0], 0.0F) * M_PI / 180), 0.0F);
             shearMatrix.translate(-p.x(), -p.y());
             matrix = matrix * shearMatrix;
         } else if (cmd == "skewy") {
+#ifndef NWORKAROUND_ODF_BUGS
+            KoOdfWorkaround::fixSkew(params, context);
+#endif
             QPointF p = absolutePosition(KoFlake::TopLeftCorner);
             QTransform shearMatrix;
             shearMatrix.translate(p.x(), p.y());
-            shearMatrix.shear(0.0F, tan(-params[0].toDouble()));
+            shearMatrix.shear(0.0F, tan(KoUnit::parseAngle(params[0], 0.0F) * M_PI / 180));
             shearMatrix.translate(-p.x(), -p.y());
             matrix = matrix * shearMatrix;
         } else if (cmd == "matrix") {
@@ -2288,6 +2364,18 @@ void KoShape::removeAdditionalStyleAttribute(const char *name)
     d->additionalStyleAttributes.remove(name);
 }
 
+QString KoShape::additionalStyleAttribute(const QByteArray &name) const
+{
+    Q_D(const KoShape);
+    return d->additionalStyleAttributes.value(name);
+}
+
+QMap<QByteArray, QString> KoShape::additionalStyleAttributes() const
+{
+    Q_D(const KoShape);
+    return d->additionalStyleAttributes;
+}
+
 KoFilterEffectStack *KoShape::filterEffectStack() const
 {
     Q_D(const KoShape);
