@@ -128,7 +128,10 @@ public:
         TextRunAroundChanged, ///< used after a setTextRunAroundSide()
         ChildChanged, ///< a child of a container was changed/removed. This is propagated to all parents
         ConnectionPointChanged, ///< a connection point has changed
-        ClipPathChanged ///< the shapes clip path has changed
+        ClipPathChanged, ///< the shapes clip path has changed
+        ControlPointChanged, ///< a control point has changed
+        BeginResize, ///< used during resizing
+        EndResize ///< used during resizing
     };
 
     /// The behavior text should do when intersecting this shape.
@@ -157,6 +160,19 @@ public:
         Foreground
     };
 
+    /// Fine grained control of allowed user interactions
+    enum AllowedInteraction {
+        MoveAllowed = 1,            ///< Moving the shape is allowed
+        ResizeAllowed = 2,          ///< Resizing the shape is allowed
+        ShearingAllowed = 4,        ///< Sharing the shape is allowed
+        RotationAllowed = 8,        ///< Rotating the shape is allowed
+        SelectionAllowed = 16,      ///< Selecting the shape is allowed
+        ContentChangeAllowed = 32,  ///< Editing the content is allowed
+        DeletionAllowed = 64        ///< Deleting the shape is allowed
+    };
+    Q_DECLARE_FLAGS(AllowedInteractions, AllowedInteraction)
+    Q_FLAGS(AllowedInteractions)
+
     /**
      * @brief Constructor
      */
@@ -175,7 +191,7 @@ public:
      * This can be done with a method like:
      * <code>
        painter.fillRect(converter.normalToView(QRectF(QPointF(0.0,0.0), size())), background());</code>
-     * Or equavalent for non-square objects.
+     * Or equivalent for non-square objects.
      * Do note that a shape's top-left is always at coordinate 0,0. Even if the shape itself is rotated
      * or translated.
      * @param painter used for painting the shape
@@ -392,7 +408,7 @@ public:
     /**
      * Set the side text should flow around this shape.
      * @param side the requested side
-     * @param runThrought run through the foreground or background or...
+     * @param runThrough run through the foreground or background or...
      */
     void setTextRunAroundSide(TextRunAroundSide side, RunThroughLevel runThrough = Background);
 
@@ -485,7 +501,7 @@ public:
     /**
      * Set the minimum height of the shape.
      * Currently it's not respected but only for informational purpose
-     * @param minimumShapeHeight the minimum height of the frame.
+     * @param height the minimum height of the frame.
      */
     void setMinimumHeight(qreal height);
 
@@ -699,7 +715,7 @@ public:
    /**
     * Returns if during compareShapeZIndex() how this shape portrays the values
     * of its children. The default behaviour is to let this shape's z values take
-    * the place of its childrens values, so you get a parent/child relationship.
+    * the place of its children values, so you get a parent/child relationship.
     * The children are naturally still ordered relatively to their z values
     *
     * But for special cases (like Calligra's TextShape) it can be overloaded to return
@@ -968,8 +984,9 @@ public:
      * In this case it can be shown on screen probably partially but it should really not be printed
      * until it is fully done processing.
      * Warning! This method can be blocking for a long time
+     * @param converter    The converter to convert between internal and view coordinates.
      * @param asynchronous If set to true the processing will can take place in a different thread and the
-     *                     function will not block until the shape is finised.
+     *                     function will not block until the shape is finished.
      *                     In case of printing Flake will call this method from a non-main thread and only
      *                     start printing it when the in case of printing method returned.
      *                     If set to false the processing needs to be done synchronously and will
@@ -1049,6 +1066,10 @@ public:
 
     void removeAdditionalStyleAttribute(const char *name);
 
+    QString additionalStyleAttribute(const QByteArray &name) const;
+
+    QMap<QByteArray, QString> additionalStyleAttributes() const;
+
     /**
      * Returns the filter effect stack of the shape
      *
@@ -1117,6 +1138,23 @@ public:
      */
     bool isDeletable() const;
 
+    /// Sets the AllowedInteraction @p flag to @p value
+    void setAllowedInteraction(AllowedInteraction flag, bool value);
+    /// @return the AllowedInteraction state for @p flag.
+    /// Convenience method that just calls allowedInteractions(recursive).testFlag(flag).
+    /// @see allowedInteractions()
+    bool allowedInteraction(AllowedInteraction flag, bool recursive = true) const;
+    /// Sets the interactions the user is allowed to perform on this shape to @p interactions
+    void setAllowedInteractions(AllowedInteractions interactions);
+    /// @return the interactions the user is allowed to perform on this shape.
+    /// If @p recursive is false, the shapes flags are returned as is. Use this e.g. for ui.
+    /// If @p recursive is true:
+    ///     If the shape is not visible, no interactions are allowed.
+    ///     If there is a parent, the parent is checked.
+    ///
+    /// @see KoShapeContainer::allowedInteractions()
+    AllowedInteractions allowedInteractions(bool recursive = true) const;
+
     /**
      * \internal
      * Returns the private object for use within the flake lib
@@ -1162,9 +1200,10 @@ protected:
     /**
      * Parses the transformation attribute from the given string
      * @param transform the transform attribute string
+     * @param context the loading context
      * @return the resulting transformation matrix
      */
-    QTransform parseOdfTransform(const QString &transform);
+    QTransform parseOdfTransform(const QString &transform, KoShapeLoadingContext &context);
 
     /**
      * @brief Saves the style used for the shape
@@ -1205,6 +1244,7 @@ protected:
      * A hook that allows inheriting classes to do something after a KoShape property changed
      * This is called whenever the shape, position rotation or scale properties were altered.
      * @param type an indicator which type was changed.
+     * @param shape the shape.
      */
     virtual void shapeChanged(ChangeType type, KoShape *shape = 0);
 
@@ -1218,5 +1258,6 @@ private:
 };
 
 Q_DECLARE_METATYPE(KoShape*)
+Q_DECLARE_OPERATORS_FOR_FLAGS(KoShape::AllowedInteractions)
 
 #endif
