@@ -26,10 +26,9 @@
 
 #include "flake_export.h"
 
-#include <KoUnit.h>
-
 class KoShape;
 class KUndo2Command;
+class KoUnit;
 
 /**
  * Base widget for shape-configuration panels.
@@ -52,7 +51,7 @@ public:
      * Default constructor
      */
     KoShapeConfigWidgetBase();
-    virtual ~KoShapeConfigWidgetBase();
+    ~KoShapeConfigWidgetBase() override;
 
     /**
      * Open the argument shape by interpreting the data and setting that data on this
@@ -73,7 +72,7 @@ public:
      * Called by the tool that created the shape using KoCavasBase::unit()
      * @param unit the new unit to show data in.
      */
-    virtual void setUnit(KoUnit unit);
+    virtual void setUnit(const KoUnit &unit);
 
     /// called to set the canvas resource manager of the canvas the user used to insert the new shape.
     void setResourceManager(KoCanvasResourceManager *rm);
