@@ -41,7 +41,9 @@
 #include <QObject>
 
 #include <kpagedialog.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
+
+#include <algorithm>
 
 class KoShapeController::Private
 {
@@ -68,11 +70,11 @@ public:
 
                 // show config dialog.
                 KPageDialog *dialog = new KPageDialog(canvas->canvasWidget());
-                dialog->setCaption(i18n("%1 Options", factory->name()));
+                dialog->setWindowTitle(i18n("%1 Options", factory->name()));
 
                 int pageCount = 0;
                 QList<KoShapeConfigFactoryBase*> panels = factory->panelFactories();
-                qSort(panels.begin(), panels.end(), KoShapeConfigFactoryBase::compare);
+                std::sort(panels.begin(), panels.end(), KoShapeConfigFactoryBase::compare);
                 QList<KoShapeConfigWidgetBase*> widgets;
                 foreach(KoShapeConfigFactoryBase *panelFactory, panels) {
                     if (! panelFactory->showForShapeId(shape->shapeId()))
