@@ -23,10 +23,10 @@
 #include "KoShapeLoadingContext.h"
 #include <KoXmlReader.h>
 #include <KoXmlWriter.h>
-#include <KoGenStyle.h>
-#include <KoGenStyles.h>
 #include <KoXmlNS.h>
 
+#include <algorithm>
+
 KoShapeLayer::KoShapeLayer()
         : KoShapeContainer(new SimpleShapeContainerModel())
 {
@@ -62,7 +62,7 @@ QRectF KoShapeLayer::boundingRect() const
 void KoShapeLayer::saveOdf(KoShapeSavingContext & context) const
 {
     QList<KoShape*> shapes = this->shapes();
-    qSort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
+    std::sort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
 
     foreach(KoShape* shape, shapes) {
         shape->saveOdf(context);
