@@ -43,12 +43,12 @@ public:
     {
     }
 
-    ~SimpleCanvas()
+    ~SimpleCanvas() override
     {
         delete m_shapeManager;
     }
 
-    virtual void gridSize(qreal *horizontal, qreal *vertical) const
+    void gridSize(qreal *horizontal, qreal *vertical) const override
     {
         if (horizontal)
             *horizontal = 0;
@@ -56,52 +56,52 @@ public:
             *vertical = 0;
     };
 
-    virtual bool snapToGrid() const
+    bool snapToGrid() const override
     {
         return false;
     }
 
-    virtual void addCommand(KUndo2Command *)
+    void addCommand(KUndo2Command *) override
     {
     }
 
-    virtual KoShapeManager *shapeManager() const
+    KoShapeManager *shapeManager() const override
     {
         return m_shapeManager;
     }
 
-    virtual void updateCanvas(const QRectF&)
+    void updateCanvas(const QRectF&) override
     {
     }
 
-    virtual KoToolProxy *toolProxy() const
+    KoToolProxy *toolProxy() const override
     {
         return 0;
     }
 
-    virtual KoViewConverter *viewConverter() const
+    KoViewConverter *viewConverter() const override
     {
         return 0;
     }
 
-    virtual QWidget *canvasWidget()
+    QWidget *canvasWidget() override
     {
         return 0;
     }
 
-    virtual const QWidget *canvasWidget() const
+    const QWidget *canvasWidget() const override
     {
         return 0;
     }
 
-    virtual KoUnit unit() const
+    KoUnit unit() const override
     {
         return KoUnit(KoUnit::Point);
     }
 
-    virtual void updateInputMethodInfo() {}
+    void updateInputMethodInfo() override {}
 
-    void setCursor(const QCursor &) {}
+    void setCursor(const QCursor &) override {}
 
 private:
     KoShapeManager *m_shapeManager;
