@@ -32,6 +32,8 @@
 #include "KoXmlNS.h"
 #include "KoGenStyle.h"
 
+#include <FlakeDebug.h>
+
 #include <QTextCursor>
 #include <QTextDocument>
 
@@ -153,6 +155,9 @@ QString KoTosContainer::saveStyle(KoGenStyle &style, KoShapeSavingContext &conte
     }
 
     style.addProperty("draw:textarea-horizontal-align", horizontalAlignment);
+    // FIXME set these dependent on flags
+    style.addProperty("draw:auto-grow-height", "false");
+    style.addProperty("draw:auto-grow-width", "false");
 
     return KoShapeContainer::saveStyle(style, context);
 }
@@ -177,7 +182,7 @@ void KoTosContainer::setPlainText(const QString &text)
 {
     KoShape *textShape = this->textShape();
     if (textShape == 0) {
-        kWarning(30006) << "No text shape present in KoTosContainer";
+        warnFlake << "No text shape present in KoTosContainer";
         return;
     }
     KoTextShapeDataBase *shapeData = qobject_cast<KoTextShapeDataBase*>(textShape->userData());
@@ -209,7 +214,7 @@ void KoTosContainer::setTextAlignment(Qt::Alignment alignment)
 
     KoShape *textShape = this->textShape();
     if (textShape == 0) {
-        kWarning(30006) << "No text shape present in KoTosContainer";
+        warnFlake << "No text shape present in KoTosContainer";
         return;
     }
 
@@ -223,7 +228,7 @@ void KoTosContainer::setTextAlignment(Qt::Alignment alignment)
     bf.setAlignment(alignment & Qt::AlignHorizontal_Mask);
 
     QTextCursor cursor(shapeData->document());
-    cursor.setPosition(QTextCursor::End, QTextCursor::KeepAnchor);
+    cursor.movePosition(QTextCursor::End, QTextCursor::KeepAnchor);
     cursor.mergeBlockFormat(bf);
 
     d->alignment = alignment;
@@ -233,7 +238,7 @@ Qt::Alignment KoTosContainer::textAlignment() const
 {
     KoShape *textShape = this->textShape();
     if (textShape == 0) {
-        kWarning(30006) << "No text shape present in KoTosContainer";
+        warnFlake << "No text shape present in KoTosContainer";
         return Qt::AlignTop;
     }
 
@@ -255,9 +260,9 @@ void KoTosContainer::setPreferredTextRect(const QRectF &rect)
     Q_D(KoTosContainer);
     d->preferredTextRect = rect;
     KoShape *textShape = this->textShape();
-    //kDebug(30006) << rect << textShape << d->resizeBehavior;
+    //debugFlake << rect << textShape << d->resizeBehavior;
     if (d->resizeBehavior == TextFollowsPreferredTextRect && textShape) {
-        //kDebug(30006) << rect;
+        //debugFlake << rect;
         textShape->setPosition(rect.topLeft());
         textShape->setSize(rect.size());
     }
@@ -272,7 +277,7 @@ QRectF KoTosContainer::preferredTextRect() const
 KoShape *KoTosContainer::createTextShape(KoDocumentResourceManager *documentResources)
 {
     if (!documentResources) {
-        kWarning(30006) << "KoDocumentResourceManager not found";
+        warnFlake << "KoDocumentResourceManager not found";
         return 0;
     }
 
@@ -310,7 +315,7 @@ KoShape *KoTosContainer::createTextShape(KoDocumentResourceManager *documentReso
         // textShape->setZIndex(zIndex() + 1); // not needed as there as the text shape is the only sub shape
         delegates << textShape;
     } else {
-        kWarning(30006) << "Text shape factory not found";
+        warnFlake << "Text shape factory not found";
     }
     setToolDelegates(delegates);
     return textShape;
