@@ -32,12 +32,12 @@ class FLAKE_EXPORT KoEventActionAddCommand : public KUndo2Command
 {
 public:
     KoEventActionAddCommand(KoShape *shape, KoEventAction *eventAction, KUndo2Command *parent = 0);
-    virtual ~KoEventActionAddCommand();
+    ~KoEventActionAddCommand() override;
 
     /// redo the command
-    void redo();
+    void redo() override;
     /// revert the actions done in redo
-    void undo();
+    void undo() override;
 
 private:
     KoEventActionAddCommandPrivate * const d;
