@@ -29,11 +29,12 @@
 
 
 /// The undo / redo command for path point moving.
-class FLAKE_TEST_EXPORT KoPathControlPointMoveCommand : public KUndo2Command
+class FLAKE_EXPORT KoPathControlPointMoveCommand : public KUndo2Command
 {
 public:
     /**
      * Command to move one control path point.
+     * @param pointData the point data
      * @param offset the offset by which the point is moved in document coordinates
      * @param pointType the type of the point to move
      * @param parent the parent command used for macro commands
@@ -41,9 +42,9 @@ public:
     KoPathControlPointMoveCommand(const KoPathPointData &pointData, const QPointF &offset,
             KoPathPoint::PointType pointType, KUndo2Command *parent = 0);
     /// redo the command
-    void redo();
+    void redo() override;
     /// revert the actions done in redo
-    void undo();
+    void undo() override;
 private:
     KoPathPointData m_pointData;
     // the offset in shape coordinates
