@@ -45,16 +45,16 @@ public:
     /**
      * Command to align a set of shapes in a rect
      * @param shapes a set of all the shapes that should be aligned
-     * @param align the aligment type
+     * @param align the alignment type
      * @param boundingRect the rect the shape will be aligned in
      * @param parent the parent command used for macro commands
      */
     KoShapeAlignCommand(const QList<KoShape*> &shapes, Align align, const QRectF &boundingRect, KUndo2Command *parent = 0);
-    virtual ~KoShapeAlignCommand();
+    ~KoShapeAlignCommand() override;
     /// redo the command
-    virtual void redo();
+    void redo() override;
     /// revert the actions done in redo
-    virtual void undo();
+    void undo() override;
 private:
     class Private;
     Private * const d;
