@@ -33,7 +33,7 @@ class KoShape;
 class FLAKE_EXPORT KoShapeDistributeCommand : public KUndo2Command
 {
 public:
-    /// The different options to ditribute with this command
+    /// The different options to distribute with this command
     enum Distribute {
         HorizontalCenterDistribution,   ///< Horizontal centered
         HorizontalGapsDistribution,     ///< Horizontal Gaps
@@ -53,11 +53,11 @@ public:
      */
     KoShapeDistributeCommand(const QList<KoShape*> &shapes, Distribute distribute,
             const QRectF &boundingRect, KUndo2Command *parent = 0);
-    virtual ~KoShapeDistributeCommand();
+    ~KoShapeDistributeCommand() override;
     /// redo the command
-    virtual void redo();
+    void redo() override;
     /// revert the actions done in redo
-    virtual void undo();
+    void undo() override;
 private:
 
     class Private;
