@@ -24,6 +24,10 @@
 #include "KoPathPointData.h"
 #include "KoPathSegment.h"
 
+#include <QTest>
+
+#include <algorithm>
+
 void TestPathShape::close()
 {
     KoPathShape path;
@@ -740,7 +744,7 @@ void TestPathShape::koPathPointDataLess()
     l.push_back(v[3]);
     l.push_back(v[4]);
 
-    qSort(l.begin(), l.end());
+    std::sort(l.begin(), l.end());
     for (int i = 0; i < v.size(); ++i) {
         KoPathPointData ld = l.at(i);
         KoPathPointData vd = v[i];
@@ -781,4 +785,3 @@ void TestPathShape::closeMerge()
 }
 
 QTEST_MAIN(TestPathShape)
-#include <TestPathShape.moc>
