@@ -22,11 +22,12 @@
 #include <KoShapeReorderCommand.h>
 #include <KoShapeManager.h>
 
-#include <kcomponentdata.h>
+#include <QTest>
+
+#include <algorithm>
 
 TestShapeReorderCommand::TestShapeReorderCommand()
 {
-    KComponentData componentData("TestShapeReorderCommand");    // we need an instance for the canvas
 }
 
 TestShapeReorderCommand::~TestShapeReorderCommand()
@@ -54,7 +55,7 @@ void TestShapeReorderCommand::testZIndexSorting()
     shapes.append(&shape4);
     shapes.append(&shape5);
 
-    qSort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
+    std::sort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
 
     QCOMPARE(shapes.indexOf(&shape1), 1);
     QCOMPARE(shapes.indexOf(&shape2), 3);
@@ -87,7 +88,7 @@ void TestShapeReorderCommand::testRunThroughSorting()
     shapes.append(&shape4);
     shapes.append(&shape5);
 
-    qSort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
+    std::sort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
 
     QCOMPARE(shapes.indexOf(&shape1), 2);
     QCOMPARE(shapes.indexOf(&shape2), 0);
@@ -142,7 +143,7 @@ void TestShapeReorderCommand::testParentChildSorting()
     shapes.append(container2);
     shapes.append(container3);
 
-    qSort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
+    std::sort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
 
 /* This is the expected result
 s3  0 fg
@@ -195,7 +196,7 @@ void TestShapeReorderCommand::testBringToFront()
     MockCanvas canvas;
     KoShapeManager manager(&canvas, shapes);
 
-    qSort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
+    std::sort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
     QCOMPARE(shapes.indexOf(&shape1), 0);
     QCOMPARE(shapes.indexOf(&shape2), 1);
     QCOMPARE(shapes.indexOf(&shape3), 2);
@@ -206,7 +207,7 @@ void TestShapeReorderCommand::testBringToFront()
     KUndo2Command * cmd = KoShapeReorderCommand::createCommand(selectedShapes, &manager, KoShapeReorderCommand::BringToFront);
     cmd->redo();
 
-    qSort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
+    std::sort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
     QCOMPARE(shapes.indexOf(&shape2), 0);
     QCOMPARE(shapes.indexOf(&shape3), 1);
     QCOMPARE(shapes.indexOf(&shape1), 2);
@@ -232,7 +233,7 @@ void TestShapeReorderCommand::testSendToBack()
     MockCanvas canvas;
     KoShapeManager manager(&canvas, shapes);
 
-    qSort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
+    std::sort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
     QCOMPARE(shapes.indexOf(&shape1), 0);
     QCOMPARE(shapes.indexOf(&shape2), 1);
     QCOMPARE(shapes.indexOf(&shape3), 2);
@@ -243,7 +244,7 @@ void TestShapeReorderCommand::testSendToBack()
     KUndo2Command * cmd = KoShapeReorderCommand::createCommand(selectedShapes, &manager, KoShapeReorderCommand::SendToBack);
     cmd->redo();
 
-    qSort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
+    std::sort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
     QCOMPARE(shapes.indexOf(&shape3), 0);
     QCOMPARE(shapes.indexOf(&shape1), 1);
     QCOMPARE(shapes.indexOf(&shape2), 2);
@@ -269,7 +270,7 @@ void TestShapeReorderCommand::testMoveUp()
     MockCanvas canvas;
     KoShapeManager manager(&canvas, shapes);
 
-    qSort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
+    std::sort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
     QCOMPARE(shapes.indexOf(&shape1), 0);
     QCOMPARE(shapes.indexOf(&shape2), 1);
     QCOMPARE(shapes.indexOf(&shape3), 2);
@@ -280,7 +281,7 @@ void TestShapeReorderCommand::testMoveUp()
     KUndo2Command * cmd = KoShapeReorderCommand::createCommand(selectedShapes, &manager, KoShapeReorderCommand::RaiseShape);
     cmd->redo();
 
-    qSort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
+    std::sort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
     QCOMPARE(shapes.indexOf(&shape2), 0);
     QCOMPARE(shapes.indexOf(&shape1), 1);
     QCOMPARE(shapes.indexOf(&shape3), 2);
@@ -306,7 +307,7 @@ void TestShapeReorderCommand::testMoveDown()
     MockCanvas canvas;
     KoShapeManager manager(&canvas, shapes);
 
-    qSort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
+    std::sort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
     QCOMPARE(shapes.indexOf(&shape1), 0);
     QCOMPARE(shapes.indexOf(&shape2), 1);
     QCOMPARE(shapes.indexOf(&shape3), 2);
@@ -317,7 +318,7 @@ void TestShapeReorderCommand::testMoveDown()
     KUndo2Command * cmd = KoShapeReorderCommand::createCommand(selectedShapes, &manager, KoShapeReorderCommand::LowerShape);
     cmd->redo();
 
-    qSort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
+    std::sort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
     QCOMPARE(shapes.indexOf(&shape2), 0);
     QCOMPARE(shapes.indexOf(&shape1), 1);
     QCOMPARE(shapes.indexOf(&shape3), 2);
@@ -375,7 +376,7 @@ void TestShapeReorderCommand::testMoveUpOverlapping()
 
 void TestShapeReorderCommand::testMoveDownOverlapping()
 {
-#if 0 // disable a current alogrithm does not yet support this
+#if 0 // disable a current algorithm does not yet support this
     MockShape shape1, shape2, shape3, shape4, shape5;
     
     shape1.setSize(QSizeF(100, 100));
@@ -450,7 +451,7 @@ void TestShapeReorderCommand::testSendToBackChildren()
     MockCanvas canvas;
     KoShapeManager manager(&canvas, shapes);
     
-    qSort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
+    std::sort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
     QCOMPARE(shapes.indexOf(container), 0); // atm the parent is always lower than its children
     QCOMPARE(shapes.indexOf(shape1), 1);
     QCOMPARE(shapes.indexOf(shape2), 2);
@@ -463,7 +464,7 @@ void TestShapeReorderCommand::testSendToBackChildren()
     cmd->redo();
     delete cmd;
     
-    qSort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
+    std::sort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
     QCOMPARE(shapes.indexOf(container), 0); // atm the parent is always lower than its children
     QCOMPARE(shapes.indexOf(shape3), 1);
     QVERIFY(shape3->zIndex() < shape1->zIndex());
@@ -478,7 +479,7 @@ void TestShapeReorderCommand::testSendToBackChildren()
     cmd->redo();
     delete cmd;
     
-    qSort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
+    std::sort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
     QCOMPARE(shapes.indexOf(container), 0); // atm the parent is always lower than its children
     QCOMPARE(shapes.indexOf(shape2), 1);
     QVERIFY(shape2->zIndex() < shape3->zIndex());
@@ -493,7 +494,7 @@ void TestShapeReorderCommand::testSendToBackChildren()
     cmd->redo();
     delete cmd;
     
-    qSort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
+    std::sort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
     QCOMPARE(shapes.indexOf(container), 0); // atm the parent is always lower than its children
     QCOMPARE(shapes.indexOf(shape1), 1);
     QVERIFY(shape1->zIndex() < shape2->zIndex());
@@ -522,7 +523,7 @@ void TestShapeReorderCommand::testNoCommand()
     MockCanvas canvas;
     KoShapeManager manager(&canvas, shapes);
 
-    qSort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
+    std::sort(shapes.begin(), shapes.end(), KoShape::compareShapeZIndex);
     QCOMPARE(shapes.indexOf(&shape1), 0);
     QCOMPARE(shapes.indexOf(&shape2), 1);
     QCOMPARE(shapes.indexOf(&shape3), 2);
@@ -561,4 +562,3 @@ void TestShapeReorderCommand::testNoCommand()
 }
 
 QTEST_MAIN(TestShapeReorderCommand)
-#include "TestShapeReorderCommand.moc"
