@@ -43,57 +43,57 @@ class FLAKE_EXPORT KoPathTool : public KoToolBase
     Q_OBJECT
 public:
     explicit KoPathTool(KoCanvasBase *canvas);
-    ~KoPathTool();
+    ~KoPathTool() override;
 
     /// reimplemented
-    virtual void paint(QPainter &painter, const KoViewConverter &converter);
+    void paint(QPainter &painter, const KoViewConverter &converter) override;
 
     /// reimplemented
-    virtual void repaintDecorations();
+    void repaintDecorations() override;
 
     /// reimplemented
-    virtual void mousePressEvent(KoPointerEvent *event);
+    void mousePressEvent(KoPointerEvent *event) override;
     /// reimplemented
-    virtual void mouseMoveEvent(KoPointerEvent *event);
+    void mouseMoveEvent(KoPointerEvent *event) override;
     /// reimplemented
-    virtual void mouseReleaseEvent(KoPointerEvent *event);
+    void mouseReleaseEvent(KoPointerEvent *event) override;
     /// reimplemented
-    virtual void keyPressEvent(QKeyEvent *event);
+    void keyPressEvent(QKeyEvent *event) override;
     /// reimplemented
-    virtual void keyReleaseEvent(QKeyEvent *event);
+    void keyReleaseEvent(QKeyEvent *event) override;
     /// reimplemented
-    virtual void mouseDoubleClickEvent(KoPointerEvent *event);
+    void mouseDoubleClickEvent(KoPointerEvent *event) override;
     /// reimplemented
-    virtual void activate(ToolActivation toolActivation, const QSet<KoShape*> &shapes);
+    void activate(ToolActivation toolActivation, const QSet<KoShape*> &shapes) override;
     /// reimplemented
-    virtual void deactivate();
+    void deactivate() override;
 
     /// reimplemented
-    virtual void deleteSelection();
+    void deleteSelection() override;
 
     /// reimplemented
-    virtual KoToolSelection* selection();
+    KoToolSelection* selection() override;
 
     /// repaints the specified rect
     void repaint(const QRectF &repaintRect);
 
 public Q_SLOTS:
-    void documentResourceChanged(int key, const QVariant & res);
+    void documentResourceChanged(int key, const QVariant & res) override;
 
 Q_SIGNALS:
     void typeChanged(int types);
     void pathChanged(KoPathShape* path); // TODO this is unused, can we remove this one?
 protected:
     /// reimplemented
-    virtual QList<QPointer<QWidget> >  createOptionWidgets();
+    QList<QPointer<QWidget> >  createOptionWidgets() override;
 
-private:
+protected:
     struct PathSegment;
 
     void updateOptionsWidget();
     PathSegment* segmentAtPoint(const QPointF &point);
 
-private Q_SLOTS:
+protected Q_SLOTS:
     void pointTypeChanged(QAction *type);
     void insertPoints();
     void removePoints();
@@ -114,15 +114,14 @@ protected:
     KoPathToolSelection m_pointSelection; ///< the point selection
     QCursor m_selectCursor;
 
-private:
-
+protected:
     KoPathToolHandle * m_activeHandle;       ///< the currently active handle
     int m_handleRadius;    ///< the radius of the control point handles
     uint m_grabSensitivity; ///< the grab sensitivity
     QPointF m_lastPoint; ///< needed for interaction strategy
     PathSegment *m_activeSegment;
 
-    // make a frind so that it can test private member/methods
+    // make a frind so that it can test protected member/methods
     friend class TestPathTool;
 
     KoInteractionStrategy *m_currentStrategy; ///< the rubber selection strategy
