@@ -22,14 +22,14 @@
 #include "KoPathShape.h"
 
 #include <KoIcon.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 
 KoPathToolFactory::KoPathToolFactory()
         : KoToolFactoryBase("PathToolFactoryId")
 {
     setToolTip(i18n("Path editing"));
     setToolType(dynamicToolType());
-    setIconName(koIconNameCStr("editpath"));
+    setIconName(koIconName("editpath"));
     setPriority(2);
     setActivationShapeId(KoPathShapeId);
 }
