@@ -41,17 +41,17 @@ public:
      * Constructor that initiates the rubber select.
      * A rubber select is basically rectangle area that the user drags out
      * from @p clicked to a point later provided in the handleMouseMove() continuously
-     * showing a semi-transarant 'rubber-mat' over the objects it is about to select.
+     * showing a semi-transparent 'rubber-mat' over the objects it is about to select.
      * @param tool the parent tool which controls this strategy
      * @param clicked the initial point that the user depressed (in pt).
      * @param useSnapToGrid use the snap-to-grid settings while doing the rubberstamp.
      */
     KoShapeRubberSelectStrategy(KoToolBase *tool, const QPointF &clicked, bool useSnapToGrid = false);
 
-    virtual void paint(QPainter &painter, const KoViewConverter &converter);
-    virtual void handleMouseMove(const QPointF &mouseLocation, Qt::KeyboardModifiers modifiers);
-    virtual KUndo2Command *createCommand();
-    virtual void finishInteraction(Qt::KeyboardModifiers modifiers);
+    void paint(QPainter &painter, const KoViewConverter &converter) override;
+    void handleMouseMove(const QPointF &mouseLocation, Qt::KeyboardModifiers modifiers) override;
+    KUndo2Command *createCommand() override;
+    void finishInteraction(Qt::KeyboardModifiers modifiers) override;
 
 protected:
     /// constructor
