@@ -224,7 +224,7 @@ bool KUndo2Command::mergeWith(const KUndo2Command *command)
     Applies a change to the document. This function must be implemented in
     the derived class. Calling KUndo2QStack::push(),
     KUndo2QStack::undo() or KUndo2QStack::redo() from this function leads to
-    undefined beahavior.
+    undefined behavior.
 
     The default implementation calls redo() on all child commands.
 
@@ -242,7 +242,7 @@ void KUndo2Command::redo()
     the document should be the same as before redo() was called. This function must
     be implemented in the derived class. Calling KUndo2QStack::push(),
     KUndo2QStack::undo() or KUndo2QStack::redo() from this function leads to
-    undefined beahavior.
+    undefined behavior.
 
     The default implementation calls undo() on all child commands in reverse order.
 
@@ -415,6 +415,10 @@ void KUndo2Command::setExtraData(KUndo2CommandExtraData *data)
     d->extraData.reset(data);
 }
 
+void KUndo2Command::addCommand(KUndo2Command *command)
+{
+    d->child_list.append(command);
+}
 
 #endif // QT_NO_UNDOCOMMAND
 
@@ -741,7 +745,7 @@ bool KUndo2QStack::push(KUndo2Command *cmd)
      *Every time a command is pushed -- it checks whether the command pushed was pushed after T1 seconds of the last merged command
      *Then the merging begins with each group depending on the time in between each command (T2).
      *
-     *@TODO : Currently it is not able to merge two merged commands together.
+     *TODO : Currently it is not able to merge two merged commands together.
     */
     if (!macro && m_command_list.size() > 1 && cmd->timedId() != -1 && m_useCumulativeUndoRedo) {
         KUndo2Command* lastcmd = m_command_list.last();
@@ -1129,12 +1133,10 @@ QAction *KUndo2QStack::createRedoAction(QObject *parent) const
     beginMacro() must have a matching call to endMacro().
 
     While a macro is composed, the stack is disabled. This means that:
-    \list
-    \i indexChanged() and cleanChanged() are not emitted,
-    \i canUndo() and canRedo() return false,
-    \i calling undo() or redo() has no effect,
-    \i the undo/redo actions are disabled.
-    \endlist
+    \li indexChanged() and cleanChanged() are not emitted,
+    \li canUndo() and canRedo() return false,
+    \li calling undo() or redo() has no effect,
+    \li the undo/redo actions are disabled.
 
     The stack becomes enabled and appropriate signals are emitted when endMacro()
     is called for the outermost macro.
