@@ -23,6 +23,7 @@
 #include <QApplication>
 
 #include "komain_export.h"
+#include "KoMainWindow.h"
 
 class KoPart;
 
@@ -73,12 +74,12 @@ public:
     /**
      *  Destructor.
      */
-    virtual ~KoApplication();
+    ~KoApplication() override;
 
     /**
      * Call this to start the application.
      *
-     * Parses command line arguments and creates the initial main windowss and docs
+     * Parses command line arguments and creates the initial main windows and docs
      * from them (or an empty doc if no cmd-line argument is specified ).
      *
      * You must call this method directly before calling QApplication::exec.
@@ -104,7 +105,7 @@ public:
     QStringList mimeFilter(KoFilterManager::Direction direction) const;
 
     // Overridden to handle exceptions from event handlers.
-    bool notify(QObject *receiver, QEvent *event);
+    bool notify(QObject *receiver, QEvent *event) override;
 
     /**
      * Returns the current application object.
@@ -135,6 +136,11 @@ Q_SIGNALS:
      */
     void documentClosed(const QString &ref);
 
+private Q_SLOTS:
+    void benchmarkLoadingFinished();
+    void slotFilePrint(KoMainWindow *view);
+    void slotExportToPdf(KoMainWindow *view);
+
 protected:
 
     // Current application object.
