@@ -105,26 +105,26 @@ public:
     {
     }
 
-    ~DocumentProgressProxy() {
+    ~DocumentProgressProxy() override {
         // signal that the job is done
         setValue(-1);
     }
 
-    int maximum() const {
+    int maximum() const override {
         return 100;
     }
 
-    void setValue(int value) {
+    void setValue(int value) override {
         if (m_mainWindow) {
             m_mainWindow->slotProgress(value);
         }
     }
 
-    void setRange(int /*minimum*/, int /*maximum*/) {
+    void setRange(int /*minimum*/, int /*maximum*/) override {
 
     }
 
-    void setFormat(const QString &/*format*/) {
+    void setFormat(const QString &/*format*/) override {
 
     }
 };
@@ -162,7 +162,6 @@ public:
         backupFile(true),
         backupPath(QString()),
         doNotSaveExtDoc(false),
-        storeInternal(false),
         isLoading(false),
         undoStack(0),
         modified(false),
@@ -223,7 +222,6 @@ public:
     bool backupFile;
     QString backupPath;
     bool doNotSaveExtDoc; // makes it possible to save only internally stored child documents
-    bool storeInternal; // Store this doc internally even if url is external
     bool isLoading; // True while loading (openUrl is async)
 
     QList<KoVersionInfo> versionInfo;
@@ -1013,6 +1011,8 @@ QString KoDocument::checkImageMimeTypes(const QString &mimeType, const QUrl &url
     imageMimeTypes << "image/jpeg"
                    << "image/x-psd" << "image/photoshop" << "image/x-photoshop" << "image/x-vnd.adobe.photoshop" << "image/vnd.adobe.photoshop"
                    << "image/x-portable-pixmap" << "image/x-portable-graymap" << "image/x-portable-bitmap"
+                   << "application/illustrator"
+                   << "application/photoshop"
                    << "application/pdf"
                    << "image/x-exr"
                    << "image/x-xcf"
@@ -1180,7 +1180,7 @@ bool KoDocument::importDocument(const QUrl &_url)
 {
     bool ret;
 
-    debugMain << "url=" << _url.url();
+    debugMain << Q_FUNC_INFO << "url=" << _url.url();
     d->isImporting = true;
 
     // open...
@@ -1202,7 +1202,7 @@ bool KoDocument::importDocument(const QUrl &_url)
 
 bool KoDocument::openUrl(const QUrl &_url)
 {
-    debugMain << "url=" << _url.url();
+    debugMain << Q_FUNC_INFO << "url=" << _url.url();
     d->lastErrorMessage.clear();
 
     // Reimplemented, to add a check for autosave files and to improve error reporting
@@ -2037,7 +2037,7 @@ void KoDocument::setModified(bool mod)
     if (isAutosaving())   // ignore setModified calls due to autosaving
         return;
 
-    if ( !d->readwrite && d->modified ) {
+    if ( !d->readwrite && mod ) {
         qCritical(/*1000*/) << "Can't set a read-only document to 'modified' !" << endl;
         return;
     }
@@ -2260,18 +2260,6 @@ QString KoDocument::backupPath()const
     return d->backupPath;
 }
 
-
-bool KoDocument::storeInternal() const
-{
-    return d->storeInternal;
-}
-
-void KoDocument::setStoreInternal(bool i)
-{
-    d->storeInternal = i;
-    //debugMain<<"="<<d->storeInternal<<" doc:"<<url().url();
-}
-
 bool KoDocument::hasExternURL() const
 {
     return    !url().scheme().isEmpty()
