@@ -23,7 +23,6 @@
 #include "KoDocumentSectionToolTip.h"
 #include "KoDocumentSectionView.h"
 
-#include <QtDebug>
 #include <QApplication>
 #include <QKeyEvent>
 #include <QLineEdit>
@@ -34,7 +33,7 @@
 #include <QStyle>
 #include <QStyleOptionViewItem>
 
-#include <klocale.h>
+#include <klocalizedstring.h>
 
 class KoDocumentSectionDelegate::Private
 {
@@ -82,7 +81,7 @@ void KoDocumentSectionDelegate::paint(QPainter *p, const QStyleOptionViewItem &o
 {
     p->save();
     {
-        QStyleOptionViewItemV4 option = getOptions(o, index);
+        QStyleOptionViewItem option = getOptions(o, index);
         QStyle *style = option.widget ? option.widget->style() : QApplication::style();
         style->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, p, option.widget);
 
@@ -272,9 +271,9 @@ bool KoDocumentSectionDelegate::eventFilter(QObject *object, QEvent *event)
 // PRIVATE
 
 
-QStyleOptionViewItemV4 KoDocumentSectionDelegate::getOptions(const QStyleOptionViewItem &o, const QModelIndex &index)
+QStyleOptionViewItem KoDocumentSectionDelegate::getOptions(const QStyleOptionViewItem &o, const QModelIndex &index)
 {
-    QStyleOptionViewItemV4 option = o;
+    QStyleOptionViewItem option = o;
     QVariant v = index.data(Qt::FontRole);
     if (v.isValid()) {
         option.font = v.value<QFont>();
@@ -512,7 +511,7 @@ void KoDocumentSectionDelegate::drawProgressBar(QPainter *p, const QStyleOptionV
         {
             p->setClipRect(r);
             QStyle* style = QApplication::style();
-            QStyleOptionProgressBarV2 opt;
+            QStyleOptionProgressBar opt;
 
             opt.minimum = 0;
             opt.maximum = 100;
@@ -528,6 +527,3 @@ void KoDocumentSectionDelegate::drawProgressBar(QPainter *p, const QStyleOptionV
         p->restore();
     }
 }
-
-
-#include <KoDocumentSectionDelegate.moc>
