@@ -23,13 +23,13 @@ Boston, MA 02110-1301, USA.
 
 #include "KoFilterManager.h"
 
-#include <kurl.h>
-#include <kdialog.h>
+#include <QUrl>
+#include <KoDialog.h>
 #include <KoProgressUpdater.h>
 
 #include <QString>
 #include <QStringList>
-#include <QWeakPointer>
+#include <QPointer>
 
 class QListWidget;
 
@@ -38,7 +38,7 @@ class Q_DECL_HIDDEN KoFilterManager::Private
 public:
     bool batch;
     QByteArray importMimeType;
-    QWeakPointer<KoProgressUpdater> progressUpdater;
+    QPointer<KoProgressUpdater> progressUpdater;
 
     Private(KoProgressUpdater *progressUpdater_ = 0)
         : progressUpdater(progressUpdater_)
@@ -47,14 +47,14 @@ public:
 
 };
 
-class KoFilterChooser : public KDialog
+class KoFilterChooser : public KoDialog
 {
     Q_OBJECT
 
 public:
     KoFilterChooser(QWidget *parent, const QStringList &mimeTypes,
-                    const QString &nativeFormat = QString(), const KUrl &url = KUrl());
-    ~KoFilterChooser();
+                    const QString &nativeFormat = QString(), const QUrl &url = QUrl());
+    ~KoFilterChooser() override;
 
     QString filterSelected();
 
