@@ -143,6 +143,7 @@ public:
         m_activePart = 0;
 
         noCleanup = false;
+        openingDocument = false;
     }
 
     ~KoMainWindowPrivate() {
@@ -174,7 +175,7 @@ public:
     QByteArray nativeMimeType;
 
     KoMainWindow *parent;
-    KoDocument *rootDocument;
+    QPointer<KoDocument> rootDocument;
     QList<KoView*> rootViews;
 
     // PartManager
@@ -243,6 +244,7 @@ public:
     KHelpMenu *m_helpMenu;
 
     bool noCleanup;
+    bool openingDocument;
 
 };
 
@@ -250,9 +252,6 @@ KoMainWindow::KoMainWindow(const QByteArray &nativeMimeType, const KoComponentDa
     : KXmlGuiWindow()
     , d(new KoMainWindowPrivate(nativeMimeType, componentData, this))
 {
-#ifdef Q_OS_MAC
-    setUnifiedTitleAndToolBarOnMac(true);
-#endif
     setStandardToolBarMenuEnabled(true);
 
     setTabPosition(Qt::AllDockWidgetAreas, QTabWidget::North);
@@ -707,7 +706,7 @@ KoView *KoMainWindow::rootView() const
 {
     if (d->rootViews.indexOf(d->activeView) != -1)
         return d->activeView;
-    return d->rootViews.first();
+    return d->rootViews.empty() ? nullptr : d->rootViews.first();
 }
 
 bool KoMainWindow::openDocument(const QUrl &url)
@@ -755,12 +754,14 @@ bool KoMainWindow::openDocumentInternal(const QUrl &url, KoPart *newpart, KoDocu
     connect(newdoc, SIGNAL(sigProgress(int)), this, SLOT(slotProgress(int)));
     connect(newdoc, SIGNAL(completed()), this, SLOT(slotLoadCompleted()));
     connect(newdoc, SIGNAL(canceled(QString)), this, SLOT(slotLoadCanceled(QString)));
+    d->openingDocument = true;
     newpart->addMainWindow(this);   // used by openUrl
     bool openRet = (!isImporting()) ? newdoc->openUrl(url) : newdoc->importDocument(url);
     if (!openRet) {
         newpart->removeMainWindow(this);
         delete newdoc;
         delete newpart;
+        d->openingDocument = false;
         return false;
     }
     updateReloadFileAction(newdoc);
@@ -783,6 +784,7 @@ void KoMainWindow::slotLoadCompleted()
     if (d->rootDocument && d->rootDocument->isEmpty()) {
         // Replace current empty document
         setRootDocument(newdoc);
+        emit loadCompleted(this);
     } else if (d->rootDocument && !d->rootDocument->isEmpty()) {
         // Open in a new main window
         // (Note : could create the main window first and the doc next for this
@@ -791,15 +793,18 @@ void KoMainWindow::slotLoadCompleted()
         s->show();
         newpart->removeMainWindow(this);
         s->setRootDocument(newdoc, newpart);
+        emit loadCompleted(s);
     } else {
         // We had no document, set the new one
         setRootDocument(newdoc);
+        emit loadCompleted(this);
     }
+
     slotProgress(-1);
     disconnect(newdoc, SIGNAL(sigProgress(int)), this, SLOT(slotProgress(int)));
     disconnect(newdoc, SIGNAL(completed()), this, SLOT(slotLoadCompleted()));
     disconnect(newdoc, SIGNAL(canceled(QString)), this, SLOT(slotLoadCanceled(QString)));
-    emit loadCompleted();
+    d->openingDocument = false;
 }
 
 void KoMainWindow::slotLoadCanceled(const QString & errMsg)
@@ -814,6 +819,8 @@ void KoMainWindow::slotLoadCanceled(const QString & errMsg)
     disconnect(doc, SIGNAL(sigProgress(int)), this, SLOT(slotProgress(int)));
     disconnect(doc, SIGNAL(completed()), this, SLOT(slotLoadCompleted()));
     disconnect(doc, SIGNAL(canceled(QString)), this, SLOT(slotLoadCanceled(QString)));
+    d->openingDocument = false;
+    emit loadCanceled();
 }
 
 void KoMainWindow::slotSaveCanceled(const QString &errMsg)
@@ -1125,7 +1132,9 @@ bool KoMainWindow::saveDocument(bool saveas, bool silent, int specialOutputFlag)
 
 void KoMainWindow::closeEvent(QCloseEvent *e)
 {
-    if(rootDocument() && rootDocument()->isLoading()) {
+    // If we are in the process of opening a new document, rootDocument() may not have been set yet,
+    // so we must prevent closing to avoid crash.
+    if(d->openingDocument || (rootDocument() && rootDocument()->isLoading())) {
         e->setAccepted(false);
         return;
     }
@@ -1659,6 +1668,7 @@ void KoMainWindow::slotProgress(int value)
     if (!d->progress.isNull()) {
         d->progress->setValue(value);
     }
+    locker.unlock();
     qApp->processEvents();
 }
 
@@ -1824,7 +1834,7 @@ QDockWidget* KoMainWindow::createDockWidget(KoDockFactoryBase* factory)
             dockWidget->widget()->layout()->setContentsMargins(1, 1, 1, 1);
 
         Qt::DockWidgetArea side = Qt::RightDockWidgetArea;
-        bool visible = true;
+        bool visible = factory->defaultVisible();
 
         switch (factory->defaultDockPosition()) {
         case KoDockFactoryBase::DockTornOff:
