@@ -40,10 +40,11 @@ public:
     /**
      * Constructor
      * @param parent the parent widget
-     * @param templateType the template-type (group) that should be selected on creation.
+     * @param mimeFilter the MIME type filter that should be selected on creation.
+     * @param templatesResourcePath the path for template resources.
      */
     KoOpenPane(QWidget *parent, const QStringList& mimeFilter, const QString& templatesResourcePath = QString());
-    virtual ~KoOpenPane();
+    ~KoOpenPane() override;
 
     QTreeWidgetItem* addPane(const QString &title, const QString &iconName, QWidget *widget, int sortWeight);
     QTreeWidgetItem* addPane(const QString& title, const QPixmap& icon, QWidget* widget, int sortWeight);
@@ -89,8 +90,8 @@ protected:
     void initTemplates(const QString& templatesResourcePath);
 
     // QWidget overrides
-    virtual void dragEnterEvent(QDragEnterEvent * event);
-    virtual void dropEvent(QDropEvent * event);
+    void dragEnterEvent(QDragEnterEvent * event) override;
+    void dropEvent(QDropEvent * event) override;
 
 private:
     QStringList m_mimeFilter;
