@@ -22,12 +22,11 @@
 #ifndef koTemplateCreateDia_h
 #define koTemplateCreateDia_h
 
-#include <kdialog.h>
+#include <KoDialog.h>
 #include "komain_export.h"
 
 class QString;
 class QPixmap;
-class KComponentData;
 class KoDocument;
 class KoTemplateCreateDiaPrivate;
 
@@ -37,18 +36,17 @@ class KoTemplateCreateDiaPrivate;
  *
  ****************************************************************************/
 
-class KOMAIN_EXPORT KoTemplateCreateDia : public KDialog
+class KOMAIN_EXPORT KoTemplateCreateDia : public KoDialog
 {
     Q_OBJECT
 
 private:
-    KoTemplateCreateDia( const QString &templatesResourcePath, const KComponentData &instance,
+    KoTemplateCreateDia( const QString &templatesResourcePath,
                          const QString &filePath, const QPixmap &thumbnail, QWidget *parent=0 );
-    ~KoTemplateCreateDia();
+    ~KoTemplateCreateDia() override;
 
 public:
     static void createTemplate(const QString &templatesResourcePath, const char *suffix,
-                               const KComponentData &componentData,
                                KoDocument *document, QWidget *parent = 0);
 
 private Q_SLOTS:
