@@ -23,8 +23,6 @@
 
 #include <QList>
 #include <QStringList>
-#include <QPixmap>
-#include <kcomponentdata.h>
 #include "komain_export.h"
 
 class KoTemplate;
