@@ -40,7 +40,7 @@ class QDropEvent;
 class QPrintDialog;
 
 /**
- * This class is used to display a @ref KoDocument.
+ * This class is used to display a KoDocument.
  *
  * Multiple views can be attached to one document at a time.
  */
@@ -54,8 +54,9 @@ public:
      * since the Calligra components come with their own view classes which inherit
      * KoView.
      *
-     * The standard way to retrieve a KoView is to call @ref KoPart::createView.
+     * The standard way to retrieve a KoView is to call KoPart::createView.
      *
+     * @param part     is the KoPart for the document.
      * @param document is the document which should be displayed in this view. This pointer
      *                 must not be zero.
      * @param parent   parent widget for this view.
@@ -65,27 +66,27 @@ public:
     /**
      * Destroys the view and unregisters at the document.
      */
-    virtual ~KoView();
+    ~KoView() override;
 
     // QWidget overrides
 protected:
 
-    virtual void dragEnterEvent(QDragEnterEvent * event);
+    void dragEnterEvent(QDragEnterEvent * event) override;
 
     /**
      * dropEvent by default calls addImages. Your KoView subclass might
      * override dropEvent and if your app can also handle images, call this
      * method.
      */
-    virtual void dropEvent(QDropEvent * event);
+    void dropEvent(QDropEvent * event) override;
 
     // KoView api
 
     /**
      * Adds the given list of QImages as imageshapes to the view's document.
      *
-     * @param imageList: a list of QImages that can be inserted
-     * @param insertPosition: the position in screen pixels where the images
+     * @param imageList a list of QImages that can be inserted
+     * @param insertAt the position in screen pixels where the images
      * can be inserted.
      */
     virtual void addImages(const QVector<QImage> &imageList, const QPoint &insertAt);
