@@ -108,7 +108,7 @@ int KoColumns::parseSeparatorHeight(const QString &value)
     if (value.endsWith(QLatin1Char('%'))) {
         bool ok = false;
         // try to convert
-        result = value.left(value.length()-1).toInt(&ok);
+        result = value.leftRef(value.length()-1).toInt(&ok);
         // reset to 100% if conversion failed (which sets result to 0)
         if (! ok) {
             result = defaultSeparatorHeight;
@@ -145,7 +145,7 @@ int KoColumns::parseRelativeWidth(const QString &value)
     if (value.endsWith(QLatin1Char('*'))) {
         bool ok = false;
         // try to convert
-        result = value.left(value.length()-1).toInt(&ok);
+        result = value.leftRef(value.length()-1).toInt(&ok);
         if (! ok) {
             result = 0;
         }
@@ -231,7 +231,7 @@ void KoColumns::loadOdf(const KoXmlElement &style)
         }
 
         if (! columnData.isEmpty() && count != columnData.count()) {
-            warnOdf << "Found not as many <style:column> elements as attribut fo:column-count has set:"<< count;
+            warnOdf << "Found not as many <style:column> elements as attribute fo:column-count has set:"<< count;
             columnData.clear();
         }
     } else {
