@@ -59,7 +59,7 @@ public:
     explicit KoDocumentInfo(QObject *parent = 0);
 
     /** The destructor */
-    ~KoDocumentInfo();
+    ~KoDocumentInfo() override;
 
     /**
      * Load the KoDocumentInfo from an OASIS document
@@ -144,8 +144,8 @@ private:
 
     /**
      * Set information about the author
-     * This sets what is actualy saved to file. The public method setAuthorInfo() can be used to set
-     * values that overide what is fetched from the author profile. During saveParameters() author
+     * This sets what is actually saved to file. The public method setAuthorInfo() can be used to set
+     * values that override what is fetched from the author profile. During saveParameters() author
      * profile and any overrides is combined resulting in calls to this method.
      * @param info the kind of information to set
      * @param data the data to set for this information
@@ -220,6 +220,7 @@ private:
     QMap<QString, QString> m_aboutInfo;
     /** The original meta:generator of the document */
     QString m_generator;
+    const QString m_keywordSeparator = QStringLiteral(";");
 
 Q_SIGNALS:
     void infoUpdated(const QString &info, const QString &data);
