@@ -18,12 +18,12 @@
  */
 #include "KoOdfNotesConfiguration.h"
 
-#include <kdebug.h>
+#include <OdfDebug.h>
 #include "KoXmlNS.h"
 #include "KoXmlWriter.h"
 #include "KoOdfNumberDefinition.h"
 
-class KoOdfNotesConfiguration::Private
+class Q_DECL_HIDDEN KoOdfNotesConfiguration::Private
 {
 public:
     KoOdfNotesConfiguration::NoteClass noteClass;
