@@ -27,9 +27,8 @@
 #include <QDateTime>
 #include <QTime>
 
-#include <kglobal.h>
-#include <klocale.h>
-#include <kdebug.h>
+#include <klocalizedstring.h>
+#include <OdfDebug.h>
 
 #include <KoXmlReader.h>
 #include <KoXmlWriter.h>
@@ -43,11 +42,12 @@ namespace KoOdfNumberStyles
 {
 
     static bool saveOdfTimeFormat(KoXmlWriter &elementWriter, QString &format, QString &text, bool &antislash);
-    static void parseOdfDateKlocale(KoXmlWriter &elementWriter, QString &format, QString &text);
-    static bool saveOdfKlocaleTimeFormat(KoXmlWriter &elementWriter, QString &format, QString &text);
-    static void parseOdfTimeKlocale(KoXmlWriter &elementWriter, QString &format, QString &text);
+    static void parseOdfDatelocale(KoXmlWriter &elementWriter, QString &format, QString &text);
+    static bool saveOdflocaleTimeFormat(KoXmlWriter &elementWriter, QString &format, QString &text);
+    static void parseOdfTimelocale(KoXmlWriter &elementWriter, QString &format, QString &text);
     static void addCalligraNumericStyleExtension(KoXmlWriter &elementWriter, const QString &_suffix, const QString &_prefix);
 
+
 QString format(const QString &value, const NumericStyleFormat &format)
 {
     switch (format.type) {
@@ -223,9 +223,10 @@ QString formatTime(qreal value, const QString &format)
 QString formatCurrency(qreal value, const QString &format, const QString& currencySymbol, int precision)
 {
     if (currencySymbol == "CCC") // undocumented hack, see doc attached to comment 6 at bug 282972
-        return KGlobal::locale()->formatMoney(value, "USD", precision);
+        return QLocale().toCurrencyString(value, "USD");
     if (format.isEmpty()) // no format means use locale format
-        return KGlobal::locale()->formatMoney(value, currencySymbol.isEmpty() ? KGlobal::locale()->currencySymbol() : currencySymbol, precision);
+        return QLocale().toCurrencyString(value, currencySymbol.isEmpty() ? QLocale().currencySymbol(QLocale::CurrencySymbol)
+                                                                          : currencySymbol);
     return formatNumber(value, format, precision);
 }
 
@@ -235,7 +236,7 @@ QString formatScientific(qreal value, const QString &format, int precision)
     QString v(QString::number(value, 'E', precision));
     int pos = v.indexOf('.');
     if (pos != -1) {
-        v.replace(pos, 1, KGlobal::locale()->decimalSymbol());
+        v.replace(pos, 1, QLocale().decimalPoint());
     }
     return v;
 }
@@ -251,25 +252,25 @@ QString formatFraction(qreal value, const QString &format)
 
     int index = 0;
     int limit = 0;
-    if (format.endsWith("/2")) {
+    if (format.endsWith(QLatin1String("/2"))) {
         index = 2;
-    } else if (format.endsWith("/4")) {
+    } else if (format.endsWith(QLatin1String("/4"))) {
         index = 4;
-    } else if (format.endsWith("/8")) {
+    } else if (format.endsWith(QLatin1String("/8"))) {
         index = 8;
-    } else if (format.endsWith("/16")) {
+    } else if (format.endsWith(QLatin1String("/16"))) {
         index = 16;
-    } else if (format.endsWith("/10")) {
+    } else if (format.endsWith(QLatin1String("/10"))) {
         index = 10;
-    } else if (format.endsWith("/100")) {
+    } else if (format.endsWith(QLatin1String("/100"))) {
         index = 100;
-    } else if (format.endsWith("/?")) {
+    } else if (format.endsWith(QLatin1String("/?"))) {
         index = 3;
         limit = 9;
-    } else if (format.endsWith("/??")) {
+    } else if (format.endsWith(QLatin1String("/??"))) {
         index = 4;
         limit = 99;
-    } else if (format.endsWith("/???")) {
+    } else if (format.endsWith(QLatin1String("/???"))) {
         index = 5;
         limit = 999;
     } else { // fallback
@@ -277,7 +278,9 @@ QString formatFraction(qreal value, const QString &format)
     }
 
     // handle halves, quarters, tenths, ...
-    if (!format.endsWith("/?") && !format.endsWith("/??") && !format.endsWith("/???")) {
+    if (!format.endsWith(QLatin1String("/?")) &&
+        !format.endsWith(QLatin1String("/??")) &&
+        !format.endsWith(QLatin1String("/???"))) {
         qreal calc = 0;
         int index1 = 0;
         qreal diff = result;
@@ -423,13 +426,13 @@ QPair<QString, NumericStyleFormat> loadOdfNumberStyle(const KoXmlElement &parent
             format += e.text();
         } else if (localName == "suffix") {
             suffix = e.text();
-            kDebug(30003) << " suffix :" << suffix;
+            debugOdf << " suffix :" << suffix;
         } else if (localName == "prefix") {
             prefix = e.text();
-            kDebug(30003) << " prefix :" << prefix;
+            debugOdf << " prefix :" << prefix;
         } else if (localName == "currency-symbol") {
             dataStyle.currencySymbol = e.text();
-            kDebug(30003) << " currency-symbol:" << dataStyle.currencySymbol;
+            debugOdf << " currency-symbol:" << dataStyle.currencySymbol;
             format += e.text();
             //TODO
             // number:language="de" number:country="DE">€</number:currency-symbol>
@@ -563,7 +566,7 @@ QPair<QString, NumericStyleFormat> loadOdfNumberStyle(const KoXmlElement &parent
         }
 
         // stylesmap's are embedded into a style and are pointing to another style that
-        // should be used insteat ot this style if the defined condition is true. E.g.;
+        // should be used instead of this style if the defined condition is true. E.g.;
         // <number:number-style style:name="N139P0" style:volatile="true"/>
         // <number:number-style style:name="N139P1" style:volatile="true"/>
         // <number:number-style style:name="N139P2" style:volatile="true"/>
@@ -587,18 +590,18 @@ QPair<QString, NumericStyleFormat> loadOdfNumberStyle(const KoXmlElement &parent
 
     const QString styleName = parent.attributeNS(KoXmlNS::style, "name", QString());
 
-kDebug()<<"99 *****************************************************************************";
+debugOdf<<"99 *****************************************************************************";
 //Q_ASSERT(false);
-    kDebug(30003) << "data style:" << styleName << " qt format=" << format;
+    debugOdf << "data style:" << styleName << " qt format=" << format;
     if (!prefix.isEmpty()) {
-        kDebug(30003) << " format.left( prefix.length() ) :" << format.left(prefix.length()) << " prefix :" << prefix;
+        debugOdf << " format.left( prefix.length() ) :" << format.left(prefix.length()) << " prefix :" << prefix;
         if (format.left(prefix.length()) == prefix) {
             format = format.right(format.length() - prefix.length());
         } else
             prefix.clear();
     }
     if (!suffix.isEmpty()) {
-        kDebug(30003) << "format.right( suffix.length() ) :" << format.right(suffix.length()) << " suffix :" << suffix;
+        debugOdf << "format.right( suffix.length() ) :" << format.right(suffix.length()) << " suffix :" << suffix;
         if (format.right(suffix.length()) == suffix) {
             format = format.left(format.length() - suffix.length());
         } else
@@ -610,7 +613,7 @@ kDebug()<<"99 ******************************************************************
     dataStyle.suffix = suffix;
     dataStyle.precision = precision;
     dataStyle.thousandsSep = thousandsSep;
-    kDebug(30003) << " finish insert format :" << format << " prefix :" << prefix << " suffix :" << suffix;
+    debugOdf << " finish insert format :" << format << " prefix :" << prefix << " suffix :" << suffix;
     return QPair<QString, NumericStyleFormat>(styleName, dataStyle);
 }
 
@@ -659,11 +662,11 @@ void addTextNumber(QString& text, KoXmlWriter &elementWriter)
     }
 }
 
-void parseOdfTimeKlocale(KoXmlWriter &elementWriter, QString &format, QString &text)
+void parseOdfTimelocale(KoXmlWriter &elementWriter, QString &format, QString &text)
 {
-    kDebug(30003) << "parseOdfTimeKlocale(KoXmlWriter &elementWriter, QString & format, QString & text ) :" << format;
+    debugOdf << "parseOdfTimelocale(KoXmlWriter &elementWriter, QString & format, QString & text ) :" << format;
     do {
-        if (!saveOdfKlocaleTimeFormat(elementWriter, format, text)) {
+        if (!saveOdflocaleTimeFormat(elementWriter, format, text)) {
             text += format[0];
             format.remove(0, 1);
         }
@@ -671,7 +674,7 @@ void parseOdfTimeKlocale(KoXmlWriter &elementWriter, QString &format, QString &t
     addTextNumber(text, elementWriter);
 }
 
-bool saveOdfKlocaleTimeFormat(KoXmlWriter &elementWriter, QString &format, QString &text)
+bool saveOdflocaleTimeFormat(KoXmlWriter &elementWriter, QString &format, QString &text)
 {
     bool changed = false;
     if (format.startsWith("%H")) {   //hh
@@ -773,20 +776,20 @@ bool saveOdfTimeFormat(KoXmlWriter &elementWriter, QString &format, QString &tex
     return changed;
 }
 
-QString saveOdfTimeStyle(KoGenStyles &mainStyles, const QString &_format, bool klocaleFormat,
+QString saveOdfTimeStyle(KoGenStyles &mainStyles, const QString &_format, bool localeFormat,
         const QString &_prefix, const QString &_suffix)
 {
     Q_UNUSED(_prefix);
     Q_UNUSED(_suffix);
-    //kDebug(30003) << "QString KoOdfNumberStyles::saveOdfTimeStyle( KoGenStyles &mainStyles, const QString & _format ) :" << _format;
+    //debugOdf << "QString KoOdfNumberStyles::saveOdfTimeStyle( KoGenStyles &mainStyles, const QString & _format ) :" << _format;
     QString format(_format);
     KoGenStyle currentStyle(KoGenStyle::NumericTimeStyle);
     QBuffer buffer;
     buffer.open(QIODevice::WriteOnly);
     KoXmlWriter elementWriter(&buffer);    // TODO pass indentation level
     QString text;
-    if (klocaleFormat) {
-        parseOdfTimeKlocale(elementWriter, format, text);
+    if (localeFormat) {
+        parseOdfTimelocale(elementWriter, format, text);
     } else {
         bool antislash = false;
         do {
@@ -808,10 +811,10 @@ QString saveOdfTimeStyle(KoGenStyles &mainStyles, const QString &_format, bool k
     return mainStyles.insert(currentStyle, "N");
 }
 
-//convert klocale string to good format
-void parseOdfDateKlocale(KoXmlWriter &elementWriter, QString &format, QString &text)
+//convert locale string to good format
+void parseOdfDatelocale(KoXmlWriter &elementWriter, QString &format, QString &text)
 {
-    kDebug(30003) << format;
+    debugOdf << format;
     do {
         if (format.startsWith("%Y")) {
             addTextNumber(text, elementWriter);
@@ -875,7 +878,7 @@ void parseOdfDateKlocale(KoXmlWriter &elementWriter, QString &format, QString &t
             number_day_of_week(&elementWriter).set_number_style("long");
             format.remove(0, 2);
         } else {
-            if (!saveOdfKlocaleTimeFormat(elementWriter, format, text)) {
+            if (!saveOdflocaleTimeFormat(elementWriter, format, text)) {
                 text += format[0];
                 format.remove(0, 1);
             }
@@ -884,12 +887,12 @@ void parseOdfDateKlocale(KoXmlWriter &elementWriter, QString &format, QString &t
     addTextNumber(text, elementWriter);
 }
 
-QString saveOdfDateStyle(KoGenStyles &mainStyles, const QString &_format, bool klocaleFormat,
+QString saveOdfDateStyle(KoGenStyles &mainStyles, const QString &_format, bool localeFormat,
         const QString &_prefix, const QString &_suffix)
 {
     Q_UNUSED(_prefix);
     Q_UNUSED(_suffix);
-    //kDebug(30003) << _format;
+    //debugOdf << _format;
     QString format(_format);
 
     // Not supported into Qt: "era" "week-of-year" "quarter"
@@ -899,8 +902,8 @@ QString saveOdfDateStyle(KoGenStyles &mainStyles, const QString &_format, bool k
     buffer.open(QIODevice::WriteOnly);
     KoXmlWriter elementWriter(&buffer);    // TODO pass indentation level
     QString text;
-    if (klocaleFormat) {
-        parseOdfDateKlocale(elementWriter, format, text);
+    if (localeFormat) {
+        parseOdfDatelocale(elementWriter, format, text);
     } else {
         bool antislash = false;
         do {
@@ -1016,7 +1019,7 @@ QString saveOdfDateStyle(KoGenStyles &mainStyles, const QString &_format, bool k
 QString saveOdfFractionStyle(KoGenStyles &mainStyles, const QString &_format,
         const QString &_prefix, const QString &_suffix)
 {
-    //kDebug(30003) << "QString saveOdfFractionStyle( KoGenStyles &mainStyles, const QString & _format ) :" << _format;
+    //debugOdf << "QString saveOdfFractionStyle( KoGenStyles &mainStyles, const QString & _format ) :" << _format;
     QString format(_format);
 
     KoGenStyle currentStyle(KoGenStyle::NumericFractionStyle);
@@ -1076,7 +1079,7 @@ QString saveOdfFractionStyle(KoGenStyles &mainStyles, const QString &_format,
 QString saveOdfNumberStyle(KoGenStyles &mainStyles, const QString &_format,
         const QString &_prefix, const QString &_suffix, bool thousandsSep)
 {
-    //kDebug(30003) << "QString saveOdfNumberStyle( KoGenStyles &mainStyles, const QString & _format ) :" << _format;
+    //debugOdf << "QString saveOdfNumberStyle( KoGenStyles &mainStyles, const QString & _format ) :" << _format;
     QString format(_format);
 
     KoGenStyle currentStyle(KoGenStyle::NumericNumberStyle);
@@ -1095,13 +1098,13 @@ QString saveOdfNumberStyle(KoGenStyles &mainStyles, const QString &_format,
         else if (format[0] == '0' && !beforeSeparator)
             decimalplaces++;
         else
-            kDebug(30003) << " error format 0";
+            debugOdf << " error format 0";
         format.remove(0, 1);
     } while (format.length() > 0);
     text = _prefix ;
     addTextNumber(text, elementWriter);
     number_number number(&elementWriter);
-    //kDebug(30003) << " decimalplaces :" << decimalplaces << " integerdigits :" << integerdigits;
+    //debugOdf << " decimalplaces :" << decimalplaces << " integerdigits :" << integerdigits;
     if (!beforeSeparator) {
         number.set_number_decimal_places(decimalplaces);
     }
@@ -1148,7 +1151,7 @@ QString saveOdfPercentageStyle(KoGenStyles &mainStyles, const QString &_format,
     //<number:text>%</number:text>
     //</number:percentage-style>
 
-    //kDebug(30003) << "QString saveOdfPercentageStyle( KoGenStyles &mainStyles, const QString & _format ) :" << _format;
+    //debugOdf << "QString saveOdfPercentageStyle( KoGenStyles &mainStyles, const QString & _format ) :" << _format;
     QString format(_format);
 
     KoGenStyle currentStyle(KoGenStyle::NumericPercentageStyle);
@@ -1167,7 +1170,7 @@ QString saveOdfPercentageStyle(KoGenStyles &mainStyles, const QString &_format,
         else if (format[0] == '0' && !beforeSeparator)
             decimalplaces++;
         else
-            kDebug(30003) << " error format 0";
+            debugOdf << " error format 0";
         format.remove(0, 1);
     } while (format.length() > 0);
     text = _prefix ;
@@ -1200,7 +1203,7 @@ QString saveOdfScientificStyle(KoGenStyles &mainStyles, const QString &_format,
     //</number:number-style>
 
     //example 000,000e+0000
-    //kDebug(30003) << "QString saveOdfScientificStyle( KoGenStyles &mainStyles, const QString & _format ) :" << _format;
+    //debugOdf << "QString saveOdfScientificStyle( KoGenStyles &mainStyles, const QString & _format ) :" << _format;
     QString format(_format);
 
     KoGenStyle currentStyle(KoGenStyle::NumericScientificStyle);
@@ -1229,7 +1232,7 @@ QString saveOdfScientificStyle(KoGenStyles &mainStyles, const QString &_format,
                 else if (format[0] == '-')
                     positive = false;
                 else
-                    kDebug(30003) << "Error into scientific number";
+                    debugOdf << "Error into scientific number";
                 exponential = true;
             }
         } else {
@@ -1238,7 +1241,7 @@ QString saveOdfScientificStyle(KoGenStyles &mainStyles, const QString &_format,
             else if (format[0] == '0' && !positive)
                 exponentdigits--;
             else
-                kDebug(30003) << " error into scientific number exponential value";
+                debugOdf << " error into scientific number exponential value";
         }
         format.remove(0, 1);
     } while (format.length() > 0);
@@ -1246,7 +1249,7 @@ QString saveOdfScientificStyle(KoGenStyles &mainStyles, const QString &_format,
     addTextNumber(text, elementWriter);
 
     number_scientific_number number(&elementWriter);
-    //kDebug(30003) << " decimalplace :" << decimalplace << " integerdigits :" << integerdigits << " exponentdigits :" << exponentdigits;
+    //debugOdf << " decimalplace :" << decimalplace << " integerdigits :" << integerdigits << " exponentdigits :" << exponentdigits;
     if (!beforeSeparator) {
         number.set_number_decimal_places(decimalplace);
     }
@@ -1277,7 +1280,7 @@ QString saveOdfCurrencyStyle(KoGenStyles &mainStyles,
     //<number:currency-symbol>VEB</number:currency-symbol>
     //</number:currency-style>
 
-    //kDebug(30003) << "QString saveOdfCurrencyStyle( KoGenStyles &mainStyles, const QString & _format ) :" << _format;
+    //debugOdf << "QString saveOdfCurrencyStyle( KoGenStyles &mainStyles, const QString & _format ) :" << _format;
     QString format(_format);
 
     KoGenStyle currentStyle(KoGenStyle::NumericCurrencyStyle);
@@ -1296,7 +1299,7 @@ QString saveOdfCurrencyStyle(KoGenStyles &mainStyles,
         else if (format[0] == '0' && !beforeSeparator)
             decimalplaces++;
         else
-            kDebug(30003) << " error format 0";
+            debugOdf << " error format 0";
         format.remove(0, 1);
     } while (format.length() > 0);
 
@@ -1304,7 +1307,7 @@ QString saveOdfCurrencyStyle(KoGenStyles &mainStyles,
     addTextNumber(text, elementWriter);
 
     number_number number(&elementWriter);
-    //kDebug(30003) << " decimalplaces :" << decimalplaces << " integerdigits :" << integerdigits;
+    //debugOdf << " decimalplaces :" << decimalplaces << " integerdigits :" << integerdigits;
     if (!beforeSeparator) {
         number.set_number_decimal_places(decimalplaces);
     }
@@ -1316,7 +1319,7 @@ QString saveOdfCurrencyStyle(KoGenStyles &mainStyles,
     addCalligraNumericStyleExtension(elementWriter, _suffix, _prefix);
 
     number_currency_symbol sym(&elementWriter);
-    //kDebug(30003) << " currency-symbol:" << symbol;
+    //debugOdf << " currency-symbol:" << symbol;
     sym.addTextNode(symbol.toUtf8());
     sym.end();
 
@@ -1333,7 +1336,7 @@ QString saveOdfTextStyle(KoGenStyles &mainStyles, const QString &_format, const
     //<number:text-content/>
     ///</number:text-style>
 
-    //kDebug(30003) << "QString saveOdfTextStyle( KoGenStyles &mainStyles, const QString & _format ) :" << _format;
+    //debugOdf << "QString saveOdfTextStyle( KoGenStyles &mainStyles, const QString & _format ) :" << _format;
 
     KoGenStyle currentStyle(KoGenStyle::NumericTextStyle);
     QBuffer buffer;
