@@ -20,6 +20,15 @@
 
 #include <KoElementReference.h>
 
+#include <QTest>
+#include <QLoggingCategory>
+
+void TestKoElementReference::initTestCase()
+{
+    QLoggingCategory::setFilterRules("*.debug=false\n"
+        "calligra.lib.store=true");
+}
+
 void TestKoElementReference::testElementReference()
 {
     KoElementReference ref1;
@@ -41,4 +50,3 @@ void TestKoElementReference::testElementReference()
 }
 
 QTEST_MAIN(TestKoElementReference)
-#include <TestKoElementReference.moc>
