@@ -19,12 +19,13 @@
  * Boston, MA 02110-1301, USA.
 */
 
-#include <QtTest>
+#include <QObject>
 
 class TestKoGenStyles : public QObject
 {
     Q_OBJECT
 private Q_SLOTS:
+    void initTestCase();
     void testLookup();
     void testLookupFlags();
     void testDefaultStyle();
