@@ -30,6 +30,15 @@
 #include <KoOdfWriteStore.h>
 #include <KoXmlWriter.h>
 
+#include <QTest>
+#include <QLoggingCategory>
+
+void TestKoOdfLoadingContext::initTestCase()
+{
+    QLoggingCategory::setFilterRules("*.debug=false\n"
+    "calligra.lib.odf=true");
+}
+
 void TestKoOdfLoadingContext::testFillStyleStack()
 {
 #if 0
@@ -141,5 +150,4 @@ void TestKoOdfLoadingContext::testFillStyleStack()
     delete store;
 }
 
-QTEST_KDEMAIN(TestKoOdfLoadingContext, NoGUI)
-#include <TestKoOdfLoadingContext.moc>
+QTEST_GUILESS_MAIN(TestKoOdfLoadingContext)
