@@ -19,12 +19,13 @@
 #ifndef TESTKOODFLOADINGCONTEXT_H
 #define TESTKOODFLOADINGCONTEXT_H
 
-#include <qtest_kde.h>
+#include <QObject>
 
 class TestKoOdfLoadingContext : public QObject
 {
     Q_OBJECT
 private Q_SLOTS:
+    void initTestCase();
     void testFillStyleStack();
 };
 
