@@ -22,13 +22,14 @@
 #define TESTKOUNIT_H
 
 // Qt
-#include <QtTest>
+#include <QObject>
 
 class TestKoUnit : public QObject
 {
     Q_OBJECT
 
 private Q_SLOTS:
+    void initTestCase();
     void testSimpleConstructor();
     void testConstructor_data();
     void testConstructor();
