@@ -19,13 +19,13 @@
 #ifndef TESTNUMBERSTYLE_H
 #define TESTNUMBERSTYLE_H
 
-#include <QtTest>
-#include <KoOdfNumberStyles.h>
+#include <QObject>
 
 class TestNumberStyle : public QObject
 {
     Q_OBJECT
 private Q_SLOTS:
+    void initTestCase();
     void testEmpty();
     void testText();
     void testNumber();
