@@ -360,7 +360,7 @@ KoColorConversionSystem::Vertex* KoColorConversionSystem::createVertex(Node* src
 
 QString KoColorConversionSystem::vertexToDot(KoColorConversionSystem::Vertex* v, const QString &options) const
 {
-    return QString("  \"%1\" -> \"%2\" %3\n").arg(v->srcNode->id()).arg(v->dstNode->id()).arg(options);
+    return QString("  \"%1\" -> \"%2\" %3\n").arg(v->srcNode->id(), v->dstNode->id(), options);
 }
 
 QString KoColorConversionSystem::toDot() const
