@@ -4,7 +4,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -144,7 +144,7 @@ struct KoColorSpaceTrait {
         return QString().setNum(100. *((qreal)c) / KoColorSpaceMathsTraits< channels_type>::unitValue);
     }
 
-    inline static void normalisedChannelsValue(const quint8 *pixel, QVector<float> &channels) {
+    inline static void normalisedChannelsValue(const quint8 *pixel, QVector<qreal> &channels) {
         Q_ASSERT((int)channels.count() == (int)channels_nb);
         channels_type c;
         for (uint i = 0; i < channels_nb; i++) {
@@ -153,7 +153,7 @@ struct KoColorSpaceTrait {
         }
     }
 
-    inline static void fromNormalisedChannelsValue(quint8 *pixel, const QVector<float> &values) {
+    inline static void fromNormalisedChannelsValue(quint8 *pixel, const QVector<qreal> &values) {
         Q_ASSERT((int)values.count() == (int)channels_nb);
         channels_type c;
         for (uint i = 0; i < channels_nb; i++) {
