@@ -24,6 +24,7 @@
 
 #include <cfloat>
 #include <cmath>
+#include <algorithm>
 
 #include <QImage>
 #include <QTextStream>
@@ -39,6 +40,7 @@
 #include <DebugPigment.h>
 #include <klocalizedstring.h>
 
+
 KoGradientSegment::RGBColorInterpolationStrategy *KoGradientSegment::RGBColorInterpolationStrategy::m_instance = 0;
 KoGradientSegment::HSVCWColorInterpolationStrategy *KoGradientSegment::HSVCWColorInterpolationStrategy::m_instance = 0;
 KoGradientSegment::HSVCCWColorInterpolationStrategy *KoGradientSegment::HSVCCWColorInterpolationStrategy::m_instance = 0;
@@ -773,7 +775,7 @@ const QList<double> KoSegmentGradient::getMiddleHandlePositions() const
 
 void KoSegmentGradient::moveSegmentStartOffset(KoGradientSegment* segment, double t)
 {
-    QList<KoGradientSegment*>::iterator it = qFind(m_segments.begin(), m_segments.end(), segment);
+    QList<KoGradientSegment*>::iterator it = std::find(m_segments.begin(), m_segments.end(), segment);
     if (it != m_segments.end()) {
         if (it == m_segments.begin()) {
             segment->setStartOffset(0.0);
@@ -794,7 +796,7 @@ void KoSegmentGradient::moveSegmentStartOffset(KoGradientSegment* segment, doubl
 
 void KoSegmentGradient::moveSegmentEndOffset(KoGradientSegment* segment, double t)
 {
-    QList<KoGradientSegment*>::iterator it = qFind(m_segments.begin(), m_segments.end(), segment);
+    QList<KoGradientSegment*>::iterator it = std::find(m_segments.begin(), m_segments.end(), segment);
     if (it != m_segments.end()) {
         if (it + 1 == m_segments.end()) {
             segment->setEndOffset(1.0);
@@ -828,7 +830,7 @@ void KoSegmentGradient::moveSegmentMiddleOffset(KoGradientSegment* segment, doub
 void KoSegmentGradient::splitSegment(KoGradientSegment* segment)
 {
     Q_ASSERT(segment != 0);
-    QList<KoGradientSegment*>::iterator it = qFind(m_segments.begin(), m_segments.end(), segment);
+    QList<KoGradientSegment*>::iterator it = std::find(m_segments.begin(), m_segments.end(), segment);
     if (it != m_segments.end()) {
         KoColor midleoffsetColor(segment->endColor().colorSpace());
         segment->colorAt(midleoffsetColor, segment->middleOffset());
@@ -849,19 +851,19 @@ void KoSegmentGradient::splitSegment(KoGradientSegment* segment)
 void KoSegmentGradient::duplicateSegment(KoGradientSegment* segment)
 {
     Q_ASSERT(segment != 0);
-    QList<KoGradientSegment*>::iterator it = qFind(m_segments.begin(), m_segments.end(), segment);
+    QList<KoGradientSegment*>::iterator it = std::find(m_segments.begin(), m_segments.end(), segment);
     if (it != m_segments.end()) {
-        double middlePostionPercentage = (segment->middleOffset() - segment->startOffset()) / segment->length();
+        double middlePositionPercentage = (segment->middleOffset() - segment->startOffset()) / segment->length();
         double center = segment->startOffset() + segment->length() / 2;
         KoGradientSegment* newSegment = new KoGradientSegment(
             segment->interpolation(), segment->colorInterpolation(),
             segment ->startOffset(),
-            segment->length() / 2 * middlePostionPercentage + segment->startOffset(),
+            segment->length() / 2 * middlePositionPercentage + segment->startOffset(),
             center, segment->startColor(),
             segment->endColor());
         m_segments.insert(it, newSegment);
         segment->setStartOffset(center);
-        segment->setMiddleOffset(segment->length() * middlePostionPercentage  + segment->startOffset());
+        segment->setMiddleOffset(segment->length() * middlePositionPercentage  + segment->startOffset());
     }
 }
 
@@ -889,20 +891,20 @@ KoGradientSegment* KoSegmentGradient::removeSegment(KoGradientSegment* segment)
     Q_ASSERT(segment != 0);
     if (m_segments.count() < 2)
         return 0;
-    QList<KoGradientSegment*>::iterator it = qFind(m_segments.begin(), m_segments.end(), segment);
+    QList<KoGradientSegment*>::iterator it = std::find(m_segments.begin(), m_segments.end(), segment);
     if (it != m_segments.end()) {
-        double middlePostionPercentage;
+        double middlePositionPercentage;
         KoGradientSegment* nextSegment;
         if (it == m_segments.begin()) {
             nextSegment = (*(it + 1));
-            middlePostionPercentage = (nextSegment->middleOffset() - nextSegment->startOffset()) / nextSegment->length();
+            middlePositionPercentage = (nextSegment->middleOffset() - nextSegment->startOffset()) / nextSegment->length();
             nextSegment->setStartOffset(segment->startOffset());
-            nextSegment->setMiddleOffset(middlePostionPercentage * nextSegment->length() + nextSegment->startOffset());
+            nextSegment->setMiddleOffset(middlePositionPercentage * nextSegment->length() + nextSegment->startOffset());
         } else {
             nextSegment = (*(it - 1));
-            middlePostionPercentage = (nextSegment->middleOffset() - nextSegment->startOffset()) / nextSegment->length();
+            middlePositionPercentage = (nextSegment->middleOffset() - nextSegment->startOffset()) / nextSegment->length();
             nextSegment->setEndOffset(segment->endOffset());
-            nextSegment->setMiddleOffset(middlePostionPercentage * nextSegment->length() + nextSegment->startOffset());
+            nextSegment->setMiddleOffset(middlePositionPercentage * nextSegment->length() + nextSegment->startOffset());
         }
 
         delete segment;
