@@ -25,7 +25,7 @@
 InsertSemanticObjectActionBase::InsertSemanticObjectActionBase(KoCanvasBase *canvas,
         KoDocumentRdf *rdf,
         const QString &name)
-        : KAction(name, canvas->canvasWidget()),
+        : QAction(name, canvas->canvasWidget()),
         m_canvas(canvas),
         m_rdf(rdf)
 {
