@@ -25,11 +25,11 @@
 #include <KoToolProxy.h>
 #include <KoDocumentResourceManager.h>
 #include <KoTextEditor.h>
-// KDE
+// KF5
 #include <kactionmenu.h>
 #include <kpagedialog.h>
 #include <kdebug.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 // Qt
 #include <QVBoxLayout>
 
@@ -89,13 +89,13 @@ KoRdfSemanticTreeWidgetItem::~KoRdfSemanticTreeWidgetItem()
 {
 }
 
-KAction *KoRdfSemanticTreeWidgetItem::createAction(QWidget *parent, KoCanvasBase *host, const QString  &text)
+QAction *KoRdfSemanticTreeWidgetItem::createAction(QWidget *parent, KoCanvasBase *host, const QString  &text)
 {
     return new RdfSemanticTreeWidgetAction(parent, host, text);
 }
 
 void KoRdfSemanticTreeWidgetItem::addApplyStylesheetActions(QWidget *parent,
-        QList<KAction *> &actions, KoCanvasBase *host)
+        QList<QAction *> &actions, KoCanvasBase *host)
 {
     if (!host) {
         return;
@@ -117,7 +117,7 @@ void KoRdfSemanticTreeWidgetItem::addApplyStylesheetActions(QWidget *parent,
     topMenu->addAction(subMenu);
     foreach (hKoSemanticStylesheet ss, semanticItem()->stylesheets()) {
         kDebug(30015) << "format(), sheet:" << ss->name() << " xmlid:" << xmlid;
-        KAction* action = new RdfSemanticTreeWidgetApplyStylesheet(parent,
+        QAction * action = new RdfSemanticTreeWidgetApplyStylesheet(parent,
                                                                    host, ss->name(),
                                                                    semanticItem(), ss);
         subMenu->addAction(action);
@@ -126,7 +126,7 @@ void KoRdfSemanticTreeWidgetItem::addApplyStylesheetActions(QWidget *parent,
     topMenu->addAction(subMenu);
     foreach (hKoSemanticStylesheet ss, semanticItem()->userStylesheets()) {
         kDebug(30015) << "format(), sheet:" << ss->name() << " xmlid:" << xmlid;
-        KAction *action = new RdfSemanticTreeWidgetApplyStylesheet(parent,
+        QAction *action = new RdfSemanticTreeWidgetApplyStylesheet(parent,
                                                                    host, ss->name(),
                                                                    semanticItem(), ss);
         subMenu->addAction(action);
@@ -135,22 +135,22 @@ void KoRdfSemanticTreeWidgetItem::addApplyStylesheetActions(QWidget *parent,
     topMenu->addSeparator();
     KoRdfSemanticItemViewSite vs(semanticItem(), xmlid);
     if (hKoSemanticStylesheet ss = vs.stylesheet()) {
-        KAction *action = new RdfSemanticTreeWidgetApplyStylesheet(parent,
+        QAction *action = new RdfSemanticTreeWidgetApplyStylesheet(parent,
                                                                    host, i18n("Reapply Current"),
                                                                    semanticItem(), ss);
         topMenu->addAction(action);
     }
-    KAction *action = new RdfSemanticTreeWidgetApplyStylesheet(parent,
+    QAction *action = new RdfSemanticTreeWidgetApplyStylesheet(parent,
                                                                host, i18n("Disassociate"),
                                                                semanticItem(), hKoSemanticStylesheet(0));
     topMenu->addAction(action);
 }
 
-QList<KAction *> KoRdfSemanticTreeWidgetItem::actions(QWidget *parent, KoCanvasBase *host)
+QList<QAction *> KoRdfSemanticTreeWidgetItem::actions(QWidget *parent, KoCanvasBase *host)
 {
     Q_UNUSED(parent);
     Q_UNUSED(host);
-    return QList<KAction *>();
+    return QList<QAction *>();
 }
 
 void KoRdfSemanticTreeWidgetItem::insert(KoCanvasBase *host)
@@ -169,7 +169,7 @@ void KoRdfSemanticTreeWidgetItem::edit()
     QWidget *w = semanticItem()->createEditor(widget);
     lay->addWidget(w);
     KPageDialog dialog;
-    dialog.setCaption(caption);
+    dialog.setWindowTitle(caption);
     dialog.addPage(widget, QString());
     if (dialog.exec() == KPageDialog::Accepted) {
         kDebug(30015) << "KoRdfSemanticTreeWidgetItem::edit() accepted...";
