@@ -30,7 +30,7 @@ class KoTextInlineRdf;
 class KoRdfPrefixMapping;
 class KoRdfSemanticTreeWidgetItem;
 class KoTextEditor;
-
+class KoRdfBasicSemanticItem;
 
 namespace Soprano
 {
@@ -41,5 +41,6 @@ namespace Soprano
 
 typedef QExplicitlySharedDataPointer<KoRdfSemanticItem> hKoRdfSemanticItem;
 typedef QExplicitlySharedDataPointer<KoSemanticStylesheet> hKoSemanticStylesheet;
+typedef QExplicitlySharedDataPointer<KoRdfBasicSemanticItem> hKoRdfBasicSemanticItem;
 
 #endif
