@@ -25,7 +25,6 @@
 
 #include <QObject>
 
-class QTextDocument;
 class KoTextEditor;
 class KoDocumentRdf;
 class QString;
@@ -34,7 +33,7 @@ class RdfTest : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
     void testCreateMarkers();
     void testFindMarkers();
     void testFindByName();
