@@ -32,7 +32,7 @@ public:
     explicit InsertTextLocator(KoCanvasBase *canvas);
 
 private:
-    virtual KoInlineObject *createInlineObject();
+    KoInlineObject *createInlineObject() override;
 };
 
 #endif
