@@ -34,7 +34,7 @@ public:
     InsertTextReferenceAction(KoCanvasBase *canvas, const KoInlineTextObjectManager *manager);
 
 private:
-    virtual KoInlineObject *createInlineObject();
+    KoInlineObject *createInlineObject() override;
 
     const KoInlineTextObjectManager *m_manager;
 };
