@@ -23,7 +23,7 @@
 #include "kotext_export.h"
 
 /**
- * This inlineObject shows the curent value of a variable as registered in the KoVariableManager.
+ * This inlineObject shows the current value of a variable as registered in the KoVariableManager.
  * The proper way to create a new class is to use KoVariableManager::createVariable()
  */
 class KoNamedVariable : public KoVariable
@@ -35,8 +35,8 @@ public:
         return m_name;
     }
 
-    virtual bool loadOdf(const KoXmlElement &element, KoShapeLoadingContext &context);
-    virtual void saveOdf(KoShapeSavingContext &context);
+    bool loadOdf(const KoXmlElement &element, KoShapeLoadingContext &context) override;
+    void saveOdf(KoShapeSavingContext &context) override;
 
 protected:
     friend class KoVariableManager;
@@ -49,9 +49,9 @@ protected:
 
 private:
     /// reimplemented method
-    void propertyChanged(Property property, const QVariant &value);
+    void propertyChanged(Property property, const QVariant &value) override;
     /// reimplemented method
-    void setup();
+    void setup() override;
 
     const QString m_name;
     const Property m_key;
