@@ -39,6 +39,8 @@
 #include <KoSectionEnd.h>
 #include <KoShapeController.h>
 
+#include <algorithm>
+
 bool DeleteCommand::SectionDeleteInfo::operator<(const DeleteCommand::SectionDeleteInfo &other) const
 {
     // At first we remove sections that lays deeper in tree
@@ -147,7 +149,7 @@ public:
     {
     }
 
-    virtual void visitBlock(QTextBlock &block, const QTextCursor &caret)
+    void visitBlock(QTextBlock &block, const QTextCursor &caret) override
     {
         for (QTextBlock::iterator it = block.begin(); it != block.end(); ++it) {
             QTextCursor fragmentSelection(caret);
@@ -206,7 +208,7 @@ public:
         }
     }
 
-    virtual void visitFragmentSelection(QTextCursor &fragmentSelection)
+    void visitFragmentSelection(QTextCursor &fragmentSelection) override
     {
         if (m_first) {
             m_firstFormat = fragmentSelection.charFormat();
@@ -374,7 +376,7 @@ void DeleteCommand::finalizeSectionHandling(QTextCursor *cur, DeleteVisitor &v)
     }
 
     // Now lets deal with KoSectionModel
-    qSort(m_sectionsToRemove.begin(), m_sectionsToRemove.end());
+    std::sort(m_sectionsToRemove.begin(), m_sectionsToRemove.end());
     deleteSectionsFromModel();
 }
 
@@ -439,7 +441,7 @@ void DeleteCommand::doDelete()
         KoAnnotation *annotation = dynamic_cast<KoAnnotation *>(range);
         if (anchorRange) {
             // we should only delete the anchor if the selection is covering it... not if the selection is
-            // just adjecent to the anchor. This is more in line with what other wordprocessors do
+            // just adjacent to the anchor. This is more in line with what other wordprocessors do
             if (anchorRange->position() != textEditor->selectionStart()
                     && anchorRange->position() != textEditor->selectionEnd()) {
                 KoShape *shape = anchorRange->anchor()->shape();
@@ -515,22 +517,22 @@ bool DeleteCommand::mergeWith(const KUndo2Command *command)
     public:
         UndoTextCommand(QTextDocument *document, KUndo2Command *parent = 0)
         : KUndo2Command(kundo2_i18n("Text"), parent),
-        m_document(document)
+          m_document(document)
         {}
 
-        void undo() {
+        void undo() override {
             QTextDocument *doc = m_document.data();
             if (doc)
                 doc->undo(KoTextDocument(doc).textEditor()->cursor());
         }
 
-        void redo() {
+        void redo() override {
             QTextDocument *doc = m_document.data();
             if (doc)
                 doc->redo(KoTextDocument(doc).textEditor()->cursor());
         }
 
-        QWeakPointer<QTextDocument> m_document;
+        QPointer<QTextDocument> m_document;
     };
 
     KoTextEditor *textEditor = KoTextDocument(m_document).textEditor();
