@@ -45,7 +45,7 @@ class KoList;
 /**
  * A container for all properties for the paragraph wide style.
  * Each paragraph in the main text either is based on a parag style, or its not. Where
- * it is based on a paragraph style this is indecated that it has a property 'StyleId'
+ * it is based on a paragraph style this is indicated that it has a property 'StyleId'
  * with an integer as value.  The integer value corresponds to the styleId() output of
  * a specific KoParagraphStyle.
  * @see KoStyleManager
@@ -58,8 +58,8 @@ public:
         // Every 10 properties, the decimal number shown indicates the decimal offset over the QTextFormat::UserProperty enum value
         StyleId = QTextFormat::UserProperty + 1,
         // Linespacing properties
-        PercentLineHeight,  ///< this propery is used for a percentage of the highest character on that line
-        FixedLineHeight,    ///< this propery is used to use a non-default line height
+        PercentLineHeight,  ///< this property is used for a percentage of the highest character on that line
+        FixedLineHeight,    ///< this property is used to use a non-default line height
         MinimumLineHeight,  ///< this property is used to have a minimum line spacing
         LineSpacing,        ///< Hard leader height.
         LineSpacingFromFont,  ///< if false, use fontsize (in pt) solely, otherwise respect font settings
@@ -183,9 +183,9 @@ public:
     /// Creates a KoParagrahStyle with the given block format, the block character format and \a parent
     KoParagraphStyle(const QTextBlockFormat &blockFormat, const QTextCharFormat &blockCharFormat, QObject *parent = 0);
     /// Destructor
-    ~KoParagraphStyle();
+    ~KoParagraphStyle() override;
 
-    virtual KoCharacterStyle::Type styleType() const;
+    KoCharacterStyle::Type styleType() const override;
 
     /// Creates a KoParagraphStyle that represents the formatting of \a block.
     static KoParagraphStyle *fromBlock(const QTextBlock &block, QObject *parent = 0);
@@ -243,7 +243,7 @@ public:
     bool hasNormalLineHeight() const;
 
     /**
-     * If set to true the font-encoded height will be used instead of the font-size propery
+     * If set to true the font-encoded height will be used instead of the font-size property
      * This property influences setLineHeightPercent() behavior.
      * When off (default) a font of 12pt will always have a linespacing of 12pt times the
      * current linespacing percentage.  When on the linespacing embedded in the font
@@ -721,7 +721,6 @@ public:
 
 
 Q_SIGNALS:
-    void nameChanged(const QString &newName);
     void styleApplied(const KoParagraphStyle*) const;
 
 private:
