@@ -71,17 +71,17 @@ public:
         textDoc.setTextEditor(editor);
     }
 
-    virtual ~TestDocument()
+    ~TestDocument() override
     {
         delete m_document;
     }
 
-    virtual void addShape(KoShape *shape)
+    void addShape(KoShape *shape) override
     {
         m_shapes << shape;
     }
 
-    virtual void removeShape(KoShape *shape)
+    void removeShape(KoShape *shape) override
     {
         m_shapes.removeAll(shape);
     }
@@ -383,7 +383,7 @@ void TestKoTextEditor::checkSectionModelLevel(TestDocument *doc)
         curBlock = curBlock.next();
     }
 
-    // Now lets compare builded tree with KoSectionModel
+    // Now lets compare built tree with KoSectionModel
     KoSectionModel *model = doc->sectionModel();
     QCOMPARE(model->rowCount(), rootSections.size());
     for (int i = 0; i < rootSections.size(); i++) {
