@@ -18,19 +18,16 @@
  */
 
 #include "FrameIterator.h"
-#include "TableIterator.h"
-#include "KoTextLayoutRootArea.h"
 
-#include <KoParagraphStyle.h>
-#include <KoTextPage.h>
+#include "TableIterator.h"
 
 #include <QTextFrame>
 #include <QTextTableCell>
-#include <QTextLine>
 
 FrameIterator::FrameIterator(QTextFrame *frame)
 {
     it = frame->begin();
+    m_frame = it.parentFrame();
     currentTableIterator = 0;
     currentSubFrameIterator = 0;
     lineTextStart = -1;
@@ -41,6 +38,7 @@ FrameIterator::FrameIterator(const QTextTableCell &cell)
 {
     Q_ASSERT(cell.isValid());
     it = cell.begin();
+    m_frame = it.parentFrame();
     currentTableIterator = 0;
     currentSubFrameIterator = 0;
     lineTextStart = -1;
@@ -50,6 +48,7 @@ FrameIterator::FrameIterator(const QTextTableCell &cell)
 FrameIterator::FrameIterator(FrameIterator *other)
 {
     it = other->it;
+    m_frame = it.parentFrame();
     masterPageName = other->masterPageName;
     lineTextStart = other->lineTextStart;
     fragmentIterator = other->fragmentIterator;
@@ -71,6 +70,11 @@ FrameIterator::~FrameIterator()
     delete currentSubFrameIterator;
 }
 
+bool FrameIterator::isValid() const
+{
+    return m_frame;
+}
+
 bool FrameIterator::operator ==(const FrameIterator &other) const
 {
     if (it != other.it)
