@@ -64,6 +64,8 @@
 #include <QTextLayout>
 #include <QTextCursor>
 
+#include <algorithm>
+
 extern int qt_defaultDpiY();
 Q_DECLARE_METATYPE(QTextDocument *)
 
@@ -1192,7 +1194,7 @@ bool KoTextLayoutArea::layoutBlock(FrameIterator *cursor)
 
     // We need to sort as the MaximumTabPos may be converted to a value that really
     // should be in the middle, and listtab needs to be sorted in too
-    qSort(qTabs.begin(), qTabs.end(), compareTab);
+    std::sort(qTabs.begin(), qTabs.end(), compareTab);
 
     // Regular interval tabs. Since Qt doesn't handle regular interval tabs offset
     // by a fixed number we need to create the regular tabs ourselves.
@@ -1791,9 +1793,8 @@ qreal KoTextLayoutArea::addLine(QTextLine &line, FrameIterator *cursor, KoTextBl
                 qreal percent = format.doubleProperty(KoParagraphStyle::PercentLineHeight);
                 if (percent != 0) {
                     height *= percent / 100.0;
-                } else {
-                    height *= 1.2; // default
                 }
+                height *= 1.16; // default
             }
             height += lineSpacing;
         }
@@ -1804,7 +1805,7 @@ qreal KoTextLayoutArea::addLine(QTextLine &line, FrameIterator *cursor, KoTextBl
         }
     } else {
         // for drop caps we just work with a basic linespacing for the dropped characters
-        height *= 1.2;
+        height *= 1.16;
     }
     //rounding problems due to Qt-scribe internally using ints.
     //also used when line was moved down because of intersections with other shapes
