@@ -158,8 +158,8 @@ void KoTextLayoutObstruction::init(const QTransform &matrix, const QPainterPath
         // However since the distance can be express in 4 directions and QPainterPathStroker only
         // handles a penWidth we do some tricks to get it working.
         //
-        // Explaination in one dimension only: we sum the distances top and below and use that as the
-        // penWidth. afterwards we translate the result so it is destributed correctly by top and bottom
+        // Explanation in one dimension only: we sum the distances top and below and use that as the
+        // penWidth. afterwards we translate the result so it is distributed correctly by top and bottom
         // Now by doing that we would also implicitly set the left+right size of the pen which is no good,
         // so in order to set that to a minimal value (we choose 1, as 0 would give division by 0) we do
         // the following:. We scale the original path by sumX, stroke the path with penwidth=sumY, then
@@ -182,8 +182,10 @@ void KoTextLayoutObstruction::init(const QTransform &matrix, const QPainterPath
 
     // Now we need to change the path into a polygon for easier handling later on
     m_polygon = path.toFillPolygon();
-    QPointF prev = *(m_polygon.begin());
-    foreach (const QPointF &vtx, m_polygon) { //initialized edges
+    QPointF &prev(m_polygon.first());
+    // There exists a problem on msvc with for(each) and QVector<QPointF>
+    for (int i = 0; i < m_polygon.count(); ++i) {
+        const QPointF &vtx(m_polygon[i]);
         if (vtx.x() == prev.x() && vtx.y() == prev.y())
             continue;
         QLineF line;
@@ -219,7 +221,9 @@ QRectF KoTextLayoutObstruction::cropToLine(const QRectF &lineRect)
         m_line = lineRect;
         bool untilFirst = true;
         //check inner points
-        foreach (const QPointF &point, m_polygon) {
+        // There exists a problem on msvc with for(each) and QVector<QPointF>
+        for (int i = 0; i < m_polygon.count(); ++i) {
+            const QPointF point(m_polygon[i]);
             if (lineRect.contains(point)) {
                 if (untilFirst) {
                     m_line.setLeft(point.x());
