@@ -41,6 +41,8 @@
 
 #include "FrameIterator.h"
 
+#include <algorithm>
+
 class Q_DECL_HIDDEN KoTextLayoutTableArea::Private
 {
 public:
@@ -184,8 +186,8 @@ KoPointedAt KoTextLayoutTableArea::hitTest(const QPointF &point, Qt::HitTestAccu
     if (point.y() > d->rowPositions[firstRow] - 3.0 && point.y() < d->rowPositions[lastRow + 1] + 3.0) {
         QVector<qreal>::const_iterator start = d->rowPositions.constBegin() + firstRow;
         QVector<qreal>::const_iterator end = d->rowPositions.constBegin() + lastRow + 1;
-        int row = qLowerBound(start, end, point.y()) - d->rowPositions.constBegin() - 1;
-        int column = qLowerBound(d->columnPositions, point.x()) - d->columnPositions.constBegin() - 1;
+        int row = std::lower_bound(start, end, point.y()) - d->rowPositions.constBegin() - 1;
+        int column = std::lower_bound(d->columnPositions.begin(), d->columnPositions.end(), point.x()) - d->columnPositions.constBegin() - 1;
         if (point.y() < d->rowPositions[firstRow]) {
             ++row;
         }
@@ -237,8 +239,8 @@ KoPointedAt KoTextLayoutTableArea::hitTest(const QPointF &point, Qt::HitTestAccu
     if (headerPoint.y() > d->headerRowPositions.first() && headerPoint.y() < d->headerRowPositions[d->headerRows]) {
         QVector<qreal>::const_iterator start = d->headerRowPositions.constBegin();
         QVector<qreal>::const_iterator end = d->headerRowPositions.constBegin() + d->headerRows;
-        int row = qLowerBound(start, end, headerPoint.y()) - d->headerRowPositions.constBegin() - 1;
-        int column = qLowerBound(d->columnPositions, headerPoint.x()) - d->columnPositions.constBegin() - 1;
+        int row = std::lower_bound(start, end, headerPoint.y()) - d->headerRowPositions.constBegin() - 1;
+        int column = std::lower_bound(d->columnPositions.begin(), d->columnPositions.end(), headerPoint.x()) - d->columnPositions.constBegin() - 1;
         column = qBound(0, column, d->table->columns() - 1);
         KoPointedAt pointedAt;
         if (qAbs(d->columnPositions[column] - headerPoint.x()) < 3.0) {
@@ -433,7 +435,9 @@ bool KoTextLayoutTableArea::layoutTable(TableIterator *cursor)
 
 
         if (complete) {
-            setVirginPage(false);
+            if (cursor->row >= d->headerRows) {
+                setVirginPage(false);
+            }
             cursor->row++;
         }
     } while (complete && cursor->row < d->table->rows());
@@ -783,10 +787,6 @@ bool KoTextLayoutTableArea::layoutRow(TableIterator *cursor, qreal topBorderWidt
         }
     }
 
-    if (noCellsFitted && row <= d->headerRows) {
-        d->totalMisFit = true;
-    }
-
     if (anyCellTried && noCellsFitted && !rowHasExactHeight && !allCellsFullyDone) {
         d->rowPositions[row+1] = d->rowPositions[row];
         nukeRow(cursor);
@@ -798,6 +798,10 @@ bool KoTextLayoutTableArea::layoutRow(TableIterator *cursor, qreal topBorderWidt
         return false; // we can't honour the anything inside so give up doing row
     }
 
+    if (noCellsFitted && d->headerRows && row <= d->headerRows) {
+        d->totalMisFit = true;
+    }
+
     if (!allCellsFullyDone) {
         layoutMergedCellsNotEnding(cursor, topBorderWidth, bottomBorderWidth, rowBottom);
     } else {
@@ -967,7 +971,7 @@ void KoTextLayoutTableArea::paint(QPainter *painter, const KoTextDocumentLayout:
             }
         }
     }
-    // Draw header row cell borders.(need to be second step so nabour cells don't overwrite)
+    // Draw header row cell borders.(need to be second step so neibor cells don't overwrite)
     for (int row = 0; row < d->headerRows; ++row) {
         for (int column = 0; column < d->table->columns(); ++column) {
             QTextTableCell tableCell = d->table->cellAt(row, column);
