@@ -55,7 +55,6 @@ private Q_SLOTS:
      * exactly this case.
      */
     void testMergedCells();
-
     /**
      * If no column-width is defined then the available width should be distributed among
      * the available columns. Since the provided rootArea's have a width of 200 and we
@@ -98,9 +97,31 @@ private Q_SLOTS:
      */
     void testRowHeightMinimum();
 
+    void testOneTableNeedsTwoRootAreas();
+    void testTwoTablesNeedsTwoRootAreas();
+    void testMergedRowsSpansAreas();
+    void testMergedRowsSpansAreas2();
+    void testTwoTablesMergedRowsSpansAreas();
+    void testTwoTablesMergedRowsSpansThreeAreas();
+    void testRowHeightLargerThanAreaHeight();
+
+    // With header rows
+    /// Table consisting of a single header row
+    void testSingleHeaderRow();
+    /// Table consisting of a two header rows
+    void testMultipleHeaderRows();
+    /// Table consisting two rows with a single header row
+    void testTableWithSingleHeaderRow();
+    /// Table consisting three rows with two header rows
+    void testTableWithMultipleHeaderRow();
+    /// Table consisting of a single header row
+    /// with height > root area height
+    void testHeaderRowHeightLargerThanAreaHeight();
+
 private:
     QTextCursor setupTest();
     void setupTest(const QString &mergedText, const QString &topRightText, const QString &midRightText, const QString &bottomLeftText, const QString &bottomMidText, const QString &bottomRightText, KoTableStyle* tableStyle = 0);
+    QTextTable *addTable(QTextCursor cursor, int rows, int columns, KoTableStyle* tableStyle = 0);
 
 private:
     QTextDocument *m_doc;
