@@ -325,7 +325,7 @@ public:
     /**
        Handler for the EMR_EXTCREATEFONTINDIRECTW record type
 
-       \param extCreateFontIndirectWRecord the contents of the
+       \param extCreateFontIndirectW the contents of the
        EMR_EXTCREATEFONTINDIRECTW record
     */
     virtual void extCreateFontIndirectW( const ExtCreateFontIndirectWRecord &extCreateFontIndirectW ) = 0;
@@ -335,7 +335,7 @@ public:
        EMR_EXTTEXTOUTW and EMR_EXTTEXTOUTA record types.
 
        \param bounds the bounds used for e.g. clipping 
-       \param texObject The object describing the text.
+       \param textObject The object describing the text.
     */
     virtual void extTextOut( const QRect &bounds, const EmrTextObject &textObject ) = 0;
 
@@ -358,7 +358,7 @@ public:
        Handler for the EMR_MOVETOEX record type
 
        \param x the X coordinate of the point to move to
-       \param y the Y coordiante of the point to move to
+       \param y the Y coordinate of the point to move to
     */
     virtual void moveToEx( const qint32 x, const qint32 y ) = 0;
 
