@@ -32,7 +32,7 @@ class KOWIDGETS_EXPORT KoAspectButton : public QAbstractButton {
 public:
     /// constructor
     explicit KoAspectButton(QWidget *parent);
-    virtual ~KoAspectButton();
+    ~KoAspectButton() override;
 
     /// Returns of keeping aspect ratio is on or off
     bool keepAspectRatio() const;
@@ -48,16 +48,16 @@ public Q_SLOTS:
 Q_SIGNALS:
     /**
      * This signal is emitted every time the button changes value, either by user interaction or
-     *  by programetically setting it.
+     *  by programatically setting it.
      */
     void keepAspectRatioChanged(bool keep);
 
 protected:
     /// reimplemented
-    virtual void mouseReleaseEvent(QMouseEvent *);
-    virtual void paintEvent (QPaintEvent *);
-    virtual QSize sizeHint () const;
-    void keyReleaseEvent (QKeyEvent *e);
+    void mouseReleaseEvent(QMouseEvent *) override;
+    void paintEvent (QPaintEvent *) override;
+    QSize sizeHint () const override;
+    void keyReleaseEvent (QKeyEvent *e) override;
 
 private:
     class Private;
