@@ -21,7 +21,7 @@
 #ifndef KOCOLORPOPUPACTION_H
 #define KOCOLORPOPUPACTION_H
 
-#include <kaction.h>
+#include <QAction>
 
 #include "kowidgets_export.h"
 
@@ -32,7 +32,7 @@ class KoColor;
  * @see KoColorPopupAction
  */
 
-class KOWIDGETS_EXPORT KoColorPopupAction : public KAction
+class KOWIDGETS_EXPORT KoColorPopupAction : public QAction
 {
     Q_OBJECT
 
@@ -42,14 +42,14 @@ public:
       *
       * @param parent The parent for this action.
       */
-    explicit KoColorPopupAction(QObject *parent = 0);
+    explicit KoColorPopupAction(QObject *parent = nullptr);
 
     /**
      * Destructor
      */
-    virtual ~KoColorPopupAction();
+    ~KoColorPopupAction() override;
 
-public slots:
+public Q_SLOTS:
     /// Sets a new color to be displayed
     void setCurrentColor( const QColor &color );
 
@@ -65,7 +65,7 @@ public slots:
     /// update the icon - only needed if you resize the iconsize in the widget that shows the action
     void updateIcon();
 
-signals:
+Q_SIGNALS:
     /**
      * Emitted every time the color changes (by calling setColor() or
      * by user interaction.
@@ -73,10 +73,10 @@ signals:
      */
     void colorChanged(const KoColor &color);
 
-private slots:
+private Q_SLOTS:
     void emitColorChanged();
     void colorWasSelected(const KoColor &color, bool final);
-    void colorWasEdited( const QColor &color );
+    void colorWasEdited( const KoColor &color );
     void opacityWasChanged( int opacity );
     void slotTriggered(bool);
 
