@@ -37,14 +37,14 @@
 #include <QPointer>
 #include <QScrollArea>
 
-#include <klocale.h>
-#include <kdebug.h>
+#include <klocalizedstring.h>
+#include <WidgetsDebug.h>
 
 #include <KoColorSet.h>
 
 class KoColorPatch;
 
-class  KoColorSetWidget::KoColorSetWidgetPrivate {
+class Q_DECL_HIDDEN KoColorSetWidget::KoColorSetWidgetPrivate {
 public:
     KoColorSetWidget *thePublic;
     QPointer<KoColorSet> colorSet;
