@@ -60,7 +60,7 @@ public:
         setHeader(item->name());
         setIcon(QIcon::fromTheme(item->iconName()));
     }
-    ~KoPageWidgetItemAdapter() { delete m_item; }
+    ~KoPageWidgetItemAdapter() override { delete m_item; }
 
     bool shouldDialogCloseBeVetoed() { return m_item->shouldDialogCloseBeVetoed(); }
     void apply() { m_item->apply(); }
@@ -77,7 +77,7 @@ public:
         toggleEncryption(false),
         applyToggleEncryption(false),
         documentSaved(false) {}
-    ~KoDocumentInfoDlgPrivate() {}
+    ~KoDocumentInfoDlgPrivate() = default;
 
     KoDocumentInfo* info;
     QList<KPageWidgetItem*> pages;
