@@ -36,7 +36,7 @@ class KoEditColorSetWidget : public QWidget
     Q_OBJECT
 public:
     KoEditColorSetWidget(const QList<KoColorSet *> &palettes, const QString &activePalette, QWidget *parent = 0);
-    virtual ~KoEditColorSetWidget();
+    ~KoEditColorSetWidget() override;
 
     /**
      * Return the active color set. The caller takes ownership of that color set.
@@ -79,11 +79,11 @@ class KOWIDGETS_EXPORT KoEditColorSetDialog : public KoDialog
 public:
     /**
      * Constructs a KoEditColorSetDialog.
-     * @param palettes all availabe palettes that are going to be edited.
+     * @param palettes all available palettes that are going to be edited.
      * @param activePalette name of the palette which will be activated after this dialog is shown.
      * @param parent the parent widget
      */
-    KoEditColorSetDialog(const QList<KoColorSet *> &palettes, const QString &activePalette, QWidget *parent = 0);
+    KoEditColorSetDialog(const QList<KoColorSet *> &palettes, const QString &activePalette, QWidget *parent = nullptr);
 
     /**
      * Returns the last active color set.
@@ -95,7 +95,7 @@ public:
     /**
      * Destructor
      */
-    virtual ~KoEditColorSetDialog();
+    ~KoEditColorSetDialog() override;
 
 private:
     KoEditColorSetWidget *ui;
