@@ -37,20 +37,20 @@ public:
 
     KoGenericRegistryModel(KoGenericRegistry<T>* registry);
 
-    virtual ~KoGenericRegistryModel();
+    ~KoGenericRegistryModel() override = default;
 
 public:
 
     /**
      * @return the number of elements in the registry
      */
-    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
 
     /**
      * When role == Qt::DisplayRole, this function will return the name of the
      * element.
      */
-    virtual QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
 
     /**
      * @return the element at the given index
@@ -68,11 +68,6 @@ KoGenericRegistryModel<T>::KoGenericRegistryModel(KoGenericRegistry<T>* registry
 {
 }
 
-template<typename T>
-KoGenericRegistryModel<T>::~KoGenericRegistryModel()
-{
-}
-
 template<typename T>
 int KoGenericRegistryModel<T>::rowCount(const QModelIndex &/*parent*/) const
 {
