@@ -27,11 +27,11 @@ class KoIconToolTip: public KoItemToolTip
 {
 Q_OBJECT
     public:
-        KoIconToolTip() {}
-        virtual ~KoIconToolTip() {}
+        KoIconToolTip() = default;
+        ~KoIconToolTip() override = default;
 
     protected:
-        virtual QTextDocument *createDocument( const QModelIndex &index );
+        QTextDocument *createDocument( const QModelIndex &index ) override;
 
     private:
         typedef KoItemToolTip super;
