@@ -26,10 +26,10 @@ class KoLineStyleItemDelegate : public QAbstractItemDelegate
 {
 Q_OBJECT
 public:
-    explicit KoLineStyleItemDelegate(QObject *parent = 0);
-    ~KoLineStyleItemDelegate() {}
-    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const;
-    QSize sizeHint (const QStyleOptionViewItem &option, const QModelIndex &index) const;
+    explicit KoLineStyleItemDelegate(QObject *parent = nullptr);
+    ~KoLineStyleItemDelegate() override = default;
+    void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
+    QSize sizeHint (const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 };
 
 #endif
