@@ -29,11 +29,11 @@ class KoMarkerModel : public QAbstractListModel
 {
 Q_OBJECT
 public:
-    KoMarkerModel(const QList<KoMarker*> markers, KoMarkerData::MarkerPosition position, QObject *parent = 0);
-    virtual ~KoMarkerModel();
+    KoMarkerModel(const QList<KoMarker*> markers, KoMarkerData::MarkerPosition position, QObject *parent = nullptr);
+    ~KoMarkerModel() override = default;
 
-    int rowCount(const QModelIndex &parent = QModelIndex()) const;
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
 
     int markerIndex(KoMarker *marker) const;
     QVariant marker(int index, int role = Qt::UserRole) const;
