@@ -20,6 +20,8 @@
  * Boston, MA 02110-1301, USA.
  */
 
+#include <algorithm>
+
 #include "KoModeBox_p.h"
 
 #include <KoCanvasControllerWidget.h>
@@ -130,22 +132,14 @@ KoModeBox::KoModeBox(KoCanvasControllerWidget *canvas, const QString &appName)
     d->stack = new QStackedWidget();
 
     d->tabBar = new QTabBar();
-    d->tabBar->setExpanding(false);
-    if (d->iconMode == IconAndText) {
-        if (d->horizontalMode) {
-            d->tabBar->setIconSize(QSize(38,32));
-        } else {
-            d->tabBar->setIconSize(QSize(32,64));
-        }
-    } else {
-        d->tabBar->setIconSize(QSize(22,22));
-    }
-    d->tabBar->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
+    setIconSize();
+    d->tabBar->setExpanding(d->horizontalMode);
     if (d->horizontalMode) {
         switchTabsSide(d->verticalTabsSide);
     } else {
         switchTabsSide(d->horizontalTabsSide);
     }
+    d->tabBar->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
     d->layout->addWidget(d->stack, 0, 1);
 
     d->layout->setContentsMargins(0,0,0,0);
@@ -155,7 +149,7 @@ KoModeBox::KoModeBox(KoCanvasControllerWidget *canvas, const QString &appName)
         addToolAction(toolAction);
     }
 
-    qSort(d->toolActions.begin(), d->toolActions.end(), compareToolActions);
+    std::sort(d->toolActions.begin(), d->toolActions.end(), compareToolActions);
 
     // Update visibility of toolActions
     updateShownTools(QList<QString>());
@@ -213,16 +207,8 @@ void KoModeBox::locationChanged(Qt::DockWidgetArea area)
     d->layout->setSizeConstraint(QLayout::SetMinAndMaxSize);
     d->layout->invalidate();
 
-    if (d->iconMode == IconAndText) {
-        if (d->horizontalMode) {
-            d->tabBar->setIconSize(QSize(42,32));
-        } else {
-            d->tabBar->setIconSize(QSize(32,64));
-        }
-    } else {
-        d->tabBar->setIconSize(QSize(22,22));
-    }
-
+    setIconSize();
+    d->tabBar->setExpanding(d->horizontalMode);
     if (d->horizontalMode) {
         switchTabsSide(d->verticalTabsSide);
     } else {
@@ -259,6 +245,8 @@ void KoModeBox::setActiveTool(KoCanvasController *canvas, int id)
 
 QIcon KoModeBox::createTextIcon(KoToolAction *toolAction) const
 {
+    Q_ASSERT(!d->horizontalMode);
+
     QSize iconSize = d->tabBar->iconSize();
     QFont smallFont = QFontDatabase::systemFont(QFontDatabase::GeneralFont);
     qreal pointSize = QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont).pointSizeF();
@@ -268,25 +256,18 @@ QIcon KoModeBox::createTextIcon(KoToolAction *toolAction) const
     QImage pm(iconSize, QImage::Format_ARGB32_Premultiplied);
     pm.fill(Qt::transparent);
     QPainter p(&pm);
-    if (!d->horizontalMode) {
-        if (d->horizontalTabsSide == LeftSide ) {
-            p.rotate(90);
-            p.translate(0,-iconSize.width());
-        } else {
-            p.rotate(-90);
-            p.translate(-iconSize.height(),0);
-        }
+    if (d->horizontalTabsSide == LeftSide ) {
+        p.rotate(90);
+        p.translate(0,-iconSize.width());
+    } else {
+        p.rotate(-90);
+        p.translate(-iconSize.height(),0);
     }
 
     QIcon::fromTheme(toolAction->iconName()).paint(&p, 0, 0, iconSize.height(), 22);
 
     QTextLayout textLayout(toolAction->iconText(), smallFont, p.device());
-    QTextOption option;
-    if (d->horizontalMode) {
-        option = QTextOption(Qt::AlignVCenter | Qt::AlignHCenter);
-    } else {
-        option = QTextOption(Qt::AlignTop | Qt::AlignHCenter);
-    }
+    QTextOption option = QTextOption(Qt::AlignTop | Qt::AlignHCenter);
     option.setWrapMode(QTextOption::WrapAtWordBoundaryOrAnywhere);
     textLayout.setTextOption(option);
     textLayout.beginLayout();
@@ -349,7 +330,7 @@ void KoModeBox::addItem(KoToolAction *toolAction)
     QWidget *oldwidget = d->addedWidgets[toolAction->buttonGroupId()];
     QWidget *widget;
 
-    // We need to create a new widget in all cases as QToolBox seeems to crash if we reuse
+    // We need to create a new widget in all cases as QToolBox seems to crash if we reuse
     // a widget (even though the item had been removed)
     QLayout *layout;
     if (!oldwidget) {
@@ -365,7 +346,11 @@ void KoModeBox::addItem(KoToolAction *toolAction)
 
     // Create a rotated icon with text
     if (d->iconMode == IconAndText) {
-        d->tabBar->addTab(createTextIcon(toolAction), QString());
+        if (d->horizontalMode) {
+            d->tabBar->addTab(QIcon::fromTheme(toolAction->iconName()), toolAction->iconText());
+        } else {
+            d->tabBar->addTab(createTextIcon(toolAction), QString());
+        }
     } else {
         int index = d->tabBar->addTab(createSimpleIcon(toolAction), QString());
         d->tabBar->setTabToolTip(index, toolAction->toolTip());
@@ -550,7 +535,7 @@ void KoModeBox::setCurrentLayer(const KoCanvasController *canvas, const KoShapeL
 {
     Q_UNUSED(canvas);
     Q_UNUSED(layer);
-    //Since tageted application don't use this we won't bother implemeting
+    //Since targeted application don't use this we won't bother implementing
 }
 
 void KoModeBox::setCanvas(KoCanvasBase *canvas)
@@ -581,7 +566,7 @@ void KoModeBox::toolAdded(KoToolAction *toolAction, KoCanvasController *canvas)
     if (canvas->canvas() == d->canvas) {
         addToolAction(toolAction);
 
-        qStableSort(d->toolActions.begin(), d->toolActions.end(), compareToolActions);
+        std::stable_sort(d->toolActions.begin(), d->toolActions.end(), compareToolActions);
 
         updateShownTools(QList<QString>());
     }
@@ -623,15 +608,7 @@ void KoModeBox::slotContextMenuRequested(const QPoint &pos)
 void KoModeBox::switchIconMode(int mode)
 {
     d->iconMode = static_cast<IconMode>(mode);
-    if (d->iconMode == IconAndText) {
-        if (d->horizontalMode) {
-            d->tabBar->setIconSize(QSize(38,32));
-        } else {
-            d->tabBar->setIconSize(QSize(32,64));
-        }
-    } else {
-        d->tabBar->setIconSize(QSize(22,22));
-    }
+    setIconSize();
     updateShownTools(QList<QString>());
 
     KConfigGroup cfg =  KSharedConfig::openConfig()->group("calligra");
@@ -672,3 +649,11 @@ void KoModeBox::switchTabsSide(int side)
     }
     updateShownTools(QList<QString>());
 }
+
+void KoModeBox::setIconSize() const {
+    if (!d->horizontalMode && d->iconMode == IconAndText) {
+        d->tabBar->setIconSize(QSize(32,64));
+    } else {
+        d->tabBar->setIconSize(QSize(22,22));
+    }
+}
