@@ -43,7 +43,7 @@ class ScrollArea : public QScrollArea
 {
     Q_OBJECT
 protected:
-    void showEvent(QShowEvent *);
+    void showEvent(QShowEvent *) override;
 };
 
 /**
@@ -60,7 +60,7 @@ class KoModeBox : public QWidget {
 public:
     /// constructor
     explicit KoModeBox(KoCanvasControllerWidget *canvas, const QString &applicationName);
-    ~KoModeBox();
+    ~KoModeBox() override;
 
     /**
      * Should been called when the docker position has changed.
@@ -143,6 +143,7 @@ private:
     QIcon createTextIcon(KoToolAction *toolAction) const;
     QIcon createSimpleIcon(KoToolAction *toolAction) const;
     void addItem(KoToolAction *toolAction);
+    void setIconSize() const;
 
 private:
     class Private;
