@@ -22,8 +22,8 @@
 #include "KoPageLayoutWidget.h"
 #include "KoPagePreviewWidget.h"
 
-#include <klocale.h>
-#include <kdebug.h>
+#include <klocalizedstring.h>
+#include <WidgetsDebug.h>
 
 #include <QCheckBox>
 #include <QDialogButtonBox>
@@ -56,15 +56,16 @@ KoPageLayoutDialog::KoPageLayoutDialog(QWidget *parent, const KoPageLayout &layo
     lay->addWidget(d->pageLayoutWidget,1);
 
     KoPagePreviewWidget *prev = new KoPagePreviewWidget(widget);
-    prev->setPageLayout(layout);
+    // use not original layout, but "fixed" one (e.g. with 0 values) as now hold by pageLayoutWidget
+    prev->setPageLayout(d->pageLayoutWidget->pageLayout());
     lay->addWidget(prev, 1);
 
-    connect (d->pageLayoutWidget, SIGNAL(layoutChanged(const KoPageLayout&)),
-            prev, SLOT(setPageLayout(const KoPageLayout&)));
-    connect (d->pageLayoutWidget, SIGNAL(layoutChanged(const KoPageLayout&)),
-            this, SLOT(setPageLayout(const KoPageLayout&)));
-    connect (d->pageLayoutWidget, SIGNAL(unitChanged(const KoUnit&)),
-            this, SIGNAL(unitChanged(const KoUnit&)));
+    connect (d->pageLayoutWidget, SIGNAL(layoutChanged(KoPageLayout)),
+            prev, SLOT(setPageLayout(KoPageLayout)));
+    connect (d->pageLayoutWidget, SIGNAL(layoutChanged(KoPageLayout)),
+            this, SLOT(setPageLayout(KoPageLayout)));
+    connect (d->pageLayoutWidget, SIGNAL(unitChanged(KoUnit)),
+            this, SIGNAL(unitChanged(KoUnit)));
 }
 
 KoPageLayoutDialog::~KoPageLayoutDialog()
