@@ -34,7 +34,7 @@ class KOWIDGETS_EXPORT KoPageLayoutDialog : public KPageDialog
     Q_OBJECT
 public:
     explicit KoPageLayoutDialog(QWidget *parent, const KoPageLayout &layout);
-    ~KoPageLayoutDialog();
+    ~KoPageLayoutDialog() override;
 
     void showTextDirection(bool on);
     KoText::Direction textDirection() const;
@@ -48,15 +48,15 @@ public:
     void showUnitchooser(bool on);
     void setUnit(const KoUnit &unit);
 
-signals:
+Q_SIGNALS:
     void unitChanged(const KoUnit &unit);
 
-public slots:
+public Q_SLOTS:
     void setPageLayout(const KoPageLayout &layout);
 
-protected slots:
-    void accept();
-    void reject();
+protected Q_SLOTS:
+    void accept() override;
+    void reject() override;
 
 private:
     class Private;
