@@ -35,7 +35,7 @@ class KOWIDGETS_EXPORT KoPageLayoutWidget : public QWidget
 
 public:
     KoPageLayoutWidget(QWidget *parent, const KoPageLayout &layout);
-    ~KoPageLayoutWidget();
+    ~KoPageLayoutWidget() override;
 
     KoPageLayout pageLayout() const;
 
