@@ -62,14 +62,14 @@ public:
     {
     }
 
-    ~RadioLayout()
+    ~RadioLayout() override
     {
         foreach( const Item & item, items )
             delete item.child;
         items.clear();
     }
 
-    void setGeometry (const QRect &geom) {
+    void setGeometry (const QRect &geom) override {
         QSize prefSize = calcSizes();
 
         qreal columnWidth, rowHeight;
@@ -116,34 +116,34 @@ public:
         return prefSize;
     }
 
-    QLayoutItem *itemAt (int index) const {
+    QLayoutItem *itemAt (int index) const override {
         if( index < count() )
             return items.at(index).child;
         else
             return 0;
     }
 
-    QLayoutItem *takeAt (int index) {
+    QLayoutItem *takeAt (int index) override {
         Q_ASSERT(index < count());
         Item item = items.takeAt(index);
         return item.child;
     }
 
-    int count () const {
+    int count () const override {
         return items.count();
     }
 
-    void addItem(QLayoutItem *) {
+    void addItem(QLayoutItem *) override {
         Q_ASSERT(0);
     }
 
-    QSize sizeHint() const {
+    QSize sizeHint() const override {
         if(preferred.isEmpty())
             const_cast<RadioLayout*> (this)->calcSizes();
         return preferred;
     }
 
-    QSize minimumSize() const {
+    QSize minimumSize() const override {
         if(minimum.isEmpty())
             const_cast<RadioLayout*> (this)->calcSizes();
         return minimum;
