@@ -48,7 +48,8 @@ bool KoResourceItemView::viewportEvent(QEvent *event)
 
 void KoResourceItemView::selectionChanged(const QItemSelection &selected, const QItemSelection &/*deselected*/)
 {
-    emit currentResourceChanged(selected.indexes().first());
+    if (!selected.isEmpty())
+        emit currentResourceChanged(selected.indexes().first());
 }
 
 void KoResourceItemView::contextMenuEvent(QContextMenuEvent *event)
@@ -56,6 +57,3 @@ void KoResourceItemView::contextMenuEvent(QContextMenuEvent *event)
     QTableView::contextMenuEvent(event);
     emit contextMenuRequested(event->globalPos());
 }
-
-
-#include "KoResourceItemView.moc"
