@@ -34,11 +34,11 @@ class KoResourceItemView : public KoTableView
 
 public:
 
-    explicit KoResourceItemView(QWidget *parent = 0);
-    virtual ~KoResourceItemView() { disconnect(); }
+    explicit KoResourceItemView(QWidget *parent = nullptr);
+    ~KoResourceItemView() override { disconnect(); }
 
     /// reimplemented
-    virtual bool viewportEvent(QEvent *event);
+    bool viewportEvent(QEvent *event) override;
 
 Q_SIGNALS:
 
@@ -46,8 +46,8 @@ Q_SIGNALS:
     void contextMenuRequested(const QPoint &);
 
 protected:
-    virtual void contextMenuEvent(QContextMenuEvent *event);
-    void selectionChanged(const QItemSelection &selected, const QItemSelection &deselected);
+    void contextMenuEvent(QContextMenuEvent *event) override;
+    void selectionChanged(const QItemSelection &selected, const QItemSelection &deselected) override;
 
 private:
     KoIconToolTip m_tip;
