@@ -141,7 +141,8 @@ QModelIndex KoResourceModel::index ( int row, int column, const QModelIndex & )
 void KoResourceModel::doSafeLayoutReset(KoResource *activateAfterReformat)
 {
     emit beforeResourcesLayoutReset(activateAfterReformat);
-    reset();
+    beginResetModel();
+    endResetModel();
     emit afterResourcesLayoutReset();
 }
 
@@ -149,8 +150,9 @@ void KoResourceModel::setColumnCount( int columnCount )
 {
     if (columnCount != m_columnCount) {
         emit beforeResourcesLayoutReset(0);
+        beginResetModel();
         m_columnCount = columnCount;
-        reset();
+        endResetModel();
         emit afterResourcesLayoutReset();
     }
 }
