@@ -21,6 +21,8 @@
 #ifndef KORESOURCEPOPUPACTION_H
 #define KORESOURCEPOPUPACTION_H
 
+#include "kowidgets_export.h"
+
 #include <QAction>
 
 #include <QSharedPointer>
@@ -29,7 +31,7 @@ class KoShapeBackground;
 class KoAbstractResourceServerAdapter;
 class QModelIndex;
 
-class KoResourcePopupAction : public QAction
+class KOWIDGETS_EXPORT KoResourcePopupAction : public QAction
 {
     Q_OBJECT
 
@@ -37,6 +39,7 @@ public:
     /**
      * Constructs a KoResourcePopupAction (gradient or pattern) with the specified parent.
      *
+     * @param gradientResourceAdapter A pointer to gradient resource adapter.
      * @param parent The parent for this action.
      */
     explicit KoResourcePopupAction(QSharedPointer<KoAbstractResourceServerAdapter>gradientResourceAdapter, QObject *parent = 0);
@@ -44,7 +47,7 @@ public:
     /**
      * Destructor
      */
-    virtual ~KoResourcePopupAction();
+    ~KoResourcePopupAction() override;
 
     QSharedPointer<KoShapeBackground> currentBackground() const;
     void setCurrentBackground(QSharedPointer<KoShapeBackground> background);
