@@ -53,7 +53,7 @@ class KOWIDGETS_EXPORT KoResourceServerBase {
 public:
     /**
     * Constructs a KoResourceServerBase
-    * @param resource type, has to be the same as used by KoResourcePaths
+    * @param type type, has to be the same as used by KoResourcePaths
     * @param extensions the file extensions separate by ':', e.g. "*.kgr:*.svg:*.ggr"
     */
     KoResourceServerBase(const QString& type, const QString& extensions)
@@ -140,7 +140,7 @@ public:
         m_tagStore->loadTags();
     }
 
-    virtual ~KoResourceServer()
+    ~KoResourceServer() override
     {
         if (m_tagStore) {
             delete m_tagStore;
@@ -158,7 +158,7 @@ public:
 
     }
 
-    int resourceCount() const {
+    int resourceCount() const override {
         return m_resources.size();
     }
 
@@ -168,7 +168,7 @@ public:
      * be loaded or and invalid aren't added to the server.
      * @param filenames list of filenames to be loaded
      */
-    void loadResources(QStringList filenames) {
+    void loadResources(QStringList filenames) override {
 
         QStringList uniqueFiles;
 
@@ -290,11 +290,10 @@ public:
         if (m_blackListFileNames.contains(resource->filename())) {
             m_blackListFileNames.removeAll(resource->filename());
             writeBlackListFile();
-            }
-            else{
-                warnWidgets<<"Doesn't contain filename";
-                return false;
-            }
+        } else{
+            warnWidgets<<"Doesn't contain filename";
+            return false;
+        }
         
         
         //then return true//
@@ -479,7 +478,7 @@ public:
         notifyResourceChanged(resource);
     }
 
-    QStringList blackListedFiles() const
+    QStringList blackListedFiles() const override
     {
         return m_blackListFileNames;
     }
@@ -543,7 +542,7 @@ public:
         }
     }
 
-    QStringList queryResources(const QString &query) const
+    QStringList queryResources(const QString &query) const override
     {
         return m_tagStore->searchTag(query);
     }
@@ -556,7 +555,7 @@ public:
 
     /**
      * Create one or more resources from a single file. By default one resource is created.
-     * Overide to create more resources from the file.
+     * Override to create more resources from the file.
      * @param filename the filename of the resource or resource collection
      */
     virtual QList<PointerType> createResources( const QString & filename )
@@ -671,12 +670,12 @@ protected:
 
 protected:
 
-    KoResource* byMd5(const QByteArray &md5) const
+    KoResource* byMd5(const QByteArray &md5) const override
     {
         return Policy::toResourcePointer(resourceByMD5(md5));
     }
 
-    KoResource* byFileName(const QString &fileName) const
+    KoResource* byFileName(const QString &fileName) const override
     {
         return Policy::toResourcePointer(resourceByFilename(fileName));
     }
@@ -705,7 +704,7 @@ public:
     {
     }
 
-typename KoResourceServer<T, Policy>::PointerType createResource( const QString & filename ) {
+typename KoResourceServer<T, Policy>::PointerType createResource( const QString & filename ) override {
         return new T(filename);
     }
 };
