@@ -28,6 +28,7 @@
 
 class KoCanvasBase;
 class KoToolBox;
+class KoToolBoxScrollArea;
 
 class KoToolBoxDocker : public QDockWidget, public KoCanvasObserverBase
 {
@@ -36,10 +37,12 @@ public:
     explicit KoToolBoxDocker(KoToolBox *toolBox);
 
     /// reimplemented from KoCanvasObserverBase
-    virtual void setCanvas(KoCanvasBase *canvas);
-    virtual void unsetCanvas();
-    virtual QString observerName() const { return QStringLiteral("KoToolBoxDocker"); }
+    void setCanvas(KoCanvasBase *canvas) override;
+    void unsetCanvas() override;
+    QString observerName() const override { return QStringLiteral("KoToolBoxDocker"); }
 
+protected:
+    void resizeEvent(QResizeEvent *event) override;
 
 protected Q_SLOTS:
     void updateToolBoxOrientation(Qt::DockWidgetArea area);
@@ -47,6 +50,7 @@ protected Q_SLOTS:
 
 private:
     KoToolBox *m_toolBox;
+    KoToolBoxScrollArea *m_scrollArea;
 };
 
 #endif // _KO_TOOLBOX_DOCKER_H_
