@@ -35,13 +35,13 @@
 class KOWIDGETS_EXPORT KoToolBoxFactory : public KoDockFactoryBase
 {
 public:
-    explicit KoToolBoxFactory();
-    ~KoToolBoxFactory();
+    explicit KoToolBoxFactory() = default;
+    ~KoToolBoxFactory() override = default;
 
-    virtual QString id() const;
-    KoDockFactoryBase::DockPosition defaultDockPosition() const;
-    QDockWidget* createDockWidget();
-    virtual bool isCollapsable() const { return false; }
+    QString id() const override;
+    KoDockFactoryBase::DockPosition defaultDockPosition() const override;
+    QDockWidget* createDockWidget() override;
+    bool isCollapsable() const override { return false; }
 };
 
 #endif
