@@ -32,12 +32,12 @@ class KoUnit;
  * Spin box for double precision numbers with unit display.
  * Use this widget for any value that represents a real measurable value for consistency throughout
  * Calligra.
- * This widget shows the value in the user-selected units (inch, milimeters, etc) but keeps the
+ * This widget shows the value in the user-selected units (inch, millimeters, etc) but keeps the
  * calligra-widget default measurement unit internally. This has the advantage that just setting and
  * getting a value will not change the value due to conversions.
  * The KoDocument class has a unit() method for consistent (document wide) configuration of the
  * used unit.
- * It is adviced to use a QDoubleSpinBox in QtDesigner and then use the context-menu item: 'Promote to Custom Widget' and use the values: 'classname=KoUnitDoubleSpinBox', 'headerfile=KoUnitDoubleSpinBox.h'
+ * It is advised to use a QDoubleSpinBox in QtDesigner and then use the context-menu item: 'Promote to Custom Widget' and use the values: 'classname=KoUnitDoubleSpinBox', 'headerfile=KoUnitDoubleSpinBox.h'
  * This will generate code that uses this spinbox in the correct manner.
  */
 class KOWIDGETS_EXPORT KoUnitDoubleSpinBox : public QDoubleSpinBox
@@ -52,7 +52,7 @@ public:
      * @param parent the parent widget
      */
     explicit KoUnitDoubleSpinBox( QWidget *parent = 0);
-    ~KoUnitDoubleSpinBox();
+    ~KoUnitDoubleSpinBox() override;
 
     /**
      * Set the new value in points which will then be converted to the current unit for display
@@ -84,20 +84,20 @@ public:
     void setMinMaxStep( double min, double max, double step );
 
     /// reimplemented from superclass, will forward to KoUnitDoubleValidator
-    virtual QValidator::State validate(QString &input, int &pos) const;
+    QValidator::State validate(QString &input, int &pos) const override;
 
     /**
      * Transform the double in a nice text, using locale symbols
      * @param value the number as double
      * @return the resulting string
      */
-    virtual QString textFromValue( double value ) const;
+    QString textFromValue( double value ) const override;
     /**
-     * Transfrom a string into a double, while taking care of locale specific symbols.
+     * Transform a string into a double, while taking care of locale specific symbols.
      * @param str the string to transform into a number
      * @return the value as double
      */
-    virtual double valueFromText( const QString& str ) const;
+    double valueFromText( const QString& str ) const override;
 
 
 Q_SIGNALS:
