@@ -47,12 +47,12 @@ public:
    * @param parent The action's parent object.
    */
     KoZoomAction( KoZoomMode::Modes zoomModes, const QString& text, QObject *parent);
-    ~KoZoomAction();
+    ~KoZoomAction() override;
 
     /**
      * Reimplemented from QWidgetAction.
      */
-    virtual QWidget* createWidget(QWidget* parent);
+    QWidget* createWidget(QWidget* parent) override;
 
     enum SpecialButton {
         AspectMode = 1, ///< changing aspect mode
@@ -169,8 +169,8 @@ Q_SIGNALS:
      */
     void zoomedToAll();
 
-    void zoomLevelsChanged(QStringList values);
-    void currentZoomLevelChanged(QString valueString);
+    void zoomLevelsChanged(const QStringList &values);
+    void currentZoomLevelChanged(const QString &valueString);
     void sliderChanged(int value);
 
 public:
