@@ -24,8 +24,8 @@
 #include <KoZoomController_p.h>
 
 #include <kactioncollection.h>
-#include <klocale.h>
-#include <kdebug.h>
+#include <klocalizedstring.h>
+#include <WidgetsDebug.h>
 
 #include <KoZoomHandler.h>
 #include <KoCanvasBase.h>
@@ -39,8 +39,8 @@ void KoZoomController::Private::init(KoCanvasController *co,
     canvasController = co;
     fitMargin = co->margin();
     zoomHandler = zh;
-    connect(action, SIGNAL(zoomChanged(KoZoomMode::Mode, qreal)),
-            parent, SLOT(setZoom(KoZoomMode::Mode, qreal)));
+    connect(action, SIGNAL(zoomChanged(KoZoomMode::Mode,qreal)),
+            parent, SLOT(setZoom(KoZoomMode::Mode,qreal)));
     connect(action, SIGNAL(aspectModeChanged(bool)),
             parent, SIGNAL(aspectModeChanged(bool)));
     connect(action, SIGNAL(zoomedToSelection()),
@@ -55,9 +55,9 @@ void KoZoomController::Private::init(KoCanvasController *co,
         actionCollection->addAction(KStandardAction::ZoomOut,  "zoom_out", action, SLOT(zoomOut()));
     }
 
-    connect(canvasController->proxyObject, SIGNAL( sizeChanged(const QSize & ) ), parent, SLOT( setAvailableSize() ) );
+    connect(canvasController->proxyObject, SIGNAL(sizeChanged(QSize)), parent, SLOT(setAvailableSize()) );
 
-    connect(canvasController->proxyObject, SIGNAL( zoomRelative(const qreal, const QPointF& ) ), parent, SLOT( requestZoomRelative( const qreal, const QPointF& ) ) );
+    connect(canvasController->proxyObject, SIGNAL(zoomRelative(qreal,QPointF)), parent, SLOT(requestZoomRelative(qreal,QPointF)) );
 }
 
 KoZoomController::KoZoomController(KoCanvasController *co, KoZoomHandler *zh, KActionCollection *actionCollection, KoZoomAction::SpecialButtons specialButtons, QObject *parent)
@@ -198,9 +198,9 @@ void KoZoomController::setZoom(KoZoomMode::Mode mode, qreal zoom, qreal resoluti
 
 #ifdef DEBUG
     if(! d->documentSize.isValid())
-        kWarning(30004) << "Setting zoom while there is no document size set, this will fail";
+        warnWidgets << "Setting zoom while there is no document size set, this will fail";
     else if (d->pageSize.width() > d->documentSize.width() || d->pageSize.height() > d->documentSize.height())
-        kWarning(30004) << "ZoomController; Your page size is larger than your document size (" <<
+        warnWidgets << "ZoomController; Your page size is larger than your document size (" <<
             d->pageSize << " > " << d->documentSize << ")\n";
 #endif
 
@@ -262,5 +262,5 @@ void KoZoomController::setAspectMode(bool status)
         d->action->setAspectMode(status);
     }
 }
-
-#include <KoZoomController.moc>
+//have to include this because of Q_PRIVATE_SLOT
+#include <moc_KoZoomController.cpp>
