@@ -67,11 +67,39 @@ public:
     * @param zoomHandler the zoom handler (viewconverter with setter methods)
     * @param actionCollection the action collection where the KoZoomAction is added to
     * @param specialButtons controls which special buttons to show
+    * @param parent the parent QObject
     */
-    KoZoomController(KoCanvasController *controller, KoZoomHandler *zoomHandler, KActionCollection *actionCollection, KoZoomAction::SpecialButtons specialButtons = 0, QObject *parent = 0);
+    KoZoomController(KoCanvasController *controller,
+                     KoZoomHandler *zoomHandler,
+                     KActionCollection *actionCollection,
+                     KoZoomAction::SpecialButtons specialButtons = nullptr,
+                     QObject *parent = nullptr);
+
+    /**
+     * A special override for for creation of a zoom controller
+     * without automatic generation of standard zoom in and zoom out
+     * actions. The caller is supposed create and connect the
+     * corresponding actions himself.
+     *
+     * @param controller the canvasController
+     * @param zoomHandler the zoom handler (viewconverter with setter methods)
+     * @param actionCollection the action collection where the KoZoomAction is added to
+     * @param createZoomShortcuts shows whether the zoom actions should be
+     *                            created or not.
+     * @param specialButtons controls which special buttons to show
+     * @param parent the parent QObject
+     *
+     * Used in KisZoomController.
+     */
+    KoZoomController(KoCanvasController *controller,
+                     KoZoomHandler *zoomHandler,
+                     KActionCollection *actionCollection,
+                     bool createZoomShortcuts,
+                     KoZoomAction::SpecialButtons specialButtons = nullptr,
+                     QObject *parent = nullptr);
 
     /// destructor
-    ~KoZoomController();
+    ~KoZoomController() override;
 
     /// returns the zoomAction that is maintained by this controller
     KoZoomAction *zoomAction() const;
