@@ -46,7 +46,7 @@ public:
         GroupCenter  //!< The button is on the center of the group, so it would have separators on both sides
     };
 private:
-    Q_ENUM( GroupPosition )
+    Q_ENUMS( GroupPosition )
     Q_PROPERTY( GroupPosition groupPosition READ groupPosition WRITE setGroupPosition )
 public:
 
@@ -57,14 +57,14 @@ public:
      */
     explicit KoGroupButton(QWidget* parent = 0);
 
-    virtual ~KoGroupButton();
+    ~KoGroupButton() override;
 
     void setGroupPosition(KoGroupButton::GroupPosition groupPosition);
 
     KoGroupButton::GroupPosition groupPosition() const;
 
 protected:
-    virtual void paintEvent(QPaintEvent* event);
+    void paintEvent(QPaintEvent* event) override;
 
 private:
     class Private;
