@@ -36,12 +36,12 @@ public:
 
     explicit KoProgressBar(QWidget *parent = 0);
 
-    ~KoProgressBar();
+    ~KoProgressBar() override;
 
-    int maximum() const;
-    void setValue(int value);
-    void setRange(int minimum, int maximum);
-    void setFormat(const QString &format);
+    int maximum() const override;
+    void setValue(int value) override;
+    void setRange(int minimum, int maximum) override;
+    void setFormat(const QString &format) override;
 
 Q_SIGNALS:
 
