@@ -49,18 +49,15 @@ public:
         , m_progress(0)
         , m_weight(weight)
         , m_interrupted(false)
-        , m_hasOutput(false)
+        , m_hasOutput(parent->hasOutput())
         , m_parent(parent)
     {
-        if (parent) {
-            m_hasOutput = parent->hasOutput();
-        }
         setObjectName(name);
     }
 
     /// when deleting an updater, make sure the accompanying thread is
     /// interrupted, too.
-    virtual ~KoUpdaterPrivate();
+    ~KoUpdaterPrivate() override;
 
     bool interrupted() const { return m_interrupted; }
 
