@@ -83,7 +83,7 @@ void ArtisticTextShape::saveOdf(KoShapeSavingContext &context) const
         return;
 
     if(!svgWriter.save(fileContentDevice)) {
-        qWarning() << "Could not write svg content";
+        qWarning() << "ArtisticTextShape::saveOdf: Could not write svg content";
         return;
     }
 
@@ -91,13 +91,14 @@ void ArtisticTextShape::saveOdf(KoShapeSavingContext &context) const
     const QString mimeType = "image/svg+xml";
 
     context.xmlWriter().startElement("draw:frame");
+    saveOdfAttributes(context, OdfAllAttributes);
     context.embeddedSaver().embedFile(context.xmlWriter(), "draw:image", fileName, mimeType.toLatin1(), fileContent);
     context.xmlWriter().endElement(); // draw:frame
 }
 
-bool ArtisticTextShape::loadOdf(const KoXmlElement &/*element*/, KoShapeLoadingContext &/*context*/)
+bool ArtisticTextShape::loadOdf(const KoXmlElement &element, KoShapeLoadingContext &context)
 {
-    return false;
+    return loadOdfAttributes(element, context, OdfAllAttributes);
 }
 
 QSizeF ArtisticTextShape::size() const
@@ -788,7 +789,16 @@ void ArtisticTextShape::insertText(int charIndex, const QList<ArtisticTextRange>
         }
     }
 
-    // TODO: merge ranges with same style
+    for (auto it = m_ranges.begin(); it != m_ranges.end(); ++it) {
+        for (auto itNext = it + 1; itNext != m_ranges.end();) {
+            if (it->hasEqualStyle(*itNext)) {
+                it->appendText(itNext->text());
+                itNext = m_ranges.erase(itNext);
+            } else {
+                ++itNext;
+            }
+        }
+    }
 
     finishTextUpdate();
 }
@@ -810,9 +820,18 @@ void ArtisticTextShape::appendText(const ArtisticTextRange &text)
 {
     beginTextUpdate();
 
-    m_ranges.append(text);
+    bool merged = false;
+    for (ArtisticTextRange &textRange : m_ranges) {
+        if (textRange.hasEqualStyle(text)) {
+            textRange.appendText(text.text());
+            merged = true;
+            break;
+        }
+    }
 
-    // TODO: merge ranges with same style
+    if (!merged) {
+        m_ranges.append(text);
+    }
 
     finishTextUpdate();
 }
