@@ -49,7 +49,6 @@
 #include <QAction>
 #include <QDebug>
 
-#include <QAction>
 #include <QGridLayout>
 #include <QToolButton>
 #include <QCheckBox>
@@ -236,22 +235,21 @@ void ArtisticTextTool::mousePressEvent( KoPointerEvent *event )
 {
     if (m_hoverHandle) {
         m_currentStrategy = new MoveStartOffsetStrategy(this, m_currentShape);
+        event->accept();
+        return;
     }
     if (m_hoverText) {
-        KoSelection *selection = canvas()->shapeManager()->selection();
-        if(m_hoverText != m_currentShape) {
-            // if we hit another text shape, select that shape
-            selection->deselectAll();
-            setCurrentShape(m_hoverText);
-            selection->select( m_currentShape );
+        if(m_hoverText == m_currentShape) {
+            // change the text cursor position
+            int hitCursorPos = cursorFromMousePosition(event->point);
+            if (hitCursorPos >= 0) {
+                setTextCursorInternal(hitCursorPos);
+                m_selection.clear();
+            }
+            m_currentStrategy = new SelectTextStrategy(this, m_textCursor);
+            event->accept();
+            return;
         }
-        // change the text cursor position
-        int hitCursorPos = cursorFromMousePosition(event->point);
-        if (hitCursorPos >= 0) {
-            setTextCursorInternal(hitCursorPos);
-            m_selection.clear();
-        }
-        m_currentStrategy = new SelectTextStrategy(this, m_textCursor);
     }
     event->ignore();
 }
@@ -334,8 +332,11 @@ void ArtisticTextTool::mouseReleaseEvent( KoPointerEvent *event )
             canvas()->addCommand(cmd);
         delete m_currentStrategy;
         m_currentStrategy = 0;
+        event->accept();
+        return;
     }
     updateActions();
+    event->ignore();
 }
 
 void ArtisticTextTool::shortcutOverrideEvent(QKeyEvent *event)
@@ -492,7 +493,7 @@ void ArtisticTextTool::activate(ToolActivation toolActivation, const QSet<KoShap
         emit done();
         return;
     }
-
+    useCursor(Qt::ArrowCursor);
     m_hoverText = 0;
     m_hoverPath = 0;
 
@@ -605,7 +606,7 @@ QList<QPointer<QWidget> > ArtisticTextTool::createOptionWidgets()
     ArtisticTextShapeConfigWidget * configWidget = new ArtisticTextShapeConfigWidget(this);
     configWidget->setObjectName("ArtisticTextConfigWidget");
     configWidget->setWindowTitle(i18n("Text Properties"));
-    connect(configWidget, SIGNAL(fontFamilyChanged(QFont)), this, SLOT(setFontFamiliy(QFont)));
+    connect(configWidget, SIGNAL(fontFamilyChanged(QFont)), this, SLOT(setFontFamily(QFont)));
     connect(configWidget, SIGNAL(fontSizeChanged(int)), this, SLOT(setFontSize(int)));
     connect(this, SIGNAL(shapeSelected()), configWidget, SLOT(updateWidget()));
     connect(canvas()->shapeManager(), SIGNAL(selectionContentChanged()),
@@ -830,7 +831,7 @@ void ArtisticTextTool::changeFontProperty(FontProperty property, const QVariant
         case ItalicProperty:
             font.setItalic(value.toBool());
             break;
-        case FamiliyProperty:
+        case FamilyProperty:
             font.setFamily(value.toString());
             break;
         case SizeProperty:
@@ -870,9 +871,9 @@ void ArtisticTextTool::anchorChanged(QAction* action)
     }
 }
 
-void ArtisticTextTool::setFontFamiliy(const QFont &font)
+void ArtisticTextTool::setFontFamily(const QFont &font)
 {
-    changeFontProperty(FamiliyProperty, QVariant(font.family()));
+    changeFontProperty(FamilyProperty, QVariant(font.family()));
 }
 
 void ArtisticTextTool::setFontSize(int size)
