@@ -19,7 +19,7 @@
 
 #include "DetachTextFromPathCommand.h"
 #include "ArtisticTextShape.h"
-#include <klocale.h>
+#include <klocalizedstring.h>
 
 DetachTextFromPathCommand::DetachTextFromPathCommand( ArtisticTextShape * textShape, KUndo2Command * parent )
 : KUndo2Command(parent), m_textShape(textShape), m_pathShape(0)
