@@ -69,6 +69,7 @@
 #include <KChartThreeDLineAttributes>
 #include <KChartBackgroundAttributes>
 #include <KChartRulerAttributes>
+#include <kchart_version.h>
 
 // KoChart
 #include "PlotArea.h"
@@ -259,6 +260,7 @@ Axis::Private::Private(Axis *axis, AxisDimension dim)
 
     KChart::RulerAttributes attr = kdAxis->rulerAttributes();
     attr.setShowRulerLine(true);
+    attr.setRulerLinePen(QPen());
     kdAxis->setRulerAttributes(attr);
 }
 
@@ -876,6 +878,8 @@ Axis::Axis(PlotArea *parent, AxisDimension dimension)
     d->titleData->setResizeMethod(KoTextShapeDataBase::AutoResize);
     d->title->setAdditionalStyleAttribute("chart:auto-position", "true");
     d->title->setAllowedInteraction(KoShape::ShearingAllowed, false);
+    d->title->setAllowedInteraction(KoShape::RotationAllowed, false);
+    d->title->setAllowedInteraction(KoShape::ResizeAllowed, false);
     d->title->setVisible(false); // Needed to avoid problems when creating secondary axes (Axis creation needs review/refactoring)
 
     connect(d->plotArea, SIGNAL(angleOffsetChanged(qreal)), this, SLOT(setAngleOffset(qreal)));
@@ -1010,6 +1014,18 @@ void Axis::clearDataSets()
         detachDataSet(dataSet, true);
 }
 
+bool Axis::showRuler() const
+{
+    return d->kdAxis->rulerAttributes().showRulerLine();
+}
+
+void Axis::setShowRuler(bool show)
+{
+    KChart::RulerAttributes attr = d->kdAxis->rulerAttributes();
+    attr.setShowRulerLine(!attr.showRulerLine());
+    d->kdAxis->setRulerAttributes(attr);
+}
+
 qreal Axis::majorInterval() const
 {
     return d->majorInterval;
@@ -1339,6 +1355,8 @@ bool Axis::loadOdf(const KoXmlElement &axisElement, KoShapeLoadingContext &conte
 
         // NOTE: chart:dimension already handled by PlotArea before and passed
         // explicitly in the constructor.
+    } else {
+        warnChartOdf<<"No axis element";
     }
 
     if (axisElement.hasAttributeNS(KoXmlNS::chart, "style-name")) {
@@ -1410,6 +1428,13 @@ bool Axis::loadOdf(const KoXmlElement &axisElement, KoShapeLoadingContext &conte
         /*if (styleStack.hasProperty(KoXmlNS::chart, "origin")) {
             const qreal origin = KoUnit::parseValue(styleStack.property(KoXmlNS::chart, "origin"));
         }*/
+        styleStack.setTypeProperties("chart");
+        if (styleStack.hasProperty(KoXmlNS::chart, "axis-position")) {
+            d->axisPosition = styleStack.property(KoXmlNS::chart, "axis-position");
+        }
+        if (styleStack.hasProperty(KoXmlNS::chart, "axis-label-position")) {
+            d->axisLabelsPosition = styleStack.property(KoXmlNS::chart, "axis-label-position");
+        }
 
         styleStack.setTypeProperties("text");
         if (styleStack.hasProperty(KoXmlNS::fo, "font-size")) {
@@ -1456,13 +1481,8 @@ bool Axis::loadOdf(const KoXmlElement &axisElement, KoShapeLoadingContext &conte
                 // TODO
             }
         }
-        if (styleStack.hasProperty(KoXmlNS::chart, "axis-position")) {
-            d->axisPosition = styleStack.property(KoXmlNS::chart, "axis-position");
-        }
-        if (styleStack.hasProperty(KoXmlNS::chart, "axis-label-position")) {
-            d->axisLabelsPosition = styleStack.property(KoXmlNS::chart, "axis-label-position");
-        }
     } else {
+        warnChartOdf<<"Axis element has no style information";
         setShowLabels(KoOdfWorkaround::fixMissingStyle_DisplayLabel(axisElement, context));
     }
 
@@ -1521,6 +1541,7 @@ bool Axis::loadOdf(const KoXmlElement &axisElement, KoShapeLoadingContext &conte
     }
     requestRepaint();
 
+    debugChartOdf<<"Loaded axis:"<<name()<<"dimension:"<<dimension();
     return true;
 }
 
