@@ -28,9 +28,6 @@
 #include <QRegion>
 #include <QPoint>
 
-// KDE
-#include <kdebug.h>
-
 // Calligra
 #include <KoXmlReader.h>
 #include <KoShapeLoadingContext.h>
@@ -42,13 +39,18 @@
 #include <KoOdfGraphicStyles.h>
 #include <interfaces/KoChartModel.h>
 
-// KChart
+// KoChart
 #include "Axis.h"
 #include "DataSet.h"
 #include "TableSource.h"
 #include "OdfLoadingHelper.h"
+#include "ChartTableModel.h"
+#include "ChartDebug.h"
 
-using namespace KChart;
+// Other
+#include <algorithm>
+
+using namespace KoChart;
 
 
 // ================================================================
@@ -68,6 +70,8 @@ public:
     /// Used to avoid repeatedly updating data.
     bool isLoading;
 
+    bool manualControl;
+
     bool             firstRowIsLabel;
     bool             firstColumnIsLabel;
     Qt::Orientation  dataDirection;
@@ -106,6 +110,7 @@ ChartProxyModel::Private::Private(ChartProxyModel *parent, ChartShape *shape, Ta
     , shape(shape)
     , tableSource(source)
     , isLoading(false)
+    , manualControl(false)
 {
     firstRowIsLabel    = false;
     firstColumnIsLabel = false;
@@ -158,6 +163,9 @@ CellRegion ChartProxyModel::cellRangeAddress() const
 
 void ChartProxyModel::Private::rebuildDataMap()
 {
+    if (manualControl) {
+        return;
+    }
     // This was intended to speed up the loading process, by executing this
     // method only once in endLoading(), however the approach is actually
     // incorrect as it would potentially override a data set's regions
@@ -347,6 +355,9 @@ QMap<int, QVector<QRect> > sortDataRegions(Qt::Orientation dataDirection, QVecto
 QList<DataSet*> ChartProxyModel::Private::createDataSetsFromRegion(QList<DataSet*> *dataSetsToRecycle,
                                                                     bool overrideCategories)
 {
+    if (manualControl) {
+        return dataSets;
+    }
     if (!selection.isValid())
         return QList<DataSet*>();
 
@@ -412,7 +423,7 @@ QList<DataSet*> ChartProxyModel::Private::createDataSetsFromRegion(QList<DataSet
     // that are later used for the data sets
     Table *internalTable = shape ? shape->tableSource()->get(shape->internalModel()) : 0;
     QList<int> sortedDataKeys = sortedDataRegions.keys();
-    qSort(sortedDataKeys);
+    std::sort(sortedDataKeys.begin(), sortedDataKeys.end());
     foreach(int key, sortedDataKeys) {
         QVector<QRect> rects = sortedDataRegions[key];
         QVector<QRect> dataRects;
@@ -447,13 +458,13 @@ QList<DataSet*> ChartProxyModel::Private::createDataSetsFromRegion(QList<DataSet
             (dataDirection == Qt::Vertical && firstColumnIsLabel);
 
     /*
-    kDebug(35001) << "selection=" << selection.toString();
-    kDebug(35001) << "dataDirection=" << (dataDirection == Qt::Horizontal ? "Horizontal" : "Vertical");
-    kDebug(35001) << "firstRowIsLabel=" << firstRowIsLabel;
-    kDebug(35001) << "firstColumnIsLabel=" << firstColumnIsLabel;
-    kDebug(35001) << "overrideCategories=" << overrideCategories;
-    kDebug(35001) << "useCategories=" << useCategories;
-    kDebug(35001) << "dataRegions.count()="<<dataRegions.count();
+    debugChart << "selection=" << selection.toString();
+    debugChart << "dataDirection=" << (dataDirection == Qt::Horizontal ? "Horizontal" : "Vertical");
+    debugChart << "firstRowIsLabel=" << firstRowIsLabel;
+    debugChart << "firstColumnIsLabel=" << firstColumnIsLabel;
+    debugChart << "overrideCategories=" << overrideCategories;
+    debugChart << "useCategories=" << useCategories;
+    debugChart << "dataRegions.count()="<<dataRegions.count();
     */
 
     // Regions shared by all data sets: categories and x-data
@@ -507,11 +518,11 @@ if(overrideCategories) categoryDataRegion = CellRegion();
             dataSet->setCustomDataRegion(CellRegion());
 
         /*
-        kDebug(35001) << "xDataRegion=" << dataSet->xDataRegion().toString();
-        kDebug(35001) << "yDataRegion=" << dataSet->yDataRegion().toString();
-        kDebug(35001) << "categoryDataRegion=" << dataSet->categoryDataRegion().toString();
-        kDebug(35001) << "labelDataRegion=" << dataSet->labelDataRegion().toString();
-        kDebug(35001) << "customDataRegion=" << dataSet->customDataRegion().toString();
+        debugChart << "xDataRegion=" << dataSet->xDataRegion().toString();
+        debugChart << "yDataRegion=" << dataSet->yDataRegion().toString();
+        debugChart << "categoryDataRegion=" << dataSet->categoryDataRegion().toString();
+        debugChart << "labelDataRegion=" << dataSet->labelDataRegion().toString();
+        debugChart << "customDataRegion=" << dataSet->customDataRegion().toString();
         */
 
         createdDataSets.append(dataSet);
@@ -519,20 +530,24 @@ if(overrideCategories) categoryDataRegion = CellRegion();
         // Increment number at the very end!
         dataSetNumber++;
     }
-
     return createdDataSets;
 }
 
 void ChartProxyModel::saveOdf(KoShapeSavingContext &context) const
 {
-    foreach (DataSet *dataSet, d->dataSets)
-        dataSet->saveOdf(context);
+    int dataSetCount = rowCount();
+    if (d->shape->chartType() == StockChartType && d->shape->chartSubType() == HighLowCloseChartSubtype && dataSetCount > 3) {
+        // When loading, stock chart subtype is determined by number of datasets (sigh)
+        dataSetCount = 3;
+    }
+    for (int i = 0; i < dataSetCount; ++i) {
+        d->dataSets.at(i)->saveOdf(context);
+    }
 }
 
 // This loads the properties of the datasets (chart:series).
 // FIXME: This is a strange place to load them (the proxy model)
-bool ChartProxyModel::loadOdf(const KoXmlElement &element,
-                              KoShapeLoadingContext &context, int seriesPerDataset, ChartType type)
+bool ChartProxyModel::loadOdf(const KoXmlElement &element, KoShapeLoadingContext &context, ChartType type)
 {
     Q_ASSERT(d->isLoading);
 
@@ -575,7 +590,7 @@ bool ChartProxyModel::loadOdf(const KoXmlElement &element,
 
     // Do not ignore the data-source-has-labels in any case, even if a
     // category data region is specified for an axis, as the first
-    // column still has to be exluded from the actual data region if
+    // column still has to be excluded from the actual data region if
     // e.g. data-source-has-labels is set to "column" If an axis
     // contains the chart:categories element, the category data region
     // will automatically be set on every data set attached to that
@@ -597,16 +612,14 @@ bool ChartProxyModel::loadOdf(const KoXmlElement &element,
         d->firstColumnIsLabel = false;
     }
 
-    // For every data set, there must be an explicit <chart:series> element,
+    // For every dataset, there must be an explicit <chart:series> element,
     // which we will load later.
     d->dataSets.clear();
     d->removedDataSets.clear();
 
     // A cell range for all data is optional.
     // If cell ranges are in addition specified for one or more of these
-    // data series, they'll be overwritten by these values.
-    // Note: In case ignoreCellRanges is true, ChartShape::loadOdf() has
-    // already made sure the proxy is reset with data from the internal model.
+    // data series, they'll be overwritten by the data loaded from the series
     if (!ignoreCellRanges
         && element.hasAttributeNS(KoXmlNS::table, "cell-range-address"))
     {
@@ -636,110 +649,47 @@ bool ChartProxyModel::loadOdf(const KoXmlElement &element,
 
     int loadedDataSetCount = 0;
     KoXmlElement n;
-    QPen p;
-    QBrush brush;
-    bool penLoaded = false;
-    bool brushLoaded = false;
-    int stockSeriesCounter = 0;
     forEachElement (n, element) {
-        if (n.namespaceURI() != KoXmlNS::chart)
+        if (n.namespaceURI() != KoXmlNS::chart) {
             continue;
-
+        }
         if (n.localName() == "series") {
-            if (stockSeriesCounter == 0) {
-                DataSet *dataSet;
-                if (loadedDataSetCount < createdDataSets.size()) {
-                    dataSet = createdDataSets[loadedDataSetCount];
+            DataSet *dataSet;
+            if (loadedDataSetCount < createdDataSets.size()) {
+                dataSet = createdDataSets[loadedDataSetCount];
+            } else {
+                // the datasetnumber needs to be known at construction time, to ensure
+                // default colors are set correctly
+                dataSet = new DataSet(d->dataSets.size());
+            }
+            dataSet->setChartType(type);
+            d->dataSets.append(dataSet);
+            if (d->categoryDataRegion.isValid()) {
+                dataSet->setCategoryDataRegion(d->categoryDataRegion);
+            }
+            dataSet->loadOdf(n, context);
+
+            if (isBubble || isScatter) {
+                // bubble- and scatter-charts have chart:domain's that define the
+                // x- and y-data. But if they are not defined in the series then
+                // a previous defined one needs to be used.
+                // NOTE: This is not quite what odf specifies, but imho better (danders)
+                if (dataSet->xDataRegion().isValid()) {
+                    prevXData = dataSet->xDataRegion();
                 }
                 else {
-                    // the datasetnumber needs to be known at construction time, to ensure
-                    // default colors are set correctly
-                    dataSet = new DataSet(d->dataSets.size());
-                    // add the newly created dataSet to the createdDataSets list so our
-                    // stockSeriesCounter != 0 condition below is able to pick it up.
-                    createdDataSets.append(dataSet);
+                    dataSet->setXDataRegion(prevXData);
                 }
-                dataSet->setChartType(type);
-                d->dataSets.append(dataSet);
-                if (d->categoryDataRegion.isValid()) {
-                    dataSet->setCategoryDataRegion(d->categoryDataRegion);
-                }
-                dataSet->loadOdf(n, context);
-
-                if (isBubble || isScatter) {
-                    // bubble- and scatter-charts have chart:domain's that define the
-                    // x- and y-data. But if they are not defined in the series then
-                    // a previous defined one needs to be used.
-                    if (dataSet->xDataRegion().isValid()) {
-                        prevXData = dataSet->xDataRegion();
+                if (isBubble) {
+                    if (dataSet->yDataRegion().isValid()) {
+                        prevYData = dataSet->yDataRegion();
                     }
                     else {
-                        dataSet->setXDataRegion(prevXData);
-                    }
-                    if (isBubble) {
-                        if (dataSet->yDataRegion().isValid()) {
-                            prevYData = dataSet->yDataRegion();
-                        }
-                        else {
-                            dataSet->setYDataRegion(prevYData);
-                        }
-                    }
-                }
-
-                if (penLoaded)
-                    dataSet->setPen(p);
-                if (brushLoaded)
-                    dataSet->setBrush(brush);
-            }
-            else {
-                DataSet *dataSet;
-                if (loadedDataSetCount < createdDataSets.size())
-                    dataSet = createdDataSets[loadedDataSetCount];
-                else {
-                    Q_ASSERT_X(false, __FUNCTION__, "Unexpected series. Is the document broken?");
-                    continue; // be sure we don't crash in release-mode if that happens
-                }
-                dataSet->loadSeriesIntoDataset(n, context);
-            }
-            stockSeriesCounter = (stockSeriesCounter + 1) %  seriesPerDataset;
-            if (stockSeriesCounter == 0)
-                ++loadedDataSetCount;
-        } else if (n.localName() == "stock-range-line") {
-            KoStyleStack &styleStack = context.odfLoadingContext().styleStack();
-            styleStack.clear();
-
-            context.odfLoadingContext().fillStyleStack(n, KoXmlNS::chart, "style-name", "chart");
-            if (n.hasAttributeNS(KoXmlNS::chart, "style-name")) {
-                KoOdfLoadingContext &odfLoadingContext = context.odfLoadingContext();
-                brushLoaded = false;
-                penLoaded = false;
-
-                styleStack.setTypeProperties("graphic");
-
-                if (styleStack.hasProperty(KoXmlNS::svg, "stroke-color")) {
-                    QString stroke = "solid";/*styleStack.property(KoXmlNS::svg, "stroke-color");*/
-                    p = KoOdfGraphicStyles::loadOdfStrokeStyle(styleStack, stroke, odfLoadingContext.stylesReader());
-                    penLoaded = true;
-                    Q_FOREACH(DataSet* set, d->dataSets) {
-                        set->setPen(p);
-                        set->setBrush(p.color());
-                    }
-                }
-
-                if (styleStack.hasProperty(KoXmlNS::draw, "fill")) {
-                    QString fill = styleStack.property(KoXmlNS::draw, "fill");
-                    if (fill == "solid" || fill == "hatch") {
-                        brush = KoOdfGraphicStyles::loadOdfFillStyle(styleStack, fill, odfLoadingContext.stylesReader());
-                        brushLoaded = true;
-                    } else if (fill == "gradient") {
-                        brush = KoOdfGraphicStyles::loadOdfGradientStyle(styleStack, odfLoadingContext.stylesReader(), QSizeF(5.0, 60.0));
-                        brushLoaded = true;
-                    }
-                    Q_FOREACH(DataSet* set, d->dataSets) {
-                        set->setBrush(brush);
+                        dataSet->setYDataRegion(prevYData);
                     }
                 }
             }
+            ++loadedDataSetCount;
         }
     }
 
@@ -825,7 +775,11 @@ int ChartProxyModel::rowCount(const QModelIndex &/*parent  = QModelIndex() */) c
 int ChartProxyModel::columnCount(const QModelIndex &/*parent = QModelIndex() */) const
 {
     // FIXME: Replace this by the actual column count once the proxy is properly being used.
-    return INT_MAX;
+    int cols = 0;
+    for (int i = 0; i < d->dataSets.count(); ++i) {
+        cols = qMax(cols, d->dataSets.at(i)->size());
+    }
+    return cols;
 }
 
 void ChartProxyModel::setFirstRowIsLabel(bool b)
@@ -931,4 +885,72 @@ QList<DataSet*> ChartProxyModel::dataSets() const
     return d->dataSets;
 }
 
-#include "ChartProxyModel.moc"
+void ChartProxyModel::addDataSet(int pos)
+{
+    int dataSetNr = pos;
+    QMap<int, int> numbers;
+    for (int i = 0; i < d->dataSets.count(); ++i) {
+        numbers[d->dataSets.at(i)->number()] = i;
+    }
+    if (numbers.contains(pos)) {
+        // find first free one
+        for (int i = 1; i < numbers.count(); ++ i) {
+            if (!numbers.contains(i)) {
+                dataSetNr = i;
+                break;
+            }
+        }
+    }
+    DataSet *ds = new DataSet(dataSetNr);
+    if (!d->dataSets.isEmpty()) {
+        DataSet *copy = d->dataSets.first();
+        ds->setXDataRegion(copy->xDataRegion());
+        ds->setYDataRegion(copy->yDataRegion());
+        ds->setCustomDataRegion(copy->customDataRegion());
+        ds->setCategoryDataRegion(copy->categoryDataRegion());
+    }
+    d->dataSets.insert(pos, ds);
+}
+
+bool ChartProxyModel::insertRows(int row, int count, const QModelIndex &/*parent*/)
+{
+    if (count < 1 || row < 0 || row > d->dataSets.count()) {
+        return false;
+    }
+    beginResetModel();
+    for (int i = 0; i < count; ++i) {
+        addDataSet(row + i);
+    }
+    endResetModel();
+    dataChanged(QModelIndex(), QModelIndex());
+    return true;
+}
+
+bool ChartProxyModel::removeRows(int row, int count, const QModelIndex &/*parent*/)
+{
+    if (count < 1 || row < 0 || row >= d->dataSets.count()) {
+        return false;
+    }
+    beginResetModel();
+    QList<DataSet*> remove;
+    for (int i = 0;  i < count; ++i) {
+        remove <<  d->dataSets.at(row + i);
+    }
+    for (DataSet *ds : remove) {
+        d->dataSets.removeAll(ds);
+        delete ds;
+    }
+    endResetModel();
+    dataChanged(QModelIndex(), QModelIndex());
+    return true;
+}
+
+void ChartProxyModel::setManualControl(bool value)
+{
+    d->manualControl = value;
+}
+
+bool ChartProxyModel::manualControl()
+{
+    return d->manualControl;
+}
