@@ -31,6 +31,7 @@
 // Qt
 #include <QPointF>
 #include <QPainter>
+#include <QPainterPath>
 #include <QSizeF>
 #include <QTextDocument>
 #include <QUrl>
@@ -1060,6 +1061,7 @@ bool ChartShape::loadOdfData(const KoXmlElement &tableElement,
     internalModel->loadOdf(tableElement, context);
 
     QString tableName = tableElement.attributeNS(KoXmlNS::table, "name");
+    debugChartOdf<<"Loaded table:"<<tableName;
     d->tableSource.add(tableName, internalModel);
     // TODO: d->tableSource.setAvoidNameClash(tableName)
     setInternalModel(internalModel);
