@@ -23,7 +23,7 @@
 
 #include <KoToolFactoryBase.h>
 
-namespace KChart
+namespace KoChart
 {
 
 class ChartToolFactory : public KoToolFactoryBase
@@ -32,10 +32,10 @@ public:
     ChartToolFactory();
     ~ChartToolFactory();
 
-    KoToolBase * createTool(KoCanvasBase *canvas);
+    KoToolBase * createTool(KoCanvasBase *canvas) override;
 };
 
-} // namespace KChart
+} // namespace KoChart
 
 
 #endif
