@@ -25,6 +25,7 @@
 
 // Own
 #include "DataSet.h"
+#include "ChartDebug.h"
 
 // Qt
 #include <QAbstractItemModel>
@@ -72,24 +73,24 @@ const int numDefaultMarkerTypes = 15;
 // These are the values that are defined for chart:symbol-name
 // Ref: ODF 1.2 20.54 chart:symbol-name, page 716
 const QByteArray symbolNames[] = {
-    "square", 
-    "diamond", 
+    "square",
+    "diamond",
     "arrow-down",
-    "arrow-up", 
-    "arrow-right", 
-    "arrow-left", 
-    "bow-tie", 
-    "hourglass", 
-    "circle", 
-    "star", 
-    "x", 
+    "arrow-up",
+    "arrow-right",
+    "arrow-left",
+    "bow-tie",
+    "hourglass",
+    "circle",
+    "star",
+    "x",
     "plus",
-    "asterisk", 
-    "horizontal-bar", 
+    "asterisk",
+    "horizontal-bar",
     "vertical-bar"
 };
 
-const KChart::MarkerAttributes::MarkerStyle defaultMarkerTypes[]= { 
+const KChart::MarkerAttributes::MarkerStyle defaultMarkerTypes[]= {
     KChart::MarkerAttributes::MarkerSquare,     // 0
     KChart::MarkerAttributes::MarkerDiamond,    // 1
     KChart::MarkerAttributes::MarkerArrowDown,  // 2
@@ -127,10 +128,10 @@ public:
                         const QBrush& brush, const QPen& pen,
                         const QPointF& point, const QSizeF& size );
 public: // abstract KChart::AbstractDiagram API
-    virtual void paint ( KChart::PaintContext* /*paintContext*/ ) {}
-    virtual void resize ( const QSizeF& /*area*/ ) {}
+    void paint ( KChart::PaintContext* /*paintContext*/ ) override {}
+    void resize ( const QSizeF& /*area*/ ) override {}
 protected: // abstract KChart::AbstractDiagram API
-    virtual const QPair<QPointF, QPointF> calculateDataBoundaries() const { return QPair<QPointF, QPointF>(); }
+    const QPair<QPointF, QPointF> calculateDataBoundaries() const override { return QPair<QPointF, QPointF>(); }
 };
 
 void MarkerPainterDummyDiagram::doPaintMarker(QPainter* painter, const KChart::MarkerAttributes& markerAttributes, const QBrush& brush, const QPen& pen, const QPointF& point, const QSizeF& size)
@@ -190,6 +191,7 @@ public:
     ChartSubtype  chartSubType;
 
     Axis *attachedAxis;
+    QString axisName;
     bool showMeanValue;
     QPen meanValuePen;
     bool showLowerErrorIndicator;
@@ -204,8 +206,6 @@ public:
     bool penIsSet;
     // Determines whether brush has been set
     bool brushIsSet;
-    // Determines whether marker has been set automatically
-    bool markerIsAutoSet;
     QPen pen;
     QBrush brush;
     QMap<int, DataSet::ValueLabelType> valueLabelType;
@@ -242,8 +242,11 @@ public:
 
     /// Used if no data region for the label is specified
     const QString defaultLabel;
-    bool symbolsActivated;
+    // TODO markers can also apply to chart:data-point>, <chart:series> or <chart:plot-area>
     int symbolID;
+    OdfSymbolType odfSymbolType; // Used for markers
+    bool markersUsed;
+
     int loadedDimensions;
 
     KoOdfNumberStyles::NumericStyleFormat *numericStyleFormat;
@@ -263,7 +266,6 @@ DataSet::Private::Private(DataSet *parent, int dataSetNr) :
     upperErrorLimit(0.0),
     penIsSet(false),
     brushIsSet(false),
-    markerIsAutoSet(true),
     pen(QPen(Qt::black)),
     brush(QColor(Qt::white)),
     dataValueAttributes(defaultDataValueAttributes()),
@@ -271,8 +273,9 @@ DataSet::Private::Private(DataSet *parent, int dataSetNr) :
     kdChartModel(0),
     size(0),
     defaultLabel(i18n("Series %1", dataSetNr + 1)),
-    symbolsActivated(true),
     symbolID(0),
+    odfSymbolType(AutomaticSymbol),
+    markersUsed(false),
     loadedDimensions(0),
     numericStyleFormat(0)
 {
@@ -358,6 +361,7 @@ KChart::DataValueAttributes DataSet::Private::defaultDataValueAttributes() const
 
 void DataSet::Private::insertDataValueAttributeSectionIfNecessary(int section)
 {
+    Q_ASSERT(section >= 0);
     if (!sectionsDataValueAttributes.contains(section))
         sectionsDataValueAttributes[section] = dataValueAttributes;
 }
@@ -635,6 +639,7 @@ void DataSet::Private::setAttributesAccordingToType()
     dataValueAttributes = attr;
 
     for (int i = 0; i < sectionsDataValueAttributes.count(); ++i) {
+        Q_ASSERT(sectionsDataValueAttributes.contains(i));
         KChart::DataValueAttributes attr = sectionsDataValueAttributes[i];
         KChart::RelativePosition positivePosition = attr.positivePosition();
         if (chartType ==  KoChart::BarChartType && chartSubType != KoChart::NormalChartSubtype) {
@@ -688,7 +693,20 @@ void DataSet::setChartType(ChartType type)
     d->setAttributesAccordingToType();
 
     if (axis)
-        axis->attachDataSet(this);    
+        axis->attachDataSet(this);
+
+    switch (type) {
+        case LineChartType:
+        case AreaChartType:
+        case ScatterChartType:
+        case RadarChartType:
+        case FilledRadarChartType:
+            d->markersUsed = true;
+            break;
+        default:
+            d->markersUsed = false;
+            break;
+    }
 }
 
 void DataSet::setChartSubType(ChartSubtype subType)
@@ -729,17 +747,14 @@ OdfMarkerStyle DataSet::markerStyle() const
 
 QIcon DataSet::markerIcon(OdfMarkerStyle markerStyle)
 {
-    if (markerStyle != NoMarker) {
-        QPixmap markerPixmap(16,16);
-        markerPixmap.fill(QColor(255,255,255,0));
-        QPainter painter(&markerPixmap);
-        KChart::MarkerAttributes matt;
-        matt.setMarkerStyle(odf2kdMarker(markerStyle));
-        MarkerPainterDummyDiagram().doPaintMarker(&painter, matt, brush(), pen(), QPointF(7,7), QSizeF(12,12));
-        QIcon markerIcon = QIcon(markerPixmap);
-        return markerIcon;
-    }
-    return QIcon();
+    QPixmap markerPixmap(16,16);
+    markerPixmap.fill(QColor(255,255,255,0));
+    QPainter painter(&markerPixmap);
+    KChart::MarkerAttributes matt;
+    matt.setMarkerStyle(odf2kdMarker(markerStyle));
+    MarkerPainterDummyDiagram().doPaintMarker(&painter, matt, brush(), pen(), QPointF(7,7), QSizeF(12,12));
+    QIcon markerIcon = QIcon(markerPixmap);
+    return markerIcon;
 }
 
 QPen DataSet::pen(int section) const
@@ -781,7 +796,7 @@ qreal DataSet::Private::maxBubbleSize() const
 {
     // TODO: Improve performance by caching. This is currently O(n^2).
     // this is not in O(n^2), its quite linear on the number of datapoints
-    // hoever it could be constant for any then the first case by implementing
+    // however it could be constant for any then the first case by implementing
     // cashing
     qreal max = 0.0;
     Q_ASSERT(kdChartModel);
@@ -807,12 +822,6 @@ KChart::DataValueAttributes DataSet::dataValueAttributes(int section /* = -1 */)
 
     // The chart type is a property of the plot area, check that.
     switch (d->effectiveChartType()) {
-//     case ScatterChartType:
-//         // TODO: Marker type should be customizable
-//         // TODO: Marker size should be customizable
-//         ma.setMarkerStyle(defaultMarkerTypes[number() % numDefaultMarkerTypes]);
-//         ma.setVisible(true);
-//         break;
     case BarChartType:
     case CircleChartType:
     case RingChartType:
@@ -821,15 +830,14 @@ KChart::DataValueAttributes DataSet::dataValueAttributes(int section /* = -1 */)
         Q_ASSERT(attr.isVisible());
         ma.setMarkerStyle(KChart::MarkerAttributes::MarkerSquare);
         ma.setMarkerSize(QSize(10, 10));
-        ma.setVisible(true);
-        d->symbolsActivated = false;
+        ma.setVisible(true); // For legend
         break;
     }
     case BubbleChartType:
     {
         Q_ASSERT(attachedAxis());
         Q_ASSERT(attachedAxis()->plotArea());
-        ma.setMarkerStyle(KChart::MarkerAttributes::MarkerCircle);        
+        ma.setMarkerStyle(KChart::MarkerAttributes::MarkerCircle);
         ma.setThreeD(attachedAxis()->plotArea()->isThreeD());
         qreal maxSize = d->maxBubbleSize();
         if (section >= 0) {
@@ -844,56 +852,76 @@ KChart::DataValueAttributes DataSet::dataValueAttributes(int section /* = -1 */)
             ma.setMarkerSize(QSizeF(bubbleWidth, bubbleWidth));
         }
         ma.setVisible(true);
-        d->symbolsActivated = false;
         break;
     }
     default:
-        // TODO: Make markers customizable even for other types
         Q_ASSERT(attr.isVisible());
-        ma.setMarkerStyle(odf2kdMarker((OdfMarkerStyle)d->symbolID));
-        ma.setMarkerSize(QSize(10, 10));
-        ma.setVisible(true);
-        d->symbolsActivated = true;
-//             attr.setVisible(true);
-        // Do not overwrite visibility in this case. It could very well have
-        // been set to 'visible' on purpose by e.g. loadOdf().
-        //else
-        //    ma.setVisible(false);
+        switch (d->odfSymbolType) {
+            case NoSymbol:
+                ma.setVisible(false);
+                break;
+            case ImageSymbol: // Not supported
+            case AutomaticSymbol:
+                ma.setMarkerStyle(odf2kdMarker((OdfMarkerStyle)(d->num % numDefaultMarkerTypes)));
+                ma.setMarkerSize(QSize(10, 10));
+                ma.setVisible(true);
+            case NamedSymbol:
+                ma.setMarkerStyle(odf2kdMarker((OdfMarkerStyle)d->symbolID));
+                ma.setVisible(true);
+                break;
+        }
         break;
     }
 
     ma.setMarkerColor(brush(section).color());
     ma.setPen(pen(section));
 
-    QString dataLabel = ""; // initialize with empty and NOT null!
+    QLocale locale;
+    QString dataLabel = ""; // must not be isNull() because then KChart uses a default text
     ValueLabelType type = valueLabelType(section);
-    if (type.symbol) {
-        //TODO is that correct?
-        ma.setVisible(true);
-    }
     if (type.category) {
         QString s = categoryData(section, Qt::DisplayRole).toString().trimmed();
         if (!s.isEmpty()) dataLabel += s + QLatin1Char(' ');
     }
     if (type.number) {
-        QString s = d->formatData(d->yDataRegion, section, Qt::DisplayRole);
+        QString s;
+        if (d->effectiveChartType() == BubbleChartType) {
+            s = d->formatData(d->customDataRegion, section, Qt::DisplayRole);
+        } else {
+            s = d->formatData(d->yDataRegion, section, Qt::DisplayRole);
+        }
         if (!s.isEmpty()) dataLabel += s + QLatin1Char(' ');
     }
     if (type.percentage) {
         bool ok;
-        qreal value = yData(section, Qt::EditRole).toDouble(&ok);
-        if (ok) {
-            qreal sum = 0.0;
-            for(int i = 0; i < d->yDataRegion.cellCount(); ++i) {
-                sum += yData(i, Qt::EditRole).toDouble();
+        qreal value;
+        if (d->effectiveChartType() == BubbleChartType) {
+            value = customData(section, Qt::EditRole).toDouble(&ok);
+            if (ok) {
+                qreal sum = 0.0;
+                for(int i = 0; i < d->customDataRegion.cellCount(); ++i) {
+                    sum += customData(i, Qt::EditRole).toDouble();
+                }
+                if (sum == 0.0)
+                    ok = false;
+                else
+                    value = value / sum * 100.0;
+            }
+        } else {
+            value = yData(section, Qt::EditRole).toDouble(&ok);
+            if (ok) {
+                qreal sum = 0.0;
+                for(int i = 0; i < d->yDataRegion.cellCount(); ++i) {
+                    sum += yData(i, Qt::EditRole).toDouble();
+                }
+                if (sum == 0.0)
+                    ok = false;
+                else
+                    value = value / sum * 100.0;
             }
-            if (sum == 0.0)
-                ok = false;
-            else
-                value = value / sum * 100.0;
         }
         if (ok)
-            dataLabel += QString::number(value, 'f', 0) + "% ";
+            dataLabel += locale.toString(value, 'f', 0) + locale.percent();
     }
     attr.setDataLabel(dataLabel.trimmed());
 
@@ -917,11 +945,6 @@ KChart::MarkerAttributes DataSet::getMarkerAttributes(int section) const
     return ma;
 }
 
-bool DataSet::markerAutoSet() const
-{
-    return d->markerIsAutoSet;
-}
-
 void DataSet::setMarkerAttributes(const KChart::MarkerAttributes &attribs, int section)
 {
     KChart::DataValueAttributes attr(d->dataValueAttributes);
@@ -933,9 +956,14 @@ void DataSet::setMarkerAttributes(const KChart::MarkerAttributes &attribs, int s
     d->dataValueAttributes = attr;
 }
 
-void DataSet::setAutoMarker(bool isAuto)
+OdfSymbolType DataSet::odfSymbolType() const
 {
-    d->markerIsAutoSet = isAuto;
+    return d->odfSymbolType;
+}
+
+void DataSet::setOdfSymbolType(OdfSymbolType type)
+{
+    d->odfSymbolType = type;
 }
 
 void DataSet::setPen(const QPen &pen)
@@ -953,7 +981,7 @@ void DataSet::setPen(const QPen &pen)
 //         mattr.setMarkerColor(pen.color());
 //         it->setMarkerAttributes(mattr);
 //     }
-    
+
 }
 
 void DataSet::setBrush(const QBrush &brush)
@@ -982,6 +1010,10 @@ void DataSet::setPieExplodeFactor(int factor)
 
 void DataSet::setPen(int section, const QPen &pen)
 {
+    if (section < 0) {
+        setPen(pen);
+        return;
+    }
     d->pens[section] = pen;
     if (d->kdChartModel)
         d->kdChartModel->dataSetChanged(this, KChartModel::PenDataRole, section);
@@ -993,6 +1025,10 @@ void DataSet::setPen(int section, const QPen &pen)
 
 void DataSet::setBrush(int section, const QBrush &brush)
 {
+    if (section < 0) {
+        setBrush(brush);
+        return;
+    }
     d->brushes[section] = brush;
     if (d->kdChartModel)
         d->kdChartModel->dataSetChanged(this, KChartModel::BrushDataRole, section);
@@ -1008,12 +1044,15 @@ void DataSet::setMarkerStyle(OdfMarkerStyle style)
     matt.setMarkerStyle(odf2kdMarker(style));
     setMarkerAttributes(matt);
 
-    d->symbolsActivated = true;
     d->symbolID = style;
 }
 
 void DataSet::setPieExplodeFactor(int section, int factor)
 {
+    if (section < 0) {
+        setPieExplodeFactor(factor);
+        return;
+    }
     KChart::PieAttributes &pieAttributes = d->sectionsPieAttributes[section];
     pieAttributes.setExplodeFactor((qreal)factor / (qreal)100);
     if (d->kdChartModel)
@@ -1088,6 +1127,9 @@ QVariant DataSet::xData(int index, int role) const
     // 2 data sets in total afterwards. The first column is y data, the second
     // bubble width. Same for the second data set. So there is nothing left
     // for x data. Instead use a fall-back to the data points index.
+    // Note by danders:
+    // ODF spec says bubble charts *must* have xdata, ydata and bubble width.
+    // However LO allows for no xdata in which case it used data index (as we do here).
     QVariant data = d->data(d->xDataRegion, index, role);
     if (data.isValid() && data.canConvert< double >() && data.convert(QVariant::Double) )
         return data;
@@ -1225,7 +1267,7 @@ void DataSet::setCustomDataRegion(const CellRegion &region)
 {
     d->customDataRegion = region;
     d->updateSize();
-    
+
     if (d->kdChartModel)
         d->kdChartModel->dataSetChanged(this, KChartModel::CustomDataRole);
 }
@@ -1414,17 +1456,21 @@ void DataSet::Private::readValueLabelType(KoStyleStack &styleStack, int section
 
     const QString number = styleStack.property(KoXmlNS::chart, "data-label-number");
     if (!number.isNull()) {
+        type.numberIsLoaded = true;
         type.number = (number == "value" || number == "value-and-percentage");
         type.percentage = (number == "percentage" || number == "value-and-percentage");
     }
 
     const QString text = styleStack.property(KoXmlNS::chart, "data-label-text");
     if (!text.isNull()) {
+        type.categoryIsLoaded = true;
         type.category = (text == "true");
     }
 
     const QString symbol = styleStack.property(KoXmlNS::chart, "data-label-symbol");
     if (!symbol.isNull()) {
+        warnChartOdf<<"data-label-symbol not supported";
+        type.symbolIsLoaded = true;
         type.symbol = (symbol == "true");
     }
 
@@ -1434,7 +1480,6 @@ void DataSet::Private::readValueLabelType(KoStyleStack &styleStack, int section
 bool DataSet::loadOdf(const KoXmlElement &n,
                       KoShapeLoadingContext &context)
 {
-    d->symbolsActivated = false;
     KoOdfLoadingContext &odfLoadingContext = context.odfLoadingContext();
     KoOdfStylesReader &stylesReader = odfLoadingContext.stylesReader();
     KoStyleStack &styleStack = odfLoadingContext.styleStack();
@@ -1515,7 +1560,7 @@ bool DataSet::loadOdf(const KoXmlElement &n,
                     setXDataRegion(CellRegion(helper->tableSource, region));
                 }
                 else {
-                    const QString region = elem.attributeNS(KoXmlNS::table, "cell-range-address", QString());                    
+                    const QString region = elem.attributeNS(KoXmlNS::table, "cell-range-address", QString());
                     setYDataRegion(CellRegion(helper->tableSource, region));
                 }
                 ++domainCount;
@@ -1525,12 +1570,14 @@ bool DataSet::loadOdf(const KoXmlElement &n,
             cn = cn.nextSibling();
         }
     }
-
+    if (n.hasAttributeNS(KoXmlNS::chart, "attached-axis")) {
+        d->axisName = n.attributeNS(KoXmlNS::chart, "attached-axis");
+    }
     if (n.hasAttributeNS(KoXmlNS::chart, "values-cell-range-address") && !ignoreCellRanges) {
         const QString regionString = n.attributeNS(KoXmlNS::chart, "values-cell-range-address", QString());
         const CellRegion region(helper->tableSource, regionString);
         if (bubbleChart) {
-            setCustomDataRegion(region);            
+            setCustomDataRegion(region);
         }
         else {
             setYDataRegion(region);
@@ -1548,12 +1595,17 @@ bool DataSet::loadOdf(const KoXmlElement &n,
 
     if (n.hasAttributeNS(KoXmlNS::chart, "class") && !ignoreCellRanges) {
         const QString chartClass = n.attributeNS(KoXmlNS::chart, "class", QString());
-        KoChart::ChartType chartType = KoChart::BarChartType;
-        for (int type = 0; type < (int)LastChartType; ++type) {
-            if (chartClass == odfCharttype(type)) {
-                chartType = (ChartType)type;
-                setChartType(chartType);
-                break;
+        if (d->chartType == RingChartType && chartClass == "chart:circle") {
+            // LO marks all datasets in a ring chart as circle
+            // We keep it as RingChartType
+        } else {
+            KoChart::ChartType chartType = KoChart::BarChartType;
+            for (int type = 0; type < (int)LastChartType; ++type) {
+                if (chartClass == odfCharttype(type)) {
+                    chartType = (ChartType)type;
+                    setChartType(chartType);
+                    break;
+                }
             }
         }
     }
@@ -1561,16 +1613,13 @@ bool DataSet::loadOdf(const KoXmlElement &n,
     d->readValueLabelType(styleStack);
 
     if (styleStack.hasProperty(KoXmlNS::chart, "symbol-type")) {
-
         const QString name = styleStack.property(KoXmlNS::chart, "symbol-type");
         if (name == "automatic") {
-            d->symbolsActivated = true;
+            d->odfSymbolType = AutomaticSymbol;
             d->symbolID = d->num % numDefaultMarkerTypes;
-            d->markerIsAutoSet = true;
         }
         else if (name == "named-symbol") {
-            d->symbolsActivated = true;
-            d->markerIsAutoSet = false;
+            d->odfSymbolType = NamedSymbol;
             if (styleStack.hasProperty(KoXmlNS::chart, "symbol-name")) {
 
                 const QString type = styleStack.property(KoXmlNS::chart, "symbol-name");
@@ -1608,9 +1657,12 @@ bool DataSet::loadOdf(const KoXmlElement &n,
                     d->symbolID = 0;
             }
         } else if (name == "none") {
-            d->symbolsActivated = false;
-            d->symbolID = 19;
-            d->markerIsAutoSet = false;
+            d->odfSymbolType = NoSymbol;
+        } else if (name == "image") {
+            // TODO: Not supported by KChart
+            warnChartOdf<<"symbol-type = image not supported";
+        } else {
+            errorChartOdf<<"Unknown symbol-type"<<name;
         }
     }
 
@@ -1650,7 +1702,6 @@ bool DataSet::loadOdf(const KoXmlElement &n,
 
 bool DataSet::loadSeriesIntoDataset(const KoXmlElement &n, KoShapeLoadingContext &context)
 {
-    d->symbolsActivated = false;
     KoOdfLoadingContext &odfLoadingContext = context.odfLoadingContext();
     KoStyleStack &styleStack = odfLoadingContext.styleStack();
     styleStack.clear();
@@ -1746,48 +1797,62 @@ void DataSet::saveOdf(KoShapeSavingContext &context) const
     }
 
     DataSet::ValueLabelType type = valueLabelType();
-    if (type.number && type.percentage)
-        style.addProperty("chart:data-label-number", "value-and-percentage");
-    else if (type.number)
-        style.addProperty("chart:data-label-number", "value");
-    else if (type.percentage)
-        style.addProperty("chart:data-label-number", "percentage");
-    if (type.category)
-        style.addProperty("chart:data-label-text", "true");
-    if (type.symbol)
-        style.addProperty("chart:data-label-symbol", "true");
-
-    if (d->symbolsActivated) {
-        QString symbolName;
-        QString symbolType = "named-symbol";
-
-        if (!d->markerIsAutoSet) {
-            switch (d->symbolID) {
-            case 0: symbolName = "square"; break;
-            case 1: symbolName = "diamond"; break;
-            case 2: symbolName = "arrow-down"; break;
-            case 3: symbolName = "arrow-up"; break;
-            case 4: symbolName = "arrow-right"; break;
-            case 5: symbolName = "arrow-left"; break;
-            case 6: symbolName = "bow-tie"; break;
-            case 7: symbolName = "hourglass"; break;
-            case 8: symbolName = "circle"; break;
-            case 9: symbolName = "star"; break;
-            case 10: symbolName = 'x'; break;
-            case 11: symbolName = "plus"; break;
-            case 12: symbolName = "asterisk"; break;
-            case 13: symbolName = "horizontal-bar"; break;
-            case 14: symbolName = "vertical-bar"; break;
-            case 19: symbolType = "none"; break;
-            default: symbolType = "automatic"; break;
-            }
+    if (!type.noLabel()) {
+        if (type.number && type.percentage) {
+            style.addProperty("chart:data-label-number", "value-and-percentage");
+        } else if (type.number) {
+            style.addProperty("chart:data-label-number", "value");
+        } else if (type.percentage) {
+            style.addProperty("chart:data-label-number", "percentage");
         } else {
-            symbolType = "automatic";
+            style.addProperty("chart:data-label-number", "none");
+        }
+        style.addProperty("chart:data-label-text", type.category ? "true" : "false");
+        // TODO Not supported, should we write back if loaded?
+//         if (type.symbolIsLoaded) {
+//             style.addProperty("chart:data-label-symbol", type.symbol ? "true" : "false");
+//         }
+    }
+    if (d->markersUsed) {
+        switch (d->odfSymbolType) {
+            case NoSymbol:
+                break;
+            case NamedSymbol: {
+                QString symbolType = "named-symbol";
+                QString symbolName;
+                switch (d->symbolID) {
+                    case MarkerSquare: symbolName = "square"; break;
+                    case MarkerDiamond: symbolName = "diamond"; break;
+                    case MarkerArrowDown: symbolName = "arrow-down"; break;
+                    case MarkerArrowUp: symbolName = "arrow-up"; break;
+                    case MarkerArrowRight: symbolName = "arrow-right"; break;
+                    case MarkerArrowLeft: symbolName = "arrow-left"; break;
+                    case MarkerBowTie: symbolName = "bow-tie"; break;
+                    case MarkerHourGlass: symbolName = "hourglass"; break;
+                    case MarkerCircle: symbolName = "circle"; break;
+                    case MarkerStar: symbolName = "star"; break;
+                    case MarkerX: symbolName = 'x'; break;
+                    case MarkerCross: symbolName = "plus"; break;
+                    case MarkerAsterisk: symbolName = "asterisk"; break;
+                    case MarkerHorizontalBar: symbolName = "horizontal-bar"; break;
+                    case MarkerVerticalBar: symbolName = "vertical-bar"; break;
+                    default:
+                        break;
+                }
+                if (!symbolName.isEmpty()) {
+                    style.addProperty("chart:symbol-type", symbolType, KoGenStyle::ChartType);
+                    style.addProperty("chart:symbol-name", symbolName, KoGenStyle::ChartType);
+                }
+                break;
+            }
+            case ImageSymbol: // TODO: Not supported
+            case AutomaticSymbol:
+                style.addProperty("chart:symbol-type", "automatic", KoGenStyle::ChartType);
+                break;
+            default:
+                Q_ASSERT(false);
+                break;
         }
-
-        style.addProperty("chart:symbol-type", symbolType, KoGenStyle::ChartType);
-        if (!symbolName.isEmpty())
-            style.addProperty("chart:symbol-name", symbolName, KoGenStyle::ChartType);
     }
 
     KoOdfGraphicStyles::saveOdfFillStyle(style, mainStyles, brush());
@@ -1797,21 +1862,33 @@ void DataSet::saveOdf(KoShapeSavingContext &context) const
     bodyWriter.addAttribute("chart:style-name", styleName);
 
     // Save cell regions for values if defined.
-    QString values = yDataRegion().toString();
-    if (!values.isEmpty())
-        bodyWriter.addAttribute("chart:values-cell-range-address", values);
-
+    if (chartType() != KoChart::BubbleChartType) {
+        QString values = yDataRegion().toString();
+        if (!values.isEmpty())
+            bodyWriter.addAttribute("chart:values-cell-range-address", values);
+    }
     // Save cell regions for labels if defined. If not defined then the internal
     // table:table "local-table" (the data is stored in the ChartTableModel) is used.
     QString label = labelDataRegion().toString();
     if (!label.isEmpty())
         bodyWriter.addAttribute("chart:label-cell-address", label);
 
-    int charttype = (chartType() < LastChartType) ? chartType() : 0;
+    int charttype = LastChartType;
+    if (d->chartType == RingChartType || d->chartType == LastChartType) {
+        if (d->attachedAxis->plotArea()->chartType() == RingChartType) {
+            charttype = CircleChartType; // LO needs this
+        }
+    }
+    if (charttype == LastChartType) {
+        charttype = d->effectiveChartType();
+    }
     QString chartClass = odfCharttype(charttype);
-    if (!chartClass.isEmpty())
+    if (!chartClass.isEmpty()) {
         bodyWriter.addAttribute("chart:class", chartClass);
-
+    }
+    if (d->attachedAxis) {
+        bodyWriter.addAttribute("chart:attached-axis", d->attachedAxis->name());
+    }
     if (chartType() == KoChart::CircleChartType || chartType() == KoChart::RingChartType) {
         for (int j=0; j<yDataRegion().cellCount(); ++j) {
             bodyWriter.startElement("chart:data-point");
@@ -1826,7 +1903,24 @@ void DataSet::saveOdf(KoShapeSavingContext &context) const
             bodyWriter.endElement();
         }
     }
-
+    if (chartType() == KoChart::BubbleChartType) {
+        // Custom data shall contain bubble size
+        QString values = customDataRegion().toString();
+        bodyWriter.addAttribute("chart:values-cell-range-address", values);
+        bodyWriter.startElement("chart:domain");
+        // Y-data shall be the first domain
+        values = yDataRegion().toString();
+        bodyWriter.addAttribute("table:cell-range-address", values);
+        bodyWriter.endElement();
+        // X-data shall be the second domain
+        values = xDataRegion().toString();
+        if (!values.isEmpty()) {
+            // Note, this is contrary to ODF but in line with LO
+            bodyWriter.startElement("chart:domain");
+            bodyWriter.addAttribute("table:cell-range-address", values);
+            bodyWriter.endElement();
+        }
+    }
     bodyWriter.endElement(); // chart:series
 }
 
@@ -1870,9 +1964,55 @@ static KChart::MarkerAttributes::MarkerStyle odf2kdMarker(OdfMarkerStyle style)
         return KChart::MarkerAttributes::Marker1Pixel;
     case Marker4Pixels:
         return KChart::MarkerAttributes::Marker4Pixels;
-    case NoMarker:
-        return KChart::MarkerAttributes::NoMarker;
     }
 
     return KChart::MarkerAttributes::MarkerSquare;
 }
+
+QString DataSet::axisName() const
+{
+    return d->axisName;
+}
+
+QDebug operator<<(QDebug dbg, const KoChart::DataSet *ds)
+{
+    if (ds) {
+        QVariantList x;
+        for (int i = 0; i < ds->size(); ++i) {
+            x << ds->xData(i);
+        }
+        QVariantList y;
+        for (int i = 0; i < ds->size(); ++i) {
+            y << ds->yData(i);
+        }
+        QVariantList cust;
+        for (int i = 0; i < ds->size(); ++i) {
+            cust << ds->customData(i);
+        }
+        QVariantList cat;
+        for (int i = 0; i < ds->size(); ++i) {
+            cat << ds->categoryData(i);
+        }
+        QString axis = ds->attachedAxis() ? ds->attachedAxis()->name() : "0x0";
+        return dbg.nospace()<<endl
+        <<"\tDataSet[chart:"<<ds->chartType()<<" axis:"<<axis<<" size:"<<ds->size()<<" label:"<<ds->labelData()<<endl
+        <<"\t  X:"<<ds->xDataRegion().toString()<<':'<<x<<endl
+        <<"\t  Y:"<<ds->yDataRegion().toString()<<':'<<y<<endl
+        <<"\t  Cust:"<<ds->customDataRegion().toString()<<':'<<cust<<endl
+        <<"\t  Cat:"<<ds->categoryDataRegion().toString()<<':'<<cat<<endl
+        <<"\t]";
+    }
+    return dbg.noquote()<<"DataSet(0x0)";
+}
+
+QDebug operator<<(QDebug dbg, const KoChart::DataSet::ValueLabelType &v)
+{
+    QStringList lst;
+    if (v.number) lst << "N";
+    if (v.percentage) lst << "%";
+    if (v.category) lst << "C";
+    if (v.symbol) lst << "S";
+    QString s = lst.isEmpty() ? QString("None") : lst.join(',');
+    dbg.nospace() << "ValueLabelType[" << s << ']';
+    return dbg.space();
+}
