@@ -38,6 +38,46 @@
 
 using namespace KoChart;
 
+/**
+ * Method for debugging purposes.
+ */
+QString roleToString(int role)
+{
+    switch (role) {
+        case Qt::DisplayRole:
+            return "Qt::DisplayRole";
+        case KChart::DatasetBrushRole:
+            return "KChart::DatasetBrushRole";
+        case KChart::DatasetPenRole:
+            return "KChart::DatasetPenRole";
+        case KChart::PieAttributesRole:
+            return "KChart::PieAttributesRole";
+        case KChart::DataValueLabelAttributesRole:
+            return "KChart::DataValueLabelAttributesRole";
+        case KChart::ThreeDAttributesRole:
+            return "KChart::ThreeDAttributesRole";
+        case KChart::LineAttributesRole:
+            return "KChart::LineAttributesRole";
+        case KChart::ThreeDLineAttributesRole:
+            return "KChart::ThreeDLineAttributesRole";
+        case KChart::BarAttributesRole:
+            return "KChart::BarAttributesRole";
+        case KChart::StockBarAttributesRole:
+            return "KChart::StockBarAttributesRole";
+        case KChart::ThreeDBarAttributesRole:
+            return "KChart::ThreeDBarAttributesRole";
+        case KChart::ThreeDPieAttributesRole:
+            return "KChart::ThreeDPieAttributesRole";
+        case KChart::DataHiddenRole:
+            return "KChart::DataHiddenRole";
+        case KChart::ValueTrackerAttributesRole:
+            return "KChart::ValueTrackerAttributesRole";
+        case KChart::CommentRole:
+            return "KChart::CommentRole";
+    }
+    return "Unknown DataRole";
+}
+
 class KChartModel::Private {
 public:
     Private(KChartModel *parent, PlotArea *plotArea);
@@ -200,7 +240,7 @@ QVariant KChartModel::data(const QModelIndex &index,
          !d->isKnownDataRole(role)) {
         return QVariant();
     }
-
+//     if (!role == Qt::DisplayRole) {qInfo()<<Q_FUNC_INFO<<index.row()<<roleToString(role);}
     int dataSetNumber, section;
     // Offset from the data set's row or column (depending on the data direction).
     // With one data dimension, it's always 0. Otherwise it's 1 for y data, and
@@ -208,7 +248,7 @@ QVariant KChartModel::data(const QModelIndex &index,
     // In other words, with one data dimension, there's only y data. With two data
     // dimensions, there's x and y data, and the x data comes before the y data,
     // each data set thus occupying two rows/columns.
-    // With three data dimensions (though we don't support that yet) there will be
+    // With three data dimensions there will be
     // x, y and some kind of custom data. Like the size of a bubble in a bubble chart.
     int dataSection;
 
@@ -225,8 +265,7 @@ QVariant KChartModel::data(const QModelIndex &index,
     if (dataSetNumber >= d->dataSets.size())
         return QVariant();
 
-    DataSet  *dataSet       = d->dataSets[ dataSetNumber ];
-
+    DataSet *dataSet = d->dataSets[dataSetNumber];
     switch (role) {
     case Qt::DisplayRole:
         if (d->dataDimensions > 1 && dataSection == 0)
@@ -370,24 +409,6 @@ bool KChartModel::Private::isKnownDataRole(int role) const
     return false;
 }
 
-/**
- * Method for debugging purposes.
- */
-QString roleToString(int role)
-{
-    switch (role) {
-    case Qt::DisplayRole:
-        return "Qt::DisplayRole";
-    case KChart::DatasetBrushRole:
-        return "KChart::DatasetBrushRole";
-    case KChart::DatasetPenRole:
-        return "KChart::DatasetPenRole";
-    case KChart::PieAttributesRole:
-        return "KChart::PieAttributesRole";
-    }
-    return "Unknown DataRole";
-}
-
 QVariant KChartModel::headerData(int section,
                                   Qt::Orientation orientation,
                                   int role /* = Qt::DisplayRole */) const
@@ -572,30 +593,41 @@ void KChartModel::removeDataSet(DataSet *dataSet, bool silent)
         int newMaxDataSetSize = d->calcMaxDataSetSize(_dataSets);
 
         if (newMaxDataSetSize < oldMaxDataSetSize) {
-            if (d->dataDirection == Qt::Horizontal)
+            if (d->dataDirection == Qt::Horizontal) {
                 beginRemoveColumns(QModelIndex(), newMaxDataSetSize, oldMaxDataSetSize - 1);
-            else
+            } else {
                 beginRemoveRows(QModelIndex(), newMaxDataSetSize, oldMaxDataSetSize - 1);
+            }
             d->dataSets = _dataSets;
             d->biggestDataSetSize = newMaxDataSetSize;
-            if (d->dataDirection == Qt::Horizontal)
+            if (d->dataDirection == Qt::Horizontal) {
                 endRemoveColumns();
-            else
+            } else {
                 endRemoveRows();
+            }
+        }
+        // If the dataSet has been removed above we cannot remove it again.
+        // This should only happen when the last dataSet is removed
+        if (d->dataSets.contains(dataSet)) {
+            int first = dataSetIndex * d->dataDimensions;
+            int last = first + d->dataDimensions - 1;
+            if (d->dataDirection == Qt::Horizontal) {
+                beginRemoveRows(QModelIndex(), first, last);
+            } else {
+                beginRemoveColumns(QModelIndex(), first, last);
+            }
+            d->dataSets.removeAt(dataSetIndex);
+            if (d->dataDirection == Qt::Horizontal) {
+                endRemoveRows();
+            } else {
+                endRemoveColumns();
+            }
+        } else {
+            Q_ASSERT(d->dataSets.count() == 0);
+            // tell consumers that there is nothing left
+            beginResetModel();
+            endResetModel();
         }
-
-        int columnAboutToBeRemoved = dataSetIndex * d->dataDimensions;
-        if (d->dataDirection == Qt::Horizontal)
-            beginRemoveRows(QModelIndex(), columnAboutToBeRemoved,
-                             columnAboutToBeRemoved + d->dataDimensions - 1);
-        else
-            beginRemoveColumns(QModelIndex(), columnAboutToBeRemoved,
-                                columnAboutToBeRemoved + d->dataDimensions - 1);
-        d->dataSets.removeAt(dataSetIndex);
-        if (d->dataDirection == Qt::Horizontal)
-            endRemoveRows();
-        else
-            endRemoveColumns();
     }
 }
 
