@@ -30,6 +30,7 @@
 #include <QBrush>
 #include <QFont>
 #include <QImage>
+#include <QPainterPath>
 
 // Calligra
 #include <KoXmlReader.h>
@@ -52,6 +53,7 @@
 #include <KChartBackgroundAttributes>
 #include <KChartLegend>
 #include "KChartConvertions.h"
+#include "kchart_version.h"
 
 // KoChart
 #include "PlotArea.h"
@@ -285,12 +287,11 @@ void Legend::setLegendPosition(Position position)
     d->position = position;
     d->pixmapRepaintRequested = true;
 }
-
+// Note that size is controlled by the KChart::Legend
+// via the propertyChanged() signal
+// so size will change dependent on amount of data
 void Legend::setSize(const QSizeF &newSize)
 {
-    QSize newSizePx = ScreenConversions::scaleFromPtToPx(newSize);
-    d->kdLegend->resize(newSizePx);
-    d->kdLegend->resizeLayout(newSizePx);
     KoShape::setSize(newSize);
 }
 
@@ -351,35 +352,16 @@ void Legend::paint(QPainter &painter, const KoViewConverter &converter, KoShapeP
         background()->paint(painter, converter, paintContext, p);
     }
 
+    disconnect (d->kdLegend, SIGNAL(propertiesChanged()), this, SLOT(slotKdLegendChanged()));
+
     // KChart thinks in pixels, Calligra in pt
-    // KChart also for non-QWidget painting devices cares for the logicalDpi
-    // Other than PlotArea we do not control the output size via the paint method,
-    // so here have to resize the legend temporarily.
-    // Printing should only result in 1 paint call, so this should not happen too often.
-    // TODO: something in KChart seems broken in general on printer output, also seen in kchart examples
-    // so legend in print is still broken :/
-    const QSize sizePx = d->kdLegend->size();
-    const QSize newSizePx = ScreenConversions::scaleFromPtToPx(size(), painter);
-    const bool isPainterDifferentDpi = (sizePx != newSizePx);
-    if (isPainterDifferentDpi) {
-        // temporarily set a size matching the painterdevice
-        d->kdLegend->resize(newSizePx);
-        d->kdLegend->resizeLayout(newSizePx);
-    }
-
     ScreenConversions::scaleFromPtToPx(painter);
+    const QRect rect = ScreenConversions::scaleFromPtToPx(paintRect, painter);
+    // KChart works with its logicalDpi which may differ from ours if set with --dpi <x,y>
+    ScreenConversions::scaleToWidgetDpi(d->kdLegend, painter);
+    d->kdLegend->paint(&painter, rect);
 
-    d->kdLegend->paint(&painter);
-
-    if (isPainterDifferentDpi) {
-        // restore screen-dpi size
-        d->kdLegend->resize(sizePx);
-        d->kdLegend->resizeLayout(sizePx);
-    }
-
-    //painter.restore();
-    // Paint the cached pixmap
-    //painter.drawImage(0, 0, d->image);
+    connect (d->kdLegend, SIGNAL(propertiesChanged()), this, SLOT(slotKdLegendChanged()));
 }
 
 
@@ -556,8 +538,8 @@ void Legend::slotKdLegendChanged()
     // FIXME: Update legend properly by implementing all *DataChanged() slots
     // in KChartModel. Right now, only yDataChanged() is implemented.
     //d->kdLegend->forceRebuild();
-    QSize size = d->kdLegend->sizeHint();
-    setSize(ScreenConversions::scaleFromPxToPt(size));
+    QSizeF size = ScreenConversions::scaleFromPxToPt(d->kdLegend->sizeHint());
+    setSize(ScreenConversions::fromWidgetDpi(d->kdLegend, size));
     update();
 }
 
