@@ -43,11 +43,6 @@ public:
     ~Legend();
 
     QString title() const;
-    bool showFrame() const;
-    QPen framePen() const;
-    QColor frameColor() const;
-    QBrush backgroundBrush() const;
-    QColor backgroundColor() const;
     QFont font() const;
     qreal fontSize() const;
     QColor fontColor() const;
@@ -58,11 +53,6 @@ public:
     Position legendPosition() const;
 
     void setTitle(const QString &title);
-    void setShowFrame(bool show);
-    void setFramePen(const QPen &pen);
-    void setFrameColor(const QColor &color);
-    void setBackgroundBrush(const QBrush &brush);
-    void setBackgroundColor(const QColor &color);
     void setFont(const QFont &font);
     void setFontSize(qreal size);
     void setFontColor(const QColor &color);
@@ -71,19 +61,19 @@ public:
     void setExpansion(LegendExpansion expansion);
     void setAlignment(Qt::Alignment alignment);
     void setLegendPosition(Position position);
-    void setSize(const QSizeF &size);
+    void setSize(const QSizeF &size) override;
 
-    void paint(QPainter &painter, const KoViewConverter &converter, KoShapePaintingContext &paintcontext);
+    void paint(QPainter &painter, const KoViewConverter &converter, KoShapePaintingContext &paintcontext) override;
     void paintPixmap(QPainter &painter, const KoViewConverter &converter);
 
-    bool loadOdf(const KoXmlElement &legendElement, KoShapeLoadingContext &context);
-    void saveOdf(KoShapeSavingContext &context) const;
+    bool loadOdf(const KoXmlElement &legendElement, KoShapeLoadingContext &context) override;
+    void saveOdf(KoShapeSavingContext &context) const override;
 
     KChart::Legend *kdLegend() const;
 
     void rebuild();
     using KoShape::update;
-    void update() const;
+    void update() const override;
 
 Q_SIGNALS:
     void updateConfigWidget();
