@@ -30,12 +30,12 @@
 #include "KoSharedLoadingData.h"
 #include "KoXmlReader.h"
 
-// KChart
+// KoChart
 #include "TableSource.h"
 
 class KoodfStylesReader;
 
-namespace KChart {
+namespace KoChart {
 
 class OdfLoadingHelper : public KoSharedLoadingData
 {
@@ -50,6 +50,6 @@ public:
     bool         categoryRegionSpecifiedInXAxis;
 };
 
-} // namespace KChart
+} // namespace KoChart
 
 #endif // KCHART_ODF_LOADING_HELPER_H
