@@ -59,32 +59,38 @@ public:
     /**
      * Executes the actual operation.
      */
-    virtual void redo();
+    void redo() override;
 
     /**
      * Executes the actual operation in reverse order.
      */
-    virtual void undo();
+    void undo() override;
 
     void setAxisShowTitle(bool show);
-    void setAxisTitle(const QString& title);
-    void setAxisShowGridLines(bool show);
+    void setShowAxis(bool show);
+    void setAxisShowLabels(bool show);
+    void setAxisShowMajorGridLines(bool show);
+    void setAxisShowMinorGridLines(bool show);
     void setAxisUseLogarithmicScaling(bool b);
     void setAxisStepWidth(qreal width);
     void setAxisSubStepWidth(qreal width);
     void setAxisUseAutomaticStepWidth(bool automatic);
     void setAxisUseAutomaticSubStepWidth(bool automatic);
     void setAxisLabelsFont(const QFont& font);
+    void setAxisPosition(const QString &pos);
+    void setAxisLabelsPosition(const QString &pos);
 
 private:
     ChartShape *m_chart;
     Axis *m_axis;
-    bool m_oldShowTitle;
-    bool m_newShowTitle;
-    QString m_oldTitleText;
-    QString m_newTitleText;
-    bool m_oldShowGridLines;
-    bool m_newShowGridLines;
+    bool m_oldShowAxis;
+    bool m_newShowAxis;
+    bool m_oldShowLabels;
+    bool m_newShowLabels;
+    bool m_oldShowMajorGridLines;
+    bool m_oldShowMinorGridLines;
+    bool m_newShowMajorGridLines;
+    bool m_newShowMinorGridLines;
     bool m_oldUseLogarithmicScaling;
     bool m_newUseLogarithmicScaling;
     qreal m_oldStepWidth;
@@ -97,6 +103,10 @@ private:
     bool m_newUseAutomaticSubStepWidth;
     QFont m_oldLabelsFont;
     QFont m_newLabelsFont;
+    QString m_oldPosition;
+    QString m_newPosition;
+    QString m_oldLabelsPosition;
+    QString m_newLabelsPosition;
 };
 
 } // namespace KoChart
