@@ -63,12 +63,14 @@ public:
     /**
      * Executes the actual operation.
      */
-    virtual void redo();
+    void redo() override;
 
     /**
      * Executes the actual operation in reverse order.
      */
-    virtual void undo();
+    void undo() override;
+
+    void setRotation(int angle);
 
 private:
     void init();
@@ -78,6 +80,8 @@ private:
     ChartShape *m_chart;
     bool m_oldIsVisible;
     bool m_newIsVisible;
+    int m_oldRotation;
+    int m_newRotation;
 };
 
 } // namespace KoChart
