@@ -50,7 +50,7 @@ public:
     /**
      * Constructor.
      */
-    DatasetCommand(DataSet* dataSet, ChartShape* chart);
+    DatasetCommand(DataSet* dataSet, ChartShape* chart, int section = -1, KUndo2Command *parent = 0);
 
     /**
      * Destructor.
@@ -60,12 +60,12 @@ public:
     /**
      * Executes the actual operation.
      */
-    virtual void redo();
+    void redo() override;
 
     /**
      * Executes the actual operation in reverse order.
      */
-    virtual void undo();
+    void undo() override;
 
     void setDataSetChartType(ChartType type, ChartSubtype subtype);
 
@@ -76,12 +76,13 @@ public:
 
     void setDataSetPen(const QColor& color);
     void setDataSetBrush(const QColor& color);
-    void setDataSetMarker(OdfMarkerStyle style);
+    void setDataSetMarker(OdfSymbolType type, OdfMarkerStyle style);
     void setDataSetAxis(Axis *axis);
 
 private:
     DataSet *m_dataSet;
     ChartShape *m_chart;
+    int m_section;
 
     ChartType m_oldType;
     ChartType m_newType;
@@ -101,6 +102,8 @@ private:
     QColor m_newPenColor;
     QColor m_oldBrushColor;
     QColor m_newBrushColor;
+    OdfSymbolType m_oldOdfSymbolType;
+    OdfSymbolType m_newOdfSymbolType;
     OdfMarkerStyle m_oldMarkerStyle;
     OdfMarkerStyle m_newMarkerStyle;
 
