@@ -59,12 +59,12 @@ public:
     /**
      * Executes the actual operation.
      */
-    virtual void redo();
+    void redo() override;
 
     /**
      * Executes the actual operation in reverse order.
      */
-    virtual void undo();
+    void undo() override;
 
     void setLegendTitle(const QString &title);
     void setLegendFont(const QFont &font);
@@ -74,7 +74,6 @@ public:
     void setLegendFixedPosition(Position);
     void setLegendBackgroundColor(QColor &color);
     void setLegendFrameColor(QColor &color);*/
-    void setLegendShowFrame(bool show);
 
 private:
     Legend *m_legend;
@@ -86,8 +85,6 @@ private:
     int m_newFontSize;
     LegendExpansion m_oldExpansion;
     LegendExpansion m_newExpansion;
-    bool m_oldShowFrame;
-    bool m_newShowFrame;
     ChartShape *m_chart;
 };
 
