@@ -40,6 +40,7 @@
 #include "Legend.h"
 #include "DataSet.h"
 #include "TableSource.h"
+#include "ChartTableModel.h"
 #include "Axis.h"
 
 // KD Chart
@@ -58,7 +59,7 @@ TestLoadingBase::TestLoadingBase()
 
 void TestLoadingBase::initTestCase()
 {
-    ChartDocument document(m_chart);
+    ChartDocument *document = m_chart->document();
 
     QDir srcdir(QFINDTESTDATA("doc"));
     QVERIFY(srcdir.exists());
@@ -75,16 +76,25 @@ void TestLoadingBase::initTestCase()
     if (!success)
         qDebug() << "Error in odfReadStore.loadAndParse(): " << errorMsg;
     QVERIFY(success);
-    QVERIFY(document.loadOdf(odfReadStore));
+    QVERIFY(document->loadOdf(odfReadStore));
 }
 
-void TestLoadingBase::testElementIsVisible(KoShape *element, bool shouldBeVisible)
+void TestLoadingBase::cleanupTestCase()
+{
+    delete m_chart;
+}
+
+LoadingTests::LoadingTests()
+{
+}
+
+void LoadingTests::testElementIsVisible(KoShape *element, bool shouldBeVisible)
 {
     QVERIFY(element);
     QCOMPARE(element->isVisible(), shouldBeVisible);
 }
 
-void TestLoadingBase::testLegendElements(QStringList labels)
+void LoadingTests::testLegendElements(QStringList labels)
 {
     QVERIFY(m_chart->legend());
     QVERIFY(m_chart->legend()->kdLegend());
@@ -103,7 +113,7 @@ void TestLoadingBase::testLegendElements(QStringList labels)
     QVERIFY(labels.isEmpty());
 }
 
-void TestLoadingBase::testDataSetCellRegions(int dataSetNr,
+void LoadingTests::testDataSetCellRegions(int dataSetNr,
                                              CellRegion yDataRegion,
                                              CellRegion labelDataRegion,
                                              CellRegion categoryDataRegion,
@@ -131,13 +141,13 @@ void TestLoadingBase::testDataSetCellRegions(int dataSetNr,
     QCOMPARE(dataSet->customDataRegion(),   customDataRegion);
 }
 
-void TestLoadingBase::testHasOnlyInternalTable()
+void LoadingTests::testHasOnlyInternalTable()
 {
     QVERIFY(m_chart->usesInternalModelOnly());
     QVERIFY(internalTable());
 }
 
-void TestLoadingBase::testInternalTableSize(int rowCount, int colCount)
+void LoadingTests::testInternalTableSize(int rowCount, int colCount)
 {
     QAbstractItemModel *model = m_chart->internalModel();
     QVERIFY(model);
@@ -146,7 +156,7 @@ void TestLoadingBase::testInternalTableSize(int rowCount, int colCount)
     QCOMPARE(model->columnCount(), colCount);
 }
 
-void TestLoadingBase::testTitleText(const QString &text)
+void LoadingTests::testTitleText(const QString &text)
 {
     QVERIFY(m_chart->title());
     KoTextShapeDataBase *data = dynamic_cast<KoTextShapeDataBase*>(m_chart->title()->userData());
@@ -155,7 +165,7 @@ void TestLoadingBase::testTitleText(const QString &text)
     QCOMPARE(data->document()->toPlainText(), text);
 }
 
-void TestLoadingBase::testSubTitleText(const QString &text)
+void LoadingTests::testSubTitleText(const QString &text)
 {
     QVERIFY(m_chart->subTitle());
     KoTextShapeDataBase *data = dynamic_cast<KoTextShapeDataBase*>(m_chart->subTitle()->userData());
@@ -164,7 +174,7 @@ void TestLoadingBase::testSubTitleText(const QString &text)
     QCOMPARE(data->document()->toPlainText(), text);
 }
 
-void TestLoadingBase::testFooterText(const QString &text)
+void LoadingTests::testFooterText(const QString &text)
 {
     QVERIFY(m_chart->footer());
     KoTextShapeDataBase *data = dynamic_cast<KoTextShapeDataBase*>(m_chart->footer()->userData());
@@ -173,7 +183,7 @@ void TestLoadingBase::testFooterText(const QString &text)
     QCOMPARE(data->document()->toPlainText(), text);
 }
 
-void TestLoadingBase::testAxisTitle(Axis *axis, const QString &text)
+void LoadingTests::testAxisTitle(Axis *axis, const QString &text)
 {
     QVERIFY(axis);
     QVERIFY(axis->title());
@@ -183,7 +193,7 @@ void TestLoadingBase::testAxisTitle(Axis *axis, const QString &text)
     QCOMPARE(data->document()->toPlainText(), text);
 }
 
-Table *TestLoadingBase::internalTable()
+Table *LoadingTests::internalTable()
 {
     QAbstractItemModel *internalModel = m_chart->internalModel();
     if (!internalModel)
@@ -191,7 +201,7 @@ Table *TestLoadingBase::internalTable()
     return m_chart->tableSource()->get(internalModel);
 }
 
-TableSource *TestLoadingBase::tableSource()
+TableSource *LoadingTests::tableSource()
 {
     return m_chart->tableSource();
 }
