@@ -21,11 +21,11 @@
 #ifndef KCHART_TESTLOADING_H_BUBBLE_CHART
 #define KCHART_TESTLOADING_H_BUBBLE_CHART
 
-#include "../TestLoadingBase.h"
+#include "../TestMultipleFiles.h"
 
 namespace KoChart {
 
-class TestLoading : public TestLoadingBase
+class TestLoading : public TestMultipleFiles
 {
     Q_OBJECT
 
@@ -33,7 +33,10 @@ public:
     TestLoading();
 
 private Q_SLOTS:
-    /// Tests title, subtitle and footer
+    void testInvalidOOChart();
+    void testValidOOChart();
+
+private:
     void testLabels();
     void testInternalTable();
     void testDataSets();
