@@ -26,7 +26,7 @@
 // Base
 #include "../TestLoadingBase.h"
 
-namespace KChart {
+namespace KoChart {
 
 class TestLoading : public TestLoadingBase
 {
@@ -43,6 +43,6 @@ private Q_SLOTS:
     void testLegend();
 };
 
-} // namespace KChart
+} // namespace KoChart
 
 #endif // KCHART_TESTLOADING_H_DEFAULT_OOO_CHART
