@@ -21,7 +21,7 @@
 #define KIS_STRATEGY_COLORSPACE_CMYK_U8_H_
 
 #include <LcmsColorSpace.h>
-#include <KoColorSpaceTraits.h>
+#include <KoCmykColorSpaceTraits.h>
 #include "KoColorModelStandardIds.h"
 
 typedef KoCmykTraits<quint8> CmykU8Traits;
@@ -31,21 +31,28 @@ class CmykU8ColorSpace : public LcmsColorSpace<CmykU8Traits>
 public:
     CmykU8ColorSpace(const QString &name, KoColorProfile *p);
 
-    virtual bool willDegrade(ColorSpaceIndependence independence) const;
+    bool willDegrade(ColorSpaceIndependence independence) const override;
 
-    virtual KoID colorModelId() const {
+    KoID colorModelId() const override
+    {
         return CMYKAColorModelID;
     }
 
-    virtual KoID colorDepthId() const {
+    KoID colorDepthId() const override
+    {
         return Integer8BitsColorDepthID;
     }
 
-    virtual KoColorSpace* clone() const;
+    virtual KoColorSpace *clone() const;
 
-    virtual void colorToXML(const quint8* pixel, QDomDocument& doc, QDomElement& colorElt) const;
+    void colorToXML(const quint8 *pixel, QDomDocument &doc, QDomElement &colorElt) const override;
 
-    virtual void colorFromXML(quint8* pixel, const QDomElement& elt) const;
+    void colorFromXML(quint8* pixel, const QDomElement& elt) const override;
+    
+    void toHSY(const QVector<double> &channelValues, qreal *hue, qreal *sat, qreal *luma) const override;
+    QVector <double> fromHSY(qreal *hue, qreal *sat, qreal *luma) const override;
+    void toYUV(const QVector<double> &channelValues, qreal *y, qreal *u, qreal *v) const override;
+    QVector <double> fromYUV(qreal *y, qreal *u, qreal *v) const override;
 
     static QString colorSpaceId()
     {
@@ -63,38 +70,45 @@ public:
 
     }
 
-    virtual bool userVisible() const {
+    bool userVisible() const override
+    {
         return true;
     }
 
-    virtual QString id() const {
+    QString id() const override
+    {
         return CmykU8ColorSpace::colorSpaceId();
     }
 
-    virtual QString name() const {
+    QString name() const override
+    {
         return i18n("CMYK (8-bit integer/channel)");
     }
 
-    virtual KoID colorModelId() const {
+    KoID colorModelId() const override
+    {
         return CMYKAColorModelID;
     }
 
-    virtual KoID colorDepthId() const {
+    KoID colorDepthId() const override
+    {
         return Integer8BitsColorDepthID;
     }
 
-    virtual int referenceDepth() const {
+    int referenceDepth() const override
+    {
         return 8;
     }
 
-    virtual KoColorSpace *createColorSpace(const KoColorProfile *p) const {
+    KoColorSpace *createColorSpace(const KoColorProfile *p) const override
+    {
         return new CmykU8ColorSpace(name(), p->clone());
     }
 
-    virtual QString defaultProfile() const {
+    QString defaultProfile() const override
+    {
         return "Chemical proof";
     }
 };
 
-
 #endif
