@@ -30,31 +30,31 @@ class GrayAU16ColorSpace : public LcmsColorSpace<GrayAU16Traits>
 public:
     GrayAU16ColorSpace(const QString &name, KoColorProfile *p);
 
-    virtual bool willDegrade(ColorSpaceIndependence) const
+    bool willDegrade(ColorSpaceIndependence) const override
     {
         return false;
     }
 
-    virtual KoID colorModelId() const
+    KoID colorModelId() const override
     {
         return GrayAColorModelID;
     }
 
-    virtual KoID colorDepthId() const
+    KoID colorDepthId() const override
     {
         return Integer16BitsColorDepthID;
     }
 
     virtual KoColorSpace *clone() const;
 
-    virtual void colorToXML(const quint8 *pixel, QDomDocument &doc, QDomElement &colorElt) const;
+    void colorToXML(const quint8 *pixel, QDomDocument &doc, QDomElement &colorElt) const override;
 
-    virtual void colorFromXML(quint8* pixel, const QDomElement& elt) const;
+    void colorFromXML(quint8* pixel, const QDomElement& elt) const override;
     
-    virtual void toHSY(const QVector<double> &channelValues, qreal *hue, qreal *sat, qreal *luma) const;
-    virtual QVector <double> fromHSY(qreal *hue, qreal *sat, qreal *luma) const;
-    virtual void toYUV(const QVector<double> &channelValues, qreal *y, qreal *u, qreal *v) const;
-    virtual QVector <double> fromYUV(qreal *y, qreal *u, qreal *v) const;
+    void toHSY(const QVector<double> &channelValues, qreal *hue, qreal *sat, qreal *luma) const override;
+    QVector <double> fromHSY(qreal *hue, qreal *sat, qreal *luma) const override;
+    void toYUV(const QVector<double> &channelValues, qreal *y, qreal *u, qreal *v) const override;
+    QVector <double> fromYUV(qreal *y, qreal *u, qreal *v) const override;
 
     static QString colorSpaceId()
     {
@@ -70,42 +70,42 @@ public:
     {
     }
 
-    virtual QString id() const
+    QString id() const override
     {
         return GrayAU16ColorSpace::colorSpaceId();
     }
 
-    virtual QString name() const
+    QString name() const override
     {
         return i18n("Grayscale (16-bit integer/channel)");
     }
 
-    virtual KoID colorModelId() const
+    KoID colorModelId() const override
     {
         return GrayAColorModelID;
     }
 
-    virtual KoID colorDepthId() const
+    KoID colorDepthId() const override
     {
         return Integer16BitsColorDepthID;
     }
 
-    virtual int referenceDepth() const
+    int referenceDepth() const override
     {
         return 16;
     }
 
-    virtual bool userVisible() const
+    bool userVisible() const override
     {
         return true;
     }
 
-    virtual KoColorSpace *createColorSpace(const KoColorProfile *p) const
+    KoColorSpace *createColorSpace(const KoColorProfile *p) const override
     {
         return new GrayAU16ColorSpace(name(), p->clone());
     }
 
-    virtual QString defaultProfile() const
+    QString defaultProfile() const override
     {
         return "gray built-in";
     }
