@@ -18,7 +18,7 @@
 #ifndef KIS_GRAY_COLORSPACE_H_
 #define KIS_GRAY_COLORSPACE_H_
 
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <LcmsColorSpace.h>
 #include <KoColorSpaceTraits.h>
 #include "KoColorModelStandardIds.h"
@@ -31,23 +31,31 @@ public:
 
     GrayAU8ColorSpace(const QString &name, KoColorProfile *p);
 
-    virtual bool willDegrade(ColorSpaceIndependence) const {
+    bool willDegrade(ColorSpaceIndependence) const override
+    {
         return false;
     }
 
-    virtual KoID colorModelId() const {
+    KoID colorModelId() const override
+    {
         return GrayAColorModelID;
     }
 
-    virtual KoID colorDepthId() const {
+    KoID colorDepthId() const override
+    {
         return Integer8BitsColorDepthID;
     }
 
-    virtual KoColorSpace* clone() const;
+    virtual KoColorSpace *clone() const;
 
-    virtual void colorToXML(const quint8* pixel, QDomDocument& doc, QDomElement& colorElt) const;
+    void colorToXML(const quint8 *pixel, QDomDocument &doc, QDomElement &colorElt) const override;
 
-    virtual void colorFromXML(quint8* pixel, const QDomElement& elt) const;
+    void colorFromXML(quint8* pixel, const QDomElement& elt) const override;
+    
+    void toHSY(const QVector<double> &channelValues, qreal *hue, qreal *sat, qreal *luma) const override;
+    QVector <double> fromHSY(qreal *hue, qreal *sat, qreal *luma) const override;
+    void toYUV(const QVector<double> &channelValues, qreal *y, qreal *u, qreal *v) const override;
+    QVector <double> fromYUV(qreal *y, qreal *u, qreal *v) const override;
 
     static QString colorSpaceId()
     {
@@ -64,35 +72,43 @@ public:
     {
     }
 
-    virtual QString id() const {
+    QString id() const override
+    {
         return GrayAU8ColorSpace::colorSpaceId();
     }
 
-    virtual QString name() const {
+    QString name() const override
+    {
         return i18n("Grayscale (8-bit integer/channel)");
     }
 
-    virtual KoID colorModelId() const {
+    KoID colorModelId() const override
+    {
         return GrayAColorModelID;
     }
 
-    virtual KoID colorDepthId() const {
+    KoID colorDepthId() const override
+    {
         return Integer8BitsColorDepthID;
     }
 
-    virtual int referenceDepth() const {
+    int referenceDepth() const override
+    {
         return 8;
     }
 
-    virtual bool userVisible() const {
+    bool userVisible() const override
+    {
         return true;
     }
 
-    virtual KoColorSpace *createColorSpace(const KoColorProfile *p) const {
+    KoColorSpace *createColorSpace(const KoColorProfile *p) const override
+    {
         return new GrayAU8ColorSpace(name(), p->clone());
     }
 
-    virtual QString defaultProfile() const {
+    QString defaultProfile() const override
+    {
         return "gray built-in";
     }
 };
