@@ -21,34 +21,41 @@
 #define LabU8ColorSpace_H_
 
 #include "LcmsColorSpace.h"
-#include "KoColorSpaceTraits.h"
 #include "KoColorModelStandardIds.h"
 
 #define TYPE_LABA_8 (COLORSPACE_SH(PT_Lab) | CHANNELS_SH(3) | BYTES_SH(1) | EXTRA_SH(1))
 
+struct KoLabU8Traits;
+
 class LabU8ColorSpace : public LcmsColorSpace<KoLabU8Traits>
 {
 public:
     LabU8ColorSpace(const QString &name, KoColorProfile *p);
-    virtual bool willDegrade(ColorSpaceIndependence independence) const;
-    virtual QString normalisedChannelValueText(const quint8 *pixel, quint32 channelIndex) const;
+    bool willDegrade(ColorSpaceIndependence independence) const override;
+    QString normalisedChannelValueText(const quint8 *pixel, quint32 channelIndex) const override;
 
     static QString colorSpaceId()
     {
         return QString("LABAU8");
     }
 
-    virtual KoID colorModelId() const {
+    KoID colorModelId() const override
+    {
         return LABAColorModelID;
     }
 
-    virtual KoID colorDepthId() const {
+    KoID colorDepthId() const override
+    {
         return Integer8BitsColorDepthID;
     }
 
     virtual KoColorSpace* clone() const;
-    virtual void colorToXML(const quint8* pixel, QDomDocument& doc, QDomElement& colorElt) const;
-    virtual void colorFromXML(quint8* pixel, const QDomElement& elt) const;
+    void colorToXML(const quint8* pixel, QDomDocument& doc, QDomElement& colorElt) const override;
+    void colorFromXML(quint8* pixel, const QDomElement& elt) const override;
+    void toHSY(const QVector<double> &channelValues, qreal *hue, qreal *sat, qreal *luma) const override;
+    QVector <double> fromHSY(qreal *hue, qreal *sat, qreal *luma) const override;
+    void toYUV(const QVector<double> &channelValues, qreal *y, qreal *u, qreal *v) const override;
+    QVector <double> fromYUV(qreal *y, qreal *u, qreal *v) const override;
 
 private:
     static const quint32 MAX_CHANNEL_L = 100;
@@ -61,38 +68,45 @@ class LabU8ColorSpaceFactory : public LcmsColorSpaceFactory
 public:
     LabU8ColorSpaceFactory() : LcmsColorSpaceFactory(TYPE_LABA_8, cmsSigLabData) {}
 
-    virtual bool userVisible() const {
+    bool userVisible() const override
+    {
         return true;
     }
 
-    virtual QString id() const {
+    QString id() const override
+    {
         return LabU8ColorSpace::colorSpaceId();
     }
 
-    virtual QString name() const {
+    QString name() const override
+    {
         return i18n("L*a*b* (8-bit integer/channel)");
     }
 
-    virtual KoID colorModelId() const {
+    KoID colorModelId() const override
+    {
         return LABAColorModelID;
     }
 
-    virtual KoID colorDepthId() const {
+    KoID colorDepthId() const override
+    {
         return Integer8BitsColorDepthID;
     }
 
-    virtual int referenceDepth() const {
+    int referenceDepth() const override
+    {
         return 8;
     }
 
-    virtual KoColorSpace *createColorSpace(const KoColorProfile *p) const {
+    KoColorSpace *createColorSpace(const KoColorProfile *p) const override
+    {
         return new LabU8ColorSpace(name(), p->clone());
     }
 
-    virtual QString defaultProfile() const {
+    QString defaultProfile() const override
+    {
         return "Lab identity built-in";
     }
 };
 
-
 #endif
