@@ -21,81 +21,95 @@
 #define KIS_YCBCR_U16_COLORSPACE_H_
 
 #include <LcmsColorSpace.h>
-#include <KoColorSpaceTraits.h>
 
 #include <KoColorModelStandardIds.h>
 
 #define TYPE_YCbCrA_16 (COLORSPACE_SH(PT_YCbCr)|CHANNELS_SH(3)|BYTES_SH(2)|EXTRA_SH(1))
 
+struct KoYCbCrU16Traits;
+
 class YCbCrU16ColorSpace : public LcmsColorSpace<KoYCbCrU16Traits>
 {
 public:
 
     YCbCrU16ColorSpace(const QString &name, KoColorProfile *p);
 
-    virtual bool willDegrade(ColorSpaceIndependence independence) const;
+    bool willDegrade(ColorSpaceIndependence independence) const override;
 
     static QString colorSpaceId()
     {
         return QString("YCBCRAU16");
     }
 
-    virtual KoID colorModelId() const {
+    KoID colorModelId() const override
+    {
         return YCbCrAColorModelID;
     }
 
-    virtual KoID colorDepthId() const {
+    KoID colorDepthId() const override
+    {
         return Integer16BitsColorDepthID;
     }
 
-    virtual KoColorSpace* clone() const;
+    virtual KoColorSpace *clone() const;
 
-    virtual void colorToXML(const quint8* pixel, QDomDocument& doc, QDomElement& colorElt) const;
+    void colorToXML(const quint8 *pixel, QDomDocument &doc, QDomElement &colorElt) const override;
 
-    virtual void colorFromXML(quint8* pixel, const QDomElement& elt) const;
+    void colorFromXML(quint8* pixel, const QDomElement& elt) const override;
+    void toHSY(const QVector<double> &channelValues, qreal *hue, qreal *sat, qreal *luma) const override;
+    QVector <double> fromHSY(qreal *hue, qreal *sat, qreal *luma) const override;
+    void toYUV(const QVector<double> &channelValues, qreal *y, qreal *u, qreal *v) const override;
+    QVector <double> fromYUV(qreal *y, qreal *u, qreal *v) const override;
 
 };
 
-
 class YCbCrU16ColorSpaceFactory : public LcmsColorSpaceFactory
 {
 public:
 
-    YCbCrU16ColorSpaceFactory() : LcmsColorSpaceFactory(TYPE_YCbCrA_16, cmsSigYCbCrData) {
+    YCbCrU16ColorSpaceFactory() : LcmsColorSpaceFactory(TYPE_YCbCrA_16, cmsSigYCbCrData)
+    {
     }
 
-    virtual QString id() const {
+    QString id() const override
+    {
         return YCbCrU16ColorSpace::colorSpaceId();
     }
 
-    virtual QString name() const {
+    QString name() const override
+    {
         return i18n("YCBCR (16-bit integer/channel)");
     }
 
-    virtual bool userVisible() const {
+    bool userVisible() const override
+    {
         return true;
     }
 
-    virtual KoID colorModelId() const {
+    KoID colorModelId() const override
+    {
         return YCbCrAColorModelID;
     }
 
-    virtual KoID colorDepthId() const {
+    KoID colorDepthId() const override
+    {
         return Integer16BitsColorDepthID;
     }
 
-    virtual int referenceDepth() const {
+    int referenceDepth() const override
+    {
         return 16;
     }
 
-    virtual KoColorSpace *createColorSpace(const KoColorProfile *p) const {
+    KoColorSpace *createColorSpace(const KoColorProfile *p) const override
+    {
         return new YCbCrU16ColorSpace(name(), p->clone());
     }
 
-    virtual QString defaultProfile() const {
+    QString defaultProfile() const override
+    {
         return QString();
     }
 };
 
-
 #endif
