@@ -30,13 +30,13 @@ class KoShape;
 class RemoveConnectionPointCommand : public KUndo2Command
 {
 public:
-    /// Creates new comand to remove connection point from shape
+    /// Creates new command to remove connection point from shape
     RemoveConnectionPointCommand(KoShape *shape, int connectionPointId, KUndo2Command *parent = 0);
-    virtual ~RemoveConnectionPointCommand();
+    ~RemoveConnectionPointCommand() override;
     /// reimplemented from KUndo2Command
-    virtual void redo();
+    void redo() override;
     /// reimplemented from KUndo2Command
-    virtual void undo();
+    void undo() override;
 
 private:
     void updateRoi();
