@@ -22,7 +22,7 @@
 #include "DefaultTool.h"
 
 #include <KoIcon.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 
 DefaultToolFactory::DefaultToolFactory()
     : KoToolFactoryBase(KoInteractionTool_ID)
@@ -30,7 +30,7 @@ DefaultToolFactory::DefaultToolFactory()
     setToolTip(i18n("Shape handling"));
     setToolType(mainToolType());
     setPriority(0);
-    setIconName(koIconNameCStr("select"));
+    setIconName(koIconName("select"));
     setActivationShapeId("flake/always");
 }
 
