@@ -36,7 +36,7 @@ class ChartResizeStrategy;
 /**
  * A strategy for the KoInteractionTool.
  * This strategy is invoked when the user starts a resize of a selection of objects,
- * the stategy will then resize the objects interactively and provide a command afterwards.
+ * the strategy will then resize the objects interactively and provide a command afterwards.
  */
 class ShapeResizeStrategy : public KoInteractionStrategy
 {
@@ -45,13 +45,13 @@ public:
      * Constructor
      */
     ShapeResizeStrategy(KoToolBase *tool, const QPointF &clicked, KoFlake::SelectionHandle direction);
-    virtual ~ShapeResizeStrategy();
+    ~ShapeResizeStrategy() override;
 
-    void handleMouseMove(const QPointF &mouseLocation, Qt::KeyboardModifiers modifiers);
-    KUndo2Command* createCommand();
-    void finishInteraction(Qt::KeyboardModifiers modifiers);
-    virtual void paint( QPainter &painter, const KoViewConverter &converter);
-    virtual void handleCustomEvent( KoPointerEvent * event );
+    void handleMouseMove(const QPointF &mouseLocation, Qt::KeyboardModifiers modifiers) override;
+    KUndo2Command* createCommand() override;
+    void finishInteraction(Qt::KeyboardModifiers modifiers) override;
+    void paint( QPainter &painter, const KoViewConverter &converter) override;
+    void handleCustomEvent( KoPointerEvent * event ) override;
 private:
     void resizeBy( const QPointF &center, qreal zoomX, qreal zoomY );
 
