@@ -1,4 +1,5 @@
 /* This file is part of the KDE project
+ * Copyright (C) 2018 Dag Andersen <danders@get2net.dk>
  * Copyright (C) 2008 Peter Simonsson <peter.simonsson@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -59,7 +60,7 @@ class CollectionMenu : public QMenu
 {
     public:
         CollectionMenu(QWidget * parent = 0);
-        virtual QSize sizeHint() const;
+        QSize sizeHint() const override;
 };
 
 CollectionMenu::CollectionMenu(QWidget * parent)
@@ -237,12 +238,15 @@ void ShapeCollectionDocker::unsetCanvas()
     setEnabled(false);
 }
 
-static
-bool operator<(const KoShapeTemplate &left, const KoShapeTemplate &right)
+inline bool operator<(const struct KoShapeTemplate &a, const struct KoShapeTemplate &b)
 {
-    const auto &leftId = left.templateId.isEmpty() ? left.id : left.templateId;
-    const auto &rightId = right.templateId.isEmpty() ? right.id : right.templateId;
-    return leftId < rightId;
+    if (a.order != b.order) {
+        return a.order < b.order;
+    }
+    if (a.id != b.id) {
+        return a.id < b.id;
+    }
+    return a.templateId < b.templateId;
 }
 
 void ShapeCollectionDocker::loadDefaultShapes()
@@ -252,15 +256,21 @@ void ShapeCollectionDocker::loadDefaultShapes()
     QMap<KoShapeTemplate, KoCollectionItem> funnyList;
     QMap<KoShapeTemplate, KoCollectionItem> geometricList;
     QMap<KoShapeTemplate, KoCollectionItem> quicklist;
+    QMap<QString, QMap<KoShapeTemplate, KoCollectionItem> > extras;
+    QMap<QString, QString> extraNames;
+
     int quickCount=0;
 
     QStringList quickShapes;
-    quickShapes << "TextShapeID" << "PictureShape" << "ChartShape" << "ArtisticText";
+    quickShapes << "TextShapeID" << "PictureShape" << "ChartShape_Bar" << "ArtisticText";
     KConfigGroup cfg =  KSharedConfig::openConfig()->group("KoShapeCollection");
     quickShapes = cfg.readEntry("QuickShapes", quickShapes);
 
     foreach(const QString & id, KoShapeRegistry::instance()->keys()) {
         KoShapeFactoryBase *factory = KoShapeRegistry::instance()->value(id);
+        if (!factory) {
+            continue;
+        }
         // don't show hidden factories
         if ( factory->hidden() ) {
             continue;
@@ -285,8 +295,12 @@ void ShapeCollectionDocker::loadDefaultShapes()
                 arrowList[shapeTemplate] = temp;
             else if(shapeTemplate.family == "geometric")
                 geometricList[shapeTemplate] = temp;
-            else
+            else if (factory->family() == "default" || factory->family().isEmpty()) {
                 defaultList[shapeTemplate] = temp;
+            } else {
+                extras[factory->family()][shapeTemplate] = temp;
+                extraNames[factory->family()] = factory->name();
+            }
 
             QString id= temp.id;
             if (!shapeTemplate.templateId.isEmpty()) {
@@ -332,6 +346,13 @@ void ShapeCollectionDocker::loadDefaultShapes()
     model->setShapeTemplateList(geometricList.values());
     addCollection("geometric", i18n("Geometrics"), model);
 
+    QMap<QString, QMap<KoShapeTemplate, KoCollectionItem> >::const_iterator it;
+    for (it = extras.constBegin(); it != extras.constEnd(); ++it) {
+        model = new CollectionItemModel(this);
+        model->setShapeTemplateList(it.value().values());
+        addCollection(it.key(), extraNames[it.key()], model);
+    }
+
     model = new CollectionItemModel(this);
     model->setShapeTemplateList(arrowList.values());
     addCollection("arrow", i18n("Arrows"), model);
