@@ -28,11 +28,11 @@
  */
 class KOFORMULA_EXPORT PhantomElement : public RowElement {
 public:
-    /// The standart constructor
+    /// The standard constructor
     explicit PhantomElement(BasicElement *parent = 0);
 
     /// @return The element's ElementType
-    ElementType elementType() const;
+    ElementType elementType() const override;
 };
 
 #endif // PHANTOMELEMENT_H
