@@ -52,20 +52,21 @@ public:
     /**
      * Render the element to the given QPainter
      * @param painter The QPainter to paint the element to
+     * @param am The AttributeManager providing information about attributes values
      */
-    void paint( QPainter& painter, AttributeManager* am );
+    void paint( QPainter& painter, AttributeManager* am ) override;
 
     /**
      * Calculate the size of the element and the positions of its children
      * @param am The AttributeManager providing information about attributes values
      */
-    void layout( const AttributeManager* am );
+    void layout( const AttributeManager* am ) override;
 
     /// @return The element's ElementType
-    ElementType elementType() const;
+    ElementType elementType() const override;
 
     /// @return The default value of the attribute for this element
-    QString attributesDefaultValue( const QString& attribute ) const;
+    QString attributesDefaultValue( const QString& attribute ) const override;
 };
 
 #endif // SPACEELEMENT_H
