@@ -28,13 +28,13 @@
  */
 class KOFORMULA_EXPORT StringElement : public TokenElement {
 public:
-    /// The standart constructor
+    /// The standard constructor
     explicit StringElement(BasicElement *parent = 0);
 
     /// @return The element's ElementType
-    ElementType elementType() const;
+    ElementType elementType() const override;
 
-    QRectF renderToPath( const QString& raw, QPainterPath& path ) const;
+    QRectF renderToPath( const QString& raw, QPainterPath& path ) const override;
 };
 
 #endif // STRINGELEMENT_H
