@@ -32,11 +32,11 @@
  */
 class KOFORMULA_EXPORT StyleElement : public RowElement {
 public:
-    /// The standart constructor
+    /// The standard constructor
     explicit StyleElement(BasicElement *parent = 0);
 
     /// @return The element's ElementType
-    ElementType elementType() const;
+    ElementType elementType() const override;
 };
 
 #endif // STYLEELEMENT_H
