@@ -43,71 +43,71 @@ public:
     explicit TableRowElement(BasicElement *parent = 0);
 
     /// The standard destructor
-    ~TableRowElement();
+    ~TableRowElement() override;
 
     /**
      * Render the element to the given QPainter
      * @param painter The QPainter to paint the element to
      * @param am AttributeManager containing style info
      */
-    void paint( QPainter& painter, AttributeManager* am );
+    void paint( QPainter& painter, AttributeManager* am ) override;
 
     /**
      * Calculate the size of the element and the positions of its children
      * @param am The AttributeManager providing information about attributes values
      */
-    void layout( const AttributeManager* am );
+    void layout( const AttributeManager* am ) override;
 
     /**
      * Obtain a list of all child elements of this element
      * @return a QList with pointers to all child elements
      */
-    const QList<BasicElement*> childElements() const;
+    const QList<BasicElement*> childElements() const override;
  
     /**
      * Insert a new child at the cursor position
-     * @param cursor The cursor holding the position where to inser
+     * @param position The cursor position where to insert
      * @param child A BasicElement to insert
      */
     bool insertChild( int position, BasicElement* child );
     
     /**
      * Remove a child element
-     * @param element The BasicElement to remove
+     * @param child The BasicElement to remove
      */ 
     bool removeChild( BasicElement* child );
 
     /**
      * Implement the cursor behaviour for the element
-     * @param direction Indicates whether the cursor moves up, down, right or left
+     * @param cursor The cursor
      * @return A this pointer if the element accepts if not the element to asked instead
      */
-    bool acceptCursor( const FormulaCursor& cursor );
+    bool acceptCursor( const FormulaCursor& cursor ) override;
     
     /// inherited from BasicElement
-    virtual int positionOfChild(BasicElement* child) const;
+    int positionOfChild(BasicElement* child) const override;
     
     /// inherited from BasicElement
-    virtual int endPosition() const;
+    int endPosition() const override;
     
     /// inherited from BasicElement
-    virtual bool moveCursor(FormulaCursor& newcursor, FormulaCursor& oldcursor);
+    bool moveCursor(FormulaCursor& newcursor, FormulaCursor& oldcursor) override;
     
     /// inherited from BasicElement
-    virtual bool setCursorTo(FormulaCursor& cursor, QPointF point);
+    bool setCursorTo(FormulaCursor& cursor, QPointF point) override;
     
     /// inherited from BasicElement
-    virtual QLineF cursorLine ( int position ) const;
+    QLineF cursorLine ( int position ) const override;
     
     /// @return The element's ElementType
-    ElementType elementType() const;
+    ElementType elementType() const override;
 
 protected:
     /// Read all content from the node - reimplemented by child elements
-    bool readMathMLContent( const KoXmlElement& element );
+    bool readMathMLContent( const KoXmlElement& element ) override;
 
     /// Write all content to the KoXmlWriter - reimplemented by the child elements
-    void writeMathMLContent( KoXmlWriter* writer, const QString& ns ) const;
+    void writeMathMLContent( KoXmlWriter* writer, const QString& ns ) const override;
 
 private:
     /// @return A list of alignments in @p orientation for each element of the table
