@@ -24,7 +24,7 @@
 #define TEXTELEMENT_H
 
 #include "TokenElement.h"
-#include "kformula_export.h"
+#include "koformula_export.h"
 
 /**
  * @short Implementation of the MathML
@@ -36,9 +36,9 @@ public:
     explicit TextElement(BasicElement *parent = 0);
 
     /// @return The element's ElementType
-    ElementType elementType() const;
+    ElementType elementType() const override;
 
-    QRectF renderToPath( const QString& raw, QPainterPath& path ) const;
+    QRectF renderToPath( const QString& raw, QPainterPath& path ) const override;
 };
 
 #endif // TEXTELEMENT_H
