@@ -41,18 +41,18 @@ class SimpleEntryTool : public KoToolBase
     Q_OBJECT
 public:
     explicit SimpleEntryTool( KoCanvasBase* canvas );
-    ~SimpleEntryTool();
+    ~SimpleEntryTool() override;
 
-    virtual void paint( QPainter& painter, const KoViewConverter& converter );
+    void paint( QPainter& painter, const KoViewConverter& converter ) override;
 
-    virtual void mousePressEvent( KoPointerEvent* event ) ;
-    virtual void mouseMoveEvent( KoPointerEvent* event );
-    virtual void mouseReleaseEvent( KoPointerEvent* event );
+    void mousePressEvent( KoPointerEvent* event ) override ;
+    void mouseMoveEvent( KoPointerEvent* event ) override;
+    void mouseReleaseEvent( KoPointerEvent* event ) override;
 
-    virtual void keyPressEvent( QKeyEvent *event );
+    void keyPressEvent( QKeyEvent *event ) override;
 
-    virtual void activate(ToolActivation toolActivation, const QSet<KoShape*> &shapes);
-    void deactivate();
+    void activate(ToolActivation toolActivation, const QSet<KoShape*> &shapes) override;
+    void deactivate() override;
 
     void addCommand(KUndo2Command* command);
 
@@ -61,7 +61,7 @@ public:
     
     void setSelection(int startBar, int endBar, MusicCore::Staff* startStaff, MusicCore::Staff* endStaff);
 protected:
-    virtual QWidget * createOptionWidget();
+    QWidget * createOptionWidget() override;
 protected Q_SLOTS:
     void activeActionChanged(QAction* action);
     void voiceChanged(int voice);
