@@ -35,8 +35,8 @@ public:
     AbstractNoteMusicAction(const QIcon& icon, const QString& text, SimpleEntryTool* tool);
     AbstractNoteMusicAction(const QString& text, SimpleEntryTool* tool);
     
-    virtual void mousePress(MusicCore::Staff* staff, int bar, const QPointF& pos);
-    virtual void mouseMove(MusicCore::Staff* staff, int bar, const QPointF& pos);
+    void mousePress(MusicCore::Staff* staff, int bar, const QPointF& pos) override;
+    void mouseMove(MusicCore::Staff* staff, int bar, const QPointF& pos) override;
 
     virtual void mousePress(MusicCore::Chord* chord, MusicCore::Note* note, qreal distance, const QPointF& pos) = 0;
     virtual void mouseMove(MusicCore::Chord* chord, MusicCore::Note* note, qreal distance, const QPointF& pos);
