@@ -27,7 +27,7 @@
 #include "../SimpleEntryTool.h"
 #include "../MusicShape.h"
 
-#include <klocale.h>
+#include <klocalizedstring.h>
 
 using namespace MusicCore;
 
