@@ -29,8 +29,8 @@ class MusicShape;
 class AddDotCommand : public KUndo2Command {
 public:
     AddDotCommand(MusicShape* shape, MusicCore::Chord* chord);
-    virtual void redo();
-    virtual void undo();
+    void redo() override;
+    void undo() override;
 private:
     MusicShape* m_shape;
     MusicCore::Chord* m_chord;
