@@ -17,7 +17,7 @@
  * Boston, MA 02110-1301, USA.
  */
 #include "RemoveBarCommand.h"
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include "../core/Bar.h"
 #include "../core/Sheet.h"
 
