@@ -62,8 +62,8 @@ public Q_SLOTS:
      */
     void engrave();
 protected:
-    void paintEvent(QPaintEvent* event);
-    void resizeEvent(QResizeEvent* event);
+    void paintEvent(QPaintEvent* event) override;
+    void resizeEvent(QResizeEvent* event) override;
 private:
     Engraver m_engraver;
     MusicStyle m_style;
