@@ -31,13 +31,13 @@ class EllipseShapeConfigWidget : public KoShapeConfigWidgetBase
 public:
     EllipseShapeConfigWidget();
     /// reimplemented
-    virtual void open(KoShape *shape);
+    void open(KoShape *shape) override;
     /// reimplemented
-    virtual void save();
+    void save() override;
     /// reimplemented
-    virtual bool showOnShapeCreate() { return false; }
+    bool showOnShapeCreate() override { return false; }
     /// reimplemented
-    virtual KUndo2Command * createCommand();
+    KUndo2Command * createCommand() override;
 private Q_SLOTS:
     void closeEllipse();
 private:
