@@ -45,7 +45,6 @@ EnhancedPathShapeFactory::EnhancedPathShapeFactory()
 
     addCross();
     addArrow();
-    addCallout();
     addSmiley();
     addCircularArrow();
     addGearhead();
@@ -300,86 +299,6 @@ void EnhancedPathShapeFactory::addArrow()
     }
 }
 
-void EnhancedPathShapeFactory::addCallout()
-{
-    QString modifiers("4250 45000");
-
-    QStringList commands;
-    commands.append("M 3590 0");
-    commands.append("X 0 3590");
-    commands.append("L ?f2 ?f3 0 8970 0 12630 ?f4 ?f5 0 18010");
-    commands.append("Y 3590 21600");
-    commands.append("L ?f6 ?f7 8970 21600 12630 21600 ?f8 ?f9 18010 21600");
-    commands.append("X 21600 18010");
-    commands.append("L ?f10 ?f11 21600 12630 21600 8970 ?f12 ?f13 21600 3590");
-    commands.append("Y 18010 0");
-    commands.append("L ?f14 ?f15 12630 0 8970 0 ?f16 ?f17");
-    commands.append("Z");
-    commands.append("N");
-
-    ComplexType formulae;
-    formulae["f0"] = "$0 -10800";
-    formulae["f1"] = "$1 -10800";
-    formulae["f2"] = "if(?f18 ,$0 ,0)";
-    formulae["f3"] = "if(?f18 ,$1 ,6280)";
-    formulae["f4"] = "if(?f23 ,$0 ,0)";
-    formulae["f5"] = "if(?f23 ,$1 ,15320)";
-    formulae["f6"] = "if(?f26 ,$0 ,6280)";
-    formulae["f7"] = "if(?f26 ,$1 ,21600)";
-    formulae["f8"] = "if(?f29 ,$0 ,15320)";
-    formulae["f9"] = "if(?f29 ,$1 ,21600)";
-    formulae["f10"] = "if(?f32 ,$0 ,21600)";
-    formulae["f11"] = "if(?f32 ,$1 ,15320)";
-    formulae["f12"] = "if(?f34 ,$0 ,21600)";
-    formulae["f13"] = "if(?f34 ,$1 ,6280)";
-    formulae["f14"] = "if(?f36 ,$0 ,15320)";
-    formulae["f15"] = "if(?f36 ,$1 ,0)";
-    formulae["f16"] = "if(?f38 ,$0 ,6280)";
-    formulae["f17"] = "if(?f38 ,$1 ,0)";
-    formulae["f18"] = "if($0 ,-1,?f19)";
-    formulae["f19"] = "if(?f1 ,-1,?f22)";
-    formulae["f20"] = "abs(?f0)";
-    formulae["f21"] = "abs(?f1)";
-    formulae["f22"] = "?f20 -?f21";
-    formulae["f23"] = "if($0 ,-1,?f24)";
-    formulae["f24"] = "if(?f1 ,?f22 ,-1)";
-    formulae["f25"] = "$1 -21600";
-    formulae["f26"] = "if(?f25 ,?f27 ,-1)";
-    formulae["f27"] = "if(?f0 ,-1,?f28)";
-    formulae["f28"] = "?f21 -?f20";
-    formulae["f29"] = "if(?f25 ,?f30 ,-1)";
-    formulae["f30"] = "if(?f0 ,?f28 ,-1)";
-    formulae["f31"] = "$0 -21600";
-    formulae["f32"] = "if(?f31 ,?f33 ,-1)";
-    formulae["f33"] = "if(?f1 ,?f22 ,-1)";
-    formulae["f34"] = "if(?f31 ,?f35 ,-1)";
-    formulae["f35"] = "if(?f1 ,-1,?f22)";
-    formulae["f36"] = "if($1 ,-1,?f37)";
-    formulae["f37"] = "if(?f0 ,?f28 ,-1)";
-    formulae["f38"] = "if($1 ,-1,?f39)";
-    formulae["f39"] = "if(?f0 ,-1,?f28)";
-    formulae["f40"] = "$0";
-    formulae["f41"] = "$1";
-
-    ListType handles;
-    ComplexType handle;
-    handle["draw:handle-position"] = "$0 $1";
-    handles.append(QVariant(handle));
-
-    KoShapeTemplate t;
-    t.id = KoPathShapeId;
-    t.templateId = "callout";
-    t.name = i18n("Callout");
-    t.family = "funny";
-    t.toolTip = i18n("A callout");
-    t.iconName = koIconName("callout-shape");
-    KoProperties* properties = dataToProperties(modifiers, commands, handles, formulae);
-    properties->setProperty(QLatin1String("viewBox"), QRect(0, 0, 21600, 21600));
-    t.properties = properties;
-
-    addTemplate(t);
-}
-
 void EnhancedPathShapeFactory::addSmiley()
 {
     QString modifiers("17520");
@@ -554,5 +473,6 @@ void EnhancedPathShapeFactory::addGearhead()
 bool EnhancedPathShapeFactory::supports(const KoXmlElement & e, KoShapeLoadingContext &context) const
 {
     Q_UNUSED(context);
+    qInfo()<<Q_FUNC_INFO<<e.localName();
     return (e.localName() == "custom-shape" && e.namespaceURI() == KoXmlNS::draw);
 }
