@@ -27,13 +27,13 @@
 #include <KoShapeLoadingContext.h>
 
 #include <KoIcon.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 
 RectangleShapeFactory::RectangleShapeFactory()
     : KoShapeFactoryBase(RectangleShapeId, i18n("Rectangle"))
 {
     setToolTip(i18n("A rectangle"));
-    setIconName(koIconNameCStr("rectangle-shape"));
+    setIconName(koIconName("rectangle-shape"));
     setFamily("geometric");
     setLoadingPriority(1);
 
