@@ -26,7 +26,7 @@
 
 extern const QLoggingCategory &PICTURE_LOG();
 
-#define debugPicture qCDebug(PICTURE_LOG)
+#define debugPicture qCDebug(PICTURE_LOG)<<Q_FUNC_INFO
 #define warnPicture qCWarning(PICTURE_LOG)
 #define errorPicture qCCritical(PICTURE_LOG)
 
