@@ -23,9 +23,13 @@
  */
 
 #include "PictureShape.h"
+
 #include "filters/GreyscaleFilterEffect.h"
 #include "filters/MonoFilterEffect.h"
 #include "filters/WatermarkFilterEffect.h"
+#include "filters/ColoringFilterEffect.h"
+#include "filters/GammaFilterEffect.h"
+#include "PictureDebug.h"
 
 #include <KoOdfWorkaround.h>
 #include <KoViewConverter.h>
@@ -37,9 +41,9 @@
 #include <KoShapeSavingContext.h>
 #include <KoXmlWriter.h>
 #include <KoXmlNS.h>
-#include <KoStoreDevice.h>
 #include <KoUnit.h>
 #include <KoGenStyle.h>
+#include <KoStyleStack.h>
 #include <KoFilterEffectStack.h>
 #include <KoClipPath.h>
 #include <SvgSavingContext.h>
@@ -47,10 +51,6 @@
 #include <SvgUtil.h>
 #include <KoPathShape.h>
 
-#include <kdebug.h>
-#include <kjob.h>
-#include <KIO/Job>
-
 #include <QPainter>
 #include <QTimer>
 #include <QPixmapCache>
@@ -97,7 +97,7 @@ void _Private::PictureShapeProxy::setImage(const QString &key, const QImage &ima
 
 // ----------------------------------------------------------------- //
 
-QPainterPath _Private::generateOutline(const QImage &imageIn, int treshold)
+QPainterPath _Private::generateOutline(const QImage &imageIn, int threshold)
 {
     int leftArray[100];
     int rightArray[100];
@@ -110,7 +110,7 @@ QPainterPath _Private::generateOutline(const QImage &imageIn, int treshold)
         leftArray[y] = -1;
         for (int x = 0; x < 100; x++) {
             int a = qAlpha(image.pixel(x,y));
-            if (a > treshold) {
+            if (a > threshold) {
                 leftArray[y] = x;
                 break;
             }
@@ -121,7 +121,7 @@ QPainterPath _Private::generateOutline(const QImage &imageIn, int treshold)
         if (leftArray[y] != -1) {
             for (int x = 100-1; x >= 0; x--) {
                 int a = qAlpha(image.pixel(x,y));
-                if (a > treshold) {
+                if (a > threshold) {
                     rightArray[y] = x;
                     break;
                 }
@@ -167,6 +167,9 @@ PictureShape::PictureShape()
     KoFilterEffectStack * effectStack = new KoFilterEffectStack();
     effectStack->setClipRect(QRectF(0, 0, 1, 1));
     setFilterEffectStack(effectStack);
+    filterEffectStack()->insertFilterEffect(0, new KoFilterEffect("NoOpFilterEffect", "NoOpFilterEffect")); // let's just set 3
+    filterEffectStack()->insertFilterEffect(1, new KoFilterEffect("NoOpFilterEffect", "NoOpFilterEffect")); // no-op filters
+    filterEffectStack()->insertFilterEffect(2, new KoFilterEffect("NoOpFilterEffect", "NoOpFilterEffect"));
 }
 
 KoImageData* PictureShape::imageData() const
@@ -232,7 +235,7 @@ ClippingRect PictureShape::parseClippingRectString(const QString &originalString
         const QStringList valueStrings = string.split(QLatin1Char(','));
 
         if (valueStrings.count() != 4) {
-            kWarning() << "Not exactly 4 values for attribute fo:clip=rect(...):" << originalString << ", please report.";
+            warnPicture << "Not exactly 4 values for attribute fo:clip=rect(...):" << originalString << ", please report.";
             // hard to guess which value is for which offset, so just cancel parsing and return with the default rect
             return rect;
         }
@@ -314,11 +317,11 @@ void PictureShape::paint(QPainter &painter, const KoViewConverter &converter,
         QTransform outputTransform = painter.transform();
         QTransform worldTransform  = QTransform();
 
-        //kDebug(31000) << "Flipping" << midpointX << midpointY << scaleX << scaleY;
+        //debugPicture << "Flipping" << midpointX << midpointY << scaleX << scaleY;
         worldTransform.translate(midpointX, midpointY);
         worldTransform.scale(scaleX, scaleY);
         worldTransform.translate(-midpointX, -midpointY);
-        //kDebug(31000) << "After flipping for window" << worldTransform;
+        //debugPicture << "After flipping for window" << worldTransform;
 
         QTransform newTransform = worldTransform * outputTransform;
         painter.setWorldTransform(newTransform);
@@ -427,6 +430,7 @@ bool PictureShape::loadOdf(const KoXmlElement &element, KoShapeLoadingContext &c
     if (loadOdfFrame(element, context)) {
         // load contour (clip)
         KoImageData *imageData = qobject_cast<KoImageData*>(userData());
+        Q_ASSERT(imageData);
 
         QSizeF scaleFactor(size().width() / imageData->imageSize().width(),
                  size().height() / imageData->imageSize().height());
@@ -440,6 +444,37 @@ bool PictureShape::loadOdf(const KoXmlElement &element, KoShapeLoadingContext &c
     return false;
 }
 
+static const char *s_emptyImageXpm[] = {
+    /* <Values> */
+    /* <width/columns> <height/rows> <colors> <chars per pixel>*/
+    "16 16 2 1",
+    /* <Colors> */
+    "a c #ffffff",
+    "b c #000000",
+    /* <Pixels> */
+    "bbbbbbbbbbbbbbbb",
+    "baaaaaaaaaaaaaab",
+    "baaaaaaaaaaaaaab",
+    "baaaaaaaaaaaaaab",
+    "baaaaaaaaaaaaaab",
+    "baaaaaaaaaaaaaab",
+    "baaaaaaaaaaaaaab",
+    "baaaaaaaaaaaaaab",
+    "baaaaaaaaaaaaaab",
+    "baaaaaaaaaaaaaab",
+    "baaaaaaaaaaaaaab",
+    "baaaaaaaaaaaaaab",
+    "baaaaaaaaaaaaaab",
+    "baaaaaaaaaaaaaab",
+    "baaaaaaaaaaaaaab",
+    "bbbbbbbbbbbbbbbb"
+};
+
+// image formats (possibly) supported by Qt
+// According to docs, only jpg and png are checked for by default
+const int s_numImageFormats = 10;
+const char *s_imageFormat[s_numImageFormats] = { "jpg", "jpeg", "png", "bmp", "gif", "pbm", "pgm", "ppm", "xbm", "xpm" };
+
 bool PictureShape::loadOdfFrameElement(const KoXmlElement &element, KoShapeLoadingContext &context)
 {
     if (m_imageCollection) {
@@ -454,12 +489,24 @@ bool PictureShape::loadOdfFrameElement(const KoXmlElement &element, KoShapeLoadi
             const KoXmlElement &binaryData(KoXml::namedItemNS(element, KoXmlNS::office, "binary-data"));
             if (!binaryData.isNull()) {
                 QImage image;
-                if (image.loadFromData(QByteArray::fromBase64(binaryData.text().toLatin1()))) {
-                    KoImageData *data = m_imageCollection->createImageData(image);
-                    setUserData(data);
+                for (int i = 0; i < s_numImageFormats; ++i) {
+                    if (image.loadFromData(QByteArray::fromBase64(binaryData.text().toLatin1()), s_imageFormat[i])) {
+                        KoImageData *data = m_imageCollection->createImageData(image);
+                        setUserData(data);
+                        debugPicture<<"Found image format:"<<s_imageFormat[i];
+                        break;
+                    }
                 }
+            } else {
+                debugPicture<<"No image binary data";
             }
         }
+        if (!userData()) {
+            // We must crate an image or else things crashes later on
+            warnPicture<<"Could not find an image, creating an empty one";
+            KoImageData *data = m_imageCollection->createImageData(QImage(s_emptyImageXpm));
+            setUserData(data);
+        }
     }
 
     loadText(element, context);
@@ -478,7 +525,7 @@ QString PictureShape::saveStyle(KoGenStyle& style, KoShapeSavingContext& context
         style.addProperty("draw:image-opacity", QString("%1%").arg((1.0 - transparency()) * 100.0));
     }
 
-    // this attribute is need to work around a bug in LO 3.4 to make it recognice us as an
+    // this attribute is need to work around a bug in LO 3.4 to make it recognize us as an
     // image and not just any shape. But we shouldn't produce illegal odf so: only for testing!
     // style.addAttribute("style:parent-style-name", "dummy");
 
@@ -518,6 +565,18 @@ QString PictureShape::saveStyle(KoGenStyle& style, KoShapeSavingContext& context
         break;
     }
 
+    if (ColoringFilterEffect *cEffect = dynamic_cast<ColoringFilterEffect *>(filterEffectStack()->filterEffects()[1])) {
+        style.addProperty("draw:red", QString("%1%").arg(100*cEffect->red()));
+        style.addProperty("draw:green", QString("%1%").arg(100*cEffect->green()));
+        style.addProperty("draw:blue", QString("%1%").arg(100*cEffect->blue()));
+        style.addProperty("draw:luminance", QString("%1%").arg(100*cEffect->luminance()));
+        style.addProperty("draw:contrast", QString("%1%").arg(100*cEffect->contrast()));
+    }
+
+    if (GammaFilterEffect *gEffect = dynamic_cast<GammaFilterEffect *>(filterEffectStack()->filterEffects()[2])) {
+        style.addProperty("draw:gamma", QString("%1%").arg(100*gEffect->gamma()));
+    }
+
     KoImageData *imageData = qobject_cast<KoImageData*>(userData());
 
     if (imageData != 0) {
@@ -587,6 +646,20 @@ void PictureShape::loadStyle(const KoXmlElement& element, KoShapeLoadingContext&
         }
     }
 
+    QString red = styleStack.property(KoXmlNS::draw, "red");
+    QString green = styleStack.property(KoXmlNS::draw, "green");
+    QString blue = styleStack.property(KoXmlNS::draw, "blue");
+    QString luminance = styleStack.property(KoXmlNS::draw, "luminance");
+    QString contrast = styleStack.property(KoXmlNS::draw, "contrast");
+    setColoring(red.right(1) == "%" ? (red.left(red.length() - 1).toDouble() / 100.0) : 0.0
+              , green.right(1) == "%" ? (green.left(green.length() - 1).toDouble() / 100.0) : 0.0
+              , blue.right(1) == "%" ? (blue.left(blue.length() - 1).toDouble() / 100.0) : 0.0
+              , luminance.right(1) == "%" ? (luminance.left(luminance.length() - 1).toDouble() / 100.0) : 0.0
+              , contrast.right(1) == "%" ? (contrast.left(contrast.length() - 1).toDouble() / 100.0) : 0.0);
+
+    QString gamma = styleStack.property(KoXmlNS::draw, "gamma");
+    setGamma(gamma.right(1) == "%" ? (gamma.left(gamma.length() - 1).toDouble() / 100.0) : 0.0);
+
     // image opacity
     QString opacity(styleStack.property(KoXmlNS::draw, "image-opacity"));
     if (! opacity.isEmpty() && opacity.right(1) == "%") {
@@ -633,15 +706,17 @@ void PictureShape::setColorMode(PictureShape::ColorMode mode)
         switch(mode)
         {
         case Greyscale:
-            filterEffectStack()->appendFilterEffect(new GreyscaleFilterEffect());
+            filterEffectStack()->insertFilterEffect(0, new GreyscaleFilterEffect());
             break;
         case Mono:
-            filterEffectStack()->appendFilterEffect(new MonoFilterEffect());
+            filterEffectStack()->insertFilterEffect(0, new MonoFilterEffect());
             break;
         case Watermark:
-            filterEffectStack()->appendFilterEffect(new WatermarkFilterEffect());
+            filterEffectStack()->insertFilterEffect(0, new WatermarkFilterEffect());
             break;
+        case Standard:
         default:
+            filterEffectStack()->insertFilterEffect(0, new KoFilterEffect("NoOpFilterEffect", "NoOpFilterEffect"));
             break;
         }
 
@@ -650,6 +725,30 @@ void PictureShape::setColorMode(PictureShape::ColorMode mode)
     }
 }
 
+void PictureShape::setColoring(qreal red, qreal green, qreal blue, qreal luminance, qreal contrast)
+{
+    filterEffectStack()->removeFilterEffect(1);
+
+    ColoringFilterEffect *cEffect = new ColoringFilterEffect();
+    cEffect->setColoring(red, green, blue, luminance, contrast);
+
+    filterEffectStack()->insertFilterEffect(1, cEffect);
+
+    update();
+}
+
+void PictureShape::setGamma(qreal gamma)
+{
+    filterEffectStack()->removeFilterEffect(2);
+
+    GammaFilterEffect *gEffect = new GammaFilterEffect();
+    gEffect->setGamma(gamma);
+
+    filterEffectStack()->insertFilterEffect(2, gEffect);
+
+    update();
+}
+
 KoClipPath *PictureShape::generateClipPath()
 {
     QPainterPath path = _Private::generateOutline(imageData()->image());
@@ -668,7 +767,7 @@ bool PictureShape::saveSvg(SvgSavingContext &context)
 {
     KoImageData *imageData = qobject_cast<KoImageData*>(userData());
     if (!imageData) {
-        qWarning() << "Picture has no image data. Omitting.";
+        warnPicture << "Picture has no image data. Omitting.";
         return false;
     }
 
