@@ -26,9 +26,9 @@ class PictureToolFactory : public KoToolFactoryBase
 {
 public:
     PictureToolFactory();
-    ~PictureToolFactory();
+    ~PictureToolFactory() override;
 
-    KoToolBase *createTool(KoCanvasBase *canvas);
+    KoToolBase *createTool(KoCanvasBase *canvas) override;
 };
 
 
