@@ -28,10 +28,10 @@ class GammaFilterEffect : public KoFilterEffect
 {
 public:
     GammaFilterEffect();
-    virtual ~GammaFilterEffect();
-    virtual void save(KoXmlWriter& writer);
-    virtual bool load(const KoXmlElement& element, const KoFilterEffectLoadingContext& context);
-    virtual QImage processImage(const QImage& image, const KoFilterEffectRenderContext& context) const;
+    ~GammaFilterEffect() override;
+    void save(KoXmlWriter& writer) override;
+    bool load(const KoXmlElement& element, const KoFilterEffectLoadingContext& context) override;
+    QImage processImage(const QImage& image, const KoFilterEffectRenderContext& context) const override;
     void setGamma(qreal gamma);
     qreal gamma() const;
 
