@@ -28,10 +28,10 @@ class MonoFilterEffect : public KoFilterEffect
 {
 public:
     MonoFilterEffect();
-    virtual ~MonoFilterEffect();
-    virtual void save(KoXmlWriter& writer);
-    virtual bool load(const KoXmlElement& element, const KoFilterEffectLoadingContext& context);
-    virtual QImage processImage(const QImage& image, const KoFilterEffectRenderContext& context) const;
+    ~MonoFilterEffect() override;
+    void save(KoXmlWriter& writer) override;
+    bool load(const KoXmlElement& element, const KoFilterEffectLoadingContext& context) override;
+    QImage processImage(const QImage& image, const KoFilterEffectRenderContext& context) const override;
 };
 
 #endif // MONOFILTEREFFECT_H
