@@ -30,10 +30,10 @@ class PluginShapeFactory : public KoShapeFactoryBase
 {
 public:
     PluginShapeFactory();
-    ~PluginShapeFactory() {}
+    ~PluginShapeFactory() override {}
 
-    virtual KoShape *createDefaultShape(KoDocumentResourceManager *documentResources = 0) const;
-    virtual bool supports(const KoXmlElement &e, KoShapeLoadingContext &context) const;
+    KoShape *createDefaultShape(KoDocumentResourceManager *documentResources = 0) const override;
+    bool supports(const KoXmlElement &e, KoShapeLoadingContext &context) const override;
 };
 
 #endif
