@@ -40,7 +40,7 @@ public:
     // inherited and reimplemented...
 
     hKoRdfCalendarEvent semanticObject() const;
-    virtual QList<KAction *> actions(QWidget *parent, KoCanvasBase *host = 0);
+    virtual QList<QAction *> actions(QWidget *parent, KoCanvasBase *host = 0);
     virtual void insert(KoCanvasBase *host);
 
 public Q_SLOTS:
