@@ -33,7 +33,7 @@ public:
     explicit ImageEffectConfigWidget(QWidget *parent = 0);
 
     /// reimplemented from KoFilterEffectConfigWidgetBase
-    virtual bool editFilterEffect(KoFilterEffect * filterEffect);
+    bool editFilterEffect(KoFilterEffect * filterEffect) override;
 
 private Q_SLOTS:
     void selectImage();
