@@ -27,14 +27,14 @@ class ThreedShapeFactory : public KoShapeFactoryBase
 {
 public:
     ThreedShapeFactory();
-    ~ThreedShapeFactory() {}
+    ~ThreedShapeFactory() override {}
 
-    virtual KoShape *createDefaultShape(KoDocumentResourceManager *documentResources = 0) const;
-    virtual KoShape *createShape(const KoProperties *params, KoDocumentResourceManager *documentResources = 0) const;
-    virtual bool supports(const KoXmlElement &e, KoShapeLoadingContext &context) const;
+    KoShape *createDefaultShape(KoDocumentResourceManager *documentResources = 0) const override;
+    KoShape *createShape(const KoProperties *params, KoDocumentResourceManager *documentResources = 0) const override;
+    bool supports(const KoXmlElement &e, KoShapeLoadingContext &context) const override;
 
     /// reimplemented
-    virtual QList<KoShapeConfigWidgetBase*> createShapeOptionPanels();
+    QList<KoShapeConfigWidgetBase*> createShapeOptionPanels() override;
 };
 
 #endif
