@@ -25,6 +25,8 @@
 #include <QTextCharFormat>
 #include <QSet>
 
+class QAction;
+
 /* struct AutocorrectEntry
 {
     QString replace;
@@ -41,11 +43,11 @@ public:
     };
 
     Autocorrect();
-    virtual ~Autocorrect();
+    ~Autocorrect() override;
 
-    void finishedWord(QTextDocument *document, int cursorPosition);
-    void finishedParagraph(QTextDocument *document, int cursorPosition);
-    void startingSimpleEdit(QTextDocument *document, int cursorPosition);
+    void finishedWord(QTextDocument *document, int cursorPosition) override;
+    void finishedParagraph(QTextDocument *document, int cursorPosition) override;
+    void startingSimpleEdit(QTextDocument *document, int cursorPosition) override;
 
     void setUppercaseFirstCharOfSentence(bool b) { m_uppercaseFirstCharOfSentence = b; }
     void setFixTwoUppercaseChars(bool b) { m_fixTwoUppercaseChars = b; }
@@ -147,7 +149,7 @@ private:
     QHash<QString, QString /*AutocorrectEntry*/> m_autocorrectEntries;
     TypographicQuotes m_typographicSingleQuotes;
     TypographicQuotes m_typographicDoubleQuotes;
-    KAction *m_enabled;
+    QAction *m_enabled;
 };
 
 #endif
