@@ -30,7 +30,6 @@ class KActionMenu;
 class QAction;
 class QAction;
 class QMenu;
-class QSignalMapper;
 class SpellCheck;
 
 class SpellCheckMenu : public QObject
@@ -38,7 +37,7 @@ class SpellCheckMenu : public QObject
     Q_OBJECT
 public:
     explicit SpellCheckMenu(const Sonnet::Speller &speller, SpellCheck *spellCheck);
-    ~SpellCheckMenu();
+    ~SpellCheckMenu() override;
 
     QPair<QString, QAction*> menuAction();
     void setMisspelled(const QString &word, int position,int length);
@@ -63,7 +62,6 @@ private:
     QAction *m_addToDictionaryAction;
     QMenu *m_suggestionsMenu;
     int m_lengthMisspelled;
-    QSignalMapper *m_suggestionsSignalMapper;
     int m_currentMisspelledPosition;
     QString m_currentMisspelled;
     QStringList m_suggestions;
