@@ -19,6 +19,8 @@
 
 #include "AnnotationTextShape.h"
 
+#include "TextShapeDebug.h"
+
 #include <KoInlineTextObjectManager.h>
 #include <KoTextRangeManager.h>
 #include <KoShapeLoadingContext.h>
@@ -36,8 +38,6 @@
 #include <QPen>
 #include <QTextLayout>
 
-#include <kdebug.h>
-
 AnnotationTextShape::AnnotationTextShape(KoInlineTextObjectManager *inlineTextObjectManager,
                                          KoTextRangeManager *textRangeManager)
     : TextShape(inlineTextObjectManager, textRangeManager)
@@ -46,14 +46,17 @@ AnnotationTextShape::AnnotationTextShape(KoInlineTextObjectManager *inlineTextOb
     , m_dateString()
 {
     setBackground(QSharedPointer<KoColorBackground>(new KoColorBackground(Qt::yellow)));
-    setGeometryProtected(true);
+    setAllowedInteraction(KoShape::ResizeAllowed, false);
+    setAllowedInteraction(KoShape::MoveAllowed, false);
+    setAllowedInteraction(KoShape::ShearingAllowed, false);
+    setAllowedInteraction(KoShape::RotationAllowed, false);
 }
 
 AnnotationTextShape::~AnnotationTextShape()
 {
 }
 
-void AnnotationTextShape::setAnnotaionTextData(KoTextShapeData *textShapeData)
+void AnnotationTextShape::setAnnotationTextData(KoTextShapeData *textShapeData)
 {
     m_textShapeData = textShapeData;
     m_textShapeData->setTopPadding(HeaderSpace);
@@ -84,7 +87,7 @@ void AnnotationTextShape::paintComponent(QPainter &painter, const KoViewConverte
 
 bool AnnotationTextShape::loadOdf(const KoXmlElement &element, KoShapeLoadingContext &context)
 {
-    //kDebug(31000) << "****** Start Load odf ******";
+    //debugTextShape << "****** Start Load odf ******";
 
     KoTextLoader textLoader(context);
     QTextCursor cursor(textShapeData()->document());
@@ -112,7 +115,7 @@ bool AnnotationTextShape::loadOdf(const KoXmlElement &element, KoShapeLoadingCon
             }
         }
         textLoader.loadBody(element, cursor);
-        //kDebug(31000) << "****** End Load ******";
+        //debugTextShape << "****** End Load ******";
     }
     else {
         // something pretty weird going on...
@@ -123,7 +126,7 @@ bool AnnotationTextShape::loadOdf(const KoXmlElement &element, KoShapeLoadingCon
 
 void AnnotationTextShape::saveOdf(KoShapeSavingContext &context) const
 {
-    //kDebug(31000) << " ****** Start saveing annotation shape **********";
+    //debugTextShape << " ****** Start saving annotation shape **********";
     KoXmlWriter *writer = &context.xmlWriter();
 
     writer->startElement("dc:creator", false);
