@@ -32,9 +32,10 @@
 
 #include "FontFamilyAction.h"
 
+#include "TextShapeDebug.h"
+
 #include <QToolBar>
 
-#include <QDebug>
 #include <QIcon>
 #include <klocalizedstring.h>
 #include <kfontchooser.h>
@@ -51,7 +52,7 @@ class KoFontFamilyAction::KoFontFamilyActionPrivate
 
         void _ko_slotFontChanged(const QFont &font)
         {
-            qDebug() << "KoFontComboBox - slotFontChanged("
+            debugTextShape << "KoFontComboBox - slotFontChanged("
                         << font.family() << ") settingFont=" << settingFont;
             if (settingFont)
                 return;
@@ -59,7 +60,7 @@ class KoFontFamilyAction::KoFontFamilyActionPrivate
             q->setFont(font.family());
             q->triggered(font.family());
 
-            qDebug() << "\tslotFontChanged done";
+            debugTextShape << "\tslotFontChanged done";
         }
 
 
@@ -115,7 +116,7 @@ QString KoFontFamilyAction::font() const
 
 QWidget* KoFontFamilyAction::createWidget(QWidget* parent)
 {
-    qDebug() << "KoFontFamilyAction::createWidget()";
+    debugTextShape << "KoFontFamilyAction::createWidget()";
 // silence unclear warning from original kfontaction.acpp
 // #ifdef __GNUC__
 // #warning FIXME: items need to be converted
@@ -126,10 +127,10 @@ QWidget* KoFontFamilyAction::createWidget(QWidget* parent)
     KoFontComboBox *cb = new KoFontComboBox( parent );
     //cb->setFontList(items());
 
-    qDebug() << "\tset=" << font();
+    debugTextShape << "\tset=" << font();
     // Do this before connecting the signal so that nothing will fire.
     cb->setCurrentFont( QFont( font().toLower() ) );
-    qDebug() << "\tspit back=" << cb->currentFont().family();
+    debugTextShape << "\tspit back=" << cb->currentFont().family();
 
     connect( cb, SIGNAL(currentFontChanged(QFont)), SLOT(_ko_slotFontChanged(QFont)) );
     cb->setMinimumWidth( cb->sizeHint().width() );
@@ -141,7 +142,7 @@ QWidget* KoFontFamilyAction::createWidget(QWidget* parent)
  */
 void KoFontFamilyAction::setFont( const QString &family )
 {
-    qDebug() << "KoFontFamilyAction::setFont(" << family << ")";
+    debugTextShape << "KoFontFamilyAction::setFont(" << family << ")";
 
     // Suppress triggered(QString) signal and prevent recursive call to ourself.
     d->settingFont++;
@@ -149,17 +150,17 @@ void KoFontFamilyAction::setFont( const QString &family )
     foreach(QWidget *w, createdWidgets())
     {
         KoFontComboBox *cb = qobject_cast<KoFontComboBox *>(w);
-        qDebug() << "\tw=" << w << "cb=" << cb;
+        debugTextShape << "\tw=" << w << "cb=" << cb;
 
         if(!cb) continue;
 
         cb->setCurrentFont(QFont(family.toLower()));
-        qDebug() << "\t\tw spit back=" << cb->currentFont().family();
+        debugTextShape << "\t\tw spit back=" << cb->currentFont().family();
     }
 
     d->settingFont--;
 
-    qDebug() << "\tcalling setCurrentAction()";
+    debugTextShape << "\tcalling setCurrentAction()";
 
     QString lowerName = family.toLower();
     if (setCurrentAction(lowerName, Qt::CaseInsensitive))
@@ -180,7 +181,7 @@ void KoFontFamilyAction::setFont( const QString &family )
 
     // TODO: Inconsistent state if KFontComboBox::setCurrentFont() succeeded
     //       but setCurrentAction() did not and vice-versa.
-    qDebug() << "Font not found " << family.toLower();
+    debugTextShape << "Font not found " << family.toLower();
 }
 
 // have to include this because of Q_PRIVATE_SLOT
