@@ -35,6 +35,8 @@
 
 #include "FontSizeAction.h"
 
+#include <algorithm>
+
 QString format(qreal v) {
     static const QString f("%1");
     static const QString e("");
@@ -129,7 +131,7 @@ void FontSizeAction::setFontSize( qreal size )
         clear();
 
         // Sort the list
-        qSort( lst );
+        std::sort( lst.begin(), lst.end() );
         Q_FOREACH( qreal it, lst ) {
             QAction* const action = addAction( format(it) );
             if (it == size) {
