@@ -43,12 +43,12 @@ class ReferencesTool : public TextTool
 public:
     explicit ReferencesTool(KoCanvasBase *canvas);
 
-    virtual ~ReferencesTool();
+    ~ReferencesTool() override;
 
-    virtual void activate(ToolActivation toolActivation, const QSet<KoShape*> &shapes);
-    virtual void deactivate();
+    void activate(ToolActivation toolActivation, const QSet<KoShape*> &shapes) override;
+    void deactivate() override;
 
-    virtual void createActions();
+    void createActions() override;
 
     KoTextEditor *editor();
     /// inserts a ToC and open a configure dialog for customization
@@ -58,7 +58,7 @@ public:
 
 protected:
     /// reimplemented from superclass
-    virtual QList<QPointer<QWidget> > createOptionWidgets();
+    QList<QPointer<QWidget> > createOptionWidgets() override;
 
 private Q_SLOTS:
     /// insert a citation
@@ -104,7 +104,7 @@ private:
     KoCanvasBase *m_canvas;
 };
 
-class KAction;
+class QAction;
 class QLineEdit;
 class QLabel;
 class LabeledWidget : public QWidget
@@ -112,7 +112,7 @@ class LabeledWidget : public QWidget
     Q_OBJECT
 public:
     enum LabelPosition {INLINE, ABOVE};
-    LabeledWidget(KAction *action, const QString &label, LabelPosition pos, bool warningLabelRequired);
+    LabeledWidget(QAction *action, const QString &label, LabelPosition pos, bool warningLabelRequired);
     void setWarningText(int pos, const QString &warning);
     void clearLineEdit();
 Q_SIGNALS:
@@ -123,12 +123,12 @@ private Q_SLOTS:
     void returnPressed();
 
 protected:
-    virtual void enterEvent(QEvent *event);
+    void enterEvent(QEvent *event) override;
 
 private :
     QLineEdit *m_lineEdit;
     QLabel *m_warningLabel[2];
-    KAction *m_action;
+    QAction *m_action;
 };
 
 #endif // REFERENCESTOOL_H
