@@ -27,7 +27,7 @@
 #include <KoDocumentResourceManager.h>
 
 #include <KoIcon.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 
 #include <QDebug>
 
@@ -36,7 +36,7 @@ ReviewToolFactory::ReviewToolFactory()
 {
     setToolTip(i18n("Review"));
     setToolType(dynamicToolType()+",calligrawords,calligraauthor");
-    setIconName(koIconNameCStr("tool_review"));
+    setIconName(koIconName("tool_review"));
     setPriority(30);
     setActivationShapeId(TextShape_SHAPEID "," AnnotationShape_SHAPEID);
 }
