@@ -24,6 +24,7 @@
 #include <KoBorder.h>
 #include <KoTextLayoutRootArea.h>
 #include <KoTextLayoutObstruction.h>
+#include <KoInsets.h>
 
 SimpleRootAreaProvider::SimpleRootAreaProvider(KoTextShapeData *data, TextShape *textshape)
     : m_textShape(textshape)
@@ -67,9 +68,11 @@ void SimpleRootAreaProvider::doPostLayout(KoTextLayoutRootArea *rootArea, bool i
                              m_textShapeData->topPadding() + m_textShapeData->bottomPadding());
 
     KoBorder *border = m_textShape->border();
-
     if (border) {
         newSize -= QSizeF(border->borderWidth(KoBorder::LeftBorder) + border->borderWidth(KoBorder::RightBorder), border->borderWidth(KoBorder::TopBorder) + border->borderWidth(KoBorder::BottomBorder));
+    } else {
+        KoInsets inset = m_textShape->strokeInsets();
+        newSize -= QSizeF((inset.right+inset.left), (inset.bottom+inset.top));
     }
 
 
@@ -77,23 +80,36 @@ void SimpleRootAreaProvider::doPostLayout(KoTextLayoutRootArea *rootArea, bool i
     }
     if (m_textShapeData->verticalAlignment() & Qt::AlignVCenter) {
     }
-    if (m_textShapeData->resizeMethod() == KoTextShapeData::AutoGrowWidthAndHeight
-        ||m_textShapeData->resizeMethod() == KoTextShapeData::AutoGrowHeight) {
-        qreal height = rootArea->bottom() - rootArea->top();
-        if (height > newSize.height()) {
-            newSize.setHeight(height);
+
+    if (m_textShapeData->resizeMethod() == KoTextShapeData::AutoResize) {
+        newSize = QSizeF(rootArea->right() - rootArea->left(), rootArea->bottom() - rootArea->top());
+        // HACK: The size we get from the shape will cut descents,
+        // so we add some reasonable (approximate) value that works ok in normal cases
+        QSizeF s(0.0, 0.0);
+        int lines = m_textShapeData->document()->lineCount();
+        if (lines > 0) {
+            s.setHeight(newSize.height() / lines * 0.2);
         }
-        if (m_textShape->shapeId() == "AnnotationTextShapeID") {
-            if (height < newSize.height()) {
-                newSize.setHeight(rootArea->bottom() - rootArea->top());
+        newSize += s;
+    } else {
+        if (m_textShapeData->resizeMethod() == KoTextShapeData::AutoGrowWidthAndHeight
+            ||m_textShapeData->resizeMethod() == KoTextShapeData::AutoGrowHeight) {
+            qreal height = rootArea->bottom() - rootArea->top();
+            if (height > newSize.height()) {
+                newSize.setHeight(height);
+            }
+            if (m_textShape->shapeId() == "AnnotationTextShapeID") {
+                if (height < newSize.height()) {
+                    newSize.setHeight(rootArea->bottom() - rootArea->top());
+                }
             }
         }
-    }
-    if (m_textShapeData->resizeMethod() == KoTextShapeData::AutoGrowWidthAndHeight
-        ||m_textShapeData->resizeMethod() == KoTextShapeData::AutoGrowWidth) {
-        qreal width = rootArea->right() - rootArea->left();
-        if (width > newSize.width()) {
-            newSize.setWidth(rootArea->right() - rootArea->left());
+        if (m_textShapeData->resizeMethod() == KoTextShapeData::AutoGrowWidthAndHeight
+            ||m_textShapeData->resizeMethod() == KoTextShapeData::AutoGrowWidth) {
+            qreal width = rootArea->right() - rootArea->left();
+            if (width > newSize.width()) {
+                newSize.setWidth(rootArea->right() - rootArea->left());
+            }
         }
     }
 
@@ -116,6 +132,9 @@ void SimpleRootAreaProvider::doPostLayout(KoTextLayoutRootArea *rootArea, bool i
                       m_textShapeData->topPadding() + m_textShapeData->bottomPadding());
     if (border) {
         newSize += QSizeF(border->borderWidth(KoBorder::LeftBorder) + border->borderWidth(KoBorder::RightBorder), border->borderWidth(KoBorder::TopBorder) + border->borderWidth(KoBorder::BottomBorder));
+    } else {
+        KoInsets inset = m_textShape->strokeInsets();
+        newSize += QSizeF((inset.right+inset.left), (inset.bottom+inset.top));
     }
 
     if (newSize != m_textShape->size()) {
@@ -156,6 +175,9 @@ QRectF SimpleRootAreaProvider::suggestRect(KoTextLayoutRootArea *rootArea)
     if (border) {
         rect.adjust(border->borderWidth(KoBorder::LeftBorder),  border->borderWidth(KoBorder::TopBorder),
               -border->borderWidth(KoBorder::RightBorder), - border->borderWidth(KoBorder::BottomBorder));
+    } else {
+        KoInsets inset = m_textShape->strokeInsets();
+        rect.adjust(inset.left, inset.top, -inset.right, -inset.bottom);
     }
 
     // In simple cases we always set height way too high so that we have no breaking
@@ -163,11 +185,12 @@ QRectF SimpleRootAreaProvider::suggestRect(KoTextLayoutRootArea *rootArea)
     rect.setHeight(1E6);
 
     if (m_textShapeData->resizeMethod() == KoTextShapeData::AutoGrowWidthAndHeight
-        ||m_textShapeData->resizeMethod() == KoTextShapeData::AutoGrowWidth) {
+        ||m_textShapeData->resizeMethod() == KoTextShapeData::AutoGrowWidth
+        ||m_textShapeData->resizeMethod() == KoTextShapeData::AutoResize) {
         rootArea->setNoWrap(1E6);
     }
 
-    // Make sure the size is not negative due to padding and border with
+    // Make sure the size is not negative due to padding and border width
     // This can happen on vertical lines containing text on shape.
     if (rect.width() < 0) {
         rect.setWidth(0);
