@@ -30,13 +30,13 @@ class TextShapeFactory : public KoShapeFactoryBase
 public:
     /// constructor
     TextShapeFactory();
-    ~TextShapeFactory() {}
+    ~TextShapeFactory() override {}
 
-    virtual KoShape *createShape(const KoProperties *params, KoDocumentResourceManager *documentResources = 0) const;
-    virtual KoShape *createDefaultShape(KoDocumentResourceManager *documentResources = 0) const;
-    virtual bool supports(const KoXmlElement & e, KoShapeLoadingContext &context) const;
+    KoShape *createShape(const KoProperties *params, KoDocumentResourceManager *documentResources = 0) const override;
+    KoShape *createDefaultShape(KoDocumentResourceManager *documentResources = 0) const override;
+    bool supports(const KoXmlElement & e, KoShapeLoadingContext &context) const override;
 
-    virtual void newDocumentResourceManager(KoDocumentResourceManager *manager) const;
+    void newDocumentResourceManager(KoDocumentResourceManager *manager) const override;
 };
 
 #endif
