@@ -32,15 +32,15 @@
 #include <KoTextCommandBase.h>
 #include <KoUnit.h>
 #include <KoBorder.h>
+#include <KoTextEditor.h>
 
 #include <QClipboard>
 #include <QHash>
 #include <QTextBlock>
 #include <QTextCursor>
 #include <QTimer>
-#include <QWeakPointer>
-#include <QRectF>
 #include <QPointer>
+#include <QRectF>
 
 #include <TextEditingPluginContainer.h>
 
@@ -78,65 +78,65 @@ public:
 #ifndef NDEBUG
     explicit TextTool(MockCanvas *canvas);
 #endif
-    virtual ~TextTool();
+    ~TextTool() override;
 
     /// reimplemented from superclass
-    virtual void paint(QPainter &painter, const KoViewConverter &converter);
+    void paint(QPainter &painter, const KoViewConverter &converter) override;
 
     /// reimplemented from superclass
-    virtual void mousePressEvent(KoPointerEvent *event);
+    void mousePressEvent(KoPointerEvent *event) override;
     /// reimplemented from superclass
-    virtual void mouseDoubleClickEvent(KoPointerEvent *event);
+    void mouseDoubleClickEvent(KoPointerEvent *event) override;
     /// reimplemented from superclass
-    virtual void mouseTripleClickEvent(KoPointerEvent *event);
+    void mouseTripleClickEvent(KoPointerEvent *event) override;
     /// reimplemented from superclass
-    virtual void mouseMoveEvent(KoPointerEvent *event);
+    void mouseMoveEvent(KoPointerEvent *event) override;
     /// reimplemented from superclass
-    virtual void mouseReleaseEvent(KoPointerEvent *event);
+    void mouseReleaseEvent(KoPointerEvent *event) override;
     /// reimplemented from superclass
-    virtual void shortcutOverrideEvent(QKeyEvent *event);
+    void shortcutOverrideEvent(QKeyEvent *event) override;
     /// reimplemented from superclass
-    virtual void keyPressEvent(QKeyEvent *event);
+    void keyPressEvent(QKeyEvent *event) override;
     /// reimplemented from superclass
-    virtual void keyReleaseEvent(QKeyEvent *event);
+    void keyReleaseEvent(QKeyEvent *event) override;
 
     /// reimplemented from superclass
-    virtual void activate(ToolActivation toolActivation, const QSet<KoShape*> &shapes);
+    void activate(ToolActivation toolActivation, const QSet<KoShape*> &shapes) override;
     /// reimplemented from superclass
-    virtual void deactivate();
+    void deactivate() override;
     /// reimplemented from superclass
-    virtual void copy() const;
+    void copy() const override;
 
     /// reimplemented from KoUndoableTool
-    virtual void setAddUndoCommandAllowed(bool allowed) { m_allowAddUndoCommand = allowed; }
+    void setAddUndoCommandAllowed(bool allowed) override { m_allowAddUndoCommand = allowed; }
 
     ///reimplemented
-    virtual void deleteSelection();
+    void deleteSelection() override;
     /// reimplemented from superclass
-    virtual void cut();
+    void cut() override;
     /// reimplemented from superclass
-    virtual bool paste();
+    bool paste() override;
     /// reimplemented from superclass
-    virtual QStringList supportedPasteMimeTypes() const;
+    QStringList supportedPasteMimeTypes() const override;
     /// reimplemented from superclass
-    virtual void dragMoveEvent(QDragMoveEvent *event, const QPointF &point);
+    void dragMoveEvent(QDragMoveEvent *event, const QPointF &point) override;
     /// reimplemented from superclass
-    void dragLeaveEvent(QDragLeaveEvent *event);
+    void dragLeaveEvent(QDragLeaveEvent *event) override;
     /// reimplemented from superclass
-    virtual void dropEvent(QDropEvent *event, const QPointF &point);
+    void dropEvent(QDropEvent *event, const QPointF &point) override;
 
     /// reimplemented from superclass
-    virtual void repaintDecorations();
+    void repaintDecorations() override;
 
     /// reimplemented from superclass
-    virtual KoToolSelection* selection();
+    KoToolSelection* selection() override;
     /// reimplemented from superclass
-    virtual QList<QPointer<QWidget> > createOptionWidgets();
+    QList<QPointer<QWidget> > createOptionWidgets() override;
 
     /// reimplemented from superclass
-    virtual QVariant inputMethodQuery(Qt::InputMethodQuery query, const KoViewConverter &converter) const;
+    QVariant inputMethodQuery(Qt::InputMethodQuery query, const KoViewConverter &converter) const override;
     /// reimplemented from superclass
-    virtual void inputMethodEvent(QInputMethodEvent * event);
+    void inputMethodEvent(QInputMethodEvent * event) override;
 
 
     /// The following two methods allow an undo/redo command to tell the tool, it will modify the QTextDocument and wants to be parent of the undo/redo commands resulting from these changes.
@@ -166,7 +166,7 @@ public Q_SLOTS:
     /// start the textedit-plugin.
     void startTextEditingPlugin(const QString &pluginId);
     /// reimplemented from KoToolBase
-    virtual void canvasResourceChanged(int key, const QVariant &res);
+    void canvasResourceChanged(int key, const QVariant &res) override;
 
 Q_SIGNALS:
     /// emitted every time a different styleManager is set.
@@ -263,6 +263,8 @@ private Q_SLOTS:
     void setTextColor(const KoColor &color);
     /// change background color of a selected text
     void setBackgroundColor(const KoColor &color);
+    /// Enable or disable auto-resize
+    void setAutoResize(bool enabled);
     /// Enable or disable grow-width-to-fit-text.
     void setGrowWidthToFit(bool enabled);
     /// Enable or disable grow-height-to-fit-text.
@@ -344,8 +346,8 @@ private:
 
     TextShape *m_textShape; // where caret of m_textEditor currently is
     KoTextShapeData *m_textShapeData; // where caret of m_textEditor currently is
-    QWeakPointer<KoTextEditor> m_textEditor;
-    QWeakPointer<KoTextEditor> m_oldTextEditor;
+    QPointer<KoTextEditor> m_textEditor;
+    QPointer<KoTextEditor> m_oldTextEditor;
     KoChangeTracker *m_changeTracker;
     KoUnit m_unit;
     bool m_allowActions;
@@ -369,6 +371,7 @@ private:
     QAction *m_actionFormatSub;
     QAction *m_actionFormatIncreaseIndent;
     QAction *m_actionFormatDecreaseIndent;
+    QAction *m_autoResizeAction;
     QAction *m_growWidthAction;
     QAction *m_growHeightAction;
     QAction *m_shrinkToFitAction;
