@@ -20,15 +20,15 @@
 #ifndef __CHANGE_CONFIGURE_DIALOG_H__
 #define __CHANGE_CONFIGURE_DIALOG_H__
 
-#include <QtGui>
+#include <QLabel>
 #include <KoChangeTracker.h>
 
 class ColorDisplayLabel:public QLabel
 {
     public:
         explicit ColorDisplayLabel(QWidget *parent = 0);
-        ~ColorDisplayLabel();
-        void paintEvent(QPaintEvent *event);
+        ~ColorDisplayLabel() override;
+        void paintEvent(QPaintEvent *event) override;
         const QColor& color() const;
         void setColor(const QColor &color);
 
@@ -51,7 +51,7 @@ class ChangeConfigureDialog:public QDialog
     }ChangeType;
 
     public:
-        ChangeConfigureDialog(const QColor& insertionColor, const QColor& deletionColor, const QColor& formatChangeColor, const QString& authorName, KoChangeTracker::ChangeSaveFormat changeSaveFormat, QWidget *parent=NULL);
+        ChangeConfigureDialog(const QColor& insertionColor, const QColor& deletionColor, const QColor& formatChangeColor, const QString& authorName, KoChangeTracker::ChangeSaveFormat changeSaveFormat, QWidget *parent=nullptr);
         ~ChangeConfigureDialog();
         
         const QColor& getInsertionBgColor();
