@@ -35,7 +35,7 @@ class CharacterHighlighting : public QWidget
 
 public:
     explicit CharacterHighlighting(QWidget* parent = 0);
-    ~CharacterHighlighting() {}
+    ~CharacterHighlighting() override {}
 
     void setDisplay(KoCharacterStyle *style, bool directFormattingMode);
     void save(KoCharacterStyle *style);
