@@ -24,17 +24,15 @@
 #include <KoBibliographyInfo.h>
 #include <KoTextEditor.h>
 
-#include <kaction.h>
-#include <kdebug.h>
+#include <QAction>
+#include <QDebug>
 
 #include <QWidget>
-#include <QSignalMapper>
 
 SimpleCitationBibliographyWidget::SimpleCitationBibliographyWidget(ReferencesTool *tool, QWidget *parent)
         : QWidget(parent),
           m_blockSignals(false),
-          m_referenceTool(tool),
-          m_signalMapper(0)
+          m_referenceTool(tool)
 {
     widget.setupUi(this);
     Q_ASSERT(tool);
@@ -45,7 +43,6 @@ SimpleCitationBibliographyWidget::SimpleCitationBibliographyWidget(ReferencesToo
     connect(widget.addCitation,SIGNAL(clicked(bool)),this,SIGNAL(doneWithFocus()));
 
     widget.addBibliography->setDefaultAction(tool->action("insert_bibliography"));
-    widget.addBibliography->setNumColumns(1);
     connect(widget.addBibliography,SIGNAL(clicked(bool)),this,SIGNAL(doneWithFocus()));
     connect(widget.addBibliography, SIGNAL(aboutToShowMenu()), this, SLOT(prepareTemplateMenu()));
     connect(widget.addBibliography, SIGNAL(itemTriggered(int)), this, SLOT(applyTemplate(int)));
@@ -67,18 +64,12 @@ void SimpleCitationBibliographyWidget::setStyleManager(KoStyleManager *sm)
 void SimpleCitationBibliographyWidget::prepareTemplateMenu()
 {
     m_previewGenerator.clear();
-    if (m_signalMapper) {
-        delete m_signalMapper;
-        m_signalMapper = 0;
-    }
     qDeleteAll(m_templateList.begin(), m_templateList.end());
     m_templateList.clear();
 
-    m_signalMapper = new QSignalMapper();
-
     m_templateList = m_templateGenerator->templates();
 
-    connect(m_signalMapper, SIGNAL(mapped(int)), this, SLOT(pixmapReady(int)));
+    m_chooser = widget.addBibliography->addItemChooser(1);
 
     int index = 0;
     foreach (KoBibliographyInfo *info, m_templateList) {
@@ -86,8 +77,7 @@ void SimpleCitationBibliographyWidget::prepareTemplateMenu()
         preview->setStyleManager(KoTextDocument(m_referenceTool->editor()->document()).styleManager());
         preview->setPreviewSize(QSize(200,120));
         preview->updatePreview(info);
-        connect(preview, SIGNAL(pixmapGenerated()), m_signalMapper, SLOT(map()));
-        m_signalMapper->setMapping(preview, index);
+        connect(preview, &BibliographyPreview::pixmapGenerated, [this, index] { pixmapReady(index); });
         m_previewGenerator.append(preview);
         ++index;
 
@@ -95,7 +85,7 @@ void SimpleCitationBibliographyWidget::prepareTemplateMenu()
         if (! widget.addBibliography->hasItemId(index)) {
             QPixmap pmm(QSize(200,120));
             pmm.fill(Qt::white);
-            widget.addBibliography->addItem(pmm, index);
+            widget.addBibliography->addItem(m_chooser, pmm, index);
         }
     }
     if (widget.addBibliography->isFirstTimeMenuShown()) {
@@ -116,8 +106,8 @@ void SimpleCitationBibliographyWidget::insertCustomBibliography()
 void SimpleCitationBibliographyWidget::pixmapReady(int templateId)
 {
     // +1 to the templateId is because formattingButton does not allow id = 0
-    widget.addBibliography->addItem(m_previewGenerator.at(templateId)->previewPixmap(), templateId + 1);
-    disconnect(m_previewGenerator.at(templateId), SIGNAL(pixmapGenerated()), m_signalMapper, SLOT(map()));
+    widget.addBibliography->addItem(m_chooser, m_previewGenerator.at(templateId)->previewPixmap(), templateId + 1);
+    disconnect(m_previewGenerator.at(templateId), &BibliographyPreview::pixmapGenerated, this, nullptr);
     m_previewGenerator.at(templateId)->deleteLater();
 }
 
@@ -126,5 +116,3 @@ void SimpleCitationBibliographyWidget::applyTemplate(int templateId)
     m_templateGenerator->moveTemplateToUsed(m_templateList.at(templateId - 1));
     m_referenceTool->editor()->insertBibliography(m_templateList.at(templateId - 1));
 }
-
-#include <SimpleCitationBibliographyWidget.moc>
