@@ -39,7 +39,6 @@ class StylesModel;
 class DockerStylesComboModel;
 class StylesDelegate;
 
-class QSignalMapper;
 namespace Lists {class ListStyleItem;};
 
 class SimpleParagraphWidget : public QWidget
@@ -47,7 +46,7 @@ class SimpleParagraphWidget : public QWidget
     Q_OBJECT
 public:
     explicit SimpleParagraphWidget(TextTool *tool, QWidget *parent = 0);
-    virtual ~SimpleParagraphWidget();
+    ~SimpleParagraphWidget() override;
 
     void setInitialUsedStyles(QVector<int> list);
 
