@@ -28,18 +28,18 @@
 #include <QImage>
 #include <QList>
 #include <QSharedPointer>
-#include <QSignalMapper>
 #include <QCollator>
 
 #include <klocalizedstring.h>
 #include <QDebug>
 
+#include <algorithm>
+
 StylesModel::StylesModel(KoStyleManager *manager, AbstractStylesModel::Type modelType, QObject *parent)
     : AbstractStylesModel(parent),
       m_styleManager(0),
       m_currentParagraphStyle(0),
       m_defaultCharacterStyle(0),
-      m_styleMapper(new QSignalMapper(this)),
       m_provideStyleNone(false)
 {
     m_modelType = modelType;
@@ -53,8 +53,6 @@ StylesModel::StylesModel(KoStyleManager *manager, AbstractStylesModel::Type mode
 
         m_provideStyleNone = true;
     }
-
-    connect(m_styleMapper, SIGNAL(mapped(int)), this, SLOT(updateName(int)));
 }
 
 StylesModel::~StylesModel()
@@ -319,9 +317,9 @@ void StylesModel::addParagraphStyle(KoParagraphStyle *style)
         ++index;
     }
     beginInsertRows(QModelIndex(), index, index);
-    m_styleList.insert(begin, style->styleId());
-    m_styleMapper->setMapping(style, style->styleId());
-    connect(style, SIGNAL(nameChanged(QString)), m_styleMapper, SLOT(map()));
+    int styleId = style->styleId();
+    m_styleList.insert(begin, styleId);
+    connect(style, &KoParagraphStyle::nameChanged, this, [this, styleId] { updateName(styleId); });
     endInsertRows();
 }
 
@@ -340,13 +338,13 @@ void StylesModel::updateParagraphStyles()
     m_styleList.clear();
 
     QList<KoParagraphStyle *> styles = m_styleManager->paragraphStyles();
-    qSort(styles.begin(), styles.end(), sortParagraphStyleByName);
+    std::sort(styles.begin(), styles.end(), sortParagraphStyleByName);
 
     foreach(KoParagraphStyle *style, styles) {
         if (style != m_styleManager->defaultParagraphStyle()) { //The default character style is not user selectable. It only provides individual property defaults and is not a style per say.
-            m_styleList.append(style->styleId());
-            m_styleMapper->setMapping(style, style->styleId());
-            connect(style, SIGNAL(nameChanged(QString)), m_styleMapper, SLOT(map()));
+            int styleId = style->styleId();
+            m_styleList.append(styleId);
+            connect(style, &KoParagraphStyle::nameChanged, this, [this, styleId] { updateName(styleId); });
         }
     }
 
@@ -380,8 +378,8 @@ void StylesModel::addCharacterStyle(KoCharacterStyle *style)
     beginInsertRows(QModelIndex(), index, index);
     m_styleList.insert(index, style->styleId());
     endInsertRows();
-    m_styleMapper->setMapping(style, style->styleId());
-    connect(style, SIGNAL(nameChanged(QString)), m_styleMapper, SLOT(map()));
+    int styleId = style->styleId();
+    connect(style, &KoParagraphStyle::nameChanged, this, [this, styleId] (const QString &) { updateName(styleId); });
 }
 
 bool sortCharacterStyleByName(KoCharacterStyle *style1, KoCharacterStyle *style2)
@@ -403,13 +401,13 @@ void StylesModel::updateCharacterStyles()
     }
 
     QList<KoCharacterStyle *> styles = m_styleManager->characterStyles();
-    qSort(styles.begin(), styles.end(), sortCharacterStyleByName);
+    std::sort(styles.begin(), styles.end(), sortCharacterStyleByName);
 
     foreach(KoCharacterStyle *style, styles) {
         if (style != m_styleManager->defaultCharacterStyle()) { //The default character style is not user selectable. It only provides individual property defaults and is not a style per say.
-            m_styleList.append(style->styleId());
-            m_styleMapper->setMapping(style, style->styleId());
-            connect(style, SIGNAL(nameChanged(QString)), m_styleMapper, SLOT(map()));
+            int styleId = style->styleId();
+            m_styleList.append(styleId);
+            connect(style, &KoParagraphStyle::nameChanged, this, [this, styleId] { updateName(styleId); });
         }
     }
 
@@ -421,8 +419,7 @@ void StylesModel::removeParagraphStyle(KoParagraphStyle *style)
 {
     int row = m_styleList.indexOf(style->styleId());
     beginRemoveRows(QModelIndex(), row, row);
-    m_styleMapper->removeMappings(style);
-    disconnect(style, SIGNAL(nameChanged(QString)), m_styleMapper, SLOT(map()));
+    disconnect(style, &KoParagraphStyle::nameChanged, this, nullptr);
     m_styleList.removeAt(row);
     endRemoveRows();
 }
@@ -432,8 +429,7 @@ void StylesModel::removeCharacterStyle(KoCharacterStyle *style)
 {
     int row = m_styleList.indexOf(style->styleId());
     beginRemoveRows(QModelIndex(), row, row);
-    m_styleMapper->removeMappings(style);
-    disconnect(style, SIGNAL(nameChanged(QString)), m_styleMapper, SLOT(map()));
+    disconnect(style, &KoParagraphStyle::nameChanged, this, nullptr);
     m_styleList.removeAt(row);
     endRemoveRows();
 }
