@@ -19,13 +19,13 @@
 
 #include "TableDialog.h"
 
-#include <klocale.h>
+#include <klocalizedstring.h>
 
 TableDialog::TableDialog(QWidget *parent)
-        : KDialog(parent)
+        : KoDialog(parent)
 {
     setCaption(i18n("Insert Table"));
-    setButtons(KDialog::Ok | KDialog::Cancel);
+    setButtons(KoDialog::Ok | KoDialog::Cancel);
     showButtonSeparator(true);
     QWidget *form = new QWidget;
     widget.setupUi(form);
@@ -44,6 +44,3 @@ int TableDialog::rows()
 {
     return widget.intRows->value();
 }
-
-
-#include <TableDialog.moc>
