@@ -28,7 +28,7 @@ class TestTextTool : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
     void testCaretRect();
 };
 
