@@ -28,7 +28,7 @@ class PageVariableFactory : public KoInlineObjectFactoryBase
 public:
     PageVariableFactory();
 
-    virtual KoInlineObject *createInlineObject(const KoProperties *properties = 0) const;
+    KoInlineObject *createInlineObject(const KoProperties *properties = 0) const override;
 };
 
 #endif
