@@ -20,9 +20,8 @@
 #include "ChangeVectorDataCommand.h"
 
 #include <math.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <KoImageData.h>
-#include <kdebug.h>
 
 #include "VectorShape.h"
 
