@@ -30,12 +30,12 @@ public:
     VideoShapeFactory();
     ~VideoShapeFactory() {}
 
-    virtual KoShape *createDefaultShape(KoDocumentResourceManager *documentResources = 0) const;
-    virtual bool supports(const KoXmlElement &e, KoShapeLoadingContext &context) const;
+    KoShape *createDefaultShape(KoDocumentResourceManager *documentResources = 0) const override;
+    bool supports(const KoXmlElement &e, KoShapeLoadingContext &context) const override;
 
     /// reimplemented
-    virtual QList<KoShapeConfigWidgetBase*> createShapeOptionPanels();
-    virtual void newDocumentResourceManager(KoDocumentResourceManager *manager) const;
+    QList<KoShapeConfigWidgetBase*> createShapeOptionPanels() override;
+    void newDocumentResourceManager(KoDocumentResourceManager *manager) const override;
 };
 
 #endif
