@@ -24,7 +24,7 @@
 #include <klocale.h>
 #include <KoXmlReader.h>
 
-#include "calligra_sheets_export.h"
+#include "sheets_odf_export.h"
 
 class QDomElement;
 class QDomDocument;
@@ -34,6 +34,7 @@ namespace Calligra
 namespace Sheets
 {
 
+// This should be ported to QLocale, however, there is no substitute for currency formatting with precision support.
 class CALLIGRA_SHEETS_ODF_EXPORT Localization : public KLocale
 {
 public:
