@@ -27,6 +27,8 @@
 #include "Region.h"
 #include "calligra_sheets_limits.h"
 
+#include <algorithm>
+
 // #define KSPREAD_POINT_STORAGE_HASH
 
 namespace Calligra
@@ -125,7 +127,7 @@ public:
         else {
             const QVector<int>::const_iterator cstart(m_cols.begin() + m_rows.value(row - 1));
             const QVector<int>::const_iterator cend((row < m_rows.count()) ? (m_cols.begin() + m_rows.value(row)) : m_cols.end());
-            const QVector<int>::const_iterator cit = qLowerBound(cstart, cend, col);
+            const QVector<int>::const_iterator cit = std::lower_bound(cstart, cend, col);
             // column's missing?
             if (cit == cend || *cit != col) {
                 // determine the index where the data and column has to be inserted
@@ -171,9 +173,9 @@ public:
             return defaultVal;
         const QVector<int>::const_iterator cstart(m_cols.begin() + m_rows.value(row - 1));
         const QVector<int>::const_iterator cend((row < m_rows.count()) ? (m_cols.begin() + m_rows.value(row)) : m_cols.end());
-        const QVector<int>::const_iterator cit = qBinaryFind(cstart, cend, col);
+        const QVector<int>::const_iterator cit = std::lower_bound(cstart, cend, col);
         // is the col not present?
-        if (cit == cend)
+        if (cit == cend || col != *cit)
             return defaultVal;
         return m_data.value(m_rows.value(row - 1) + (cit - cstart));
     }
@@ -191,9 +193,9 @@ public:
         const int rowStart = (row - 1 < m_rows.count()) ? m_rows.value(row - 1) : m_data.count();
         const int rowLength = (row < m_rows.count()) ? m_rows.value(row) - rowStart : -1;
         const QVector<int> cols = m_cols.mid(rowStart, rowLength);
-        QVector<int>::const_iterator cit = qBinaryFind(cols, col);
+        QVector<int>::const_iterator cit = std::lower_bound(cols.begin(), cols.end(), col);
         // column's missing?
-        if (cit == cols.constEnd())
+        if (cit == cols.constEnd() || col != *cit)
             return defaultVal;
         const int index = rowStart + (cit - cols.constBegin());
         // save the old data
@@ -401,8 +403,9 @@ public:
     QVector< QPair<QPoint, T> > removeShiftUp(const QRect& rect) {
         Q_ASSERT(1 <= rect.top() && rect.top() <= KS_rowMax);
         // row's missing?
-        if (rect.top() > m_rows.count())
+        if (rect.top() > m_rows.count()) {
             return QVector< QPair<QPoint, T> >();
+        }
         QVector< QPair<QPoint, T> > oldData;
         for (int row = rect.top(); row <= m_rows.count() && row <= KS_rowMax - rect.height(); ++row) {
             const int rowStart = m_rows.value(row - 1);
@@ -420,9 +423,9 @@ public:
                     const int srcRow = row + rect.height();
                     const QVector<int>::const_iterator cstart2((srcRow - 1 < m_rows.count()) ? m_cols.begin() + m_rows.value(srcRow - 1) : m_cols.end());
                     const QVector<int>::const_iterator cend2((srcRow < m_rows.count()) ? (m_cols.begin() + m_rows.value(srcRow)) : m_cols.end());
-                    const QVector<int>::const_iterator cit2 = qBinaryFind(cstart2, cend2, column);
+                    const QVector<int>::const_iterator cit2 = std::lower_bound(cstart2, cend2, column);
                     // column's missing?
-                    if (cit2 == cend2) {
+                    if (cit2 == cend2 || *cit2 != column) {
                         m_cols.remove(rowStart + col);
                         m_data.remove(rowStart + col);
                         // adjust the offsets of the following rows
@@ -455,10 +458,10 @@ public:
                     // find the insertion position
                     const QVector<int>::const_iterator cstart((row - 1 < m_rows.count()) ? m_cols.begin() + m_rows.value(row - 1) : m_cols.end());
                     const QVector<int>::const_iterator cend(((row < m_rows.count())) ? (m_cols.begin() + m_rows.value(row)) : m_cols.end());
-                    const QVector<int>::const_iterator cit = qUpperBound(cstart, cend, cols2.value(col));
+                    const QVector<int>::const_iterator cit = std::upper_bound(cstart, cend, cols2.value(col));
                     // Destination column:
-                    const QVector<int>::const_iterator dstcit = qBinaryFind(cols.begin(), cols.end(), column);
-                    if (dstcit != cols.end()) { // destination column exists
+                    const QVector<int>::const_iterator dstcit = std::lower_bound(cols.begin(), cols.end(), column);
+                    if (dstcit != cols.end() && *dstcit == column) { // destination column exists
                         // replace the existing destination value
                         const int dstCol = (dstcit - cols.constBegin());
                         m_data[rowStart + dstCol] = m_data.value(rowStart2 + col);
@@ -521,7 +524,7 @@ public:
                         const int row2 = row + rect.height();
                         const QVector<int>::const_iterator cstart2(m_cols.begin() + m_rows.value(row2 - 1));
                         const QVector<int>::const_iterator cend2((row2 < m_rows.count()) ? (m_cols.begin() + m_rows.value(row2)) : m_cols.end());
-                        const QVector<int>::const_iterator cit2 = qLowerBound(cstart2, cend2, cols.value(col));
+                        const QVector<int>::const_iterator cit2 = std::lower_bound(cstart2, cend2, cols.value(col));
                         // column's missing?
                         if (cit2 == cend2 || *cit2 != cols.value(col)) {
                             // determine the index where the data and column has to be inserted
@@ -566,7 +569,7 @@ public:
             if (index == -1)   // not found
                 *newRow = 0;
             else
-                *newRow = qUpperBound(m_rows, index) - m_rows.begin();
+                *newRow = std::upper_bound(m_rows.begin(), m_rows.end(), index) - m_rows.begin();
         }
         return m_data.value(index);
     }
@@ -579,7 +582,7 @@ public:
     T firstInRow(int row, int* newCol = 0) const {
         Q_ASSERT(1 <= row && row <= KS_rowMax);
         // row's empty?
-        if ((row < m_rows.count()) && m_rows.value(row - 1) == m_rows.value(row)) {
+        if (row > m_rows.count() || ((row < m_rows.count()) && m_rows.value(row - 1) == m_rows.value(row))) {
             if (newCol)
                 *newCol = 0;
             return T();
@@ -601,7 +604,7 @@ public:
             if (index == -1)   // not found
                 *newRow = 0;
             else
-                *newRow = qUpperBound(m_rows, index) - m_rows.begin();
+                *newRow = std::upper_bound(m_rows.begin(), m_rows.end(), index) - m_rows.begin();
         }
         return m_data.value(index);
     }
@@ -613,18 +616,23 @@ public:
      */
     T lastInRow(int row, int* newCol = 0) const {
         Q_ASSERT(1 <= row && row <= KS_rowMax);
+        if (m_rows.isEmpty()) {
+            if (newCol)
+                *newCol = 0;
+            return T();
+        }
+        // last row?
+        if (row == m_rows.count()) {
+            if (newCol)
+                *newCol = m_cols.value(m_data.count() - 1);
+            return m_data.last();
+        }
         // row's empty?
         if (m_rows.value(row - 1) == m_rows.value(row) || m_rows.value(row - 1) == m_data.count()) {
             if (newCol)
                 *newCol = 0;
             return T();
         }
-        // last row ends on data vector end
-        if (row == m_rows.count()) {
-            if (newCol)
-                *newCol = m_cols.value(m_data.count() - 1);
-            return m_data.value(m_data.count() - 1);
-        }
         if (newCol)
             *newCol = m_cols.value(m_rows.value(row) - 1);
         return m_data.value(m_rows.value(row) - 1);
@@ -650,7 +658,7 @@ public:
             if (index == -1)   // not found
                 *newRow = 0;
             else
-                *newRow = qUpperBound(m_rows, index) - m_rows.begin();
+                *newRow = std::upper_bound(m_rows.begin(), m_rows.end(), index) - m_rows.begin();
         }
         return m_data.value(index);
     }
@@ -671,7 +679,7 @@ public:
         }
         const QVector<int>::const_iterator cstart(m_cols.begin() + m_rows.value(row - 1));
         const QVector<int>::const_iterator cend((row < m_rows.count()) ? (m_cols.begin() + m_rows.value(row)) : m_cols.end());
-        const QVector<int>::const_iterator cit = qUpperBound(cstart, cend, col);
+        const QVector<int>::const_iterator cit = std::upper_bound(cstart, cend, col);
         if (cit == cend || *cit <= col) {
             if (newCol)
                 *newCol = 0;
@@ -701,7 +709,7 @@ public:
             if (index == -1)   // not found
                 *newRow = 0;
             else
-                *newRow = qUpperBound(m_rows, index) - m_rows.begin();
+                *newRow = std::upper_bound(m_rows.begin(), m_rows.end(), index) - m_rows.begin();
         }
         return m_data.value(index);
     }
@@ -716,7 +724,7 @@ public:
         Q_ASSERT(1 <= row && row <= KS_rowMax);
         const QVector<int>::const_iterator cstart((row - 1 < m_rows.count()) ? m_cols.begin() + m_rows.value(row - 1) : m_cols.end());
         const QVector<int>::const_iterator cend((row < m_rows.count()) ? (m_cols.begin() + m_rows.value(row)) : m_cols.end());
-        const QVector<int>::const_iterator cit = qLowerBound(cstart, cend, col);
+        const QVector<int>::const_iterator cit = std::lower_bound(cstart, cend, col);
         if (cit == cstart) {
             if (newCol)
                 *newCol = 0;
@@ -786,7 +794,7 @@ public:
      * \see data()
      */
     int row(int index) const {
-        return qUpperBound(m_rows, index) - m_rows.begin();
+        return std::upper_bound(m_rows.begin(), m_rows.end(), index) - m_rows.begin();
     }
 
     /**
