@@ -195,7 +195,7 @@ class RectStorageLoader : public QRunnable
 {
 public:
     RectStorageLoader(RectStorage<T>* storage, const QList<QPair<QRegion, T> >& data);
-    virtual void run();
+    void run() override;
     void waitForFinished();
     bool isFinished() const;
     QList<QPair<QRegion, T> > data() const;
@@ -570,19 +570,15 @@ void RectStorageLoader<T>::run()
 
     QList<QPair<QRegion, T> > treeData;
     typedef QPair<QRegion, T> TRegion;
-    QMap<T, int> indexCache;
     foreach (const TRegion& tr, m_data) {
         const QRegion& reg = tr.first;
         const T& d = tr.second;
 
-        typename QMap<T, int>::iterator idx = indexCache.find(d);
-        int index = idx != indexCache.end() ? idx.value() : m_storage->m_storedData.indexOf(d);
+        int index = m_storage->m_storedData.indexOf(d);
         if (index != -1) {
             treeData.append(qMakePair(reg, m_storage->m_storedData[index]));
-            if (idx == indexCache.end()) indexCache.insert(d, index);
         } else {
             treeData.append(tr);
-            if (idx == indexCache.end()) indexCache.insert(d, m_storage->m_storedData.size());
             m_storage->m_storedData.append(d);
         }
     }
@@ -619,10 +615,10 @@ public:
     CommentStorage(const CommentStorage& other) : QObject(other.parent()), RectStorage<QString>(other) {}
 
 protected Q_SLOTS:
-    virtual void triggerGarbageCollection() {
+    void triggerGarbageCollection() override {
         QTimer::singleShot(g_garbageCollectionTimeOut, this, SLOT(garbageCollection()));
     }
-    virtual void garbageCollection() {
+    void garbageCollection() override {
         RectStorage<QString>::garbageCollection();
     }
 };
@@ -637,10 +633,10 @@ public:
     FusionStorage(const FusionStorage& other) : QObject(other.parent()), RectStorage<bool>(other) {}
 
 protected Q_SLOTS:
-    virtual void triggerGarbageCollection() {
+    void triggerGarbageCollection() override {
         QTimer::singleShot(g_garbageCollectionTimeOut, this, SLOT(garbageCollection()));
     }
-    virtual void garbageCollection() {
+    void garbageCollection() override {
         RectStorage<bool>::garbageCollection();
     }
 };
@@ -655,10 +651,10 @@ public:
     MatrixStorage(const MatrixStorage& other) : QObject(other.parent()), RectStorage<bool>(other) {}
 
 protected Q_SLOTS:
-    virtual void triggerGarbageCollection() {
+    void triggerGarbageCollection() override {
         QTimer::singleShot(g_garbageCollectionTimeOut, this, SLOT(garbageCollection()));
     }
-    virtual void garbageCollection() {
+    void garbageCollection() override {
         RectStorage<bool>::garbageCollection();
     }
 };
