@@ -19,9 +19,11 @@
 
 #include "ShapeApplicationData.h"
 
+#include <Qt> // Q_DECL_HIDDEN
+
 using namespace Calligra::Sheets;
 
-class  ShapeApplicationData::Private
+class Q_DECL_HIDDEN ShapeApplicationData::Private
 {
 public:
     bool anchoredToCell;
