@@ -30,6 +30,7 @@
 #include <KoShape.h>
 #include <KoDocumentResourceManager.h>
 #include <KoUnit.h>
+#include <KoCanvasResourceIdentities.h>
 
 #include "CellStorage.h"
 #include "Cluster.h"
@@ -129,7 +130,7 @@ Sheet::Sheet(Map* map, const QString &sheetName)
         resourceManager()->setUndoStack(map->doc()->undoStack());
         QVariant variant;
         variant.setValue<void*>(map->doc()->sheetAccessModel());
-        resourceManager()->setResource(75751149, variant); // duplicated in kochart.
+        resourceManager()->setResource(::Sheets::CanvasResource::AccessModel, variant);
     }
     d->model = new SheetModel(this);
 
@@ -210,9 +211,12 @@ Sheet::Sheet(const Sheet &other)
     KoShape* shape;
     const QList<KoShape*> shapes = other.d->shapes;
     for (int i = 0; i < shapes.count(); ++i) {
-        shape = KoShapeRegistry::instance()->value(shapes[i]->shapeId())->createDefaultShapeAndInit(0);
-        shape->copySettings(shapes[i]);
-        addShape(shape);
+        KoShapeFactoryBase *factory = KoShapeRegistry::instance()->value(shapes[i]->shapeId());
+        if (factory) {
+            shape = factory->createDefaultShapeAndInit(0);
+            shape->copySettings(shapes[i]);
+            addShape(shape);
+        }
     }
 #endif // CALLIGRA_SHEETS_WIP_COPY_SHEET_(SHAPES)
 
@@ -224,11 +228,11 @@ Sheet::Sheet(const Sheet &other)
 
 Sheet::~Sheet()
 {
-    //Disable automatic recalculation of dependancies on this sheet to prevent crashes
+    //Disable automatic recalculation of dependencies on this sheet to prevent crashes
     //in certain situations:
     //
     //For example, suppose a cell in SheetB depends upon a cell in SheetA.  If the cell in SheetB is emptied
-    //after SheetA has already been deleted, the program would try to remove dependancies from the cell in SheetA
+    //after SheetA has already been deleted, the program would try to remove dependencies from the cell in SheetA
     //causing a crash.
     setAutoCalculationEnabled(false);
 
@@ -368,7 +372,7 @@ bool Sheet::isAutoCalculationEnabled() const
 
 void Sheet::setAutoCalculationEnabled(bool enable)
 {
-    //Avoid possible recalculation of dependancies if the auto calc setting hasn't changed
+    //Avoid possible recalculation of dependencies if the auto calc setting hasn't changed
     if (d->autoCalc == enable)
         return;
 
