@@ -101,7 +101,7 @@ public:
     /**
      * Destructor.
      */
-    ~Sheet();
+    ~Sheet() override;
 
     /**
      * \return a model for this sheet
@@ -119,9 +119,9 @@ public:
     DocBase* doc() const;
 
     // KoShapeBasedDocumentBase interface
-    virtual void addShape(KoShape* shape);
-    virtual void removeShape(KoShape* shape);
-    virtual KoDocumentResourceManager* resourceManager() const;
+    void addShape(KoShape* shape) override;
+    void removeShape(KoShape* shape) override;
+    KoDocumentResourceManager* resourceManager() const override;
 
     /**
      * Deletes all shapes without emitting shapeRemoved()
@@ -412,7 +412,6 @@ public:
     const ValueStorage* valueStorage() const;
 
     /**
-     * \ingroup Coordinates
      * \ingroup Storage
      * Determines the used area, i.e. the area spanning from A1 to the maximum
      * occupied column and row.
@@ -756,6 +755,7 @@ Q_SIGNALS:
      * \ingroup Embedding
      * Emitted, if a \p shape was added.
      * \param sheet this sheet (for the View to determine, if it's the active one)
+     * \param shape the shape
      */
     void shapeAdded(Sheet *sheet, KoShape *shape);
 
@@ -763,6 +763,7 @@ Q_SIGNALS:
      * \ingroup Embedding
      * Emitted, if a \p shape was removed.
      * \param sheet this sheet (for the View to determine, if it's the active one)
+     * \param shape the shape
      */
     void shapeRemoved(Sheet *sheet, KoShape *shape);
 
@@ -771,7 +772,7 @@ protected:
      * \ingroup Value
      * Change the name of a sheet in all formulas.
      * When you change name sheet Sheet1 -> Price
-     * for all cell which refere to Sheet1, this function changes the name.
+     * for all cell which refers to Sheet1, this function changes the name.
      */
     void changeCellTabName(QString const & old_name, QString const & new_name);
 
