@@ -51,7 +51,7 @@ public:
     {}
     Map* map;
     RTree<SharedSubStyle> tree;
-    QMap<int, bool> usedColumns; // FIXME Stefan: Use QList and qUpperBound() for insertion.
+    QMap<int, bool> usedColumns; // FIXME Stefan: Use QList and std::upper_bound() for insertion.
     QMap<int, bool> usedRows;
     QRegion usedArea;
     QHash<Style::Key, QList<SharedSubStyle> > subStyles;
@@ -70,7 +70,7 @@ class Calligra::Sheets::StyleStorageLoaderJob : public QRunnable
 {
 public:
     StyleStorageLoaderJob(StyleStorage* storage, const QList<QPair<QRegion, Style> >& styles);
-    virtual void run();
+    void run() override;
     void waitForFinished();
     bool isFinished();
     QList<QPair<QRegion, Style> > data() const { return m_styles; }
@@ -886,10 +886,10 @@ Style StyleStorage::composeStyle(const QList<SharedSubStyle>& subStyles) const
 
     // TODO review loading of libreOffice generated files:
     // It seems libreOffice saves parent also when parent is the Default style.
-    // Sheets do not do this, it is handled implecitly.
+    // Sheets do not do this, it is handled implicitly.
     // According to the spec, both ways should be ok,
     // but the result is that when loading lo files, it may exist multiple (two) NamedStyleKey substyles:
-    // One loaded explecitly (first in the list), and one generated by our loading code (later in the list).
+    // One loaded explicitly (first in the list), and one generated by our loading code (later in the list).
     // We use the last one in the list here, this should be our generated one.
     CustomStyle *namedStyle = 0;
     for (int i = subStyles.count() - 1; i >= 0; --i) {
@@ -968,7 +968,7 @@ Style StyleStorage::composeStyle(const QList<SharedSubStyle>& subStyles) const
             style.clearAttribute(Style::DefaultStyleKey);
         }
     }
-    // Implictly merge in any missing attributes from the family (table-cell) default style
+    // Implicitly merge in any missing attributes from the family (table-cell) default style
     // It might have been merged in via parent styles above, but we cannot rely on that.
     if (!styleManager()->defaultStyle()->isEmpty()) {
         // debugSheetsStyle << "StyleStorage: merging family default in";
