@@ -20,8 +20,9 @@
 // Local
 #include "BorderColorCommand.h"
 
-#include <kdebug.h>
-#include <klocale.h>
+#include <QPen>
+
+#include <KLocalizedString>
 
 #include "Cell.h"
 #include "CellStorage.h"
@@ -29,8 +30,6 @@
 #include "Style.h"
 #include "StyleStorage.h"
 
-#include <QPen>
-
 using namespace Calligra::Sheets;
 
 BorderColorCommand::BorderColorCommand()
