@@ -20,8 +20,7 @@
 // Local
 #include "IndentationCommand.h"
 
-#include <kdebug.h>
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include "ApplicationSettings.h"
 #include "Cell.h"
