@@ -20,8 +20,7 @@
 // Local
 #include "PrecisionCommand.h"
 
-#include <kdebug.h>
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include "Cell.h"
 #include "CellStorage.h"
