@@ -51,7 +51,7 @@ public:
 
     RectStorageUndoCommand(QAbstractItemModel *const model, int role, KUndo2Command *parent = 0);
 
-    virtual void undo();
+    void undo() override;
 
     void add(const QList<Pair> &pairs);
 
