@@ -22,8 +22,7 @@
 
 #include <QBrush>
 
-#include <kdebug.h>
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include "Cell.h"
 #include "CellStorage.h"
