@@ -32,7 +32,7 @@
 
 using namespace Calligra::Sheets;
 
-class  DatabaseManager::Private
+class Q_DECL_HIDDEN DatabaseManager::Private
 {
 public:
     const Map* map;
@@ -101,6 +101,3 @@ void DatabaseManager::saveOdf(KoXmlWriter& xmlWriter) const
     }
     xmlWriter.endElement();
 }
-
-#include "DatabaseStorage.moc"
-#include "DatabaseManager.moc"
