@@ -27,10 +27,10 @@
 #include <QPushButton>
 #include <QVBoxLayout>
 
-#include <klocale.h>
+#include <KLocalizedString>
 #include <ktextedit.h>
 
-//KSpread includes
+// Sheets
 #include "Cell.h"
 #include "ui/Selection.h"
 #include "Sheet.h"
@@ -40,7 +40,7 @@
 using namespace Calligra::Sheets;
 
 CommentDialog::CommentDialog(QWidget* parent, Selection* selection)
-        : KDialog(parent)
+        : KoDialog(parent)
 {
     setCaption(i18n("Cell Comment"));
     setModal(true);
@@ -77,11 +77,9 @@ void CommentDialog::slotOk()
 {
     CommentCommand* command = new CommentCommand();
     command->setSheet(m_selection->activeSheet());
-    command->setText(i18nc("(qtundo-format)", "Add Comment"));
+    command->setText(kundo2_i18n("Add Comment"));
     command->setComment(multiLine->toPlainText().trimmed());
     command->add(*m_selection);
     command->execute(m_selection->canvas());
     accept();
 }
-
-#include "CommentDialog.moc"
