@@ -47,7 +47,7 @@
 
 using namespace Calligra::Sheets;
 
-ConditionalWidget::ConditionalWidget(QWidget* parent, const char* /*name*/, Qt::WFlags fl)
+ConditionalWidget::ConditionalWidget(QWidget* parent, const char* /*name*/, Qt::WindowFlags fl)
         : QWidget(parent, fl)
 {
     QGridLayout * Form1Layout = new QGridLayout(this);
@@ -538,7 +538,7 @@ void ConditionalDialog::slotOk()
         newList.append(newCondition);
 
     debugSheets << "Setting conditional list";
-    CondtionCommand* manipulator = new CondtionCommand();
+    ConditionCommand* manipulator = new ConditionCommand();
     manipulator->setSheet(m_selection->activeSheet());
     manipulator->setConditionList(newList);
     manipulator->add(*m_selection);
