@@ -45,8 +45,8 @@ class ConditionalWidget : public QWidget
     Q_OBJECT
 
 public:
-    explicit ConditionalWidget(QWidget * parent = 0, const char * name = 0, Qt::WFlags fl = 0);
-    ~ConditionalWidget();
+    explicit ConditionalWidget(QWidget * parent = 0, const char * name = 0, Qt::WindowFlags fl = 0);
+    ~ConditionalWidget() override;
 
     KComboBox * m_condition_1;
     KComboBox * m_style_1;
