@@ -28,10 +28,10 @@
 #include <QVBoxLayout>
 #include <QListWidget>
 
-// KDE
-#include <klocale.h>
+// KF5
+#include <KLocalizedString>
 
-// KSpread
+// Sheets
 #include "calligra_sheets_limits.h"
 #include "Region.h"
 #include "RowColumnFormat.h"
@@ -42,10 +42,13 @@
 // commands
 #include "commands/RowColumnManipulators.h"
 
+// Other
+#include <algorithm>
+
 using namespace Calligra::Sheets;
 
 ShowColRow::ShowColRow(QWidget* parent, Selection* selection, Type _type)
-        : KDialog(parent)
+        : KoDialog(parent)
 {
     setModal(true);
     setButtons(Ok | Cancel);
@@ -81,9 +84,8 @@ ShowColRow::ShowColRow(QWidget* parent, Selection* selection, Type _type)
             if (col->isHidden())
                 listInt.append(col->column());
         }
-        qSort(listInt);
-        QList<int>::Iterator it;
-        for (it = listInt.begin(); it != listInt.end(); ++it) {
+        std::sort(listInt.begin(), listInt.end());
+        for (QList<int>::ConstIterator it = listInt.constBegin(); it != listInt.constEnd(); ++it) {
             if (!showColNumber)
                 listCol += i18n("Column: %1", Cell::columnName(*it));
             else
@@ -101,8 +103,7 @@ ShowColRow::ShowColRow(QWidget* parent, Selection* selection, Type _type)
             }
             row = lastRow+1;
         }
-        QList<int>::Iterator it;
-        for (it = listInt.begin(); it != listInt.end(); ++it)
+        for (QList<int>::ConstIterator it = listInt.constBegin(); it != listInt.constEnd(); ++it)
             listRow += i18n("Row: %1", text.setNum(*it));
 
         list->addItems(listRow);
@@ -152,5 +153,3 @@ void ShowColRow::slotOk()
 
     accept();
 }
-
-#include "ShowColRowDialog.moc"
