@@ -49,6 +49,8 @@
 // Qt
 #include <QStyledItemDelegate>
 
+#include <algorithm>
+
 using namespace Calligra::Sheets;
 
 Q_DECLARE_METATYPE(Qt::CaseSensitivity)
@@ -62,9 +64,9 @@ public:
     {
     }
 
-    virtual QWidget *createEditor(QWidget *parent,
+    QWidget *createEditor(QWidget *parent,
                                   const QStyleOptionViewItem &option,
-                                  const QModelIndex &index) const
+                                  const QModelIndex &index) const override
     {
         Q_UNUSED(index)
         Q_UNUSED(option)
@@ -79,7 +81,7 @@ public:
         return combo;
     }
 
-    virtual void setEditorData(QWidget *editor, const QModelIndex &index) const
+    void setEditorData(QWidget *editor, const QModelIndex &index) const override
     {
         if (!index.isValid()) {
             return;
@@ -145,8 +147,8 @@ public:
         }
     }
 
-    virtual void setModelData(QWidget *editor, QAbstractItemModel *model,
-                              const QModelIndex &index) const
+    void setModelData(QWidget *editor, QAbstractItemModel *model,
+                              const QModelIndex &index) const override
     {
         KComboBox *const combo = static_cast<KComboBox*>(editor);
         const int currentIndex = combo->currentIndex();
@@ -161,9 +163,9 @@ public:
         }
     }
 
-    virtual void updateEditorGeometry(QWidget *editor,
+    void updateEditorGeometry(QWidget *editor,
                                       const QStyleOptionViewItem &option,
-                                      const QModelIndex &index) const
+                                      const QModelIndex &index) const override
     {
         Q_UNUSED(index)
         editor->setGeometry(option.rect);
@@ -223,14 +225,14 @@ void SortDialog::Private::insertIndex(int index, Qt::Orientation orientation) co
 {
     if (orientation == Qt::Vertical) /* data grouped in columns; criteria/header per row */ {
         Q_ASSERT(1 <= index && index <= KS_colMax);
-        QList<int>::Iterator it = qLowerBound(rows.begin(), rows.end(), index);
+        QList<int>::Iterator it = std::lower_bound(rows.begin(), rows.end(), index);
         if (*it == index) {
             return;
         }
         rows.insert(it, index);
     } else /* data grouped in rows; criteria/header per column */ {
         Q_ASSERT(1 <= index && index <= KS_rowMax);
-        QList<int>::Iterator it = qLowerBound(columns.begin(), columns.end(), index);
+        QList<int>::Iterator it = std::lower_bound(columns.begin(), columns.end(), index);
         if (*it == index) {
             return;
         }
@@ -338,8 +340,8 @@ SortDialog::SortDialog(QWidget* parent, Selection* selection)
     d->mainWidget.m_upButton->setIcon(koIcon("go-up"));
     d->mainWidget.m_downButton->setIcon(koIcon("go-down"));
     QHeaderView *const header = d->mainWidget.m_tableWidget->horizontalHeader();
-    header->setResizeMode(QHeaderView::ResizeToContents);
-    header->setResizeMode(0, QHeaderView::Stretch);
+    header->setSectionResizeMode(QHeaderView::ResizeToContents);
+    header->setSectionResizeMode(0, QHeaderView::Stretch);
     d->mainWidget.m_tableWidget->setItemDelegateForColumn(0, d);
 
     connect(d->mainWidget.m_useHeader, SIGNAL(toggled(bool)),
@@ -642,7 +644,7 @@ void SortDialog::removeCriterion()
     if (ranges.isEmpty()) {
         return;
     }
-    qStableSort(ranges.begin(), ranges.end(), greaterThan);
+    std::stable_sort(ranges.begin(), ranges.end(), greaterThan);
     for (int i = 0; i < ranges.count(); ++i) {
         for (int row = ranges[i].bottomRow(); row >= ranges[i].topRow(); --row) {
             // Reinsert the item to be removed into the map of available items.
