@@ -23,7 +23,7 @@
 #ifndef CALLIGRA_SHEETS_SUBTOTAL_DIALOG
 #define CALLIGRA_SHEETS_SUBTOTAL_DIALOG
 
-#include <kdialog.h>
+#include <KoDialog.h>
 
 namespace Calligra
 {
@@ -35,17 +35,17 @@ class Selection;
  * \ingroup UI
  * Dialog to add subtotals.
  */
-class SubtotalDialog : public KDialog
+class SubtotalDialog : public KoDialog
 {
     Q_OBJECT
 
 public:
     SubtotalDialog(QWidget* parent, Selection* selection);
-    ~SubtotalDialog();
+    ~SubtotalDialog() override;
 
 public Q_SLOTS: // reimplemented
-    virtual void accept();
-    virtual void reject();
+    void accept() override;
+    void reject() override;
 
 private Q_SLOTS:
     void slotUser1();
