@@ -35,7 +35,7 @@ class DatabaseModule : public FunctionModule
 public:
     explicit DatabaseModule(QObject* parent, const QVariantList& args = QVariantList());
 
-    QString descriptionFileName() const;
+    QString descriptionFileName() const override;
 };
 
 } // namespace Sheets
