@@ -35,7 +35,7 @@ class MathModule : public FunctionModule
 public:
     explicit MathModule(QObject* parent, const QVariantList& args = QVariantList());
 
-    QString descriptionFileName() const;
+    QString descriptionFileName() const override;
 };
 
 } // namespace Sheets
