@@ -45,7 +45,6 @@
 #include <KoOdfWorkaround.h>
 #include <KoStyleStack.h>
 #include <KoUnit.h>
-#include <KoXmlNS.h>
 
 #include "CalculationSettings.h"
 #include "Condition.h"
@@ -944,7 +943,7 @@ QString Odf::saveStyle(const Style *style, KoGenStyle& xmlstyle, KoGenStyles& ma
         }
     }
 
-    // Calligra::Sheets::Style is definitly an OASIS auto style,
+    // Calligra::Sheets::Style is definitely an OASIS auto style,
     // but don't overwrite it, if it already exists
     if (xmlstyle.isEmpty())
         xmlstyle = KoGenStyle(KoGenStyle::TableCellAutoStyle, "table-cell");
