@@ -22,7 +22,7 @@
 
 #include <QWidget>
 
-#include "calligra_sheets_export.h"
+#include "sheets_common_export.h"
 
 class QLabel;
 class KoPointerEvent;
@@ -33,7 +33,6 @@ namespace Sheets
 {
 class CanvasBase;
 class Selection;
-class View;
 
 /**
  * Base class for the widget above the cells showing the column headers.
