@@ -21,14 +21,16 @@
 *   OTHER DEALINGS IN THE SOFTWARE.                                       *
 ***************************************************************************/
 
-#include <CalendarToolWidget.h>
+#include "CalendarToolWidget.h"
+
+#include "SheetsDebug.h"
 
 #include <KoIcon.h>
 
 #include <kdatepicker.h>
-#include <kdebug.h>
 
 #include <QPushButton>
+#include <QDate>
 
 namespace Calligra
 {
@@ -51,7 +53,7 @@ CalendarToolWidget::CalendarToolWidget(QWidget* parent)
     this->m_startDateWidget->setDate(first_day_in_month);
     this->m_endDateWidget->setDate(last_day_in_month);
 
-    const KIcon calendarIcon(koIconName("x-office-calendar"));
+    const QIcon calendarIcon = koIcon("x-office-calendar");
     this->m_selectStartDateButton->setIcon(calendarIcon);
     this->m_selectEndDateButton->setIcon(calendarIcon);
 
@@ -87,7 +89,7 @@ bool CalendarToolWidget::buildDatePickerFrame()
 
 void CalendarToolWidget::datePickerDeleted()
 {
-    kDebug() << "date picker deleted";
+    debugSheets << "date picker deleted";
     m_datePicker = 0;
 }
 
@@ -138,5 +140,3 @@ QDate CalendarToolWidget::endDate() const
 
 } // namespace Sheets
 } // namespace Calligra
-
-#include "CalendarToolWidget.moc"
