@@ -25,7 +25,8 @@
 
 #include <QString>
 #include <QObject>
-#include <klocale.h>
+
+#include <KLocalizedString>
 
 #include <part/Doc.h>
 #include <Sheet.h>
@@ -81,7 +82,7 @@ public:
     /**
     * Destructor.
     */
-    virtual ~ScriptingWriter() {}
+    ~ScriptingWriter() override {}
 
 public Q_SLOTS:
 
@@ -213,7 +214,7 @@ public Q_SLOTS:
             case QVariant::Double:      v = Calligra::Sheets::Value(value.toDouble()); break;
             case QVariant::String:      v = Calligra::Sheets::Value(value.toString()); break;
             case QVariant::Date:        v = Calligra::Sheets::Value(value.toDate(), settings); break;
-            case QVariant::Time:        v = Calligra::Sheets::Value(value.toTime(), settings); break;
+            case QVariant::Time:        v = Calligra::Sheets::Value(value.toTime()); break;
             case QVariant::DateTime:    v = Calligra::Sheets::Value(value.toDateTime(), settings); break;
             default: return false;
             }
