@@ -20,8 +20,7 @@
 #ifndef CALLIGRA_SHEETS_TEST_DATETIME_FUNCTIONS
 #define CALLIGRA_SHEETS_TEST_DATETIME_FUNCTIONS
 
-#include <QtGui>
-#include <QtTest>
+#include <QObject>
 
 #include <Value.h>
 
